@@ -106,10 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Initialisation de l'application Cercles",
     "Fresh installation status" : "Statut de l'installation",
     "Building Local Database" : "Construction de la base de données locale",
+    "Testing Basic Team Creation" : "Test de création d'une Équipe basique",
     "Adding local users and moderators" : "Ajout d'utilisateurs locaux et de modérateurs",
     "Show all teams" : "Afficher toutes les équipes",
     "Create a new team" : "Créer une nouvelle équipe",
     "Files" : "Fichiers",
+    "This feature is not available for personal teams" : "Cette fonctionnalité n'est pas disponible pour les Équipes personnelles",
     "The team is not federated" : "L'équipe n'est pas fédérée",
     "You cannot join this team" : "Vous ne pouvez pas rejoindre cette équipe",
     "This member is not a moderator" : "Ce membre n’est pas modérateur",
@@ -117,6 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Ce membre n’existe pas",
     "This member is the owner of the team" : "Ce membre est le propriétaire de l'équipe",
     "Level cannot be changed for this type of member" : "Le niveau ne peut pas être modifié pour ce type de membre",
+    "You are already a member of this team" : "Vous êtes déjà membre de cette Équipe",
+    "You have been blocked from this team" : "Vous êtes bloqué(e) de cette Équipe",
+    "The account is already a member of this team" : "Le compte est déjà membre de cette Équipe",
+    "The account has already been invited into this team" : "Le compte a déjà été invité à participer à cette Équipe",
     "%s (Team owned by %s)" : "%s (%s est propriétaire de l'équipe)",
     "You are now a member of the Team \"%2$s\"" : "Vous êtes désormais membre de l'équipe \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Vous avez été invité·e par %1$s dans l'équipe \"%2$s\"",
