@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "チーム",
     "You created the team {circle}" : "あなたはチーム {circle} を作成しました",
     "{author} created the team {circle}" : "{author} がチーム {circle} を作成しました",
     "You deleted {circle}" : "あなたは {circle} を削除しました",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member}が{circle}への参加リクエストを送信しました",
     "You are the new owner of {circle}" : "あなたは {circle} の新しいオーナーです",
     "{member} is the new owner of {circle}" : "{member} は {circle} の新しいオーナーです",
+    "Teams" : "チーム",
     "On events happening in a <strong>team</strong> of which you are a member" : "あなたが所属する<strong>チーム</strong> で起きた出来事について",
     "Any important event in a <strong>team</strong> you are moderating" : "あなたがモデレーターを務める <strong>チーム</strong> の重要なイベント",
     "On global events happening in any <strong>team</strong>" : "どの<strong>チーム</strong>でも起きているグローバルな出来事について",
@@ -76,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloudグループ",
     "Email address" : "メールアドレス",
     "Contact" : "連絡先",
-    "Circle" : "サークル",
+    "Team" : "チーム",
     "Nextcloud App" : "Nextcloudアプリ",
+    "Teams App" : "Temsアプリ",
+    "Admin Command Line" : "管理者コマンドライン",
     "Member" : "メンバー",
     "Moderator" : "モデレータ",
     "Admin" : "管理者",
@@ -104,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Circleアプリの初期化",
     "Fresh installation status" : "フレッシュインストールの状況",
     "Building Local Database" : "ローカルデータベースの構築",
-    "Testing Basic Circle Creation" : "基本的なサークル作成のテスト",
     "Adding local users and moderators" : "ローカルユーザーとモデレーターを追加する",
     "Show all teams" : "すべてのチームを表示",
     "Create a new team" : "新しいチームを作成する",
     "Files" : "ファイル",
-    "This feature is not available for personal circles" : "この機能は個人のサークルでは使用できません",
     "The team is not federated" : "チームは統合されていません",
     "You cannot join this team" : "あなたはこのチームに参加できません",
     "This member is not a moderator" : "このメンバーはモデレーターではありません",
@@ -117,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "このメンバーは存在しません",
     "This member is the owner of the team" : "このメンバーはチームのオーナーです",
     "Level cannot be changed for this type of member" : "このタイプのメンバーのレベルを変更することはできません",
-    "You are already a member of this circle" : "あなたはすでにこのサークルのメンバーです",
-    "You have been blocked from this circle" : "あなたはこのサークルからブロックされています",
-    "The account is already a member of this circle" : "そのアカウントはすでにこのサークルのメンバーです",
-    "The account has already been invited into this circle" : "アカウントはすでにこのサークルに招待されています",
     "%s (Team owned by %s)" : "%s (%s が所有するサークル)",
     "You are now a member of the Team \"%2$s\"" : "あなたはチーム \"%2$s\" のメンバーになりました",
     "You have been invited by %1$s into the Team \"%2$s\"" : "あなたは%1$sからチーム \"%2$s\"に招待されています",
@@ -134,6 +130,9 @@ OC.L10N.register(
     "You have no permission to create a new team" : "新しいチームを作成する権限がありません",
     "%s shared a file with \"%s\"." : "%sは\"%s\"どファイルを共有しました。",
     "%s shared a file with you." : "%sはあなたとファイルを共有しました。",
+    "%1$s shared %2$s with %3$s" : "%1$s は %2$s を %3$s と共有しました",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s は %2$s を \"%3$s\" と共有しました",
+    "Open %s" : "%sを開く",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s は、いくつかのコンテンツをあなたと共有しました。\nすでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s は、いくつかのコンテンツをあなたと共有しました。すでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。",
     "Password to access content shared with you by %1$s" : "%1$sが共有するコンテンツにアクセスするためのパスワード。",
@@ -141,16 +140,18 @@ OC.L10N.register(
     "This item is already shared with this team" : "このアイテムは既にこのチームで共有されています",
     "Bring cloud-users closer together." : "クラウドユーザー同士を近づける。",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "チームを使って自分のグループ(同僚、友人)を作成することができます。\nこれらのグループは、他のアプリで共有先として使用することができます。",
+    "Failed to load teams" : "チームの読込に失敗しました",
+    "Try again" : "もう一度試してください",
+    "No teams found" : "チームは見つかりませんでした",
+    "Join or create teams to see them here." : "チームに参加するか作成してここで確認してください。",
+    "Create your first team" : "最初のチームを作成する",
+    "Loading…" : "読み込み中…",
+    "More teams" : "その他のチーム",
     "No files in here" : "ファイルがありません",
     "No entries found in this folder" : "このフォルダーにはエントリーがありません",
     "Name" : "名前",
     "Size" : "サイズ",
     "Modified" : "更新日時",
-    "Teams' files" : "チームのファイル",
-    "Select team to filter by" : "フィルターするチームを選択",
-    "No teams found" : "チームは見つかりませんでした",
-    "Please select teams to filter by" : "フィルターするチームを選択してください",
-    "No files found for the selected teams" : "選択したチームに割りあてられているファイルはありません",
     "Shared to Circles" : "サークルと共有"
 },
 "nplurals=1; plural=0;");
