@@ -80,18 +80,12 @@ OC.L10N.register(
     "Password to access files" : "파일에 접근하기 위한 암호",
     "%s shared multiple files with \"%s\"." : "%s님이 \"%s\"와(과) 여러 파일을 공유했습니다.",
     "%s shared multiple files with you." : "%s님이 여러 파일을 공유했습니다.",
-    "Testing Basic Circle Creation" : "기본 서클 생성 테스트 중",
     "Adding local users and moderators" : "로컬 사용자와 중재자 추가 중",
     "Files" : "파일",
-    "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
     "This member is not a moderator" : "이 회원은 중재자가 아님",
     "Insufficient privileges" : "권한이 부족함",
     "This member does not exist" : "이 회원이 존재하지 않음",
     "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
-    "You are already a member of this circle" : "이미 서클 회원임",
-    "You have been blocked from this circle" : "이 서클에서 차단됨",
-    "The account is already a member of this circle" : "이 계정은 이미 이 서클의 회원임",
-    "The account has already been invited into this circle" : "이 계정을 이미 이 서클에 초대함",
     "Accept" : "수락",
     "%s" : "%s",
     "%s owned by %s" : "%s이(가) 소유한 %s",
@@ -109,7 +103,6 @@ OC.L10N.register(
     "Name" : "이름",
     "Size" : "크기",
     "Modified" : "수정한 날짜",
-    "Shared to Circles" : "서클에 공유됨",
-    "Circle" : "서클"
+    "Shared to Circles" : "서클에 공유됨"
 },
 "nplurals=1; plural=0;");
