@@ -27,6 +27,7 @@ use OCA\Circles\Tools\Exceptions\ItemNotFoundException;
 use OCA\Circles\Tools\Traits\TArrayTools;
 use OCA\Circles\Tools\Traits\TDeserialize;
 use OCA\Circles\Tools\Traits\TStringTools;
+use OCP\Server;
 use Symfony\Component\Console\Helper\Table;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
@@ -135,8 +136,7 @@ class CirclesTest extends Base {
 
 
 		// loading CirclesManager
-		/** @var CirclesManager $circlesManager */
-		$circlesManager = \OC::$server->get(CirclesManager::class);
+		$circlesManager = Server::get(CirclesManager::class);
 		//		$circlesManager->startSuperSession();
 
 
@@ -373,7 +373,7 @@ class CirclesTest extends Base {
 		$this->t('Building Local Database');
 		$this->buildingLocalDatabase();
 
-		$this->t('Testing Basic Circle Creation');
+		$this->t('Testing Basic Team Creation');
 		$this->circleCreation001();
 
 		$this->t('Adding local users and moderators');
@@ -545,7 +545,7 @@ class CirclesTest extends Base {
 			$expectedSize = sizeof($this->getConfigArray($instanceId, 'groups'))
 							+ sizeof($this->getConfigArray($instanceId, 'users'))
 							+ 1;
-			$this->r((sizeof($result) === $expectedSize), sizeof($result) . ' circles');
+			$this->r((sizeof($result) === $expectedSize), ((string)sizeof($result)) . ' circles');
 
 			$membersList = $groupsList = [];
 			foreach ($result as $item) {
@@ -714,7 +714,7 @@ class CirclesTest extends Base {
 	 * @throws ItemNotFoundException
 	 */
 	private function circleCreation001() {
-		$this->p('Creating basic circle');
+		$this->p('Creating basic team');
 
 		$localInstanceId = 'global-scale-1';
 		$name = self::$TEST_CIRCLES[0];
@@ -948,29 +948,22 @@ class CirclesTest extends Base {
 
 		if ($compareTo->hasOwner()) {
 			$compareToOwner = $compareTo->getOwner();
-			if ($compareToOwner !== null) {
-				$owner = $circle->getOwner();
-				if ($owner === null) {
-					throw new Exception('empty owner');
-				}
-				if ($owner->getCircleId() !== $circle->getSingleId()) {
-					throw new Exception($prefix . '.owner.circleId is different than ' . $prefix . '.id');
-				}
-				$this->confirmMemberData($owner, $compareToOwner, 'owner', false, $params);
+			$owner = $circle->getOwner();
+			if ($owner->getCircleId() !== $circle->getSingleId()) {
+				throw new Exception($prefix . '.owner.circleId is different than ' . $prefix . '.id');
 			}
+			$this->confirmMemberData($owner, $compareToOwner, 'owner', false, $params);
 		}
 		if ($compareTo->hasInitiator()) {
 			$compareToInitiator = $compareTo->getInitiator();
-			if ($compareToInitiator !== null) {
-				if (!$circle->hasInitiator()) {
-					throw new Exception('empty initiator');
-				}
-				$initiator = $circle->getInitiator();
-				if ($initiator->getCircleId() !== $circle->getSingleId()) {
-					throw new Exception($prefix . '.initiator.circleId is different than ' . $prefix . '.id');
-				}
-				$this->confirmMemberData($initiator, $compareToInitiator, 'owner', false, $params);
+			if (!$circle->hasInitiator()) {
+				throw new Exception('empty initiator');
 			}
+			$initiator = $circle->getInitiator();
+			if ($initiator->getCircleId() !== $circle->getSingleId()) {
+				throw new Exception($prefix . '.initiator.circleId is different than ' . $prefix . '.id');
+			}
+			$this->confirmMemberData($initiator, $compareToInitiator, 'owner', false, $params);
 		}
 
 		if ($versa) {
@@ -1049,7 +1042,7 @@ class CirclesTest extends Base {
 	private function compareInt(int $expected, int $compare, string $def, bool $force = false) {
 		if (($expected > 0 || ($force && $expected >= 0))
 			&& $expected !== $compare) {
-			throw new Exception('wrong ' . $def . ': ' . $compare . ' (' . $expected . ')');
+			throw new Exception('wrong ' . $def . ': ' . ((string)$compare) . ' (' . ((string)$expected) . ')');
 		}
 	}
 
@@ -1085,7 +1078,7 @@ class CirclesTest extends Base {
 			}
 		}
 
-		throw new CircleNotFoundException('cannot find ' . $userId . ' in the list of Single Circle');
+		throw new CircleNotFoundException('cannot find ' . $userId . ' in the list of Single Team');
 	}
 
 
@@ -1145,7 +1138,7 @@ class CirclesTest extends Base {
 	 * @param string $instance
 	 * @param string $key
 	 *
-	 * @return array
+	 * @return array<string, mixed>
 	 * @throws ItemNotFoundException
 	 */
 	private function getConfigArray(string $instance, string $key): array {
