@@ -14,6 +14,7 @@ use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\IL10N;
+use OCP\IUserManager;
 use OCP\L10N\IFactory as L10NFactory;
 use OCP\Mail\IEMailTemplate;
 use OCP\Security\ISecureRandom;
@@ -24,6 +25,7 @@ use Sabre\VObject\ITip\Message;
 use Sabre\VObject\Parameter;
 use Sabre\VObject\Property;
 use Sabre\VObject\Recur\EventIterator;
+use function htmlspecialchars;
 
 class IMipService {
 
@@ -44,6 +46,7 @@ class IMipService {
 		private ISecureRandom $random,
 		private L10NFactory $l10nFactory,
 		private ITimeFactory $timeFactory,
+		private readonly IUserManager $userManager,
 	) {
 		$language = $this->l10nFactory->findGenericLanguage();
 		$locale = $this->l10nFactory->findLocale($language);
@@ -78,10 +81,11 @@ class IMipService {
 		if (!isset($vevent->$property)) {
 			return $default;
 		}
-		$newstring = $vevent->$property->getValue();
+		$value = $vevent->$property->getValue();
+		$newstring = $value === null ? null : htmlspecialchars($value);
 		if (isset($oldVEvent->$property) && $oldVEvent->$property->getValue() !== $newstring) {
 			$oldstring = $oldVEvent->$property->getValue();
-			return sprintf($strikethrough, $oldstring, $newstring);
+			return sprintf($strikethrough, htmlspecialchars($oldstring), $newstring);
 		}
 		return $newstring;
 	}
@@ -93,9 +97,9 @@ class IMipService {
 		if (!isset($vevent->$property)) {
 			return $default;
 		}
-		/** @var string|null $newString */
-		$newString = $vevent->$property->getValue();
-		$oldString = isset($oldVEvent->$property) ? $oldVEvent->$property->getValue() : null;
+		$value = $vevent->$property->getValue();
+		$newString = $value === null ? null : htmlspecialchars($value);
+		$oldString = isset($oldVEvent->$property) ? htmlspecialchars($oldVEvent->$property->getValue()) : null;
 		if ($oldString !== $newString) {
 			return sprintf(
 				"<span style='text-decoration: line-through'>%s</span><br />%s",
@@ -159,7 +163,35 @@ class IMipService {
 		if ($eventReaderCurrent->recurs()) {
 			$data['meeting_occurring'] = $this->generateOccurringString($eventReaderCurrent);
 		}
-		
+		return $data;
+	}
+
+	/**
+	 * @param VEvent $vEvent
+	 * @return array
+	 */
+	public function buildReplyBodyData(VEvent $vEvent): array {
+		// construct event reader
+		$eventReader = new EventReader($vEvent);
+		$defaultVal = '';
+		$data = [];
+		$data['meeting_when'] = $this->generateWhenString($eventReader);
+
+		foreach (self::STRING_DIFF as $key => $property) {
+			$data[$key] = self::readPropertyWithDefault($vEvent, $property, $defaultVal);
+		}
+
+		if (($locationHtml = $this->linkify($data['meeting_location'])) !== null) {
+			$data['meeting_location_html'] = $locationHtml;
+		}
+
+		$data['meeting_url_html'] = $data['meeting_url'] ? sprintf('<a href="%1$s">%1$s</a>', $data['meeting_url']) : '';
+
+		// generate occurring next string
+		if ($eventReader->recurs()) {
+			$data['meeting_occurring'] = $this->generateOccurringString($eventReader);
+		}
+
 		return $data;
 	}
 
@@ -206,8 +238,8 @@ class IMipService {
 		// TRANSLATORS
 		// Indicates when a calendar event will happen, shown on invitation emails
 		// Output produced in order:
-		// In a minute/hour/day/week/month/year on July 1, 2024 for the entire day
-		// In a minute/hour/day/week/month/year on July 1, 2024 between 8:00 AM - 9:00 AM (America/Toronto)
+		// In 1 minute/hour/day/week/month/year on July 1, 2024 for the entire day
+		// In 1 minute/hour/day/week/month/year on July 1, 2024 between 8:00 AM - 9:00 AM (America/Toronto)
 		// In 2 minutes/hours/days/weeks/months/years on July 1, 2024 for the entire day
 		// In 2 minutes/hours/days/weeks/months/years on July 1, 2024 between 8:00 AM - 9:00 AM (America/Toronto)
 		return match ([$occurring['scale'], $endTime !== null]) {
@@ -216,37 +248,37 @@ class IMipService {
 				[$startDate]
 			),
 			['minute', false] => $this->l10n->n(
-				'In a minute on %1$s for the entire day',
+				'In %n minute on %1$s for the entire day',
 				'In %n minutes on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
 			),
 			['hour', false] => $this->l10n->n(
-				'In a hour on %1$s for the entire day',
+				'In %n hour on %1$s for the entire day',
 				'In %n hours on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
 			),
 			['day', false] => $this->l10n->n(
-				'In a day on %1$s for the entire day',
+				'In %n day on %1$s for the entire day',
 				'In %n days on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
 			),
 			['week', false] => $this->l10n->n(
-				'In a week on %1$s for the entire day',
+				'In %n week on %1$s for the entire day',
 				'In %n weeks on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
 			),
 			['month', false] => $this->l10n->n(
-				'In a month on %1$s for the entire day',
+				'In %n month on %1$s for the entire day',
 				'In %n months on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
 			),
 			['year', false] => $this->l10n->n(
-				'In a year on %1$s for the entire day',
+				'In %n year on %1$s for the entire day',
 				'In %n years on %1$s for the entire day',
 				$occurring['interval'],
 				[$startDate]
@@ -256,37 +288,37 @@ class IMipService {
 				[$startDate, $startTime, $endTime]
 			),
 			['minute', true] => $this->l10n->n(
-				'In a minute on %1$s between %2$s - %3$s',
+				'In %n minute on %1$s between %2$s - %3$s',
 				'In %n minutes on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
 			),
 			['hour', true] => $this->l10n->n(
-				'In a hour on %1$s between %2$s - %3$s',
+				'In %n hour on %1$s between %2$s - %3$s',
 				'In %n hours on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
 			),
 			['day', true] => $this->l10n->n(
-				'In a day on %1$s between %2$s - %3$s',
+				'In %n day on %1$s between %2$s - %3$s',
 				'In %n days on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
 			),
 			['week', true] => $this->l10n->n(
-				'In a week on %1$s between %2$s - %3$s',
+				'In %n week on %1$s between %2$s - %3$s',
 				'In %n weeks on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
 			),
 			['month', true] => $this->l10n->n(
-				'In a month on %1$s between %2$s - %3$s',
+				'In %n month on %1$s between %2$s - %3$s',
 				'In %n months on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
 			),
 			['year', true] => $this->l10n->n(
-				'In a year on %1$s between %2$s - %3$s',
+				'In %n year on %1$s between %2$s - %3$s',
 				'In %n years on %1$s between %2$s - %3$s',
 				$occurring['interval'],
 				[$startDate, $startTime, $endTime]
@@ -324,7 +356,7 @@ class IMipService {
 	 * @return string
 	 */
 	public function generateWhenStringRecurringDaily(EventReader $er): string {
-		
+
 		// initialize
 		$interval = (int)$er->recurringInterval();
 		$startTime = null;
@@ -375,7 +407,7 @@ class IMipService {
 	 * @return string
 	 */
 	public function generateWhenStringRecurringWeekly(EventReader $er): string {
-		
+
 		// initialize
 		$interval = (int)$er->recurringInterval();
 		$startTime = null;
@@ -428,15 +460,15 @@ class IMipService {
 	 * @return string
 	 */
 	public function generateWhenStringRecurringMonthly(EventReader $er): string {
-		
+
 		// initialize
 		$interval = (int)$er->recurringInterval();
 		$startTime = null;
 		$conclusion = null;
 		// days of month
 		if ($er->recurringPattern() === 'R') {
-			$days = implode(', ', array_map(function ($value) { return $this->localizeRelativePositionName($value); }, $er->recurringRelativePositionNamed())) . ' ' .
-					implode(', ', array_map(function ($value) { return $this->localizeDayName($value); }, $er->recurringDaysOfWeekNamed()));
+			$days = implode(', ', array_map(function ($value) { return $this->localizeRelativePositionName($value); }, $er->recurringRelativePositionNamed())) . ' '
+					. implode(', ', array_map(function ($value) { return $this->localizeDayName($value); }, $er->recurringDaysOfWeekNamed()));
 		} else {
 			$days = implode(', ', $er->recurringDaysOfMonth());
 		}
@@ -493,7 +525,7 @@ class IMipService {
 	 * @return string
 	 */
 	public function generateWhenStringRecurringYearly(EventReader $er): string {
-		
+
 		// initialize
 		$interval = (int)$er->recurringInterval();
 		$startTime = null;
@@ -502,8 +534,8 @@ class IMipService {
 		$months = implode(', ', array_map(function ($value) { return $this->localizeMonthName($value); }, $er->recurringMonthsOfYearNamed()));
 		// days of month
 		if ($er->recurringPattern() === 'R') {
-			$days = implode(', ', array_map(function ($value) { return $this->localizeRelativePositionName($value); }, $er->recurringRelativePositionNamed())) . ' ' .
-					implode(', ', array_map(function ($value) { return $this->localizeDayName($value); }, $er->recurringDaysOfWeekNamed()));
+			$days = implode(', ', array_map(function ($value) { return $this->localizeRelativePositionName($value); }, $er->recurringRelativePositionNamed())) . ' '
+					. implode(', ', array_map(function ($value) { return $this->localizeDayName($value); }, $er->recurringDaysOfWeekNamed()));
 		} else {
 			$days = $er->startDateTime()->format('jS');
 		}
@@ -582,7 +614,7 @@ class IMipService {
 			true => $this->l10n->t('On specific dates between %1$s - %2$s until %3$s', [$startTime, $endTime, $conclusion]),
 		};
 	}
-	
+
 	/**
 	 * generates a occurring next string for a recurring event
 	 *
@@ -624,9 +656,9 @@ class IMipService {
 		// TRANSLATORS
 		// Indicates when a calendar event will happen, shown on invitation emails
 		// Output produced in order:
-		// In a minute/hour/day/week/month/year on July 1, 2024
-		// In a minute/hour/day/week/month/year on July 1, 2024 then on July 3, 2024
-		// In a minute/hour/day/week/month/year on July 1, 2024 then on July 3, 2024 and July 5, 2024
+		// In 1 minute/hour/day/week/month/year on July 1, 2024
+		// In 1 minute/hour/day/week/month/year on July 1, 2024 then on July 3, 2024
+		// In 1 minute/hour/day/week/month/year on July 1, 2024 then on July 3, 2024 and July 5, 2024
 		// In 2 minutes/hours/days/weeks/months/years on July 1, 2024
 		// In 2 minutes/hours/days/weeks/months/years on July 1, 2024 then on July 3, 2024
 		// In 2 minutes/hours/days/weeks/months/years on July 1, 2024 then on July 3, 2024 and July 5, 2024
@@ -636,37 +668,37 @@ class IMipService {
 				[$occurrence]
 			),
 			['minute', false, false] => $this->l10n->n(
-				'In a minute on %1$s',
+				'In %n minute on %1$s',
 				'In %n minutes on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
 			),
 			['hour', false, false] => $this->l10n->n(
-				'In a hour on %1$s',
+				'In %n hour on %1$s',
 				'In %n hours on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
 			),
 			['day', false, false] => $this->l10n->n(
-				'In a day on %1$s',
+				'In %n day on %1$s',
 				'In %n days on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
 			),
 			['week', false, false] => $this->l10n->n(
-				'In a week on %1$s',
+				'In %n week on %1$s',
 				'In %n weeks on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
 			),
 			['month', false, false] => $this->l10n->n(
-				'In a month on %1$s',
+				'In %n month on %1$s',
 				'In %n months on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
 			),
 			['year', false, false] => $this->l10n->n(
-				'In a year on %1$s',
+				'In %n year on %1$s',
 				'In %n years on %1$s',
 				$occurrenceIn['interval'],
 				[$occurrence]
@@ -676,37 +708,37 @@ class IMipService {
 				[$occurrence, $occurrence2]
 			),
 			['minute', true, false] => $this->l10n->n(
-				'In a minute on %1$s then on %2$s',
+				'In %n minute on %1$s then on %2$s',
 				'In %n minutes on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
 			),
 			['hour', true, false] => $this->l10n->n(
-				'In a hour on %1$s then on %2$s',
+				'In %n hour on %1$s then on %2$s',
 				'In %n hours on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
 			),
 			['day', true, false] => $this->l10n->n(
-				'In a day on %1$s then on %2$s',
+				'In %n day on %1$s then on %2$s',
 				'In %n days on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
 			),
 			['week', true, false] => $this->l10n->n(
-				'In a week on %1$s then on %2$s',
+				'In %n week on %1$s then on %2$s',
 				'In %n weeks on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
 			),
 			['month', true, false] => $this->l10n->n(
-				'In a month on %1$s then on %2$s',
+				'In %n month on %1$s then on %2$s',
 				'In %n months on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
 			),
 			['year', true, false] => $this->l10n->n(
-				'In a year on %1$s then on %2$s',
+				'In %n year on %1$s then on %2$s',
 				'In %n years on %1$s then on %2$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2]
@@ -716,37 +748,37 @@ class IMipService {
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['minute', true, true] => $this->l10n->n(
-				'In a minute on %1$s then on %2$s and %3$s',
+				'In %n minute on %1$s then on %2$s and %3$s',
 				'In %n minutes on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['hour', true, true] => $this->l10n->n(
-				'In a hour on %1$s then on %2$s and %3$s',
+				'In %n hour on %1$s then on %2$s and %3$s',
 				'In %n hours on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['day', true, true] => $this->l10n->n(
-				'In a day on %1$s then on %2$s and %3$s',
+				'In %n day on %1$s then on %2$s and %3$s',
 				'In %n days on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['week', true, true] => $this->l10n->n(
-				'In a week on %1$s then on %2$s and %3$s',
+				'In %n week on %1$s then on %2$s and %3$s',
 				'In %n weeks on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['month', true, true] => $this->l10n->n(
-				'In a month on %1$s then on %2$s and %3$s',
+				'In %n month on %1$s then on %2$s and %3$s',
 				'In %n months on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
 			),
 			['year', true, true] => $this->l10n->n(
-				'In a year on %1$s then on %2$s and %3$s',
+				'In %n year on %1$s then on %2$s and %3$s',
 				'In %n years on %1$s then on %2$s and %3$s',
 				$occurrenceIn['interval'],
 				[$occurrence, $occurrence2, $occurrence3]
@@ -767,10 +799,10 @@ class IMipService {
 		$strikethrough = "<span style='text-decoration: line-through'>%s</span>";
 
 		$newMeetingWhen = $this->generateWhenString($eventReaderCurrent);
-		$newSummary = isset($vEvent->SUMMARY) && (string)$vEvent->SUMMARY !== '' ? (string)$vEvent->SUMMARY : $this->l10n->t('Untitled event');
-		$newDescription = isset($vEvent->DESCRIPTION) && (string)$vEvent->DESCRIPTION !== '' ? (string)$vEvent->DESCRIPTION : $defaultVal;
+		$newSummary = htmlspecialchars(isset($vEvent->SUMMARY) && (string)$vEvent->SUMMARY !== '' ? (string)$vEvent->SUMMARY : $this->l10n->t('Untitled event'));
+		$newDescription = htmlspecialchars(isset($vEvent->DESCRIPTION) && (string)$vEvent->DESCRIPTION !== '' ? (string)$vEvent->DESCRIPTION : $defaultVal);
 		$newUrl = isset($vEvent->URL) && (string)$vEvent->URL !== '' ? sprintf('<a href="%1$s">%1$s</a>', $vEvent->URL) : $defaultVal;
-		$newLocation = isset($vEvent->LOCATION) && (string)$vEvent->LOCATION !== '' ? (string)$vEvent->LOCATION : $defaultVal;
+		$newLocation = htmlspecialchars(isset($vEvent->LOCATION) && (string)$vEvent->LOCATION !== '' ? (string)$vEvent->LOCATION : $defaultVal);
 		$newLocationHtml = $this->linkify($newLocation) ?? $newLocation;
 
 		$data = [];
@@ -842,18 +874,45 @@ class IMipService {
 	}
 
 	/**
-	 * @param Property|null $attendee
+	 * Check if an email address belongs to a system user
+	 *
+	 * @param string $email
+	 * @return bool True if the email belongs to a system user, false otherwise
 	 */
-	public function setL10n(?Property $attendee = null) {
-		if ($attendee === null) {
-			return;
-		}
+	public function isSystemUser(string $email): bool {
+		return !empty($this->userManager->getByEmail($email));
+	}
 
-		$lang = $attendee->offsetGet('LANGUAGE');
-		if ($lang instanceof Parameter) {
-			$lang = $lang->getValue();
-			$this->l10n = $this->l10nFactory->get('dav', $lang);
+	/**
+	 * @param Property $attendee
+	 */
+	public function setL10nFromAttendee(Property $attendee) {
+		$language = null;
+		$locale = null;
+		// check if the attendee is a system user
+		$userAddress = $attendee->getValue();
+		if (str_starts_with($userAddress, 'mailto:')) {
+			$userAddress = substr($userAddress, 7);
 		}
+		$users = $this->userManager->getByEmail($userAddress);
+		if ($users !== []) {
+			$user = array_shift($users);
+			$language = $this->config->getUserValue($user->getUID(), 'core', 'lang', null);
+			$locale = $this->config->getUserValue($user->getUID(), 'core', 'locale', null);
+		}
+		// fallback to attendee LANGUAGE parameter if language not set
+		if ($language === null && isset($attendee['LANGUAGE']) && $attendee['LANGUAGE'] instanceof Parameter) {
+			$language = $attendee['LANGUAGE']->getValue();
+		}
+		// fallback to system language if language not set
+		if ($language === null) {
+			$language = $this->l10nFactory->findGenericLanguage();
+		}
+		// fallback to system locale if locale not set
+		if ($locale === null) {
+			$locale = $this->l10nFactory->findLocale($language);
+		}
+		$this->l10n = $this->l10nFactory->get('dav', $language, $locale);
 	}
 
 	/**
@@ -1020,22 +1079,22 @@ class IMipService {
 	 */
 	public function addBulletList(IEMailTemplate $template, VEvent $vevent, $data) {
 		$template->addBodyListItem(
-			$data['meeting_title_html'] ?? $data['meeting_title'], $this->l10n->t('Title:'),
+			$data['meeting_title_html'] ?? htmlspecialchars($data['meeting_title']), $this->l10n->t('Title:'),
 			$this->getAbsoluteImagePath('caldav/title.png'), $data['meeting_title'], '', IMipPlugin::IMIP_INDENT);
 		if ($data['meeting_when'] !== '') {
-			$template->addBodyListItem($data['meeting_when_html'] ?? $data['meeting_when'], $this->l10n->t('When:'),
+			$template->addBodyListItem($data['meeting_when_html'] ?? htmlspecialchars($data['meeting_when']), $this->l10n->t('When:'),
 				$this->getAbsoluteImagePath('caldav/time.png'), $data['meeting_when'], '', IMipPlugin::IMIP_INDENT);
 		}
 		if ($data['meeting_location'] !== '') {
-			$template->addBodyListItem($data['meeting_location_html'] ?? $data['meeting_location'], $this->l10n->t('Location:'),
+			$template->addBodyListItem($data['meeting_location_html'] ?? htmlspecialchars($data['meeting_location']), $this->l10n->t('Location:'),
 				$this->getAbsoluteImagePath('caldav/location.png'), $data['meeting_location'], '', IMipPlugin::IMIP_INDENT);
 		}
 		if ($data['meeting_url'] !== '') {
-			$template->addBodyListItem($data['meeting_url_html'] ?? $data['meeting_url'], $this->l10n->t('Link:'),
+			$template->addBodyListItem($data['meeting_url_html'] ?? htmlspecialchars($data['meeting_url']), $this->l10n->t('Link:'),
 				$this->getAbsoluteImagePath('caldav/link.png'), $data['meeting_url'], '', IMipPlugin::IMIP_INDENT);
 		}
 		if (isset($data['meeting_occurring'])) {
-			$template->addBodyListItem($data['meeting_occurring_html'] ?? $data['meeting_occurring'], $this->l10n->t('Occurring:'),
+			$template->addBodyListItem($data['meeting_occurring_html'] ?? htmlspecialchars($data['meeting_occurring']), $this->l10n->t('Occurring:'),
 				$this->getAbsoluteImagePath('caldav/time.png'), $data['meeting_occurring'], '', IMipPlugin::IMIP_INDENT);
 		}
 
@@ -1043,7 +1102,7 @@ class IMipService {
 
 		/* Put description last, like an email body, since it can be arbitrarily long */
 		if ($data['meeting_description']) {
-			$template->addBodyListItem($data['meeting_description_html'] ?? $data['meeting_description'], $this->l10n->t('Description:'),
+			$template->addBodyListItem($data['meeting_description_html'] ?? htmlspecialchars($data['meeting_description']), $this->l10n->t('Description:'),
 				$this->getAbsoluteImagePath('caldav/description.png'), $data['meeting_description'], '', IMipPlugin::IMIP_INDENT);
 		}
 	}
@@ -1080,9 +1139,9 @@ class IMipService {
 		$attendee = $iTipMessage->recipient;
 		$organizer = $iTipMessage->sender;
 		$sequence = $iTipMessage->sequence;
-		$recurrenceId = isset($vevent->{'RECURRENCE-ID'}) ?
-			$vevent->{'RECURRENCE-ID'}->serialize() : null;
-		$uid = $vevent->{'UID'};
+		$recurrenceId = isset($vevent->{'RECURRENCE-ID'})
+			? $vevent->{'RECURRENCE-ID'}->serialize() : null;
+		$uid = $vevent->{'UID'}?->getValue();
 
 		$query = $this->db->getQueryBuilder();
 		$query->insert('calendar_invitations')
@@ -1155,6 +1214,21 @@ class IMipService {
 		return false;
 	}
 
+	public function isCircle(Property $attendee): bool {
+		$cuType = $attendee->offsetGet('CUTYPE');
+		if (!$cuType instanceof Parameter) {
+			return false;
+		}
+
+		$uri = $attendee->getValue();
+		if (!$uri) {
+			return false;
+		}
+
+		$cuTypeValue = $cuType->getValue();
+		return $cuTypeValue === 'GROUP' && str_starts_with($uri, 'mailto:circle+');
+	}
+
 	public function minimizeInterval(\DateInterval $dateInterval): array {
 		// evaluate if time interval is in the past
 		if ($dateInterval->invert == 1) {
