@@ -8,7 +8,6 @@ OC.L10N.register(
     "Could not enable recovery key. Please check your recovery key password!" : "No s'ha pogut habilitar la clau de recuperació. Comproveu contrasenya de la clau de recuperació!",
     "Recovery key successfully disabled" : "La clau de recuperació s'ha inhabilitat",
     "Could not disable recovery key. Please check your recovery key password!" : "No s'ha pogut inhabilitar la clau de recuperació. Comproveu la contrasenya de la clau de recuperació!",
-    "Missing parameters" : "Falten paràmetres",
     "Please provide the old recovery password" : "Si us plau, proporcioneu la contrasenya de recuperació antiga",
     "Please provide a new recovery password" : "Si us plau, proporcioneu una nova contrasenya de recuperació",
     "Please repeat the new recovery password" : "Si us plau, repetiu la nova contrasenya de recuperació",
@@ -30,29 +29,31 @@ OC.L10N.register(
     "one-time password for server-side-encryption" : "contrasenya única per al xifratge en el servidor",
     "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot desxifrar aquest fitxer, probablement és un fitxer compartit. Demaneu al propietari del fitxer que torni a compartir el fitxer amb vosaltres.",
     "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot llegir aquest fitxer, probablement aquest sigui un fitxer compartit. Demana al propietari del fitxer que torni a compartir el fitxer amb tu.",
-    "Default encryption module" : "Mòdul de xifratge per defecte",
-    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'aplicació de xifratge està activada però les claus no estan inicialitzades, tanqueu la sessió i inicieu-ne una de nova.",
-    "Encrypt the home storage" : "Xifra l'emmagatzematge de casa",
     "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Si activeu aquesta opció, es xifraran tots els fitxers emmagatzemats a l’emmagatzematge principal; en cas contrari, només es xifraran els fitxers d’emmagatzematge extern",
-    "Enable recovery key" : "Habilita la clau de recuperació",
+    "Encrypt the home storage" : "Xifra l'emmagatzematge de casa",
     "Disable recovery key" : "Inhabilita la clau de recuperació",
+    "Enable recovery key" : "Habilita la clau de recuperació",
     "Recovery key password" : "Clau de recuperació de la contrasenya",
     "Repeat recovery key password" : "Repetiu la contrasenya de la clau de recuperació",
-    "Change recovery key password:" : "Canvia la clau de recuperació de contrasenya:",
     "Old recovery key password" : "Contrasenya antiga de clau de recuperació",
     "New recovery key password" : "Nova contrasenya de clau de recuperació",
     "Repeat new recovery key password" : "Repetiu la contrasenya de la clau de recuperació nova",
-    "Change Password" : "Canvia la contrasenya",
-    "Basic encryption module" : "Mòdul de xifratge bàsic",
-    "Your private key password no longer matches your log-in password." : "La clau privada ja no es correspon amb la contrasenya d'inici de sessió:",
-    "Set your old private key password to your current log-in password:" : "Establiu la vostra antiga clau privada a l'actual contrasenya d'accés:",
     "Old log-in password" : "Contrasenya antiga d’inici de sessió",
     "Current log-in password" : "Contrasenya actual d’inici de sessió",
+    "Update" : "Actualitza",
+    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Si activeu aquesta opció, podreu accedir als vostres fitxers encriptats en cas de pèrdua de contrasenya",
+    "Default encryption module" : "Mòdul de xifratge per defecte",
+    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'aplicació de xifratge està activada però les claus no estan inicialitzades, tanqueu la sessió i inicieu-ne una de nova.",
+    "Basic encryption module" : "Mòdul de xifratge bàsic",
+    "Missing parameters" : "Falten paràmetres",
+    "Default encryption module for server-side encryption" : "Mòdul criptogràfic per defecte per a xifratge de servidor",
+    "Change recovery key password:" : "Canvia la clau de recuperació de contrasenya:",
+    "Change Password" : "Canvia la contrasenya",
+    "Your private key password no longer matches your log-in password." : "La clau privada ja no es correspon amb la contrasenya d'inici de sessió:",
+    "Set your old private key password to your current log-in password:" : "Establiu la vostra antiga clau privada a l'actual contrasenya d'accés:",
     "Update Private Key Password" : "Actualitza la contrasenya de clau privada",
     "Enable password recovery:" : "Habilita la recuperació de contrasenya:",
-    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Si activeu aquesta opció, podreu accedir als vostres fitxers encriptats en cas de pèrdua de contrasenya",
     "Enabled" : "Habilitat",
-    "Disabled" : "Inhabilitat",
-    "Default encryption module for server-side encryption" : "Mòdul criptogràfic per defecte per a xifratge de servidor"
+    "Disabled" : "Inhabilitat"
 },
 "nplurals=2; plural=(n != 1);");
