@@ -4,7 +4,7 @@ OC.L10N.register(
     "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
     "Server to server sharing is not enabled on this server" : "Serveritevaheline jagamine ei ole selle pilves aktiiveeritud",
     "Couldn't establish a federated share." : "Liitjagamist ei õnnestunud luua",
-    "Couldn't establish a federated share, maybe the password was wrong." : "Liitjagamist ei õnnestunud luua, ehk oli parool vale.",
+    "Couldn't establish a federated share, maybe the password was wrong." : "Liitjagamist ei õnnestunud luua, vast oli salasõna vale.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Liitjagamise päring edastatud, sulle saadetakse kutse. Kontrolli oma teateid.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Liitjagamist ei saanud luua, näib, et liitmiseks mõeldud server on liiga vana (Nextcloud <= 9).",
     "It is not allowed to send federated group shares from this server." : "Sellest serverist ei ole lubatud liitrühma jagamisi saata.",
@@ -21,44 +21,56 @@ OC.L10N.register(
     "Decline" : "Keeldu",
     "Federated Cloud Sharing" : "Jagamine liitpilves",
     "Sharing" : "Jagamine",
-    "Federated file sharing" : "Littjagamisega failide jagamine",
-    "Provide federated file sharing across servers" : "Toeta liitjagamise kaudu failide jagamist üle serverite",
-    "Unable to update federated files sharing config" : "Liitfailide jagamise konfiguratsiooni ei saa värskendada",
+    "Federated file sharing" : "Failide jagamine liitpilves",
+    "Provide federated file sharing across servers" : "Toeta failide jagamist liitpilves üle serverite",
+    "Confirm data upload to lookup server" : "Kinnita andmete üleslaadimine tuvastusserverisse",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Kui see eelistus on kasutusel, siis kõik kasutajakonto andmed, mille nähtavuseks on märgitud „avaldatud“, sünkroniseeritakse automaatselt välistesse serveritesse ning avaldatakse liitpilve üldises aadressiraamatus.",
+    "Enable data upload" : "Luba andmete üleslaadimine",
+    "Disable upload" : "Keela üleslaadimine",
+    "Confirm querying lookup server" : "Kinnita andmete pärimine tuvastusserverist",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Kui see eelistus on kasutusel, siis jaosmeedia loomisel kasutatud otsingusisend saadetakse automaatselt välistesse serveritesse, mis tagavad liitpilve üldise ja avaliku aadressiraamatu toimimise.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "See on kasutusel liitpilve tunnuse laadimiseks ning see teeb jagamise liitpilves lihtsamaks.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Lisaks võidakse sellesse serverisse saata verifitseerimise jaoks kasutajate e-posti aadresse.",
+    "Enable querying" : "Luba päringute tegemine",
+    "Disable querying" : "Keela päringute tegemine",
+    "Unable to update federated files sharing config" : "Failide liitpilves jagamise seadistusi ei saa uuendada",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Reguleeri, kuidas inimesed saavad serverite vahel jagada. See hõlmab ka selles serveris olevate inimeste vahelisi jagamisi, kui nad kasutavad liitjagamist.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Luba selles serveris olevatel inimestel saata kaustu teistele serveritele (see valik võimaldab ka WebDAV-i juurdepääsu avalikele jagamistele)",
     "Allow people on this server to receive shares from other servers" : "Luba selles serveris olevatel inimestel saada teistelt serveritelt jagamisi",
     "Allow people on this server to send shares to groups on other servers" : "Luba selles serveris olevatel inimestel saata jagamisi teiste serverite rühmadele",
     "Allow people on this server to receive group shares from other servers" : "Luba selles serveris olevatel inimestel saada teistelt serveritelt grupi jagamisi",
+    "The lookup server is only available for global scale." : "Tuvastusserver on mõeldud kasutamiseks liitpilve jaoks.",
     "Search global and public address book for people" : "Otsi inimesi globaalsest ja avalikust aadressiraamatust",
     "Allow people to publish their data to a global and public address book" : "Luba inimestel avaldada oma andmeid globaalses ja avalikus aadressiraamatus",
     "Trusted federation" : "Usaldatud liitjagamine",
     "Automatically accept shares from trusted federated accounts and groups by default" : "Aktsepteeri vaikimisi usaldusväärsete liitkontode ja rühmade jagamisi automaatselt",
-    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Jaga minuga läbi mu #Nextcloudi Liitjagamise Pilve ID, vaata {url}",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaga minuga läbi minu #Nextcloudi liitpilve ID",
-    "Cloud ID copied to the clipboard" : "Pilve ID kopeeriti lõikelauale",
-    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
-    "Clipboard not available. Please copy the cloud ID manually." : "Lõikelaud pole saadaval. Palun kopeeri pilve ID manuaalselt.",
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Jaga minuga minu #Nextcloudi kasutajatunnuse abil liitpilves, vaata {url}",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaga minuga minu #Nextcloudi kasutajatunnuse abil liitpilves",
+    "Share with me via Nextcloud" : "Jaga minuga Nextcloudi vahendusel",
+    "Cloud ID copied" : "Kasutajatunnus liitpilves on kopeeritud",
+    "Copy" : "Kopeeri",
+    "Clipboard not available. Please copy the cloud ID manually." : "Lõikelaud pole saadaval. Palun kopeeri kasutajatunnus liitpilves käsitsi.",
     "Copied!" : "Kopeeritud!",
     "Federated Cloud" : "Liitpilv",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Saad jagada kõigiga, kes kasutavad Nextcloudi serverit või muid Open Cloud Meshi (OCM) ühilduvaid servereid ja teenuseid! Lihtsalt sisesta nende Liitjagamise Pilve ID jagamise dialoogi. See näeb välja nagu isiksus@cloud.example.com",
-    "Your Federated Cloud ID" : "Su Liitjagamise Pilve ID",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Saad jagada kõigiga, kes kasutavad {productName}i serverit või muid Open Cloud Meshi (OCM) ühilduvaid servereid ja teenuseid! Lihtsalt sisesta jagamise vaates nende kasutajatunnus liitpilves. See näeb välja nagu kasutajanimi@pilv.toreserver.com",
+    "Your Federated Cloud ID" : "Sinu kasutajatunnus liitpilves",
     "Share it so your friends can share files with you:" : "Jaga seda, et su sõbrad saaksid sinuga faile jagada:",
+    "Bluesky" : "Bluesky",
     "Facebook" : "Facebook",
-    "X (formerly Twitter)" : "X (varasemalt Twitter)",
-    "formerly Twitter" : "varasemalt Twitter",
     "Mastodon" : "Mastodon",
     "Add to your website" : "Lisa oma veebisaidile",
-    "Share with me via Nextcloud" : "Jaga minuga läbi Nextcloudi",
+    "Share with me via {productName}" : "Jaga minuga {productName}i vahendusel",
     "HTML Code:" : "HTML kood:",
     "Cancel" : "Tühista",
     "Add remote share" : "Lisa kaugjagamine",
     "Remote share" : "Kaugjagamine",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soovid lisada kaugjagamise {name} asukohast {owner}@{remote}?",
-    "Remote share password" : "Kaugjagamise parool",
+    "Remote share password" : "Kaugjagamise salasõna",
     "Incoming share could not be processed" : "Sissetulevat kausta ei saanud töödelda",
-    "Clipboard is not available" : "Lõikelauda ei ole saadaval",
-    "Your Federated Cloud ID:" : "Sinu liitpilve ID:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diasporaa"
+    "Cloud ID copied to the clipboard" : "Kasutajatunnus liitpilves on kopeeritud lõikelauale",
+    "Copy to clipboard" : "Kopeeri lõikelauale",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Saad jagada kõigiga, kes kasutavad Nextcloudi serverit või muid Open Cloud Meshi (OCM) ühilduvaid servereid ja teenuseid! Lihtsalt sisesta nende kasutajatunnus liitpilves jagamise vaates. See näeb välja nagu isiksus@pilv.toreserver.com",
+    "X (formerly Twitter)" : "X (varasemalt Twitter)",
+    "formerly Twitter" : "varasemalt Twitter"
 },
 "nplurals=2; plural=(n != 1);");
