@@ -25,14 +25,14 @@ OC.L10N.register(
     "Provide federated file sharing across servers" : "Poskytnúť združené zdieľanie súborov naprieč servermi",
     "Confirm data upload to lookup server" : "Potvrdiť nahranie dáť na vyhľadávací server",
     "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Keď je táto možnosť povolená, všetky vlastnosti účtu (napr. e-mailová adresa) s viditeľnosťou rozsahu nastavenou na „zverejnené“ sa automaticky synchronizujú a prenesú do externého systému a sprístupnia sa vo verejnom globálnom adresári.",
-    "Disable upload" : "Zakázať nahrávanie",
     "Enable data upload" : "Povoliť nahrávanie dát",
+    "Disable upload" : "Zakázať nahrávanie",
     "Confirm querying lookup server" : "Potvrďte dotaz na vyhľadávací server",
     "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Keď je táto možnosť povolená, vyhľadávací vstup pri vytváraní zdieľaných položiek sa odošle do externého systému, ktorý poskytuje verejný a globálny adresár.",
     "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Používa sa na získanie federatívneho cloudového ID, aby sa uľahčilo federatívne zdieľanie.",
     "Moreover, email addresses of users might be sent to that system in order to verify them." : "Okrem toho môžu byť do tohto systému odoslané e-mailové adresy užívateľov, aby sa mohli overiť.",
-    "Disable querying" : "Zakázať dotazovanie",
     "Enable querying" : "Povoliť dotazovanie",
+    "Disable querying" : "Zakázať dotazovanie",
     "Unable to update federated files sharing config" : "Nedá sa aktualizovať konfigurácia zdieľania združených súborov",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi ľuďmi na tomto serveri ako aj používanie združeného zdieľania.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť užívateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
@@ -47,17 +47,19 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Zdieľajte so mnou prostredníctvom môjho #identifikátora združeného cloudu Nextcloud, pozrite {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #identifikátora združeného cloudu Nextcloud",
     "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
+    "Cloud ID copied" : "Cloud ID bolo skopírované",
     "Copy" : "Kopírovať",
     "Clipboard not available. Please copy the cloud ID manually." : "Schránka nie je prístupná. Prosím skopírujte cloud ID manuálne.",
     "Copied!" : "Skopírované!",
     "Federated Cloud" : "Federovaný cloud",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server {productName} alebo iné servery a služby kompatibilné s Open Cloud Mesh (OCM). Stačí zadať ich Federated Cloud ID do dialógového okna zdieľania. Vyzerá to ako osoba@cloud.example.com",
     "Your Federated Cloud ID" : "Váš identifikátor v rámci federovaného cloudu",
     "Share it so your friends can share files with you:" : "Dajte vedieť vašim priateľom ako s vami môžu zdieľať súbory:",
+    "Bluesky" : "Bluesky",
     "Facebook" : "Facebook",
-    "X (formerly Twitter)" : "X (predtým Twitter)",
-    "formerly Twitter" : "predtým Twitter",
     "Mastodon" : "Mastodon",
     "Add to your website" : "Pridať na svoju webstránku",
+    "Share with me via {productName}" : "Zdieľať som mnou cez {productName}",
     "HTML Code:" : "HTML kód:",
     "Cancel" : "Zrušiť",
     "Add remote share" : "Pridať vzdialené úložisko",
@@ -67,6 +69,8 @@ OC.L10N.register(
     "Incoming share could not be processed" : "Prichádzajúce zdieľanie sa nepodarilo spracovať",
     "Cloud ID copied to the clipboard" : "Cloud ID bol skopírovaný do schránky",
     "Copy to clipboard" : "Skopírovať do schránky",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor federovaného cloudu v dialógovom okne zdieľania. Má podobu osoba@cloud.priklad.com"
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor federovaného cloudu v dialógovom okne zdieľania. Má podobu osoba@cloud.priklad.com",
+    "X (formerly Twitter)" : "X (predtým Twitter)",
+    "formerly Twitter" : "predtým Twitter"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
