@@ -11,11 +11,23 @@ OC.L10N.register(
     "Federation" : "Federation",
     "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federation ermöglicht die Verbindung mit anderen vertrauenswürdigen Servern, um das Kontenverzeichnis auszutauschen.",
     "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet.",
-    "External documentation for Federated Cloud Sharing" : "Externe Dokumentation für das Teilen über Federated Cloud",
+    "Could not add trusted server. Please try again later." : "Vertrauenswürdiger Server konnte nicht hinzugefügt werden. Bitte später erneut versuchen.",
+    "Add trusted server" : "Vertrauenswürdigen Server hinzufügen",
+    "Server url" : "Server-URL",
+    "Add" : "Hinzufügen",
+    "Server ok" : "Server OK",
+    "User list was exchanged at least once successfully with the remote server." : "Die Benutzerliste wurde mindestens einmal erfolgreich mit dem Remote-Server ausgetauscht.",
+    "Server pending" : "Server ausstehend",
+    "Waiting for shared secret or initial user list exchange." : "Warten auf den Austausch gemeinsamer Geheimnisse oder erster Benutzerliste.",
+    "Server access revoked" : "Serverzugriff widerrufen",
+    "Server failure" : "Serverfehler",
+    "Connection to the remote server failed or the remote server is misconfigured." : "Die Verbindung zum Remote-Server ist fehlgeschlagen oder der Remote-Server ist falsch konfiguriert.",
+    "Failed to delete trusted server. Please try again later." : "Vertrauenswürdiger Server konnte nicht gelöscht werden. Bitte später erneut versuchen.",
+    "Delete" : "Löschen",
     "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation ermöglicht es dir, dich mit anderen vertrauenswürdigen Servern zu verbinden, um das Kontoverzeichnis auszutauschen. Dies wird zum Beispiel für die automatische Vervollständigung externer Konten beim Federated-Sharing verwendet. Es ist nicht erforderlich einen Server als vertrauenswürdig hinzuzufügen, um eine \"federated\" Freigabe zu erstellen.",
     "Each server must validate the other. This process may require a few cron cycles." : "Jeder Server muss den anderen validieren. Dieser Vorgang kann einige Cron-Zyklen benötigen.",
+    "External documentation for Federated Cloud Sharing" : "Externe Dokumentation für das Teilen über Federated Cloud",
     "+ Add trusted server" : "+ Vertrauenswürdigen Server hinzufügen",
-    "Trusted server" : "Vertrauenswürdiger Server",
-    "Add" : "Hinzufügen"
+    "Trusted server" : "Vertrauenswürdiger Server"
 },
 "nplurals=2; plural=(n != 1);");
