@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Du har ikke tilladelse til at oprette en fil på den angivne placering",
     "The file could not be converted." : "Filen kunne ikke konverteres.",
     "Could not get relative path to converted file" : "Kunne ikke hente relativ sti til konverteret fil",
+    "Limit must be a positive integer." : "Grænse skal være et positivt heltal.",
+    "The replacement character may only be a single character." : "Erstatningskarakteren må kun være én enkelt karakter.",
+    "Filename sanitization already started." : "Filnavnsrensning allerede startet.",
+    "No filename sanitization in progress." : "Ingen filnavnsrensning i gang.",
     "Favorite files" : "Favoriser filer",
     "No favorites" : "Ingen foretrukne",
     "More favorites" : "Flere favoritter",
-    "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accepter",
     "Reject" : "Afvis",
     "Incoming ownership transfer from {user}" : "Indgående ejerskabsoverførsel fra {user}",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Ejerskabsoverførslen af {path} fra {user} er fuldført.",
     "in %s" : "i %s",
     "Transferred from %1$s on %2$s" : "Overført fra %1$s den %2$s",
-    "Files compatibility" : "Filkompatibilitet",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillad at begrænse filnavne for at sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavne der er gyldige på POSIX (fx Linux eller macOS) tilladte.",
-    "Enforce Windows compatibility" : "Styrk Windows kompatibilitet",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokere filnavne der ikke er gyldige på Windows systemer, såsom brug af reserverede navne eller specielle karakterer. Men dette vil ikke styrke kompatibiliteten af versalfølsomhed.",
     "File Management" : "Filhåndtering",
     "Home" : "Hjem",
     "Target folder does not exist any more" : "Destinationsmappen findes ikke længere",
@@ -95,28 +94,73 @@ OC.L10N.register(
     "Invalid filename." : "Ugyldigt filnavn.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøbte \"{oldName}\" til \"{newName}\"",
     "Rename file" : "Omdøb fil",
+    "Folder" : "Mappe",
+    "Unknown file type" : "Ukendt filtype",
+    "{ext} image" : "{ext} billede",
+    "{ext} video" : "{ext} video",
+    "{ext} audio" : "{ext} lyd",
+    "{ext} text" : "{ext} tekst",
     "Pending" : "Afventer",
     "Unknown date" : "Ukendt dato",
     "Clear filter" : "Ryd filter",
     "Modified" : "Ændret",
+    "Search everywhere" : "Søg overalt",
     "Type" : "Type",
     "Active filters" : "Aktive filtre",
     "Remove filter" : "Fjern filter",
+    "Appearance" : "Udseende",
+    "Show hidden files" : "Vis skjulte filer",
+    "Show file type column" : "Vis filtype kolonne",
+    "Show file extensions" : "Vis filendelser",
+    "Crop image previews" : "Beskær forhåndsvisninger af billeder",
+    "General" : "Generelt",
+    "Sort favorites first" : "Vis favoritter først",
+    "Sort folders before files" : "Sorter mapper før filer",
+    "Default view" : "Standard visning",
+    "All files" : "Alle filer",
+    "Personal files" : "Personlige filer",
+    "Additional settings" : "Yderligere indstillinger",
+    "Actions" : "Handlinger",
+    "File actions" : "Fil-handlinger",
+    "Selection" : "Valg",
+    "Select all files" : "Vælg alle filer",
+    "Deselect all" : "Fravælg alle",
+    "Select or deselect" : "Vælg eller fravælg",
+    "Select a range" : "Vælg et område",
+    "Navigation" : "Navigation",
+    "Go to parent folder" : "Gå til overordnet mappe",
+    "Go to file above" : "Gå til filen over",
+    "Go to file below" : "Gå til filen under",
+    "Go left in grid" : "Gå til venstre i gitter",
+    "Go right in grid" : "Gå til højre i gitter",
+    "View" : "Vis",
+    "Toggle grid view" : "Vis som liste",
+    "Open file sidebar" : "Åbn fil sidebjælke",
+    "Show those shortcuts" : "Vis disse genveje",
+    "Warnings" : "Advarsler",
+    "Warn before changing a file extension" : "Advar inden en filendelse ændres",
+    "WebDAV URL" : "WebDAV URL",
+    "How to access files using WebDAV" : "Hvordan filer tilgås ved hjælp af WebDAV",
     "Total rows summary" : "Samlet række antal",
     "Toggle selection for all files and folders" : "Skift markering for alle filer og mapper",
     "Name" : "Navn",
+    "File type" : "Filtype",
     "Size" : "Størrelse",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" fejlede på nogle elementer",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-handling mislykkedes",
-    "Actions" : "Handlinger",
+    "{displayName}: failed on some elements" : "{displayName}: fejlede på nogle elementer",
+    "{displayName}: done" : "{displayName}: færdig",
+    "{displayName}: failed" : "{displayName}: fejlede",
     "(selected)" : "(valgt)",
     "List of files and folders." : "Liste med filer og mapper.",
     "You have used your space quota and cannot upload files anymore." : "Du har opbrugt din plads kvote og kan ikke uploade flere filer.",
     "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper er sorterbare.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
     "File not found" : "Filen blev ikke fundet",
-    "{count} selected" : "{count} valgt",
+    "_{count} selected_::_{count} selected_" : ["{count} valgt","{count} valgt"],
+    "Search everywhere …" : "Søg over alt ...",
+    "Search here …" : "Søg her ...",
+    "Search scope options" : "Indstillinger for søgeområde",
+    "Search here" : "Søg her",
+    "Owner" : "Ejer",
     "{usedQuotaByte} used" : "{usedQuotaByte} brugt",
     "{used} of {quota} used" : "{used} af {quota} brugt",
     "{relative}% used" : "{relative}% brugt",
@@ -128,8 +172,27 @@ OC.L10N.register(
     "Create new folder" : "Opret ny mappe",
     "This name is already in use." : "Dette navn er allerede i brug.",
     "Create" : "Opret",
+    "Files starting with a dot are hidden by default" : "Filer der starter med et punktum er som standard skjulte",
+    "Failed to start filename sanitization." : "Kunne ikke starte filnavnsrensning.",
+    "Failed to refresh filename sanitization status." : "Kunne ikke genopfriske status for filnavnsrensning.",
+    "Filename sanitization in progress." : "Filnavnsrensning i gang.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Aktuelt er {processedUsers} ud af {totalUsers} konti allerede processeret.",
+    "Preparing …" : "Forbereder ...",
+    "Refresh" : "Opdatér",
+    "All files have been santized for Windows filename support." : "Alle filer er blevet filnavnsrensede af hensyn til Windows filnavnsunderstøttelse.",
+    "Some files could not be sanitized, please check your logs." : "Nogle filer kunne ikke blive filnavnsrensede, kontroller venligst dine logfiler.",
+    "Sanitization errors" : "Rensningsfejl",
+    "Not sanitized filenames" : "Ikke rensede filnavne",
+    "Windows filename support has been enabled." : "Windows filnavnsunderstøttelse er blevet aktiveret.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Mens dette blokeret brugere fra at oprette nye filer med ikke understøttede filnavne, så omdøbes eksisterende filer endnu ikke og kan derfor stadig ødelægge synkronisering på Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Du kan starte omdøbning af filer med ugyldige filnavne, dette vil blive gjort i baggrunden og kan tage noget tid.",
+    "Please note that this may cause high workload on the sync clients." : "Vær venligst opmærksom på at dette kan medføre en høj belastning på synkroniseringsklienterne.",
+    "Limit" : "Grænse",
+    "This allows to configure how many users should be processed in one background job run." : "Dette giver mulighed for at konfigurere hvor mange brugere der skal processereres i én kørsel af et baggrundsjob.",
+    "Sanitize filenames" : "Rens filnavne",
+    "(starting)" : "(starter)",
     "Fill template fields" : "Udfyld skabelonfelter",
-    "Submitting fields …" : "Sender felter …",
+    "Submitting fields …" : "Indsender felter ...",
     "Submit" : "Tilføj",
     "Choose a file or folder to transfer" : "Vælg en fil eller mappe til overførsel",
     "Transfer" : "Overfør",
@@ -153,6 +216,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Vis ikke denne dialog igen.",
     "Select file or folder to link to" : "Vælg fil eller mappe at linke til",
     "Choose {file}" : "Vælg {file}",
+    "Files settings" : "indstillinger for filer",
     "Share" : "Del",
     "Shared by link" : "Delt via link",
     "Shared" : "Delt",
@@ -165,85 +229,45 @@ OC.L10N.register(
     "Error during upload: {message}" : "Fejl under upload: {message}",
     "Error during upload, status code {status}" : "Fejl under upload, statuskode {status}",
     "Unknown error during upload" : "Ukendt fejl under upload",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
     "Loading current folder" : "Indlæser aktuelle mappe",
     "Retry" : "Prøv igen",
     "No files in here" : "Her er ingen filer",
     "Upload some content or sync with your devices!" : "Upload indhold eller synkroniser med dine enheder!",
     "Go back" : "Gå tilbage",
-    "Filter file names …" : "Filtrer filnavne ...",
     "Views" : "Visninger",
-    "Files settings" : "indstillinger for filer",
+    "Loading …" : "Indlæser …",
     "Your files" : "Dine filer",
     "Open in files" : "Åben i Filer",
     "File cannot be accessed" : "Filen kan ikke tilgås",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunne ikke findes eller du har ikke tilladelser til at se den. Bed afsenderen om at dele den.",
-    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
-    "WebDAV URL copied to clipboard" : "WebDAV URL kopieret til udklipsholder",
-    "Sort favorites first" : "Vis favoritter først",
-    "Sort folders before files" : "Sorter mapper før filer",
-    "Show hidden files" : "Vis skjulte filer",
-    "Crop image previews" : "Beskær forhåndsvisninger af billeder",
-    "Enable the grid view" : "Aktiver gittervisning",
-    "Enable folder tree" : "Aktiver mappetræ",
-    "Additional settings" : "Yderligere indstillinger",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Kopier til udklipsholder",
-    "Use this address to access your Files via WebDAV" : "Brug denne adresse til at få adgang til dine filer via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktiveret 2-faktor godkendelse, skal du oprette en app-token, ved at følge dette link.",
-    "Warnings" : "Advarsler",
-    "Prevent warning dialogs from open or reenable them." : "Forhindr advarselsdialoger i at åbner, eller genaktiver dem.",
-    "Show a warning dialog when changing a file extension." : "Vis en advarselsdialog når en filendelse ændres.",
-    "Keyboard shortcuts" : "Tastaturgenveje",
-    "Speed up your Files experience with these quick shortcuts." : "Øg hastigheden for din filoplevelse med disse hurtig-genveje.",
-    "Open the actions menu for a file" : "Åben handlingsmenuen for en fil",
-    "Rename a file" : "Omdøb  en fil",
-    "Delete a file" : "Slet en fil",
-    "Favorite or remove a file from favorites" : "Favoriser fil eller fjern favorisering af filer",
-    "Manage tags for a file" : "Styr tags for en fil",
-    "Selection" : "Valg",
-    "Select all files" : "Vælg alle filer",
-    "Deselect all files" : "Fravælg eller filer",
-    "Select or deselect a file" : "Vælg eller fravælg en fil",
-    "Select a range of files" : "Vælg et område af filer",
-    "Navigation" : "Navigation",
-    "Navigate to the parent folder" : "Naviger til den overordnede mappe",
-    "Navigate to the file above" : "Naviger til filen ovenover",
-    "Navigate to the file below" : "Naviger til filen nedenunder",
-    "Navigate to the file on the left (in grid mode)" : "Naviger til filen til venstre (i gittertilstand)",
-    "Navigate to the file on the right (in grid mode)" : "Naviger til filen til højre (i gittertilstand)",
-    "View" : "Vis",
-    "Toggle the grid view" : "Skift gittervisningen",
-    "Open the sidebar for a file" : "Åben sidebjælken for en fil",
-    "Show those shortcuts" : "Vis disse genveje",
-    "You" : "Dig",
-    "Shared multiple times with different people" : "Delt flere gange med forskellige mennesker",
-    "Error while loading the file data" : "Fejl under indlæsning af fildata",
-    "Owner" : "Ejer",
-    "Remove from favorites" : "Fjern fra favoritter",
-    "Add to favorites" : "Tilføj til favoritter",
-    "Tags" : "Tags",
+    "No search results for “{query}”" : "Ingen søgeresultater for “{query}”",
+    "Search for files" : "Søg efter filer",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillad at begrænse filnavne for at sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavne der er gyldige på POSIX (fx Linux eller macOS) tilladte.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Efter aktivering af Windows kompatible filnavne, så kan eksisterende filer ikke længere ændres, men de kan omdøbes til gyldige nye navne af deres ejer.",
+    "Failed to toggle Windows filename support" : "Kunne ikke skifte til Windows filnavnsunderstøttelse",
+    "Files compatibility" : "Filkompatibilitet",
+    "Enforce Windows compatibility" : "Styrk Windows kompatibilitet",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokere filnavne der ikke er gyldige på Windows systemer, såsom brug af reserverede navne eller specielle karakterer. Men dette vil ikke styrke kompatibiliteten af versalfølsomhed.",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kan ikke oprette ny fil fra skabelonen",
     "Pick a template for {name}" : "Vælg en skabelon til {name}",
     "Create a new file with the selected template" : "Opret en ny fil med den valgte skabelon",
     "Creating file" : "Opretter fil",
     "Save as {displayName}" : "Gem som {displayName}",
-    "Save as …" : "Gem som ...",
-    "Converting files …" : "Konverterer filer ...",
+    "Save as …" : "Gem som ...",
+    "Converting files …" : "Konverterer filer ...",
     "Failed to convert files: {message}" : "Kunne ikke konvertere filer: {message}",
     "All files failed to be converted" : "Alle filer kunne ikke konverteres",
     "One file could not be converted: {message}" : "En fil kunne ikke konverteres: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["En fil kunne ikke konverteres","%n filer kunne ikke konverteres"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["En fil konverteret","%n filer konverteret"],
-    "Files successfully converted" : "Filer konverteret",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n fil kunne ikke konverteres","%n filer kunne ikke konverteres"],
+    "_%n file converted_::_%n files converted_" : ["%n fil konverteret converted","%n filer konverteret"],
+    "Files converted" : "Filer konverteret",
     "Failed to convert files" : "Kunne ikke konvertere filer",
-    "Converting file …" : "Konverterer fil ...",
+    "Converting file …" : "Konverterer fil …",
     "File successfully converted" : "Filen konverteret",
     "Failed to convert file: {message}" : "Kunne ikke konvertere fil: {message}",
     "Failed to convert file" : "Kunne ikke konvertere fil",
-    "Deletion cancelled" : "Sletning annulleret",
+    "Delete" : "Slet",
     "Leave this share" : "Forlad dette delte drev",
     "Leave these shares" : "Forlad disse delinger",
     "Disconnect storage" : "Frakobl lager",
@@ -254,39 +278,44 @@ OC.L10N.register(
     "Delete files" : "Slet filer",
     "Delete folder" : "Slet mappe",
     "Delete folders" : "Slet mapper",
-    "Delete" : "Slet",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er ved at slette {count} element permanent","Du er ved at slette {count} elementer permanent"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er ved at slette {count} element","Du er ved at slette {count} elementer"],
     "Confirm deletion" : "Bekræft sletning",
-    "Cancel" : "annuller",
-    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
+    "Cancel" : "Annullér",
+    "Download" : "Download",
+    "The requested file is not available." : "Den forespurgte fil er ikke tilgængelig.",
+    "The requested files are not available." : "De forespurgte filer er ikke tilgængelige.",
+    "Add to favorites" : "Tilføj til favoritter",
+    "Remove from favorites" : "Fjern fra favoritter",
+    "Add or remove favorite" : "Tilføj eller fjern fremhævning",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
+    "Destination is not a folder" : "Destinationen er ikke en mappe",
+    "This file/folder is already in that directory" : "Filen/mappen er allerede i denne mappe",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe ind i sig selv, eller til en mappe inden i sig selv",
     "(copy)" : "(kopier)",
     "(copy %n)" : "(kopier %n)",
-    "Move cancelled" : "Flytning annulleret",
     "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navn findes allerede i denne mappe",
     "The files are locked" : "Filerne er låste",
     "The file does not exist anymore" : "Filen findes ikke længere",
     "Choose destination" : "Vælg destination",
-    "Copy to {target}" : "Kopier til {target}",
+    "Copy to {target}" : "Kopiér til {target}",
     "Copy" : "Kopier",
     "Move to {target}" : "Flyt til {target}",
     "Move" : "Flyt",
     "Move or copy operation failed" : "Flytte- eller kopioperationen fejlede",
-    "Move or copy" : "Flyt eller kopier",
-    "Cancelled move or copy of \"{filename}\"." : "Annullerede flytning eller kopiering af \"{filename}\".",
-    "Cancelled move or copy operation" : "Flytning eller kopiering er annulleret",
+    "Move or copy" : "Flyt eller kopiér",
+    "Open folder" : "Åbn mappe",
     "Open folder {displayName}" : "Åben mappe {displayName}",
     "Open in Files" : "Åben i Filer",
+    "Open locally" : "Åben lokalt",
+    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
     "Open file locally" : "Åben fil lokalt",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen bør nu åbne på dit apparat. Hvis den ikke gør det, så kontroller venligst at desktop app'en er installeret.",
     "Retry and close" : "Forsøg igen og luk",
     "Open online" : "Åben online",
-    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
-    "Open locally" : "Åben lokalt",
     "Rename" : "Omdøb",
-    "Open details" : "Mere information",
+    "Details" : "Detaljer",
     "View in folder" : "Vis i mappe",
     "Today" : "I dag",
     "Last 7 days" : "Sidste 7 dage",
@@ -299,15 +328,15 @@ OC.L10N.register(
     "PDFs" : "PDFer",
     "Folders" : "Mapper",
     "Audio" : "Lyd",
-    "Photos and images" : "Fotos og billeder",
+    "Images" : "Billeder",
     "Videos" : "Videoer",
-    "New folder creation cancelled" : "Oprettelse af ny mappe annulleret",
     "Created new folder \"{name}\"" : "Oprettede ny mappe \"{name}\"",
     "Unable to initialize the templates directory" : "Kan ikke initialisere skabelonmappen",
     "Create templates folder" : "Opret skabelonmappe",
     "Templates" : "Skabeloner",
     "New template folder" : "Ny skabelonmappe",
     "In folder" : "I mappe",
+    "Search in all files" : "Søg i alle filer",
     "Search in folder: {folder}" : "Søg i mappe: {folder}",
     "One of the dropped files could not be processed" : "En af de trukne filer kunne ikke behandles",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Din browser understøtter ikke Filesystem-API'en. Mapper vil ikke bliver uploadet",
@@ -322,16 +351,16 @@ OC.L10N.register(
     "Files moved successfully" : "Filer flyttet succesfuldt",
     "Conflicts resolution skipped" : "Konfliktløsning sprunget over",
     "Upload cancelled" : "Upload annulleret",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøbe \"{oldName}\", da den ikke længere findes",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" bruges allerede i mappen \"{dir}\". Vælg venligst et andet navn.",
+    "Could not rename \"{oldName}\"" : "Kunne ikke omdøbe \"{oldName}\"",
     "This operation is forbidden" : "Denne operation er forbudt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
+    "This folder is unavailable, please try again later or contact the administration" : "Denne mappe er ikke tilgængelig. Prøv venligst igen eller kontakt administratoren.",
     "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
     "Unexpected error: {error}" : "Uventet fejl: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mapper","1 fil og {folderCount} mapper"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mapper","{fileCount} filer og 1 mapper"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n skjult)","(%n skjult)"],
+    "_%n file_::_%n files_" : ["%n fil","%n filer"],
+    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
+    "_%n hidden_::_%n hidden_" : ["%n skjult","%n skjult"],
     "Filename must not be empty." : "Filnavnet må ikke være tomt.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tilladt i et filnavn.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reserveret navn og er ikke tilladt til filnavne.",
@@ -340,10 +369,8 @@ OC.L10N.register(
     "List of favorite files and folders." : "Liste med favoritfiler og -mapper.",
     "No favorites yet" : "Ingen foretrukne endnu",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
-    "All files" : "Alle filer",
     "List of your files and folders." : "Liste med dine filer og mapper.",
-    "All folders" : "Alle mapper",
-    "Personal files" : "Personlige filer",
+    "Folder tree" : "Mappetræ",
     "List of your files and folders that are not shared." : "Liste med dine filer og mapper, der ikke er delt.",
     "No personal files found" : "Ingen personlige filer fundet",
     "Files that are not shared will show up here." : "Filer der ikke er delt vil blive vist her.",
@@ -351,111 +378,72 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liste med nyligt ændrede filer og mapper.",
     "No recently modified files" : "Ingen filer er ændret for nyligt",
     "Files and folders you recently modified will show up here." : "Filer og mapper som du har ændret for nyligt, vil blive vist her.",
+    "Search" : "Søg",
+    "Search results within your files." : "Søgeresultater i dine filer.",
     "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
     "Select all" : "Vælg alle",
     "Upload too large" : "Upload er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
-    "File could not be found" : "Filen kunne ikke findes",
-    "Download" : "Download",
-    "Show list view" : "Vis som liste",
-    "Show grid view" : "Vis som gitter",
-    "Close" : "Luk",
-    "Could not create folder \"{dir}\"" : "Kunne ikke oprette mappen \"{dir}\"",
-    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
-    "Upload cancelled." : "Upload afbrudt.",
-    "Processing files …" : "Behandler filer...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke uploade {filename} da det er enten en mappe eller indeholder 0 bytes.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkelig fri plads. Du uplaoder {size1} men der er kun {size2} tilbage",
-    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" findes ikke længere",
-    "An unknown error has occurred" : "En ukendt fejl er opstået",
-    "File could not be uploaded" : "Filen kunne ikke uploades",
-    "Uploading …" : "Uploader ...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Uploader … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Upload af dette er ikke supporteret",
-    "Error when assembling chunks, status code {status}" : "Fejl ved montering af klumper, statuskode {status}",
-    "Choose target folder" : "Vælg destinationsmappe",
-    "Set reminder" : "Sæt påmindelse",
-    "Edit locally" : "Rediger lokalt",
-    "Open" : "Åbn",
-    "Could not load info for file \"{file}\"" : "Kunne ikke indlæse information for filen \"{file}\"",
-    "Details" : "Detaljer",
-    "Please select tag(s) to add to the selection" : "Vælg venligst tag(s) for at tilføje til markeringen",
-    "Apply tag(s) to selection" : "Anvend tag(s) på markeringen",
-    "Select directory \"{dirName}\"" : "Vælg mappe \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Vælg fil \"{fileName}\"",
-    "Unable to determine date" : "Kan ikke fastslå datoen",
-    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - filen findes allerede",
-    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
-    "copy" : "kopier",
-    "Could not copy \"{file}\", target exists" : "Kunne ikke kopiere \"{file}\" - der findes allerede en fil med dette navn",
-    "Could not copy \"{file}\"" : "Kunne ikke kopiere \"{file}\"",
-    "Copied {origin} inside {destination}" : "Kopirede {origin} ind i {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "kopierede {origin} og {nbfiles} andre filer ind i {destination}",
-    "{newName} already exists" : "{newName} eksisterer allerede",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Kunne ikke omdøbe \"{fileName}\", den findes ikke længere",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
-    "Could not rename \"{fileName}\"" : "Kunne ikke omdøbe \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", da den allerede findes",
-    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke oprette mappen \"{dir}\", da den allerede findes",
-    "Could not fetch file details \"{file}\"" : "Kunne ikke hente filoplysningerne \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søgeresultater i andre mapper efter {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Indtast mere end to tegn for at søge i andre mapper",
-    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
-    "_%n file_::_%n files_" : ["%n fil","%n filer"],
-    "{dirs} and {files}" : "{dirs} og {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
-    "You do not have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
-    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
-    "New" : "Nyt",
-    "New file/folder menu" : "Ny fil/mappe menu",
-    "Select file range" : "Vælg filområde",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} brugt",
-    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
-    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
-    "\"/\" is not allowed inside a file name." : "\"/\" er ikke tilladt i et filnavn.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tilladt filtype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen af {owner} er fuld, filer kan ikke længere opdateres eller synkroniseres!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er fuld, filer kan ikke længere opdateres eller synkroniseres!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Eksternt lager \"{mountPoint}\" er fyldt, filer kan ikke længere opdateres eller synkroniseres!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Din lagerplads er fuld, filer kan ikke længere opdateres eller synkroniseres!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opbevaring af {owner} er næsten fuld ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er næsten fuld ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Eksternt lager \"{mountPoint}\" er næsten fyldt ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagerplads er næsten fuld ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Linket er kopieret (dette link kan kun anvendes af brugere med adgang til denne fil/mappe)",
-    "Path" : "Sti",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Gjort til foretrukken",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
-    "Upload file" : "Upload fil",
-    "Not favorited" : "Ingen foretrukne",
-    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
-    "You don't have permission to upload or create files here." : "Du har ikke rettigheder til at uploade eller oprette filer her.",
-    "Storage informations" : "Lagerinformationer",
-    "Choose file" : "Vælg fil",
-    "Go to the previous folder" : "Gå til forrige mappe",
-    "Open the files app settings" : "Åbn fil-app indstillinger",
-    "Unable to change the favourite state of the file" : "Kan ikke ændre favorittilstanden for filen",
-    "Edit file locally" : "Rediger fil lokalt",
-    "Edit online" : "Rediger online",
-    "Create new templates folder" : "Opsæt ny skabelonmappe",
-    "List of favorites files and folders." : "Liste med foretrukne filer og mapper.",
-    "Personal Files" : "Personlige filer",
-    "Text file" : "Tekstfil",
-    "New text file.txt" : "Ny tekstfil.txt",
-    "Favored" : "Foretrukken",
-    "Favor" : "Foretræk",
-    "Not favored" : "Ikke foretrukket",
-    "Submitting fields…" : "Sender felter...",
-    "Filter filenames…" : "Filtrer filnavne...",
-    "{count} files could not be converted" : "{count} filer kunne ikke konverteres",
-    "{count} files successfully converted" : "{count} filer konverteret"
+    "%1$s (renamed)" : "%1$s (omdøbt)",
+    "renamed file" : "omdøbt fil",
+    "Upload (max. %s)" : "Upload (max. %s)",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Efter aktivering af windows kompatible filnavne, så vil eksisterende filer ikke længere kunne ændres, men de kan omdøbes til gyldige filnavne af deres ejer.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det er også muligt at migrere filer automatisk efter aktivering af denne indstilling. Se venligst dokumentationen omkring occ kommandoen.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" fejlede på nogle elementer",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling mislykkedes",
+    "Submitting fields …" : "Sender felter …",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
+    "Filter file names …" : "Filtrer filnavne ...",
+    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
+    "WebDAV URL copied to clipboard" : "WebDAV URL kopieret til udklipsholder",
+    "Enable the grid view" : "Aktiver gittervisning",
+    "Enable folder tree" : "Aktiver mappetræ",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Use this address to access your Files via WebDAV" : "Brug denne adresse til at få adgang til dine filer via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktiveret 2-faktor godkendelse, skal du oprette en app-token, ved at følge dette link.",
+    "Prevent warning dialogs from open or reenable them." : "Forhindr advarselsdialoger i at åbner, eller genaktiver dem.",
+    "Show a warning dialog when changing a file extension." : "Vis en advarselsdialog når en filendelse ændres.",
+    "Keyboard shortcuts" : "Tastaturgenveje",
+    "Speed up your Files experience with these quick shortcuts." : "Øg hastigheden for din filoplevelse med disse hurtig-genveje.",
+    "Open the actions menu for a file" : "Åben handlingsmenuen for en fil",
+    "Rename a file" : "Omdøb  en fil",
+    "Delete a file" : "Slet en fil",
+    "Favorite or remove a file from favorites" : "Favoriser fil eller fjern favorisering af filer",
+    "Manage tags for a file" : "Styr tags for en fil",
+    "Deselect all files" : "Fravælg eller filer",
+    "Select or deselect a file" : "Vælg eller fravælg en fil",
+    "Select a range of files" : "Vælg et område af filer",
+    "Navigate to the parent folder" : "Naviger til den overordnede mappe",
+    "Navigate to the file above" : "Naviger til filen ovenover",
+    "Navigate to the file below" : "Naviger til filen nedenunder",
+    "Navigate to the file on the left (in grid mode)" : "Naviger til filen til venstre (i gittertilstand)",
+    "Navigate to the file on the right (in grid mode)" : "Naviger til filen til højre (i gittertilstand)",
+    "Toggle the grid view" : "Skift gittervisningen",
+    "Open the sidebar for a file" : "Åben sidebjælken for en fil",
+    "You" : "Dig",
+    "Shared multiple times with different people" : "Delt flere gange med forskellige mennesker",
+    "Unable to change the favorite state of the file" : "Kan ikke ændre favoritstatus for filen",
+    "Error while loading the file data" : "Fejl under indlæsning af fildata",
+    "Tags" : "Tags",
+    "Save as …" : "Gem som ...",
+    "Converting files …" : "Konverterer filer ...",
+    "Converting file …" : "Konverterer fil ...",
+    "Deletion cancelled" : "Sletning annulleret",
+    "Edit locally" : "Redigér lokalt",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
+    "Move cancelled" : "Flytning annulleret",
+    "Cancelled move or copy of \"{filename}\"." : "Annullerede flytning eller kopiering af \"{filename}\".",
+    "Cancelled move or copy operation" : "Flytning eller kopiering er annulleret",
+    "Open details" : "Mere information",
+    "Photos and images" : "Fotos og billeder",
+    "New folder creation cancelled" : "Oprettelse af ny mappe annulleret",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
+    "All folders" : "Alle mapper",
+    "Search everywhere …" : "Søg overalt …",
+    "Search here …" : "Søg her …",
+    "Preparing …" : "Forbereder ..."
 },
 "nplurals=2; plural=(n != 1);");
