@@ -164,6 +164,7 @@ OC.L10N.register(
     "Search here …" : "جستجو ...",
     "Search scope options" : "گزینه‌های محدوده جستجو",
     "Search here" : "جستجو",
+    "Owner" : "مالک",
     "{usedQuotaByte} used" : "{usedQuotaByte} استفاده شده است",
     "{used} of {quota} used" : "{used} از {quota} استفاده شده",
     "{relative}% used" : "{relative}% used",
@@ -238,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
     "Go back" : "برگرد",
     "Views" : "بازدیدها",
-    "You" : "شما",
-    "Shared multiple times with different people" : "چندین بار با افراد مختلف به اشتراک گذاشته شده است",
-    "Unable to change the favorite state of the file" : "تغییر وضعیت مورد علاقه فایل امکان‌پذیر نیست",
-    "Error while loading the file data" : "خطا هنگام بارگیری داده های فایل",
-    "Owner" : "مالک",
-    "Remove from favorites" : "حذف کردن از برگزیده ها",
-    "Add to favorites" : "اضافه کردن به برگزیده ها",
-    "Tags" : "برچسب‌ها",
+    "Loading …" : "بارگیری",
     "Your files" : "فایل‌های شما",
     "Open in files" : "باز کردن در فایل‌ها",
     "File cannot be accessed" : "فایل قابل دسترسی نیست",
@@ -293,6 +287,8 @@ OC.L10N.register(
     "Download" : "دانلود",
     "The requested file is not available." : "فایل مورد نظر موجود نیست.",
     "The requested files are not available." : "فایل‌های درخواستی در دسترس نیستند.",
+    "Add to favorites" : "اضافه کردن به برگزیده ها",
+    "Remove from favorites" : "حذف کردن از برگزیده ها",
     "Add or remove favorite" : "اضافه کردن یا حذف کردن موارد دلخواه",
     "Moving \"{source}\" to \"{destination}\" …" : "انتقال «{source}» به «{destination}»",
     "Copying \"{source}\" to \"{destination}\" …" : "کپی کردن \"{source}\" به \"{destination}\" ...",
@@ -311,6 +307,7 @@ OC.L10N.register(
     "Move" : "انتقال",
     "Move or copy operation failed" : "عملیات انتقال یا کپی ناموفق بود",
     "Move or copy" : "انتقال یا رونوشت",
+    "Open folder" : "پوشه را بازکن",
     "Open folder {displayName}" : "باز کردن پوشه {displayName}",
     "Open in Files" : "در فایل باز کنید",
     "Open locally" : "گشودن محلی",
@@ -427,6 +424,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "به فایل سمت راست بروید (در حالت شبکه‌ای)",
     "Toggle the grid view" : "نمایش شبکه‌ای را تغییر دهید",
     "Open the sidebar for a file" : "نوار کناری را برای یک فایل باز کنید",
+    "You" : "شما",
+    "Shared multiple times with different people" : "چندین بار با افراد مختلف به اشتراک گذاشته شده است",
+    "Unable to change the favorite state of the file" : "تغییر وضعیت مورد علاقه فایل امکان‌پذیر نیست",
+    "Error while loading the file data" : "خطا هنگام بارگیری داده های فایل",
+    "Tags" : "برچسب‌ها",
     "Save as …" : "ذخیره به عنوان …",
     "Converting files …" : "تبدیل فایل‌ها…",
     "Converting file …" : "تبدیل فایل …",
