@@ -116,7 +116,7 @@ OC.L10N.register(
     "General" : "Général",
     "Sort favorites first" : "Trier les favoris en premier",
     "Sort folders before files" : "Trier les dossiers avant les fichiers",
-    "Enable folder tree view" : "Activer l'affichage arborescent des dossiers",
+    "Enable folder tree view" : "Activer la vue en arborescence des dossiers",
     "Default view" : "Vue par défaut",
     "All files" : "Tous les fichiers",
     "Personal files" : "Fichiers personnels",
@@ -164,6 +164,7 @@ OC.L10N.register(
     "Search here …" : "Rechercher ici …",
     "Search scope options" : "Options de portée de recherche",
     "Search here" : "Rechercher ici",
+    "Owner" : "Propriétaire",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
     "{used} of {quota} used" : "{used} utilisés sur {quota}",
     "{relative}% used" : "{relative}% utilisés",
@@ -238,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
     "Go back" : "Revenir en arrière",
     "Views" : "Vues",
-    "You" : "Vous",
-    "Shared multiple times with different people" : "Partagé plusieurs fois avec plusieurs personnes",
-    "Unable to change the favorite state of the file" : "Impossible de modifier l'état de mise en favori du fichier",
-    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
-    "Owner" : "Propriétaire",
-    "Remove from favorites" : "Retirer des favoris",
-    "Add to favorites" : "Ajouter aux favoris",
-    "Tags" : "Étiquettes",
+    "Loading …" : "Chargement...",
     "Your files" : "Vos fichiers",
     "Open in files" : "Ouvrir dans Fichiers",
     "File cannot be accessed" : "Impossible d'accéder au fichier",
@@ -295,6 +289,8 @@ OC.L10N.register(
     "Download" : "Télécharger",
     "The requested file is not available." : "Le fichier demandé n'est pas disponible.",
     "The requested files are not available." : "Les fichiers demandés ne sont pas disponibles.",
+    "Add to favorites" : "Ajouter aux favoris",
+    "Remove from favorites" : "Retirer des favoris",
     "Add or remove favorite" : "Ajouter ou supprimer un favoris",
     "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
@@ -313,6 +309,7 @@ OC.L10N.register(
     "Move" : "Déplacer",
     "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
     "Move or copy" : "Déplacer ou copier",
+    "Open folder" : "Ouvrir le dossier",
     "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
     "Open in Files" : "Ouvrir dans Fichiers",
     "Open locally" : "Ouvrir localement",
@@ -323,6 +320,7 @@ OC.L10N.register(
     "Open online" : "Ouvrir en ligne",
     "Rename" : "Renommer",
     "Details" : "Détails",
+    "Unfavorite" : "Retirer des favoris",
     "View in folder" : "Afficher dans le dossier",
     "Today" : "Aujourd’hui",
     "Last 7 days" : "7 derniers jours",
@@ -429,6 +427,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Naviguer vers le fichier à droite (en mode grille)",
     "Toggle the grid view" : "Activer/Désactiver la vue grille",
     "Open the sidebar for a file" : "Ouvrir la barre latérale pour un fichier",
+    "You" : "Vous",
+    "Shared multiple times with different people" : "Partagé plusieurs fois avec plusieurs personnes",
+    "Unable to change the favorite state of the file" : "Impossible de modifier l'état de mise en favori du fichier",
+    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
+    "Tags" : "Étiquettes",
     "Save as …" : "Enregistrer sous...",
     "Converting files …" : "Conversion des fichiers...",
     "Converting file …" : "Conversion du fichier...",
