@@ -164,6 +164,7 @@ OC.L10N.register(
     "Search here …" : "Search here …",
     "Search scope options" : "Search scope options",
     "Search here" : "Search here",
+    "Owner" : "Owner",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{used} of {quota} used" : "{used} of {quota} used",
     "{relative}% used" : "{relative}% used",
@@ -238,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "Go back" : "Go back",
     "Views" : "Views",
-    "You" : "You",
-    "Shared multiple times with different people" : "ແບ່ງປັນຫຼາຍຄັ້ງກັບຄົນຕ່າງກັນ",
-    "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
-    "Error while loading the file data" : "Error while loading the file data",
-    "Owner" : "Owner",
-    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
-    "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
-    "Tags" : "ປ້າຍກຳກັບ",
+    "Loading …" : "Loading …",
     "Your files" : "Your files",
     "Open in files" : "Open in files",
     "File cannot be accessed" : "File cannot be accessed",
@@ -295,6 +289,8 @@ OC.L10N.register(
     "Download" : "ດາວໂຫລດ",
     "The requested file is not available." : "The requested file is not available.",
     "The requested files are not available." : "The requested files are not available.",
+    "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
+    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
     "Add or remove favorite" : "Add or remove favorite",
     "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
@@ -313,6 +309,7 @@ OC.L10N.register(
     "Move" : "ຍ້າຍ",
     "Move or copy operation failed" : "Move or copy operation failed",
     "Move or copy" : "ຍ້າຍ ຫຼື ສຳເນົາ",
+    "Open folder" : "Open folder",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "ເປີດໃນ Files",
     "Open locally" : "Open locally",
@@ -429,6 +426,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
     "Toggle the grid view" : "Toggle the grid view",
     "Open the sidebar for a file" : "Open the sidebar for a file",
+    "You" : "You",
+    "Shared multiple times with different people" : "ແບ່ງປັນຫຼາຍຄັ້ງກັບຄົນຕ່າງກັນ",
+    "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
+    "Error while loading the file data" : "Error while loading the file data",
+    "Tags" : "ປ້າຍກຳກັບ",
     "Save as …" : "Save as …",
     "Converting files …" : "Converting files …",
     "Converting file …" : "Converting file …",
