@@ -48,11 +48,16 @@ OC.L10N.register(
     "Folder not found" : "Mappe ikke funnet",
     "The file cannot be found" : "Kunne ikke finne filen",
     "The destination path does not exist: %1$s" : "Fildestinasjonen finnes ikke: %1$s",
+    "You do not have permission to create a file at the specified location" : "Du har ikke tillattelse til å opprette en fil på denne plasseringen",
+    "The file could not be converted." : "Filen kunne ikke konverteres.",
     "Could not get relative path to converted file" : "Kunne ikke hente relativ sti til den konverterte filen",
+    "Limit must be a positive integer." : "Grensen må være et positivt heltall.",
+    "The replacement character may only be a single character." : "Erstattelsestegnet kan kun være et enkelt tegn.",
+    "Filename sanitization already started." : "Filnavnrensingen har allerede begynt.",
+    "No filename sanitization in progress." : "Ingen filnavnrensing pågår.",
     "Favorite files" : "Favorittfiler",
     "No favorites" : "Ingen favoritter",
     "More favorites" : "Flere favoritter",
-    "Upload (max. %s)" : "Opplasting (maks %s)",
     "Accept" : "Aksepter",
     "Reject" : "Avvis",
     "Incoming ownership transfer from {user}" : "Ny eierskapsoverføring fra {user}",
@@ -67,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
     "in %s" : "om %s",
     "Transferred from %1$s on %2$s" : "Overført fra %1$s på %2$s",
-    "Files compatibility" : "Kompatibilitet med filer",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
-    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
     "File Management" : "Filbehandling",
     "Home" : "Hjem",
     "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
@@ -78,6 +79,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Gå til \"{dir}\"-katalogen",
     "Current directory path" : "Gjeldende katalogsti",
     "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
+    "You do not have permission to upload or create files here." : "Du har ikke tillatelse til å laste opp eller opprette filer her.",
     "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
     "Favorite" : "Gjør til favoritt",
     "Back" : "Tilbake",
@@ -92,27 +94,71 @@ OC.L10N.register(
     "Invalid filename." : "Ugyldig filnavn.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
     "Rename file" : "Gi fil nytt navn",
+    "Folder" : "Mappe",
+    "Unknown file type" : "Ukjent filtype",
+    "{ext} image" : "{ext}-bilde",
+    "{ext} video" : "{ext}-video",
+    "{ext} audio" : "{ext}-lyd",
+    "{ext} text" : "{ext}-text",
     "Pending" : "Venter",
     "Unknown date" : "Ukjent dato",
     "Clear filter" : "Tøm filter",
     "Modified" : "Endret",
+    "Search everywhere" : "Søk overalt",
     "Type" : "Type",
     "Active filters" : "Aktivt filter",
     "Remove filter" : "Fjern filter",
+    "Appearance" : "Utseende",
+    "Show hidden files" : "Vis skjulte filer",
+    "Show file type column" : "Vis kolonne for filtype",
+    "Show file extensions" : "Vis filtyper",
+    "Crop image previews" : "Beskjær forhåndsvisninger av bilder",
+    "General" : "Generell",
+    "Sort favorites first" : "Sorter favoritter først",
+    "Sort folders before files" : "Sorter mapper før filer",
+    "Default view" : "Standardvisning",
+    "All files" : "Alle filer",
+    "Personal files" : "Personlige filer",
+    "Additional settings" : "Flere innstillinger",
+    "Actions" : "Handlinger",
+    "File actions" : "Filhandlinger",
+    "Selection" : "Valg",
+    "Select all files" : "Velg alle filer",
+    "Deselect all" : "Fjern all markering",
+    "Select or deselect" : "Velg eller fjern valg",
+    "Select a range" : "Velg område",
+    "Navigation" : "Navigasjon",
+    "Go to parent folder" : "Gå til overordnet mappe",
+    "Go to file above" : "Gå til filen ovenfor",
+    "Go to file below" : "Gå til filen nedenfor",
+    "Go left in grid" : "Gå til venstre i rutenettet",
+    "Go right in grid" : "Gå til høyre i rutenettet",
+    "View" : "Vis",
+    "Toggle grid view" : "Veksle rutenett-visning",
+    "Open file sidebar" : "Åpne sidepanelet for fil",
+    "Show those shortcuts" : "Vis hurtigtastene",
+    "Warnings" : "Advarsler",
+    "Warn before changing a file extension" : "Varsle før endring av filtype",
+    "WebDAV URL" : "WebDAV URL",
+    "How to access files using WebDAV" : "Hvordan få tilgang til filer med WebDAV",
     "Total rows summary" : "Sammendrag av totalrader",
     "Toggle selection for all files and folders" : "Veksle valg for alle filer og mapper",
     "Name" : "Navn",
+    "File type" : "Filtype",
     "Size" : "Størrelse",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
-    "Actions" : "Handlinger",
+    "{displayName}: failed on some elements" : "{displayName}: feilet på noen elementer",
+    "{displayName}: done" : "{displayName}: ferdig",
+    "{displayName}: failed" : "{displayName}: feilet",
     "(selected)" : "(valgt)",
     "List of files and folders." : "Liste over filer og mapper.",
     "You have used your space quota and cannot upload files anymore." : "Du har brukt opp lagringskvoten din og kan ikke laste opp flere filer.",
     "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper kan sorteres.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Filene gjengis når du navigerer gjennom listen.",
     "File not found" : "Finner ikke filen",
-    "{count} selected" : "{count} valgt",
+    "_{count} selected_::_{count} selected_" : ["{count} valgt","{count} valgt"],
+    "Search scope options" : "Alternativer for søkeomfang",
+    "Search here" : "Søk her",
+    "Owner" : "Eier",
     "{usedQuotaByte} used" : "{usedQuotaByte} brukt",
     "{used} of {quota} used" : "{used} av {quota} brukt",
     "{relative}% used" : "{relative}% brukt",
@@ -124,6 +170,24 @@ OC.L10N.register(
     "Create new folder" : "Opprett ny mappe",
     "This name is already in use." : "Navnet er allerede i bruk.",
     "Create" : "Opprett",
+    "Files starting with a dot are hidden by default" : "Filer som starter med punktum er som standard skjult",
+    "Failed to start filename sanitization." : "Kunne ikke starte filnavnrensing.",
+    "Failed to refresh filename sanitization status." : "Kunne ikke oppdatere status for filnavnrensing.",
+    "Filename sanitization in progress." : "Filnavnrensing pågår.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "For øyeblikket er {processedUsers} av {totalUsers} kontoer allerede behandlet.",
+    "Refresh" : "Oppdater",
+    "All files have been santized for Windows filename support." : "Alle filer har blitt renset for å støtte filnavn i Windows.",
+    "Some files could not be sanitized, please check your logs." : "Noen filer kunne ikke renses, vennligst sjekk loggene dine.",
+    "Sanitization errors" : "Rensefeil",
+    "Not sanitized filenames" : "Ikke-rensede filnavn",
+    "Windows filename support has been enabled." : "Støtte for Windows-filnavn er blitt aktivert.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Selv om dette blokkerer brukere fra å opprette nye filer med ustøttede filnavn, eksisterende filer er enda ikke omdøpt og kan derfor fortsatt føre til problemer med synkronisering på Windows. ",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Du kan sette i gang navnbytting av filer med ugyldige filnavn, denne vil bli gjort i bakgrunnen og kan ta noe tid.",
+    "Please note that this may cause high workload on the sync clients." : "Vær oppmerksom på at dette kan medføre høy arbeidsmengde på synkroniseringsklientene.",
+    "Limit" : "Grense",
+    "This allows to configure how many users should be processed in one background job run." : "Dette bestemmer hvor mange brukere kan bli behandlet i én bakgrunnsjobb.",
+    "Sanitize filenames" : "Rens filnavn",
+    "(starting)" : "(starter)",
     "Fill template fields" : "Fyll ut malfelt",
     "Submit" : "Send inn",
     "Choose a file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
@@ -137,82 +201,60 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
     "Change" : "Endre",
     "New owner" : "Ny eier",
+    "Keep {old}" : "Behold {old}",
+    "Keep without extension" : "Behold uten filtype",
+    "Use {new}" : "Bruk {new}",
     "Remove extension" : "Fjern filendelse",
     "Change file extension" : "Endre filendelse",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Å endre filendelsen fra «{old}» til «{new}» kan føre til at filen ikke kan leses.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
+    "Do not show this dialog again." : "Ikke vis denne dialogen igjen.",
     "Select file or folder to link to" : "Velg fil eller mappe å koble til",
     "Choose {file}" : "Choose {file}",
+    "Files settings" : "Filinnstillinger",
     "Share" : "Del med andre",
     "Shared by link" : "Delt med lenke",
     "Shared" : "Delt",
     "Switch to list view" : "Bytt til listevisning",
     "Switch to grid view" : "Bytt til rutevisning",
+    "The file could not be found" : "Kunne ikke finne filen",
     "Upload was cancelled by user" : "Opplasting ble avbrutt av bruker",
     "Not enough free space" : "Ikke nok ledig diskplass",
     "Operation is blocked by access control" : "Operasjonen er blokkert på grunn av tilgangskontroll",
     "Error during upload: {message}" : "Feil under opplasting: {message}",
     "Error during upload, status code {status}" : "Feil under opplasting, statuskode {status}",
     "Unknown error during upload" : "Ukjent feil under opplasting",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
     "Loading current folder" : "Laster gjeldende mappe",
     "Retry" : "Prøv igjen",
     "No files in here" : "Ingen filer",
     "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
     "Go back" : "Gå tilbake",
     "Views" : "Visninger",
-    "Files settings" : "Filinnstillinger",
     "Your files" : "Dine filer",
     "Open in files" : "Åpne i filer",
     "File cannot be accessed" : "Filen er ikke tilgjengelig",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen ble ikke funnet, eller du har ikke tillatelse til å vise den. Be avsenderen om å dele den.",
-    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
-    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
-    "Sort favorites first" : "Sorter favoritter først",
-    "Sort folders before files" : "Sorter mapper før filer",
-    "Show hidden files" : "Vis skjulte filer",
-    "Crop image previews" : "Beskjær forhåndsvisninger av bilder",
-    "Enable the grid view" : "Aktiver rutenettvisningen",
-    "Enable folder tree" : "Aktiver mappetre",
-    "Additional settings" : "Flere innstillinger",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Kopiert til utklippstavlen",
-    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
-    "Keyboard shortcuts" : "Tastatursnarveier",
-    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
-    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
-    "Rename a file" : "Gi nytt navn til en fil",
-    "Delete a file" : "Slett en fil",
-    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
-    "Manage tags for a file" : "Behandle merkelapper for en fil",
-    "Selection" : "Valg",
-    "Select all files" : "Velg alle filer",
-    "Deselect all files" : "Velg ingen filer",
-    "Navigation" : "Navigasjon",
-    "Navigate to the parent folder" : "Gå til overordnet mappe",
-    "Navigate to the file above" : "Gå til filen over",
-    "Navigate to the file below" : "Gå til filen under",
-    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
-    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
-    "View" : "Vis",
-    "Toggle the grid view" : "Slå på/av rutenettvisning",
-    "Show those shortcuts" : "Vis hurtigtastene",
-    "You" : "Du",
-    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
-    "Error while loading the file data" : "Feil ved lasting av fildata",
-    "Owner" : "Eier",
-    "Remove from favorites" : "Fjern fra favoritter",
-    "Add to favorites" : "Legg til i favoritter",
-    "Tags" : "Merkelapper",
+    "No search results for “{query}”" : "Ingen søkeresultater for \"{query}\"",
+    "Search for files" : "Søk etter filer",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
+    "Files compatibility" : "Kompatibilitet med filer",
+    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
     "Pick a template for {name}" : "Velg en mal for {name}",
     "Create a new file with the selected template" : "Opprett en ny fil med den valgte malen",
     "Creating file" : "Oppretter fil",
-    "Deletion cancelled" : "Sletting avbrutt",
+    "Save as {displayName}" : "Lagre som {displayName}",
+    "Failed to convert files: {message}" : "Kunne ikke konvertere filer: {message}",
+    "All files failed to be converted" : "Kunne ikke konvertere noen av filene",
+    "One file could not be converted: {message}" : "Én fil kunne ikke konverteres: {message}",
+    "Failed to convert files" : "Kunne ikke konvertere filene",
+    "File successfully converted" : "Filen ble konvertert",
+    "Failed to convert file: {message}" : "Kunne ikke konvertere filen: {message}",
+    "Failed to convert file" : "Kunne ikke konvertere filen",
+    "Delete" : "Slett",
     "Leave this share" : "Forlat denne delingen",
     "Leave these shares" : "Forlat disse delingene",
     "Disconnect storage" : "Koble fra lager",
@@ -223,17 +265,21 @@ OC.L10N.register(
     "Delete files" : "Slett filer",
     "Delete folder" : "Slett mappe",
     "Delete folders" : "Slett mapper",
-    "Delete" : "Slett",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er i ferd med å slette permanent {count} element","Du er i ferd med å slette permanent {count} elementer"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er i ferd med å slette {count} element","Du er i ferd med å slette {count} elementer"],
     "Confirm deletion" : "Bekreft sletting",
     "Cancel" : "Avbryt",
-    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Download" : "Last ned",
+    "The requested file is not available." : "Den forespurte filen er ikke tilgjengelig.",
+    "The requested files are not available." : "De forespurte filene er ikke tilgjengelige.",
+    "Add to favorites" : "Legg til i favoritter",
+    "Remove from favorites" : "Fjern fra favoritter",
+    "Add or remove favorite" : "Legg til eller fjern som favoritt",
+    "Destination is not a folder" : "Målplassering er ikke en mappe",
+    "This file/folder is already in that directory" : "Denne filen/mappen er allerede i den katalogen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe til seg selv eller til en undermappe av seg selv",
     "(copy)" : "(kopier)",
     "(copy %n)" : "(kopier %n)",
-    "Move cancelled" : "Flytt avbrutt",
     "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navnet finnes allerede i denne mappen",
     "The files are locked" : "Filene er låst",
     "The file does not exist anymore" : "Filen finnes ikke lenger",
@@ -244,17 +290,17 @@ OC.L10N.register(
     "Move" : "Flytt",
     "Move or copy operation failed" : "Flytte- eller kopieringsoperason feilet",
     "Move or copy" : "Flytt eller kopier",
-    "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
-    "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
+    "Open folder" : "Åpne mappe",
     "Open folder {displayName}" : "Åpne mappe {displayName}",
     "Open in Files" : "Åpne i Filer",
+    "Open locally" : "Åpne lokalt",
+    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
     "Open file locally" : "Åpne fil lokalt",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
     "Retry and close" : "Prøv igjen og lukk",
-    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
-    "Open locally" : "Åpne lokalt",
+    "Open online" : "Åpne på nett",
     "Rename" : "Gi nytt navn",
-    "Open details" : "Åpne detaljer",
+    "Details" : "Detaljer",
     "View in folder" : "Vis i mappe",
     "Today" : "I dag",
     "Last 7 days" : "Siste 7 dager",
@@ -267,15 +313,15 @@ OC.L10N.register(
     "PDFs" : "PDFer",
     "Folders" : "Mapper",
     "Audio" : "Lyd",
-    "Photos and images" : "Fotoer og bilder",
+    "Images" : "Bilder",
     "Videos" : "Filmer",
-    "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
     "Created new folder \"{name}\"" : "Opprettet ny mappe \"{name}\"",
     "Unable to initialize the templates directory" : "Kan ikke initialisere mal-mappen",
     "Create templates folder" : "Opprett malmappe",
     "Templates" : "Maler",
     "New template folder" : "Ny malermappe",
     "In folder" : "I mappen",
+    "Search in all files" : "Søk i alle filer",
     "Search in folder: {folder}" : "Søk i mappen: {folder}",
     "One of the dropped files could not be processed" : "En av de slupne filene kunne ikke behandles",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Nettleseren din støtter ikke Filesystem API. Kataloger vil ikke bli lastet opp.",
@@ -290,15 +336,16 @@ OC.L10N.register(
     "Files moved successfully" : "Filer ble flyttet",
     "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
     "Upload cancelled" : "Opplasting avbrutt",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
+    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
     "This operation is forbidden" : "Operasjonen er forbudt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
+    "This folder is unavailable, please try again later or contact the administration" : "Denne mappen er utilgjengelig, vennligst prøv igjen senere eller kontakt administrasjonen",
     "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "Unexpected error: {error}" : "Uventet feil: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mappe","1 fil og {folderCount} mapper"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mappe","{fileCount} filer og 1 mappe"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
+    "_%n file_::_%n files_" : ["%n fil","%n filer"],
+    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
+    "_%n hidden_::_%n hidden_" : ["%n skjult","%n skjult"],
     "Filename must not be empty." : "Filnavn kan ikke være tomt.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tillatt i et filnavn.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reservert navn og ikke tillatt for filnavn.",
@@ -307,10 +354,8 @@ OC.L10N.register(
     "List of favorite files and folders." : "Liste over favorittfiler og mapper.",
     "No favorites yet" : "Ingen favoritter enda",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
-    "All files" : "Alle filer",
     "List of your files and folders." : "Liste over dine filer og mapper.",
-    "All folders" : "Alle mapper",
-    "Personal files" : "Personlige filer",
+    "Folder tree" : "Mappetre",
     "List of your files and folders that are not shared." : "Liste over dine filer og mapper som ikke er delt.",
     "No personal files found" : "Ingen personlige filer funnet",
     "Files that are not shared will show up here." : "Filer som ikke er delt vil vises her.",
@@ -318,108 +363,69 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liste over nylig endrede filer og mapper.",
     "No recently modified files" : "Ingen nylig endrede filer",
     "Files and folders you recently modified will show up here." : "Filer og mapper du nylig har endret, vises her.",
+    "Search" : "Søk",
+    "Search results within your files." : "Søkeresultater innenfor dine filer.",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Select all" : "Velg alle",
     "Upload too large" : "Filen er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
-    "File could not be found" : "Filen ble ikke funnet",
-    "Download" : "Last ned",
-    "Show list view" : "Vis listevisning",
-    "Show grid view" : "Vis rutenett-visning",
-    "Close" : "Lukk",
-    "Could not create folder \"{dir}\"" : "Kunne ikke å opprette mappe \"{dir}\"",
-    "This will stop your current uploads." : "Dette vil stoppe dine nåværende opplastinger.",
-    "Upload cancelled." : "Opplasting avbrutt.",
-    "Processing files …" : "Prosesserer filer…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
-    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
-    "An unknown error has occurred" : "En ukjent feil oppsto",
-    "File could not be uploaded" : "Fil kunne ikke lastes opp",
-    "Uploading …" : "Laster opp…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Laster opp... ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Opplastning av det elementet er ikke støttet",
-    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
-    "Choose target folder" : "Velg målmappe",
-    "Set reminder" : "Angi påminnelse",
+    "%1$s (renamed)" : "%1$s (har fått nytt navn)",
+    "Upload (max. %s)" : "Opplasting (maks %s)",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det er også mulig å migrere filer automatisk etter at denne innstillingen er aktivert, se dokumentasjonen for occ-kommandoen.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" feilet på noen elementer",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
+    "Submitting fields …" : "Sender inn felt ...",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
+    "Filter file names …" : "Filtrer filnavn ...",
+    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
+    "Enable the grid view" : "Aktiver rutenettvisningen",
+    "Enable folder tree" : "Aktiver mappetre",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopiert til utklippstavlen",
+    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
+    "Show a warning dialog when changing a file extension." : "Vis en varslingsdialog ved endring av filtype.",
+    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
+    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
+    "Rename a file" : "Gi nytt navn til en fil",
+    "Delete a file" : "Slett en fil",
+    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
+    "Manage tags for a file" : "Behandle merkelapper for en fil",
+    "Deselect all files" : "Velg ingen filer",
+    "Select or deselect a file" : "Velg eller fjern valget av en fil",
+    "Select a range of files" : "Velg et utvalg av filer",
+    "Navigate to the parent folder" : "Gå til overordnet mappe",
+    "Navigate to the file above" : "Gå til filen over",
+    "Navigate to the file below" : "Gå til filen under",
+    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
+    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
+    "Toggle the grid view" : "Slå på/av rutenettvisning",
+    "Open the sidebar for a file" : "Åpne sidepanelet for en fil",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
+    "Unable to change the favorite state of the file" : "Kunne ikke endre filens favorittilstand",
+    "Error while loading the file data" : "Feil ved lasting av fildata",
+    "Tags" : "Merkelapper",
+    "Save as …" : "Lagre som ...",
+    "Converting files …" : "Konverter filer ...",
+    "Converting file …" : "Konverterer filer ...",
+    "Deletion cancelled" : "Sletting avbrutt",
     "Edit locally" : "Rediger lokalt",
-    "Open" : "Åpne",
-    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
-    "Details" : "Detaljer",
-    "Please select tag(s) to add to the selection" : "Velg merkelapper(er) for å legge til utvalget",
-    "Apply tag(s) to selection" : "Bruk merkelapp(er) på utvalget",
-    "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
-    "Unable to determine date" : "Kan ikke fastslå datoen",
-    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
-    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
-    "copy" : "kopier",
-    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
-    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
-    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
-    "{newName} already exists" : "{newName} finnes allerede",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
-    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
-    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
-    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
-    "Could not fetch file details \"{file}\"" : "Kunne ikke hente fildetaljene \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Tast inn mer enn to tegn for å lete i andre mapper",
-    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
-    "_%n file_::_%n files_" : ["%n fil","%n filer"],
-    "{dirs} and {files}" : "{dirs} og {files}",
-    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
-    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
-    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
-    "New" : "Ny",
-    "New file/folder menu" : "Ny fil/mappe-meny",
-    "Select file range" : "Velg filutvalg",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} brukt",
-    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
-    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
-    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen av {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ekstern lagring \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Lagringen din er full, filer kan ikke oppdateres eller synkroniseres lenger!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Treffer \"{filter}\"","Treff \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
-    "Path" : "Sti",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Favorisert",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
-    "Upload file" : "Last opp fil",
-    "Not favorited" : "Ikke i favoritter",
-    "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
-    "Storage informations" : "Informasjon om lagring",
-    "Choose file" : "Velg fil",
-    "Go to the previous folder" : "Gå fil forrige mappe",
-    "Open the files app settings" : "Åpne Filer-appens innstillinger",
-    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
-    "Edit file locally" : "Rediger fil lokalt",
-    "Edit online" : "Rediger på nett",
-    "Create new templates folder" : "Opprett ny malermappe",
-    "List of favorites files and folders." : "Liste over favorittfiler og -mapper.",
-    "Personal Files" : "Personlige filer",
-    "Text file" : "Tekstfil",
-    "New text file.txt" : "Ny tekstfil.txt",
-    "Favored" : "Favorittlagt",
-    "Favor" : "Favoritt",
-    "Not favored" : "Ikke favorittlagt",
-    "Submitting fields…" : "Sender inn felt...",
-    "Filter filenames…" : "Filtrer filnavn..."
+    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Move cancelled" : "Flytt avbrutt",
+    "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
+    "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
+    "Open details" : "Åpne detaljer",
+    "Photos and images" : "Fotoer og bilder",
+    "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
+    "All folders" : "Alle mapper",
+    "Search everywhere …" : "Søk overalt ...",
+    "Search here …" : "Søk her ...",
+    "Preparing …" : "Forbereder ..."
 },
 "nplurals=2; plural=(n != 1);");
