@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Nemáte oprávnenie vytvoriť súbor v zadanom umiestnení",
     "The file could not be converted." : "Súbor nemohol byť skonvertovaný.",
     "Could not get relative path to converted file" : "Nepodarilo sa získať relatícnu cestu ku skonvertovanému súboru",
+    "Limit must be a positive integer." : "Limit musí byť kladné celé číslo.",
+    "The replacement character may only be a single character." : "Zástupný znak môže byť iba jeden znak.",
+    "Filename sanitization already started." : "Sanitizácia názvu súboru bola už zahájená.",
+    "No filename sanitization in progress." : "Žiadna sanitácia názvu súboru neprebieha.",
     "Favorite files" : "Obľúbené súbory",
     "No favorites" : "Žiadne obľúbené",
     "More favorites" : "Viac obľúbených",
@@ -91,6 +95,11 @@ OC.L10N.register(
     "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
     "Rename file" : "Premenovať súbor",
     "Folder" : "Priečinok",
+    "Unknown file type" : "Neznámy typ súboru",
+    "{ext} image" : "{ext} obrázok",
+    "{ext} video" : "{ext} video",
+    "{ext} audio" : "{ext} zvuk",
+    "{ext} text" : "{ext} text",
     "Pending" : "Čaká",
     "Unknown date" : "Neznámy dátum",
     "Clear filter" : "Vyčistiť filter",
@@ -101,10 +110,14 @@ OC.L10N.register(
     "Remove filter" : "Odstrániť filter",
     "Appearance" : "Vzhľad",
     "Show hidden files" : "Zobraziť skryté súbory",
+    "Show file type column" : "Zobraziť stĺpec typu súboru",
+    "Show file extensions" : "Zobraziť prípony súborov",
     "Crop image previews" : "Orezať náhľady obrázkov",
     "General" : "Všeobecné",
     "Sort favorites first" : "Zoradiť od najobľúbenejších",
     "Sort folders before files" : "Zoradiť adresáre pred súbormi",
+    "Enable folder tree view" : "Povoliť zobrazenie stromu priečinkov",
+    "Default view" : "Predvolené zobrazenie",
     "All files" : "Všetky súbory",
     "Personal files" : "Osobné súbory",
     "Additional settings" : "Ďalšie nastavenia",
@@ -113,16 +126,33 @@ OC.L10N.register(
     "Selection" : "Výber",
     "Select all files" : "Vybrať všetky súbory",
     "Deselect all" : "Odznačiť všetko",
+    "Select or deselect" : "Vybrať alebo zrušiť výber",
+    "Select a range" : "Vybrať rozsah",
     "Navigation" : "Navigácia",
+    "Go to parent folder" : "Prejsť do nadriadeného priečinka",
+    "Go to file above" : "Prejsť na súbor vyššie",
+    "Go to file below" : "Prejsť na súbor nižšie",
+    "Go left in grid" : "Prejsť doľava v mriežke",
+    "Go right in grid" : "Prejsť doprava v mriežke",
     "View" : "Zobraziť",
     "Toggle grid view" : "Prepnúť zobrazenie mriežky",
+    "Open file sidebar" : "Otvoriť bočný panel súboru",
     "Show those shortcuts" : "Zobraziť klávesové skratky",
     "Warnings" : "Upozornenia",
+    "Warn before changing a file extension" : "Upozorniť pred zmenou prípony súboru",
+    "Warn before deleting a file" : "Upozorniť pred vymazaním súboru",
     "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "Vytvoriť heslo pre aplikáciu",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Vyžaduje sa pre autentifikáciu WebDAV, pretože pre tento účet je povolená dvojfaktorová autentifikácia.",
+    "How to access files using WebDAV" : "Ako získať prístup k súborom pomocou WebDAV",
     "Total rows summary" : "Súčet všetkých riadkov",
     "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
     "Name" : "Názov",
+    "File type" : "Typ súboru",
     "Size" : "Veľkosť",
+    "{displayName}: failed on some elements" : "{displayName}: zlyhalo na niektorých prvkoch",
+    "{displayName}: done" : "{displayName}: hotovo",
+    "{displayName}: failed" : "{displayName}: zlyhalo",
     "(selected)" : "(vybrané)",
     "List of files and folders." : "Zoznam súborov a priečinkov.",
     "You have used your space quota and cannot upload files anymore." : "Už ste využili kapacitu úložného priestoru a nie je možné nahrávať ďalšie súbory.",
@@ -130,6 +160,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
     "File not found" : "Súbor nenájdený",
     "_{count} selected_::_{count} selected_" : ["{count} vybraný","{count} vybrané","{count} vybraných","{count} vybraných"],
+    "Search everywhere …" : "Hľadať všade ...",
+    "Search here …" : "Hľadať tu …",
+    "Search scope options" : "Možnosti rozsahu vyhľadávania",
+    "Search here" : "Hľadať tu",
+    "Owner" : "Vlastník",
     "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
     "{used} of {quota} used" : "použitých {used} z {quota}",
     "{relative}% used" : "{relative}% použitých",
@@ -141,9 +176,27 @@ OC.L10N.register(
     "Create new folder" : "Vytvoriť nový priečinok",
     "This name is already in use." : "Toto meno je už používané.",
     "Create" : "Vytvoriť",
+    "Files starting with a dot are hidden by default" : "Súbory, ktoré začínajú bodkou, sú predvolene skryté.",
+    "Failed to start filename sanitization." : "Nezískalo sa spustenie sanitizácie názvu súboru.",
+    "Failed to refresh filename sanitization status." : "Nepodarilo sa obnoviť stav sanitácie názvu súboru.",
+    "Filename sanitization in progress." : "Prebieha sanitácia názvu súboru.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Aktuálne je spracovaných {processedUsers} z {totalUsers} účtov.",
+    "Preparing …" : "Pripravuje sa …",
     "Refresh" : "Obnoviť",
+    "All files have been santized for Windows filename support." : "Všetky súbory boli upravené na podporu názvov súborov vo Windows.",
+    "Some files could not be sanitized, please check your logs." : "Niektoré súbory nebolo možné upravené, prosím, skontrolujte svoje protokoly.",
+    "Sanitization errors" : "Chyby v sanitizácii",
+    "Not sanitized filenames" : "Nezabezpečené názvy súborov",
+    "Windows filename support has been enabled." : "Podpora názvov súborov vo Windows bola povolená.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Kým toto blokuje používateľov v tvorbe nových súborov s nepodporovanými názvami, existujúce súbory ešte neboli premenované a teda môžu stále spôsobiť problémy so synchronizáciou na Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Môžete spustiť premenovanie súborov s neplatnými názvami, tento proces sa vykoná na pozadí a môže trvať nejaký čas.",
+    "Please note that this may cause high workload on the sync clients." : "Upozorňujeme, že to môže spôsobiť vysokú záťaž pre klientov synchronizácie.",
     "Limit" : "Limit",
+    "This allows to configure how many users should be processed in one background job run." : "Toto umožňuje nastaviť, koľko používateľov by malo byť spracovaných v jednom spustení úlohy na pozadí.",
+    "Sanitize filenames" : "Vyčistiť názvy súborov",
+    "(starting)" : "(začína sa)",
     "Fill template fields" : "Vyplňte položky šablóny",
+    "Submitting fields …" : "Odosielanie polí …",
     "Submit" : "Odoslať",
     "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
     "Transfer" : "Prevod",
@@ -186,19 +239,16 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
     "Go back" : "Ísť späť",
     "Views" : "Zobrazenia",
-    "You" : "Vy",
-    "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
-    "Unable to change the favorite state of the file" : "Nie je možné zmeniť stav „obľúbené“ súboru",
-    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
-    "Owner" : "Vlastník",
-    "Remove from favorites" : "Odstrániť z obľúbených",
-    "Add to favorites" : "Pridať do obľúbených",
-    "Tags" : "Štítky",
+    "Loading …" : "Načítava sa …",
     "Your files" : "Vaše súbory",
     "Open in files" : "Otvoriť v súboroch",
     "File cannot be accessed" : "Súbor nie je možné sprístupniť",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Súbor sa nenašiel alebo nemáte oprávnenie na jeho zobrazenie. Požiadajte odosielateľa, aby ho sprístupnil.",
+    "No search results for “{query}”" : "Žiadne výsledky vyhľadávania pre „{query}“",
+    "Search for files" : "Vyhľadať súbory",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po povolení kompatibilných názvov súborov pre Windows už nie je možné upravovať existujúce súbory, ale ich vlastník ich môže premenovať na platné nové názvy.",
+    "Failed to toggle Windows filename support" : "Nepodarilo sa prepnúť podporu názvov súborov systému Windows",
     "Files compatibility" : "Kompatibilita súborov",
     "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
@@ -208,10 +258,16 @@ OC.L10N.register(
     "Create a new file with the selected template" : "Vytvoriť nový súbor pomocou vybranej šablóny",
     "Creating file" : "Vytvára sa súbor",
     "Save as {displayName}" : "Uložiť ako {displayName}",
+    "Save as …" : "Uložiť ako ...",
+    "Converting files …" : "Konverzia súborov ...",
     "Failed to convert files: {message}" : "Nepodarilo sa skonvertovať súbory: {message}",
     "All files failed to be converted" : "Nepodarilo sa skonvertovať žiadne súbory",
     "One file could not be converted: {message}" : "Jeden súbor sa nepodarilo skonvertovať: {message}",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n súbor sa nepodarilo skonvertovať","%n súbory sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať"],
+    "_%n file converted_::_%n files converted_" : ["%n prevedený súbor","%n prevedených súborov","%n prevedených súborov","%n prevedené súbory"],
+    "Files converted" : "Súbory boli konvertované",
     "Failed to convert files" : "Konverzia súborov zlyhala",
+    "Converting file …" : "Konverzia súborov ...",
     "File successfully converted" : "Súbor bol úspešne skonvertovaný",
     "Failed to convert file: {message}" : "Nepodarilo sa skonvertovať súbor: {message}",
     "Failed to convert file" : "Konverzia súboru zlyhala",
@@ -231,6 +287,13 @@ OC.L10N.register(
     "Confirm deletion" : "Potvrdiť vymazanie",
     "Cancel" : "Zrušiť",
     "Download" : "Stiahnuť",
+    "The requested file is not available." : "Požadovaný súbor nie je k dispozícii.",
+    "The requested files are not available." : "Požadované súbory nie sú k dispozícii.",
+    "Add to favorites" : "Pridať do obľúbených",
+    "Remove from favorites" : "Odstrániť z obľúbených",
+    "Add or remove favorite" : "Pridať alebo odstrániť obľúbené",
+    "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
     "Destination is not a folder" : "Cieľ nie je priečinok",
     "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
@@ -246,6 +309,7 @@ OC.L10N.register(
     "Move" : "Presunúť",
     "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
     "Move or copy" : "Presunúť alebo kopírovať",
+    "Open folder" : "Otvoriť priečinok",
     "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
     "Open in Files" : "Otvoriť v súboroch",
     "Open locally" : "Otvoriť lokálne",
@@ -276,6 +340,7 @@ OC.L10N.register(
     "Templates" : "Šablóny",
     "New template folder" : "Nový adresár šablóny",
     "In folder" : "V adresári",
+    "Search in all files" : "Hľadať vo všetkých súboroch",
     "Search in folder: {folder}" : "Hľadať v adresári: {folder}",
     "One of the dropped files could not be processed" : "Jeden z vložených súborov nemohol byť spracovaný.",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Váš prehliadač nepodporuje Filesystem API. Adresáre nebudú nahrané",
@@ -294,10 +359,12 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
     "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
     "This operation is forbidden" : "Táto operácia je zakázaná",
+    "This folder is unavailable, please try again later or contact the administration" : "Táto zložka nie je k dispozícii, skúste to prosím neskôr alebo kontaktujte správu.",
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Unexpected error: {error}" : "Neočakávaná chyba: {error}",
     "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
     "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
+    "_%n hidden_::_%n hidden_" : ["%n skrytý","%n skrytých","%n skrytých","%n sktyré"],
     "Filename must not be empty." : "Názov súboru nesmie byť prázdny.",
     "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" nie je povolený v názve súboru.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervované slovo a nie je možné ho použiť v názvoch súborov.",
@@ -307,6 +374,7 @@ OC.L10N.register(
     "No favorites yet" : "Zatiaľ žiadne obľúbené",
     "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
     "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
+    "Folder tree" : "Strom priečinkov",
     "List of your files and folders that are not shared." : "Zoznam vašich súborov a priečinkov, ktoré nie sú zdieľané.",
     "No personal files found" : "Žiadne osobné súbory nenájdené",
     "Files that are not shared will show up here." : "Súbory, ktoré nie sú zdieľané, sa tu nezobrazia.",
@@ -315,11 +383,16 @@ OC.L10N.register(
     "No recently modified files" : "Žiadne nedávno upravené súbory",
     "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
     "Search" : "Hľadať",
+    "Search results within your files." : "Výsledky vyhľadávania vo vašich súboroch.",
     "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
     "Select all" : "Vybrať všetko",
     "Upload too large" : "Nahrávanie je príliš veľké",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
+    "%1$s (renamed)" : "%1$s (premenovaný)",
+    "renamed file" : "premenovaný súbor",
     "Upload (max. %s)" : "Nahrať (max. %s)",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po povolení názvov súborov kompatibilných s Windows už nie je možné upravovať existujúce súbory, ale ich vlastník ich môže premenovať na platné nové názvy.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Je tiež možné automaticky migrovať súbory po povolení tohto nastavenia, prosím, prečítajte si dokumentáciu o príkaze occ.",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
     "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
     "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
@@ -353,6 +426,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Navigovať na súbor vpravo (v režime zobrazenia v mriežke)",
     "Toggle the grid view" : "Prepnúť na zobrazenie v mriežke",
     "Open the sidebar for a file" : "Otvoriť bočný panel pre súbor",
+    "You" : "Vy",
+    "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
+    "Unable to change the favorite state of the file" : "Nie je možné zmeniť stav „obľúbené“ súboru",
+    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
+    "Tags" : "Štítky",
     "Save as …" : "Uložiť ako ...",
     "Converting files …" : "Konverzia súborov ...",
     "Converting file …" : "Konverzia súborov ...",
@@ -367,6 +445,9 @@ OC.L10N.register(
     "Photos and images" : "Fotky a obrázky",
     "New folder creation cancelled" : "Vytvorenie adresára bolo zrušené",
     "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
-    "All folders" : "Všetky adresáre"
+    "All folders" : "Všetky adresáre",
+    "Search everywhere …" : "Hľadať všade ...",
+    "Search here …" : "Hľadať tu …",
+    "Preparing …" : "Pripravuje sa …"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
