@@ -160,6 +160,7 @@ OC.L10N.register(
     "Search here …" : "Претражи овде …",
     "Search scope options" : "Опције опсега претраге",
     "Search here" : "Претражи овде",
+    "Owner" : "Власник",
     "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
     "{used} of {quota} used" : "{used} од {quota} искоришћено",
     "{relative}% used" : "{relative}% искоришћено",
@@ -234,14 +235,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
     "Go back" : "Иди назад",
     "Views" : "Прикази",
-    "You" : "Ви",
-    "Shared multiple times with different people" : "Дељено више пута са разним људима",
-    "Unable to change the favorite state of the file" : "Није успела измена стања омиљено за фајл",
-    "Error while loading the file data" : "Грешка при учитавању података фајла",
-    "Owner" : "Власник",
-    "Remove from favorites" : "Избаци из омиљених",
-    "Add to favorites" : "Додај у омиљене",
-    "Tags" : "Ознаке",
+    "Loading …" : "Учитава се…",
     "Your files" : "Ваши фајлови",
     "Open in files" : "Отвори у фајловима",
     "File cannot be accessed" : "Фајлу не може да се приступи",
@@ -291,6 +285,8 @@ OC.L10N.register(
     "Download" : "Преузми",
     "The requested file is not available." : "Тражени фајл није доступан.",
     "The requested files are not available." : "Тражени фајлови нису доступни.",
+    "Add to favorites" : "Додај у омиљене",
+    "Remove from favorites" : "Избаци из омиљених",
     "Add or remove favorite" : "Додај или уклони омиљене",
     "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}” …",
     "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}” …",
@@ -309,6 +305,7 @@ OC.L10N.register(
     "Move" : "Помери",
     "Move or copy operation failed" : "Није успела операција премештања или копирања",
     "Move or copy" : "Помери или копирај",
+    "Open folder" : "Отвори фасциклу",
     "Open folder {displayName}" : "Отвори фолдер {displayName}",
     "Open in Files" : "Отвори у Фајловима",
     "Open locally" : "Отвори локално",
@@ -319,6 +316,7 @@ OC.L10N.register(
     "Open online" : "Отвори на мрежи",
     "Rename" : "Преименуј",
     "Details" : "Детаљи",
+    "Unfavorite" : "Није омиљено",
     "View in folder" : "Види у фасцикли",
     "Today" : "Данас",
     "Last 7 days" : "Последњих 7 дана",
@@ -425,6 +423,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Пређи на фајл са десне стране (у режиму мреже)",
     "Toggle the grid view" : "Укључи/искључи приказ мреже",
     "Open the sidebar for a file" : "Отвори у бочни панел за фајл",
+    "You" : "Ви",
+    "Shared multiple times with different people" : "Дељено више пута са разним људима",
+    "Unable to change the favorite state of the file" : "Није успела измена стања омиљено за фајл",
+    "Error while loading the file data" : "Грешка при учитавању података фајла",
+    "Tags" : "Ознаке",
     "Save as …" : "Сачувај као",
     "Converting files …" : "Фајлови се конвертују",
     "Converting file …" : "Фајл се конвертује",
