@@ -164,6 +164,7 @@ OC.L10N.register(
     "Search here …" : "Burada ara…",
     "Search scope options" : "Arama kapsamı seçenekleri",
     "Search here" : "Burada ara",
+    "Owner" : "Sahibi",
     "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
     "{used} of {quota} used" : "{used} / {quota} kullanılmış",
     "{relative}% used" : "%{relative} kullanılmış",
@@ -238,14 +239,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
     "Go back" : "Geri dön",
     "Views" : "Görünümler",
-    "You" : "Siz",
-    "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
-    "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
-    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
-    "Owner" : "Sahibi",
-    "Remove from favorites" : "Sık kullanılanlardan kaldır",
-    "Add to favorites" : "Sık kullanılanlara ekle",
-    "Tags" : "Etiketler",
+    "Loading …" : "Yükleniyor…",
     "Your files" : "Dosyalarınız",
     "Open in files" : "Dosyalar uygulamasında aç",
     "File cannot be accessed" : "Dosyaya erişilemedi",
@@ -295,6 +289,8 @@ OC.L10N.register(
     "Download" : "İndir",
     "The requested file is not available." : "İstenilen dosya kullanılamıyor.",
     "The requested files are not available." : "İstenilen dosyalar kullanılamıyor.",
+    "Add to favorites" : "Sık kullanılanlara ekle",
+    "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
@@ -313,6 +309,7 @@ OC.L10N.register(
     "Move" : "Taşı",
     "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
     "Move or copy" : "Taşı ya da kopyala",
+    "Open folder" : "Klasörü aç",
     "Open folder {displayName}" : "{displayName} klasörünü aç",
     "Open in Files" : "Dosyalar uygulamasında aç",
     "Open locally" : "Yerel olarak aç",
@@ -323,6 +320,7 @@ OC.L10N.register(
     "Open online" : "Çevrim içi aç",
     "Rename" : "Yeniden adlandır",
     "Details" : "Ayrıntılar",
+    "Unfavorite" : "Sık kullanılanlardan kaldır",
     "View in folder" : "Klasörde görüntüle",
     "Today" : "Bugün",
     "Last 7 days" : "Önceki 7 gün",
@@ -429,6 +427,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Sağdaki dosyaya gider (ızgara görünümünde)",
     "Toggle the grid view" : "Izgara görünümünü açar ya da kapatır",
     "Open the sidebar for a file" : "Bir dosyanın kenar çubuğunu açar",
+    "You" : "Siz",
+    "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
+    "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
+    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
+    "Tags" : "Etiketler",
     "Save as …" : "Farklı kaydet…",
     "Converting files …" : "Dosyalar dönüştürülüyor…",
     "Converting file …" : "Dosya dönüştürülüyor…",
