@@ -108,6 +108,43 @@ OC.L10N.register(
     "Type" : "類型",
     "Active filters" : "作用中的過濾條件",
     "Remove filter" : "移除過濾條件",
+    "Appearance" : "外觀",
+    "Show hidden files" : "顯示隱藏檔",
+    "Show file type column" : "顯示檔案類型欄位",
+    "Show file extensions" : "顯示副檔名",
+    "Crop image previews" : "圖片裁剪預覽",
+    "General" : "一般",
+    "Sort favorites first" : "先排序喜愛",
+    "Sort folders before files" : "將資料夾排序在檔案前",
+    "Enable folder tree view" : "啟用資料夾樹狀檢視",
+    "Default view" : "預設檢視",
+    "All files" : "所有檔案",
+    "Personal files" : "個人檔案",
+    "Additional settings" : "其他設定",
+    "Actions" : "動作",
+    "File actions" : "檔案動作",
+    "Selection" : "選取",
+    "Select all files" : "選取所有檔案",
+    "Deselect all" : "取消全選",
+    "Select or deselect" : "選取或取消選取",
+    "Select a range" : "選取範圍",
+    "Navigation" : "導覽列",
+    "Go to parent folder" : "前往上層資料夾",
+    "Go to file above" : "前往以上檔案",
+    "Go to file below" : "前往以下檔案",
+    "Go left in grid" : "在網格中向左",
+    "Go right in grid" : "在網格中向右",
+    "View" : "檢視",
+    "Toggle grid view" : "切換網格檢視",
+    "Open file sidebar" : "開啟檔案側邊欄",
+    "Show those shortcuts" : "顯示這些快捷鍵",
+    "Warnings" : "警告",
+    "Warn before changing a file extension" : "變更副檔名前警告",
+    "Warn before deleting a file" : "刪除檔案前警告",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "建立應用程式密碼",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "因為此帳號已啟用雙重驗證，故需進行 WebDAV 驗證。",
+    "How to access files using WebDAV" : "如何使用 WebDAV 存取檔案",
     "Total rows summary" : "總列摘要",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選取",
     "Name" : "名稱",
@@ -116,7 +153,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}：在部份元素上失敗",
     "{displayName}: done" : "{displayName}：完成",
     "{displayName}: failed" : "{displayName}：失敗",
-    "Actions" : "動作",
     "(selected)" : "（已選取）",
     "List of files and folders." : "檔案與資料夾清單。",
     "You have used your space quota and cannot upload files anymore." : "您已用完您的空間配額，無法再上傳檔案。",
@@ -124,10 +160,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於效能考量，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
     "_{count} selected_::_{count} selected_" : ["已選取 {count} 個"],
-    "Search everywhere …" : "搜尋各處……",
-    "Search here …" : "搜尋此處……",
+    "Search everywhere …" : "搜尋各處 ……",
+    "Search here …" : "搜尋此處 ……",
     "Search scope options" : "搜尋範圍選項",
     "Search here" : "搜尋此處",
+    "Owner" : "擁有者",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
     "{used} of {quota} used" : "已使用 {used}，共 {quota}",
     "{relative}% used" : "已使用 {relative}%",
@@ -144,7 +181,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "重新整理檔案名稱的消毒狀態失敗。",
     "Filename sanitization in progress." : "正在進行檔案名稱消毒。",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "目前已處理 {processedUsers} 個帳號，共 {totalUsers} 個。",
-    "Preparing …" : "正在準備……",
+    "Preparing …" : "正在準備 ……",
     "Refresh" : "重新整理",
     "All files have been santized for Windows filename support." : "所有檔案均已消毒以支援 Windows 檔案名稱規範。",
     "Some files could not be sanitized, please check your logs." : "部份檔案無法完成消毒流程，請檢查您的紀錄檔。",
@@ -159,7 +196,7 @@ OC.L10N.register(
     "Sanitize filenames" : "消毒檔案名稱",
     "(starting)" : "（正在開始）",
     "Fill template fields" : "檔案範本欄位",
-    "Submitting fields …" : "正在遞交欄位……",
+    "Submitting fields …" : "正在遞交欄位 ……",
     "Submit" : "遞交",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
@@ -183,6 +220,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "不要再次顯示此對話方塊。",
     "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Choose {file}" : "選擇 {file}",
+    "Files settings" : "檔案設定",
     "Share" : "分享",
     "Shared by link" : "透過連結分享",
     "Shared" : "已分享",
@@ -201,90 +239,39 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
     "Go back" : "返回",
     "Views" : "顯示",
-    "Files settings" : "檔案設定",
+    "Loading …" : "正在載入……",
     "Your files" : "您的檔案",
     "Open in files" : "在檔案中開啟",
     "File cannot be accessed" : "無法存取檔案",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請寄件者分享。",
     "No search results for “{query}”" : "沒有結果符合「{query}」",
     "Search for files" : "搜尋檔案",
-    "Clipboard is not available" : "剪貼簿無法使用",
-    "WebDAV URL copied" : "已複製 WebDAV URL",
-    "General" : "一般",
-    "Default view" : "預設檢視",
-    "All files" : "所有檔案",
-    "Personal files" : "個人檔案",
-    "Sort favorites first" : "先排序喜愛",
-    "Sort folders before files" : "將資料夾排序在檔案前",
-    "Folder tree" : "資料夾樹",
-    "Appearance" : "外觀",
-    "Show hidden files" : "顯示隱藏檔",
-    "Show file type column" : "顯示檔案類型欄位",
-    "Show file extensions" : "顯示副檔名",
-    "Crop image previews" : "圖片裁剪預覽",
-    "Additional settings" : "其他設定",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "複製",
-    "How to access files using WebDAV" : "如何使用 WebDAV 存取檔案",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "您的帳號已啟用兩階段驗證，因此您必須使用應用程式密碼才能連結外部 WebDAV 帳號。",
-    "Warnings" : "警告",
-    "Warn before changing a file extension" : "變更副檔名前警告",
-    "Warn before deleting files" : "刪除檔案前警告",
-    "Keyboard shortcuts" : "鍵盤快速鍵",
-    "File actions" : "檔案動作",
-    "Rename" : "重新命名",
-    "Delete" : "刪除",
-    "Add or remove favorite" : "新增或移除最愛",
-    "Manage tags" : "管理標籤",
-    "Selection" : "選取",
-    "Select all files" : "選取所有檔案",
-    "Deselect all" : "取消全選",
-    "Select or deselect" : "選取或取消選取",
-    "Select a range" : "選取範圍",
-    "Navigation" : "導覽列",
-    "Go to parent folder" : "前往上層資料夾",
-    "Go to file above" : "前往以上檔案",
-    "Go to file below" : "前往以下檔案",
-    "Go left in grid" : "在網格中向左",
-    "Go right in grid" : "在網格中向右",
-    "View" : "檢視",
-    "Toggle grid view" : "切換網格檢視",
-    "Open file sidebar" : "開啟檔案側邊欄",
-    "Show those shortcuts" : "顯示這些快捷鍵",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限制檔案名稱以確保檔案可以與所有客戶端同步。預設情況下，允許 POSIX（例如 Linux 或 macOS）上所有有效的檔案名稱。",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用與 Windows 相容的檔案名稱後，無法再修改現有檔案，但可以由其擁有者重新命名為有效的新名稱。",
     "Failed to toggle Windows filename support" : "切換 Windows 檔案名稱支援失敗",
     "Files compatibility" : "檔案相容性",
     "Enforce Windows compatibility" : "強制 Windows 相容性",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這會封鎖在 Windows 系統上無效的檔案名稱，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的相容性。",
-    "You" : "您",
-    "Shared multiple times with different people" : "與不同的人多次分享",
-    "Unable to change the favorite state of the file" : "無法變更檔案的喜愛狀態",
-    "Error while loading the file data" : "載入檔案資料時發生錯誤",
-    "Owner" : "擁有者",
-    "Remove from favorites" : "從喜愛中移除",
-    "Add to favorites" : "新增至喜愛",
-    "Tags" : "標籤",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從範本建立新檔案",
     "Pick a template for {name}" : "為 {name} 挑選範本",
     "Create a new file with the selected template" : "使用選定的範本建立新檔案",
     "Creating file" : "正在建立檔案",
     "Save as {displayName}" : "另存為 {displayName}",
-    "Save as …" : "另存為……",
-    "Converting files …" : "正在轉換檔案……",
+    "Save as …" : "另存為 ……",
+    "Converting files …" : "正在轉換檔案 ……",
     "Failed to convert files: {message}" : "無法轉換檔案：{message}",
     "All files failed to be converted" : "所有檔案轉換失敗",
     "One file could not be converted: {message}" : "一個檔案無法轉換：{message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["無法轉換 %n 個檔案"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["成功轉換 %n 個檔案"],
-    "Files successfully converted" : "檔案成功轉換",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["無法轉換 %n 個檔案"],
+    "_%n file converted_::_%n files converted_" : ["已轉換 %n 個檔案"],
+    "Files converted" : "檔案已轉換",
     "Failed to convert files" : "轉換檔案失敗",
-    "Converting file …" : "正在轉換檔案……",
+    "Converting file …" : "正在轉換檔案 ……",
     "File successfully converted" : "成功轉換檔案",
     "Failed to convert file: {message}" : "無法轉換檔案：{message}",
     "Failed to convert file" : "無法轉換檔案",
+    "Delete" : "刪除",
     "Leave this share" : "離開此分享",
     "Leave these shares" : "離開這些分享",
     "Disconnect storage" : "中斷連結儲存空間",
@@ -302,8 +289,11 @@ OC.L10N.register(
     "Download" : "下載",
     "The requested file is not available." : "無法取得所請求的檔案。",
     "The requested files are not available." : "無法取得所請求的檔案。",
-    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
-    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
+    "Add to favorites" : "新增至喜愛",
+    "Remove from favorites" : "從喜愛中移除",
+    "Add or remove favorite" : "新增或移除最愛",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」 ……",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」 ……",
     "Destination is not a folder" : "目的地不是資料夾",
     "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
@@ -314,10 +304,12 @@ OC.L10N.register(
     "The file does not exist anymore" : "檔案已不存在",
     "Choose destination" : "選擇目的地",
     "Copy to {target}" : "複製到 {target}",
+    "Copy" : "複製",
     "Move to {target}" : "移動到 {target}",
     "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
     "Move or copy" : "移動或複製",
+    "Open folder" : "開啟資料夾",
     "Open folder {displayName}" : "開啟資料夾 {displayName}",
     "Open in Files" : "以「檔案」開啟",
     "Open locally" : "在本機開啟",
@@ -326,7 +318,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該可以在您的裝置上開啟。如果打不開，請檢查您是否有安裝桌面應用程式。",
     "Retry and close" : "重試並關閉",
     "Open online" : "線上開啟",
+    "Rename" : "重新命名",
     "Details" : "詳細資料",
+    "Unfavorite" : "取消收藏",
     "View in folder" : "在資料夾中檢視",
     "Today" : "今日",
     "Last 7 days" : "過去7天",
@@ -381,6 +375,7 @@ OC.L10N.register(
     "No favorites yet" : "尚無喜愛",
     "Files and folders you mark as favorite will show up here" : "您標記為喜愛的檔案與資料夾將會顯示在這裡",
     "List of your files and folders." : "您的檔案與資料夾清單。",
+    "Folder tree" : "資料夾樹",
     "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
     "No personal files found" : "找不到個人檔案",
     "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
@@ -394,119 +389,28 @@ OC.L10N.register(
     "Select all" : "全選",
     "Upload too large" : "上傳檔案過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制。",
-    "File could not be found" : "找不到檔案",
-    "Show list view" : "顯示清單檢視",
-    "Show grid view" : "顯示格狀檢視",
-    "Close" : "關閉",
-    "Could not create folder \"{dir}\"" : "無法建立資料夾「{dir}」",
-    "This will stop your current uploads." : "這會停止您目前的上傳。",
-    "Upload cancelled." : "上傳已取消。",
-    "Processing files …" : "正在處理檔案…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，您正要上傳 {size1} 可是只剩下 {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "目標資料夾「{dir}」不存在",
-    "An unknown error has occurred" : "發生未知的錯誤",
-    "File could not be uploaded" : "檔案無法上傳",
-    "Uploading …" : "正在上傳…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "正在上傳… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
-    "Uploading that item is not supported" : "不支援上傳該項目",
-    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
-    "Choose target folder" : "選擇目標資料夾",
-    "Set reminder" : "設定提醒",
-    "Edit locally" : "在本機編輯",
-    "Open" : "開啟",
-    "Could not load info for file \"{file}\"" : "無法讀取「{file}」的詳細資料",
-    "Please select tag(s) to add to the selection" : "請選取要新增到選定項目的標籤",
-    "Apply tag(s) to selection" : "將標籤套用至選定項目",
-    "Select directory \"{dirName}\"" : "選取目錄「{dirName}」",
-    "Select file \"{fileName}\"" : "選取檔案「{fileName}」",
-    "Unable to determine date" : "無法確定日期",
-    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
-    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
-    "Could not move \"{file}\"" : "無法移動「{file}」",
-    "copy" : "複製",
-    "Could not copy \"{file}\", target exists" : "無法複製「{file}」，目標已經存在",
-    "Could not copy \"{file}\"" : "無法複製「{file}」",
-    "Copied {origin} inside {destination}" : "已將 {origin} 複製到 {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "已將 {origin} 和其他 {nbfiles} 個檔案複製到 {destination}",
-    "{newName} already exists" : "{newName} 已經存在",
-    "Could not create file \"{file}\"" : "無法建立檔案「{file}」",
-    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已經存在",
-    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾「{dir}」，因為此資料夾已經存在",
-    "Could not fetch file details \"{file}\"" : "無法擷取檔案詳細資訊「{file}」",
-    "Error deleting file \"{fileName}\"." : "刪除「{fileName}」時發生錯誤。",
-    "No search results in other folders for {tag}{filter}{endtag}" : "在其他資料夾中沒有找到 {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "請輸入兩個字元以上，以便在其他資料夾搜尋",
-    "{dirs} and {files}" : "{dirs} 和 {files}",
-    "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
-    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
-    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
-    "New" : "新增",
-    "New file/folder menu" : "新檔案/資料夾選單",
-    "Select file range" : "選取多個檔案",
-    "{used}%" : "{used}%",
-    "{used} used" : "已使用 {used}",
-    "\"{name}\" is an invalid file name." : "「{name}」是無效的檔名。",
-    "File name cannot be empty." : "檔名不能為空。",
-    "\"/\" is not allowed inside a file name." : "不允許檔名中出現「/」。",
-    "\"{name}\" is not an allowed filetype" : "「{name}」是不允許的檔案類型",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，已無法再更新或是同步檔案！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾「{mountPoint}」已滿，已無法再更新或同步檔案！",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間「{mountPoint}」已滿，已無法再更新或同步檔案！",
-    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，已無法再更新或是同步檔案！",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿 ({usedSpacePercent}%)。",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
-    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿 ({usedSpacePercent}%)。",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "Path" : "路徑",
-    "_%n byte_::_%n bytes_" : ["%n 位元組"],
-    "Favored" : "已加入最愛",
-    "Favor" : "加入最愛",
-    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "Upload file" : "上傳檔案",
-    "Not favored" : "未加入最愛",
-    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
+    "%1$s (renamed)" : "%1$s（已重新命名）",
+    "renamed file" : "已重新命名檔案",
     "Upload (max. %s)" : "上傳（最多 %s）",
-    "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
-    "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用與 Windows 相容的檔案名稱後，無法再修改現有檔案，但可以由其擁有者重新命名為有效的新名稱。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，也可以自動遷移檔案，詳情請參閱關於 occ 命令的文件。",
     "\"{displayName}\" failed on some elements" : "「{displayName}」在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "「{displayName}」批次動作執行成功",
-    "Submitting fields…" : "正在遞交欄位……",
-    "Filter filenames…" : "篩選檔案名稱……",
+    "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
+    "Submitting fields …" : "正在遞交欄位……",
+    "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
+    "Filter file names …" : "過濾檔案名稱……",
+    "Clipboard is not available" : "剪貼簿無法使用",
     "WebDAV URL copied to clipboard" : "WebDAV URL 已複製到剪貼簿",
     "Enable the grid view" : "啟用格狀檢視",
     "Enable folder tree" : "啟用資料夾樹",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "複製到剪貼簿",
     "Use this address to access your Files via WebDAV" : "使用此位置透過 WebDAV 存取您的檔案",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "若您啟用了雙因子認證，您必須點擊此處建立並使用新的應用程式密碼。",
-    "Deletion cancelled" : "刪除已取消",
-    "Move cancelled" : "移動已取消",
-    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製「{filename}」。",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
-    "Open details" : "開啟詳細資訊",
-    "Photos and images" : "照片與影像",
-    "New folder creation cancelled" : "已取消建立新資料夾",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
-    "All folders" : "所有資料夾",
-    "Personal Files" : "個人檔案",
-    "Text file" : "文字檔案",
-    "New text file.txt" : "新文字檔案.txt",
-    "%1$s (renamed)" : "%1$s（已重新命名）",
-    "renamed file" : "已重新命名檔案",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用與 Windows 相容的檔案名稱後，無法再修改現有檔案，但可以由其擁有者重新命名為有效的新名稱。",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，也可以自動遷移檔案，詳情請參閱關於 occ 命令的文件。",
-    "Filter file names …" : "過濾檔案名稱……",
     "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話方塊或重新啟用它們。",
     "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話方塊。",
+    "Keyboard shortcuts" : "鍵盤快速鍵",
     "Speed up your Files experience with these quick shortcuts." : "使用這些快捷鍵加速您的 Files 體驗。",
     "Open the actions menu for a file" : "開啟檔案的動作選單",
     "Rename a file" : "重新命名檔案",
@@ -522,6 +426,29 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
     "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
     "Toggle the grid view" : "切換網格檢視",
-    "Open the sidebar for a file" : "開啟檔案側邊欄"
+    "Open the sidebar for a file" : "開啟檔案側邊欄",
+    "You" : "您",
+    "Shared multiple times with different people" : "與不同的人多次分享",
+    "Unable to change the favorite state of the file" : "無法變更檔案的喜愛狀態",
+    "Error while loading the file data" : "載入檔案資料時發生錯誤",
+    "Tags" : "標籤",
+    "Save as …" : "另存為……",
+    "Converting files …" : "正在轉換檔案……",
+    "Converting file …" : "正在轉換檔案……",
+    "Deletion cancelled" : "刪除已取消",
+    "Edit locally" : "在本機編輯",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
+    "Move cancelled" : "移動已取消",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製「{filename}」。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Open details" : "開啟詳細資訊",
+    "Photos and images" : "照片與影像",
+    "New folder creation cancelled" : "已取消建立新資料夾",
+    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
+    "All folders" : "所有資料夾",
+    "Search everywhere …" : "搜尋各處……",
+    "Search here …" : "搜尋此處……",
+    "Preparing …" : "正在準備……"
 },
 "nplurals=1; plural=0;");
