@@ -19,10 +19,10 @@ OC.L10N.register(
     "Shared as public link" : "共享为公开链接",
     "Removed public link" : "移除公开链接",
     "Public link expired" : "公开链接已过期",
-    "{actor} shared as public link" : "{actor} 公共链接共享",
-    "{actor} removed public link" : "{actor} 删除公共链接",
+    "{actor} shared as public link" : "{actor} 作为公开链接共享",
+    "{actor} removed public link" : "{actor} 已移除公开链接",
     "Public link of {actor} expired" : "{actor} 的公开链接已过期",
-    "You shared {file} as public link" : "您共享了 {file} 为公开链接",
+    "You shared {file} as public link" : "您将 {file} 作为公开链接共享",
     "You removed public link for {file}" : "您移除了 {file} 的公开链接",
     "Public link expired for {file}" : "{file} 的公开链接已过期",
     "{actor} shared {file} as public link" : "{actor} 用公开链接共享了 {file} ",
@@ -54,7 +54,7 @@ OC.L10N.register(
     "{actor} removed you from the share named {file}" : "{actor} 从名为 {file} 的共享中移除了您",
     "Share for file {file} with {user} expired" : "与 {user} 的文件共享 {file} 已过期",
     "Share for file {file} expired" : "文件 {file} 的共享已过期",
-    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "通过邮件或公共链接共享的文件或文件夹<strong>已下载</strong>",
+    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "<strong>已下载</strong>通过邮件或公开链接共享的文件或文件夹",
     "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "文件<strong>已上传</strong>到通过邮件或公共链接共享的文件夹",
     "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
     "Sharing" : "共享",
@@ -68,7 +68,7 @@ OC.L10N.register(
     "Please specify a valid account to share with" : "请指定要分享的有效账号",
     "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
     "Please specify a valid group" : "请指定一个有效的组",
-    "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
+    "Public link sharing is disabled by the administrator" : "管理员已禁用公开链接共享",
     "Please specify a valid email address" : "请指定有效得电子邮箱地址",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud 通话应用没有启用，所以通过 Nextcloud 通话应用发送%s共享密码失败。",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
@@ -77,14 +77,13 @@ OC.L10N.register(
     "You cannot share to a Team if the app is not enabled" : "如果未启用应用，则无法与团队共享",
     "Please specify a valid team" : "请指定有效团队",
     "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
-    "Sharing %s failed because the back end does not support ScienceMesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
     "Unknown share type" : "未知共享类型",
     "Not a directory" : "不是一个目录",
     "Could not lock node" : "无法锁定节点",
-    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
+    "Public upload is only possible for publicly shared folders" : "公开上传仅适用于公开共享文件夹",
     "Share must at least have READ or CREATE permissions" : "分享至少具有 READ 或 CREATE 权限",
     "Share must have READ permission if UPDATE or DELETE permission is set" : "分享如果设置了 UPDATE 或 DELETE 权限，则必须具有 READ 权限",
-    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
+    "Public upload disabled by the administrator" : "管理员已禁用公开上传",
     "Could not lock path" : "无法锁定路径",
     "no sharing rights on this item" : "此项目没有共享权限",
     "You are not allowed to edit incoming shares" : "不允许编辑传入共享",
@@ -134,7 +133,7 @@ OC.L10N.register(
     "Generate a new password" : "生成新密码",
     "Your administrator has enforced a password protection." : "您的管理员已强制实施密码保护。",
     "Automatically copying failed, please copy the share link manually" : "自动复制失败，请手动复制共享链接",
-    "Link copied to clipboard" : "链接已复制到剪贴板",
+    "Link copied" : "已复制链接",
     "Email already added" : "电子邮箱已添加",
     "Invalid email address" : "无效电子邮箱地址",
     "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下电子邮箱地址无效：{emails}"],
@@ -142,7 +141,7 @@ OC.L10N.register(
     "_{count} email address added_::_{count} email addresses added_" : ["已添加 {count} 个电子邮件地址"],
     "You can now share the link below to allow people to upload files to your directory." : "现在，你可以分享下面的链接，允许人们将文件上传到你的目录。",
     "Share link" : "共享链接",
-    "Copy to clipboard" : "复制到剪贴板",
+    "Copy" : "复制",
     "Send link via email" : "通过邮件发送链接",
     "Enter an email address or paste a list" : "输入电子邮箱地址或粘贴一个列表",
     "Remove email" : "移除电子邮箱",
@@ -185,8 +184,8 @@ OC.L10N.register(
     "Set default folder for accepted shares" : "设置已接受共享的默认文件夹",
     "Reset" : "重置",
     "Reset folder to system default" : "重置文件夹为系统默认值",
-    "Share expiration: " : "共享有效期‌：",
-    "Share Expiration" : "共享有效期‌",
+    "Share expiration: {date}" : "分享过期日期：{date}",
+    "Share Expiration" : "分享过期日期",
     "group" : "分组",
     "conversation" : "会话",
     "remote" : "远程",
@@ -201,10 +200,8 @@ OC.L10N.register(
     "Via “{folder}”" : "通过“{folder}”",
     "Unshare" : "取消共享",
     "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
-    "Copy internal link to clipboard" : "复制内部链接到剪贴板",
-    "Only works for people with access to this folder" : "仅适用于可以访问该文件夹的用户",
-    "Only works for people with access to this file" : "仅适用于可以访问该文件的用户",
-    "Link copied" : "已复制链接",
+    "Copy internal link" : "复制内部链接",
+    "For people who already have access" : "对于已经拥有访问权限的人员",
     "Internal link" : "内部链接",
     "{shareWith} by {initiator}" : "由 {initiator} 通过 {shareWith} 共享",
     "Shared via link by {initiator}" : "由 {initiator} 通过链接共享",
@@ -215,10 +212,12 @@ OC.L10N.register(
     "Share link ({index})" : "分享链接（{index}）",
     "Create public link" : "生成公开链接地址",
     "Actions for \"{title}\"" : "“{title}”的动作",
-    "Copy public link of \"{title}\" to clipboard" : "将“{title}”的公开链接复制到剪贴板",
+    "Copy public link of \"{title}\"" : "复制“{title}”的公开链接",
     "Error, please enter proper password and/or expiration date" : "错误，请输入正确的密码和/或过期日期",
     "Link share created" : "已创建链接分享",
     "Error while creating the share" : "创建共享时出错",
+    "Your browser does not support copying, please copy the link manually:" : "您的浏览器不支持复制，请手动复制链接：",
+    "Successfully copied public link" : "已成功复制公开链接",
     "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
     "Password protection (enforced)" : "密码保护（强制）",
     "Password protection" : "密码保护",
@@ -237,14 +236,14 @@ OC.L10N.register(
     "Can edit" : "可以编辑",
     "Custom permissions" : "自定义权限",
     "Resharing is not allowed" : "不允许再次共享",
-    "Name or email …" : "姓名或电子邮件 ...",
-    "Name, email, or Federated Cloud ID …" : "名称、电子邮件或联合云 ID ...",
-    "Searching …" : "正在搜索 ...",
+    "Name or email …" : "名称或电子邮件 …",
+    "Name, email, or Federated Cloud ID …" : "名称、电子邮件或联合云 ID …",
+    "Searching …" : "正在搜索 …",
     "No elements found." : "未发现元素。",
-    "Search globally" : "全局搜索",
+    "Search everywhere" : "全局搜索",
     "Guest" : "访客",
     "Group" : "群组",
-    "Email" : "电子邮箱",
+    "Email" : "电子邮件",
     "Team" : "团队",
     "Talk conversation" : "通话应用对话",
     "Deck board" : "看板",
@@ -257,15 +256,10 @@ OC.L10N.register(
     "File drop" : "文件拖放",
     "Upload files to {foldername}." : "将文件上传到 {foldername}。",
     "By uploading files, you agree to the terms of service." : "上传文件即表示您同意服务条款。",
+    "Successfully uploaded files" : "已成功上传文件",
     "View terms of service" : "查看服务条款",
     "Terms of service" : "服务条款",
-    "Upload files to {folder}" : "将文件上传到 {folder}",
-    "Submit name" : "提交名称",
-    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 与您分享了一个文件夹。",
-    "To upload files, you need to provide your name first." : "要上传文件，您需要先提供名称。",
-    "Nickname" : "昵称",
-    "Enter your nickname" : "输入昵称",
-    "Share with {userName}" : "分享至 {userName}",
+    "Share with {user}" : "与 {user} 分享",
     "Share with email {email}" : "与邮箱 {email} 分享",
     "Share with group" : "分享至群组",
     "Share in conversation" : "分享至对话",
@@ -310,19 +304,22 @@ OC.L10N.register(
     "Unable to fetch inherited shares" : "无法获取继承的共享",
     "Link shares" : "链接共享",
     "Shares" : "共享",
-    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法与组织内的个人或团队共享文件。如果接收者已经可以访问共享，但找不到它，您可以向他们发送内部共享链接以便于访问。",
-    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法与组织外部的个人或组织共享文件。文件和文件夹可以通过公开共享链接和电子邮件地址共享。您还可以使用其联合云 ID 共享给托管在不同实例上的其他 Nextcloud 账号。",
-    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不属于内部或外部共享的共享，这可以是来自应用或其他来源的共享。",
+    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "在您的组织内共享文件。已经可以查看该文件的接收者也可以使用此链接轻松访问。",
+    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "通过公开链接和电子邮件地址与组织外部的其他人共享文件。您还可以使用他们的联合云 ID 将文件共享至其他实例上的 {productName} 账号。",
+    "Shares from apps or other sources which are not included in internal or external shares." : "来自应用或其他来源的共享，不包括在内部或外部共享中。",
+    "Type names, teams, federated cloud IDs" : "输入名称、团队、联合云 ID",
+    "Type names or teams" : "输入名称或团队",
+    "Type a federated cloud ID" : "输入联合云 ID",
+    "Type an email" : "输入电子邮件",
+    "Type an email or federated cloud ID" : "输入电子邮件或联合云 ID",
     "Unable to load the shares list" : "无法加载共享列表",
     "Expires {relativetime}" : "过期 {relativetime}",
     "this share just expired." : "此共享已过期。",
     "Shared with you by {owner}" : "{owner} 与您共享",
     "Internal shares" : "内部共享",
     "Internal shares explanation" : "内部共享说明",
-    "Share with accounts and teams" : "与账号和团队共享",
     "External shares" : "外部共享",
     "External shares explanation" : "外部共享说明",
-    "Email, federated cloud id" : "电子邮件、联合云 ID",
     "Additional shares" : "额外共享",
     "Additional shares explanation" : "额外共享说明",
     "Link to a file" : "链接到文件",
@@ -333,8 +330,9 @@ OC.L10N.register(
     "Shared" : "已共享",
     "Shared by {ownerDisplayName}" : "由 {ownerDisplayName} 分享",
     "Shared multiple times with different people" : "与不同的用户多次分享",
-    "Show sharing options" : "显示共享选项",
+    "Sharing options" : "共享选项",
     "Shared with others" : "你的共享",
+    "You do not have enough permissions to share this file." : "您没有足够的权限共享此文件。",
     "Create file request" : "创建文件请求",
     "Upload files to {foldername}" : "将文件上传到 {foldername}",
     "Public file share" : "公开文件共享",
@@ -371,7 +369,9 @@ OC.L10N.register(
     "List of unapproved shares." : "未批准的分享列表",
     "No pending shares" : "没有待定共享",
     "Shares you have received but not approved will show up here" : "您已收到但未批准的分享将显示在这里",
-    "Error updating the share: {errorMessage}" : "更新共享失败：{errorMessage}",
+    "Error deleting the share: {errorMessage}" : "删除共享时出错：{errorMessage}",
+    "Error deleting the share" : "删除共享时出错",
+    "Error updating the share: {errorMessage}" : "更新共享时出错：{errorMessage}",
     "Error updating the share" : "更新共享时出错",
     "File \"{path}\" has been unshared" : "文件“{path}”已取消共享",
     "Folder \"{path}\" has been unshared" : "文件夹“{path}”已取消共享",
@@ -383,14 +383,53 @@ OC.L10N.register(
     "Share note for recipient saved" : "接收者的共享备注已保存",
     "Share password saved" : "共享密码已保存",
     "Share permissions saved" : "共享权限已保存",
-    "Shared by" : "共享人",
-    "Shared with" : "共享给",
+    "To upload files to {folder}, you need to provide your name first." : "要将文件上传到 {folder}，您需要先提供名称。",
+    "Upload files to {folder}" : "将文件上传到 {folder}",
+    "Please confirm your name to upload files to {folder}" : "请确认名称以将文件上传到 {folder}",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 与您分享了一个文件夹。",
+    "Names must not be empty." : "名称不能为空。",
+    "Names must not start with a dot." : "名称不能以点开头。",
+    "\"{char}\" is not allowed inside a name." : "名称中不允许使用“{char}”。",
+    "\"{segment}\" is a reserved name and not allowed." : "“{segment}”是保留名称，不允许使用。",
+    "\"{extension}\" is not an allowed name." : "“{extension}”不是允许的名称。",
+    "Names must not end with \"{extension}\"." : "名称不能以“{extension}”结尾。",
+    "Invalid name." : "无效名称。",
     "Password created successfully" : "密码已创建成功",
     "Error generating password from password policy" : "从密码策略生成密码时出错",
     "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
     "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
     "Shared with you and the conversation {conversation} by {owner}" : "由{owner} 共享给您及对话 {conversation}",
     "Shared with you in a conversation by {owner}" : "由 {owner} 在一个会话中共享给您",
+    "Share not found" : "未找到共享",
+    "Back to %s" : "返回 %s",
+    "Add to your Nextcloud" : "添加到您的 Nextcloud",
+    "Sharing %s failed because the back end does not support ScienceMesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
+    "Link copied to clipboard" : "链接已复制到剪贴板",
+    "Copy to clipboard" : "复制到剪贴板",
+    "Copy internal link to clipboard" : "复制内部链接到剪贴板",
+    "Only works for people with access to this folder" : "仅适用于可以访问该文件夹的用户",
+    "Only works for people with access to this file" : "仅适用于可以访问该文件的用户",
+    "Copy public link of \"{title}\" to clipboard" : "将“{title}”的公开链接复制到剪贴板",
+    "Name or email …" : "名称或电子邮件…",
+    "Name, email, or Federated Cloud ID …" : "名称、电子邮件或联合云 ID…",
+    "Searching …" : "正在搜索…",
+    "Search globally" : "全局搜索",
+    "Submit name" : "提交名称",
+    "To upload files, you need to provide your name first." : "要上传文件，您需要先提供名称。",
+    "Name" : "名称",
+    "Enter your name" : "输入名称",
+    "Share with {userName}" : "分享至 {userName}",
+    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法与组织内的个人或团队共享文件。如果接收者已经可以访问共享，但找不到它，您可以向他们发送内部共享链接以便于访问。",
+    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法与组织外部的个人或组织共享文件。文件和文件夹可以通过公开共享链接和电子邮件地址共享。您还可以使用其联合云 ID 共享给托管在不同实例上的其他 Nextcloud 账号。",
+    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不属于内部或外部共享的共享，这可以是来自应用或其他来源的共享。",
+    "Share with accounts, teams, federated cloud id" : "与账号、团队、联合云 ID 共享",
+    "Share with accounts and teams" : "与账号和团队共享",
+    "Federated cloud ID" : "联合云 ID",
+    "Email, federated cloud id" : "电子邮件、联合云 ID",
+    "Show sharing options" : "显示共享选项",
+    "Filename must not be empty." : "文件名不能为空。",
+    "Shared by" : "共享人",
+    "Shared with" : "共享给",
     "Share note" : "共享笔记",
     "Show list view" : "显示列表视图",
     "Show grid view" : "显示网格视图",
@@ -400,29 +439,6 @@ OC.L10N.register(
     "Select or drop files" : "选择或拖放文件",
     "Uploading files" : "正在上传文件",
     "Uploaded files:" : "上传的文件： ",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
-    "Share not found" : "未找到共享",
-    "Back to %s" : "返回 %s",
-    "Add to your Nextcloud" : "添加到您的 Nextcloud",
-    "Waiting…" : "等待中...",
-    "error" : "错误",
-    "finished" : "完成",
-    "This will stop your current uploads." : "此操作将终止您当前的上传。",
-    "Move or copy" : "移动或复制",
-    "You can upload into this folder" : "您可以上传文件至此文件夹",
-    "No compatible server found at {remote}" : " {remote} 未发现匹配的服务器",
-    "Invalid server URL" : "无效的服务器地址",
-    "Failed to add the public link to your Nextcloud" : "添加公开链接到您的Nextcloud失败",
-    "Files" : "文件",
-    "Download all files" : "下载所有文件",
-    "Search for share recipients" : "查找共享参与者",
-    "No recommendations. Start typing." : "无建议。开始输入。",
-    "Password field can't be empty" : "密码字段不能为空",
-    "Allow download" : "允许下载",
-    "Share expire date saved" : "共享过期日期已保存",
-    "You are not allowed to edit link shares that you don't own" : "不允许编辑不属于您的链接共享",
-    "_1 email address already added_::_{count} email addresses already added_" : ["{count}个电子邮箱地址已添加"],
-    "_1 email address added_::_{count} email addresses added_" : ["{count}电子邮箱地址已添加"],
-    "Enter your name" : "输入你的名字"
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。"
 },
 "nplurals=1; plural=0;");
