@@ -1,18 +1,27 @@
 OC.L10N.register(
     "photos",
     {
+    "Public link" : "Liamm publik",
     "Photos" : "Fotoioù",
     "Videos" : "Videoioù",
+    "People" : "Tud",
     "Favorites" : "Pennrolloù",
     "Shared with you" : "Rannet ganeoc'h",
     "Tags" : "Klavioù",
     "Back" : "Distro",
     "Save" : "Enrollañ",
+    "Shared by" : "Rannet gant",
     "Copy public link" : "Eilañ al liamm foran",
-    "View" : "Gwell",
     "Favorite" : "Pennrollañ",
+    "Home" : "Degemer",
+    "General" : "Hollek",
+    "Unselect all" : "Diziuzañ pep tra",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
-    "Add" : "Ouzhpennañ",
-    "Settings" : "Arventennoù"
+    "Loading folders…" : "O kargañ an teuliad...",
+    "Details" : "Munudoù",
+    "Cancel" : "Cancel",
+    "Confirm" : "Kadarnaat",
+    "View" : "Gwell",
+    "Add" : "Ouzhpennañ"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
