@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
     "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
     "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
+    "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
+    "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Name of the album" : "Albumaren izena",
     "Location of the album" : "Albumaren kokapena",
     "Back" : "Atzera",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
     "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
     "No recommendations. Start typing." : "Gomendiorik ez. Hasi idazten.",
-    "Group" : "Taldea",
-    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
     "Copy the public link" : "Kopiatu esteka publikoa",
     "Public link copied!" : "Esteka publikoa kopiatuta!",
     "Copy public link" : "Kopiatu esteka publikoa",
@@ -52,15 +53,18 @@ OC.L10N.register(
     "No picture for this day" : "Ez dago argazkirik egun honentzat",
     "Picture taken on this day will show up here." : "Egun honetan hartutako argazkia hemen agertuko da.",
     "More photos from this day" : "Egun honetako argazki gehiago",
+    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
     "Favorite" : "Egin gogoko",
     "Favorite image, open the full size \"{name}\" image" : "Irudi gogokoa, ireki \"{name}\" irudia neurri handian",
     "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
     "Select image {imageName}" : "Hautatu irudia {imageName}",
     "Open the \"{name}\" folder" : "Ireki \"{name}\" karpeta",
-    "Back to {folder}" : "Itzuli {folder}(e)ra",
     "Go back" : "Atzera",
-    "Share this folder" : "Partekatu karpeta hau",
+    "Select a custom date range" : "Hautatu data tarte pertsonalizatu bat",
+    "Select a date range" : "Hautatu data tarte bat",
+    "Date range" : "Data tartea",
+    "Select filters" : "Hautatu iragazkiak",
     "Dates" : "Datak",
     "Jump to specific date in list" : "Joan zerrendako data zehatz batera",
     "Jump to {date}" : "Joan {date} datara",
@@ -68,21 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : " Helburu karpetaren jabea {owner} da",
     "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
     "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
-    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
+    "Squared photos view" : "Argazkien ikuspegi karratua",
     "Delete source directory" : "Ezabatu iturburuko direktorioa",
+    "Pick folder" : "Aukeratu karpeta",
     "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
+    "Media folders" : "Multimedia karpetak",
+    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
     "All folders" : "Karpeta guztiak",
     "Add a Photos source for the timelines" : "Gehitu argazki iturri bat denbora-lerroetarako",
     "Add folder" : "Gehitu karpeta",
-    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
     "Home" : "Etxea",
-    "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
-    "Choose a different folder" : "Aukeratu beste karpeta bat",
-    "View" : "Ikusi",
-    "Media folders" : "Multimedia karpetak",
-    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
+    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
     "Upload folder" : "Igo karpeta",
-    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
+    "General" : "Orokorra",
     "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
     "Unselect all" : "Desautatu dena",
     "Add photos to this album" : "Gehitu argazkiak album honetara ",
@@ -114,29 +116,30 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
     "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
     "This folder does not exist" : "Karpeta hau ez da existitzen",
-    "Loading folders …" : "Karpetak kargatzen ...",
+    "Loading folders…" : "Karpetak kargatzen...",
     "No photos in here" : "Argazkirik ez hemen",
     "Taken on {date} at {time}" : "{date} egunean {time} orduan ateratakoa",
     "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
     "Add photos to this place" : "Gehitu argazkiak leku honetara",
     "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
     "There is no place yet!" : "Oraindik ez dago lekurik!",
-    "Cover photo for shared album {albumName}." : "{albumName} album partekatuko azaleko argazkia",
+    "Cover photo for shared album {albumName}" : "Azaleko argazkia partekatutako {albumName} albumerako",
     "Back to tags overview" : "Itzuli etiketen ikuspegira",
     "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
     "No tags yet" : "Etitketarik ez oraindik",
     "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
     "Popular tags" : "Etiketa ohikoak",
     "All tags" : "Etiketa guztiak",
+    "Create new album from filters" : "Sortu album berria iragazkitik abiatuta",
     "One of the source folders does not exist" : "Iturburu-karpeta bat ez da existitzen",
     "Add to album" : "Gehitu albumera",
     "Delete selection" : "Ezabatu hautatutakoak",
     "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
     "Unassigned faces" : "Esleitu gabeko aurpegiak",
-    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
     "Failed to fetch collection." : "Ezin izan da bilduma eskuratu.",
     "Failed to fetch collections list." : "Ezin izan da bildumen zerrenda eskuratu.",
     "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
+    "Error fetching files" : "Errorea fitxategiak eskuratzean",
     "All your media" : "Zure multimedia guztia",
     "Album {title}" : "{title} albuma",
     "Shared Albums" : "Partekatutako albumak",
@@ -145,16 +148,41 @@ OC.L10N.register(
     "Tagged photos" : "Etiketaturiko argazkiak",
     "Tagged photo {title}" : "{title} etiketaturiko argazkia",
     "{title}'s face" : "{title}(r)en aurpegia",
+    "Last week" : "Joan den astean",
+    "Last Month" : "Azken hilabetea",
+    "Custom…" : "Pertsonalizatu...",
     "{startDate} to {endDate}" : "{startDate} - {endDate}",
     "Details" : "Xehetasunak",
-    "Failed to rename {oldName} to {faceName}." : "Ezin izan da {oldName} berrizendatu {faceName} gisa.",
-    "Failed to delete {faceName}." : "Ezin izan da  {faceName} ezabatu.",
-    "Failed to delete {fileId}." : "{fileId} ezabatzeak huts egin du.",
-    "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
-    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
-    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Huts egin du {fileBaseName} {collectionFileName} bildumara gehitzean",
+    "Failed to delete {fileBaseName}" : "Huts egin du {fileBaseName} ezabatzean",
+    "Failed to create {collectionFileName}" : "Huts egin du {collectionFileName} sortzean",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Huts egin du {currentCollectionFileName} bildumari {newCollectionFileName}izen berria jartzean",
+    "Failed to update properties of {collectionFileName} with {properties}" : "Huts egin du{collectionFileName}eguneratzean {properties} propietateak",
+    "Delete collection" : "Ezabatu bilduma",
+    "Leave shared album" : "Utzi partekatutako albuma",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Ziur zaude {collectionName} bilduma ezabatu nahi duzula? Ekintza honek ezin da desegin.",
+    "Failed to delete {collectionFileName}" : "Huts egin du {collectionFileName} ezabatzean",
+    "Cancel" : "Cancel",
+    "Confirm" : "Berretsi",
+    "Failed to move {fileBaseName} to person {faceName}" : "Errorea {fileBaseName} {faceName} pertsonarengana mugitzean",
+    "Failed to remove {fileBaseName}" : "Huts egin du {fileBaseName} kentzean",
+    "Failed to rename {oldName} to {faceName}" : "Huts egin du {oldName} bildumari {faceName}izen berria jartzean",
+    "Failed to delete {faceName}" : "Huts egin du {faceName} ezabatzean",
+    "Failed to delete {fileId}" : "Huts egin du {fileId} ezabatzean",
+    "Failed to delete {fileName}" : "Huts egin du {fileName} ezabatzean",
+    "Failed to set favorite state for {fileId}" : "Ezin izan da {fileId}-ren gogoko egoera ezarri",
+    "Failed to set favorite state for {fileName}" : "Ezin izan da {fileName}-ren gogoko egoera ezarri",
     "Could not load photos folder" : "Ezin izan da argazkien karpeta kargatu",
-    "One of the source folders does not exists" : "Iturburu-karpeta bat ez da existitzen",
+    "Group" : "Taldea",
+    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
+    "Back to {folder}" : "Itzuli {folder}(e)ra",
+    "Share this folder" : "Partekatu karpeta hau",
+    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
+    "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
+    "Choose a different folder" : "Aukeratu beste karpeta bat",
+    "View" : "Ikusi",
+    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
+    "Loading folders …" : "Karpetak kargatzen ...",
     "Add" : "Gehitu"
 },
 "nplurals=2; plural=(n != 1);");
