@@ -15,6 +15,9 @@ OC.L10N.register(
     "Not supported!" : "Не підтримується!",
     "Press ⌘-C to copy." : "Натисніть ⌘-C, щоб скопіювати.",
     "Press Ctrl-C to copy." : "Натисніть Ctrl-C, щоб скопіювати.",
+    "Unknown" : "Невідомо",
+    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d днів, %2$d годин, %3$d хвилин, %4$d секунд",
+    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d годин, %2$d хвилин, %3$d секунд",
     "System" : "Система",
     "Monitoring" : "Моніторинг",
     "Monitoring app with useful server information" : "Застосунок моніторингу з корисною інформацією про сервер",
@@ -63,13 +66,16 @@ OC.L10N.register(
     "PHP" : "PHP",
     "Version:" : "Версія:",
     "Memory limit:" : "Обмеження пам'яті:",
+    "MB" : "МБ",
     "Max execution time:" : "Максимальний час виконання:",
+    "seconds" : "секунд",
     "Upload max size:" : "Макс. розмір завантаження:",
     "OPcache Revalidate Frequency:" : "Частота ревалідації OPcache:",
     "Extensions:" : "Розширення:",
     "Unable to list extensions" : "Не вдалося створити список розширень",
+    "PHP Info:" : "Інфо PHP:",
     "Show phpinfo" : "Показати phpinfo",
-    "FPM worker pool" : "Кадровий резерв FPM",
+    "FPM worker pool" : "Набір обробників FPM",
     "Pool name:" : "Назва пулу:",
     "Pool type:" : "Тип пулу:",
     "Start time:" : "Початковий час:",
