@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Priváu",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Namás ye visible pa les persones que concasen pela integración del númberu de teléfonu pente Talk en móviles",
-    "Local" : "Llocal",
-    "Only visible to people on this instance and guests" : "Namás ye visible pa les persones d'esta instancia y los convidaos",
-    "Federated" : "Federada",
-    "Only synchronize to trusted servers" : "Namás sincronizar con sirvidores d'enfotu",
-    "Published" : "Espublizóse",
-    "Synchronize to trusted servers and the global and public address book" : "Sincroniza con sirvidores d'enfotu y la llibreta de direiciones global y pública",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando…",
-    "Unable to change password" : "Nun ye posible camudar la contraseña",
-    "Very weak password" : "La contraseña ye mui poco segura",
-    "Weak password" : "La contraseña ye poco segura",
-    "So-so password" : "La contraseña ye normal",
-    "Good password" : "La contraseña ye segura",
-    "Strong password" : "La contraseña ye mui segura",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La llista de grupos ta balera",
-    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
     "{actor} added you to group {group}" : "{actor} metióte nel grupu «{group}»",
     "You added {user} to group {group}" : "Metiesti a {user} nel grupu «{group}»",
     "{actor} added {user} to group {group}" : "{actor} metió a {user} nel grupu «{group}»",
@@ -57,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Nun ye posible camudar la contraseña personal",
     "Saved" : "Guardóse",
     "No Login supplied" : "Nun se fornió nenguna cuenta",
+    "Unable to change password" : "Nun ye posible camudar la contraseña",
     "Unable to change password. Password too long." : "Nun ye posible camudar la contraseña, ye mui llonga.",
     "Authentication error" : "Error de l'autenticación",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Forni una contraseña de recuperación de l'alministración; d'otra miente, van perdese colos datos de la cuenta",
@@ -103,13 +85,12 @@ OC.L10N.register(
     "Set your password" : "Afitar la contraseña",
     "Go to %s" : "Dir a «%s»",
     "Install Client" : "Instalar el veceru",
-    "Logged in account must be a subadmin" : "La cuenta qu'anició la sesión ha ser un soalministrador",
     "Apps" : "Aplicaciones",
     "Personal" : "Personal",
     "Administration" : "Alministración",
     "Users" : "Usuarios",
     "Additional settings" : "Configuración adicional",
-    "Artificial Intelligence" : "Intelixencia artificial",
+    "Assistant" : "Asistente",
     "Administration privileges" : "Privilexos de l'alministración",
     "Groupware" : "Trabayu en grupu",
     "Overview" : "Vista xeneral",
@@ -119,10 +100,13 @@ OC.L10N.register(
     "Calendar" : "Calendariu",
     "Personal info" : "Información personal",
     "Mobile & desktop" : "Móvil y ordenador",
+    "Artificial Intelligence" : "Intelixencia artificial",
     "Email server" : "Sirvidor de corréu electrónicu",
     "Background jobs" : "Trabayos en segundu planu",
     "Unlimited" : "Ensin llende",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando…",
+    "Verify" : "Verificar",
     "App directories owner" : "Propietariu de los direutorios d'aplicación",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Dalgunos direutorios d'aplicación son propiedá d'otru usuariu y non del usuariu del sirvidor web. Esto pue pasar si dalgunes aplicaciones d'instalaron manualmente. Comprueba los permisos de los direutorios d'aplicación siguientes:\n%s",
     "App directories have the correct owner \"%s\"" : "Los direutorios d'aplicación tienen el propietariu correutu «%s»",
@@ -202,11 +186,11 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La base de datos nun s'executa col nivel d'aislamientu de transaiciones «READ COMMITTED». Esta transaición pue causar problemes cuando s'executen múltiples aiciones en paralelo.",
     "Profile information" : "Información del perfil",
     "Nextcloud settings" : "Configuración de Nextcloud",
-    "Task:" : "Xera:",
     "Enable" : "Activar",
     "Machine translation" : "Traducción per ordenador",
     "Image generation" : "Xeneración d'imáxenes",
     "Text processing" : "Procesamientu de testos",
+    "Task:" : "Xera:",
     "Here you can decide which group can access certain sections of the administration settings." : "Equí pues decidir qué grupu pue acceder a ciertes seiciones de la configuración d'alministración.",
     "Unable to modify setting" : "Nun ye posible modificar la opción",
     "None" : "Nada",
@@ -220,6 +204,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "L'autenticación en dos pasos nun ye obligatoria pa los miembros de los grupos siguientes.",
     "Excluded groups" : "Grupos escluyíos",
     "Save changes" : "Guardar los cambeos",
+    "Default" : "Por defeutu",
     "Remove" : "Quitar",
     "Featured" : "Destacada",
     "Disable all" : "Desactivar too",
@@ -232,6 +217,13 @@ OC.L10N.register(
     "Results from other categories" : "Resultaos d'otres categoríes",
     "No apps found for your version" : "Nun s'atopó nenguna aplicación pa esta versión",
     "_Update_::_Update all_" : ["Anovar","Anovar too"],
+    "Failed to create group" : "Nun se pue crear el grupu",
+    "Groups" : "Grupos",
+    "Creating group…" : "Creando'l grupu…",
+    "Create group" : "Crear el grupu",
+    "Group name" : "Nome del grupu",
+    "Please enter a valid group name" : "Introduz un nome válidu pal grupu",
+    "Loading groups…" : "Cargando los grupos…",
     "Could not load app discover section" : "Nun se pudo cargar la seición de descubrimientu d'aplicaciones",
     "Could not render element" : "Nun se pudo dibuxar l'elementu",
     "Loading" : "Cargando",
@@ -260,7 +252,7 @@ OC.L10N.register(
     "Resources" : "Recursos",
     "Documentation" : "Documentación",
     "Interact" : "Interactuar",
-    "Report a bug" : "Informar d'un fallju",
+    "Report a bug" : "Informar d'un fallu",
     "Request feature" : "Pidir una función",
     "Ask questions or discuss" : "Entrugar o discutir",
     "Rate" : "Valorar",
@@ -312,6 +304,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "Nun ye posible anovar la opción predeterminada del sirvidor",
     "Profile" : "Perfil",
     "Enable or disable profile by default for new accounts." : "Des/activa'l perfil predetermináu pa les cuentes nueves.",
+    "Password confirmation is required" : "Ríquese la contraseña de confirmación",
     "Failed to save setting" : "Nun se pue guardar la opción",
     "Unable to update server side encryption config" : "Nun ye posible anovar la configuración del cifráu del sirvidor",
     "Server-side encryption" : "Cifráu de llau del sirvidor",
@@ -319,11 +312,9 @@ OC.L10N.register(
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nun se cargó nengún módulu de cifráu, activa unu nel menú d'aplicaciones.",
     "Enable encryption" : "Activar el cifráu",
     "Please read carefully before activating server-side encryption:" : "Llei con procuru enantes d'activar el cifráu nel sirvidor:",
-    "Failed to remove group \"{group}\"" : "Nun se pue quitar el grupu «{group}»",
     "Please confirm the group removal" : "Confirma'l desaniciu del grupu",
     "Submit" : "Unviar",
     "Rename group" : "Renomar el grupu",
-    "Remove group" : "Quitar el grupu",
     "Current password" : "Contraseña actual",
     "New password" : "Contraseña nueva",
     "Change password" : "Camudar la contraseña",
@@ -340,23 +331,23 @@ OC.L10N.register(
     "Set as profile picture" : "Afitar como semeya del perfil",
     "You are a member of the following groups:" : "Yes miembru de los grupos siguientes:",
     "Your full name" : "Nome completu",
+    "Unable to update primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
+    "Unable to delete additional email address" : "Nun ye posible desaniciar la direición de corréu electrónicu adicional",
+    "No email address set" : "Nun s'afitó nenguna direición de corréu electrónicu",
     "Remove primary email" : "Quitar la direición de corréu electrónicu",
     "Delete email" : "Desaniciar la direición de corréu electrónicu",
     "This address is not confirmed" : "Esta direición nun ta confirmada",
     "Set as primary email" : "Afitar como direición de corréu electrónicu primaria",
     "Unable to delete primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
-    "Unable to update primary email address" : "Nun ye posible desaniciar la direición de corréu electrónicu primaria",
     "Unable to add additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
     "Unable to update additional email address" : "Nun ye posible amestar la direición de corréu electrónicu adicional",
-    "Unable to delete additional email address" : "Nun ye posible desaniciar la direición de corréu electrónicu adicional",
-    "No email address set" : "Nun s'afitó nenguna direición de corréu electrónicu",
+    "No language set" : "Nun s'afitó nenguna llingua",
     "Unable to update language" : "Nun ye posible anovar la llingua",
     "Languages" : "Llingües",
     "Help translate" : "Ayudar a traducir",
-    "No language set" : "Nun s'afitó nenguna llingua",
+    "No locale set" : "Nun s'afitó nenguna locale",
     "Unable to update locale" : "Nun ye posible anovar la locale",
     "Locales" : "Locales",
-    "No locale set" : "Nun s'afitó nenguna locale",
     "Your city" : "Ciudá",
     "Your organisation" : "Organización",
     "Your phone number" : "Númberu de teléfonu",
@@ -377,12 +368,12 @@ OC.L10N.register(
     "Change" : "Camudar",
     "Delete" : "Desaniciar",
     "Reshare" : "Volver compartir",
+    "School" : "Escuela",
     "Default language" : "Llingua predeterminada",
     "Common languages" : "Llingües habituales",
     "Other languages" : "Otres llingües",
     "Password change is disabled because the master key is disabled" : "El cambéu de contraseña ta desactiváu porque la clave maestra ta desactivada",
     "No accounts" : "Nun hai nenguna cuenta",
-    "Loading accounts …" : "Cargando les cuentes…",
     "Manager" : "Xestor",
     "Set line manager" : "Afitar el xestor de llinies",
     "New account" : "Cuenta nueva",
@@ -412,7 +403,6 @@ OC.L10N.register(
     "Password was successfully changed" : "La contraseña camudó correutamente",
     "Email was successfully changed" : "La direición de corréu electrónicu camudó correutamente",
     "Welcome mail sent!" : "¡Unvióse'l mensaxe d'acoyida!",
-    "Loading account …" : "Cargando la cuenta…",
     "Change display name" : "Camudar el nome visible",
     "Set new password" : "Afitar una contraseña nueva",
     "You do not have permissions to see the details of this account" : "Nun tienes permisu pa ver los detalles d'esta cuenta",
@@ -436,29 +426,37 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "L'autenticación ensin contraseña rique una conexón segura.",
     "Add WebAuthn device" : "Amestar preséu WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza'l preséu WebAuthn.",
-    "Adding your device …" : "Amestando'l preséu…",
     "Unnamed device" : "Preséu ensin nome",
     "Passwordless Authentication" : "Autenticación ensin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura una cuenta pa l'autenticación ensin contraseña siguiendo l'estándar FIDO2.",
     "No devices configured." : "Nun se configuró nengún preséu.",
     "The following devices are configured for your account:" : "Configuráronse los preseos siguientes pa la cuenta:",
     "Your browser does not support WebAuthn." : "El restolador nun ye compatible con WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ye importante configurar esti sirvidor pa que seya a unviar correos electrónicos de, por exemplu, avisos o solicitúes pa reafitar contraseñes",
+    "Send mode" : "Mou d'unviu",
+    "Encryption" : "Cifráu",
+    "From address" : "De la direición",
+    "Domain" : "Dominiu",
+    "Server address" : "Direición del sirvidor",
+    "Host" : "Agospiador",
+    "Port" : "Puertu",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "L'autenticación ye obligatoria",
+    "Saving…" : "Guardando…",
+    "Security & setup warnings" : "Alvertencies de seguranza y de configuración",
+    "Try again" : "Retentar",
+    "There are some errors regarding your setup." : "Hai dalgunos errores en rellación a la configuración.",
+    "There are some warnings regarding your setup." : "Hai dalgunes alvertencies en rellación a la configuración.",
     "You need to enable the File sharing App." : "Tienes d'activar l'aplicación de compartir ficheros.",
     "App Store" : "Tienda d'aplicaciones",
     "Loading app list" : "Cargando la llista d'aplicaciones",
     "Loading categories" : "Cargando les categoríes",
     "Developer documentation ↗" : "Documentación pa desendolcadores ↗",
     "Version {version}, {license}-licensed" : "Versión {version}, con llicencia {license}",
+    "Apply" : "Aplicar",
     "Admins" : "Alministradores",
     "Account group: {group}" : "Grupu de cuentes: {group}",
-    "Failed to create group" : "Nun se pue crear el grupu",
     "Account management" : "Xestión de cuentes",
-    "Creating group…" : "Creando'l grupu…",
-    "Create group" : "Crear el grupu",
-    "Group name" : "Nome del grupu",
-    "Please enter a valid group name" : "Introduz un nome válidu pal grupu",
-    "Sending…" : "Unviando…",
-    "Email sent" : "Unvióse'l corréu electrónicu",
     "Location" : "Llocalización",
     "Profile picture" : "Semeya del perfil",
     "About" : "Tocante a",
@@ -473,6 +471,14 @@ OC.L10N.register(
     "Website" : "Sitiu web",
     "Profile visibility" : "Visibilidá del perfil",
     "Locale" : "Locale",
+    "Private" : "Priváu",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Namás ye visible pa les persones que concasen pela integración del númberu de teléfonu pente Talk en móviles",
+    "Local" : "Llocal",
+    "Only visible to people on this instance and guests" : "Namás ye visible pa les persones d'esta instancia y los convidaos",
+    "Federated" : "Federada",
+    "Only synchronize to trusted servers" : "Namás sincronizar con sirvidores d'enfotu",
+    "Published" : "Espublizóse",
+    "Synchronize to trusted servers and the global and public address book" : "Sincroniza con sirvidores d'enfotu y la llibreta de direiciones global y pública",
     "Discover" : "Descubrir",
     "Your apps" : "Les to aplicaciones",
     "Active apps" : "Aplicaciones actives",
@@ -507,58 +513,29 @@ OC.L10N.register(
     "General documentation" : "Documentación xeneral",
     "Legal notice" : "Avisu llegal",
     "Privacy policy" : "Política de privacidá",
-    "None/STARTTLS" : "Nada/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir la documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ye importante configurar esti sirvidor pa que seya a unviar correos electrónicos de, por exemplu, avisos o solicitúes pa reafitar contraseñes",
-    "Send mode" : "Mou d'unviu",
-    "Encryption" : "Cifráu",
-    "From address" : "De la direición",
-    "Server address" : "Direición del sirvidor",
-    "Port" : "Puertu",
-    "Authentication" : "Autenticación",
-    "Authentication required" : "L'autenticación ye obligatoria",
-    "SMTP Password" : "Contraseña de SMTP",
-    "Save" : "Guardar",
-    "Security & setup warnings" : "Alvertencies de seguranza y de configuración",
-    "There are some errors regarding your setup." : "Hai dalgunos errores en rellación a la configuración.",
-    "There are some warnings regarding your setup." : "Hai dalgunes alvertencies en rellación a la configuración.",
     "Reasons to use Nextcloud in your organization" : "Razones pa usar Nextcloud na to organzación",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desendolcáu pola {communityopen}comunidá de Nextcloud{linkclose}, el {githubopen}códigu fonte{linkclose} llicénciase baxo l'{licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un préstame a la nuesa páxina de Facebook",
     "Follow us on Mastodon" : "Síguinos en Mastodon",
     "Check out our blog" : "Revisa'l nuesu blogue",
     "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
-    "To allow this check to run you have to make sure that your webserver can connect to itself. Therefor it must be able to resolve and connect to at least one its `trusted_domains` or the `overwrite.cli.url`." : "Pa permitir qu'esta comprobación s'execute, tienes d'asegurate de que'l sirvidor web se pueda conectase. Poro, ha ser a resolver y conectase a, polo menos, unu de los sos «trusted_domains» o al «overwrite.cli.url».",
-    "Missing optional index \"%s\" in table \"%s\"." : "Falta l'índiz opcional «%s» de la tabla «%s».",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos fálten-y dalgunos índices. Como amestar índices a tables grandes pue tardar tiempu, nun s'amestaron automáticamente. Pues executar «occ db:add-missing-columns» p'amestar los índices que falten manualmente cola instancia en funcionamientu. Dempués d'amestar los índices, les consultes que se faigan a eses tables van ser, polo xeneral, muncho más rápides.",
-    "File locking" : "Bloquéu de ficheros",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "El bloquéu de ficheros transaicional ta desactiváu y esto quiciabes produza problemes con condiciones de carrera. Activa «filelocking.enabled» nel ficheru config.php pa evitar estos problemes.",
-    "The PHP memory limit is below the recommended value of %s." : "La llende de memoria de PHP ye inferior al valor aconseyáu de %s.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Úsase la versión «%s» de MariaDB. Nextcloud 21 y les versiones superiores nun son compatibles con esta versión y riquen MariaDB 10.2 ó superior.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Úsase la versión «%s» de MySQL. Nextcloud 21 y les versiones superiores nun son compatibles con esta versión y riquen MySQL 8.0 ó MariaDB 10.2 ó superiores.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Úsase la versión «%s» de PostgreSQL. Nextcloud 21 y les versiones superiores nun son compatibles con esta versión y riquen PostgreSQL 9.6 ó superior.",
-    "Speech-To-Text" : "Voz a testu",
-    "Your biography" : "Biografía",
-    "You are using <strong>{usage}</strong>" : "Tas usando <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Tas usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Afitar el xestor d'usuarios",
-    "Username will be autogenerated" : "El nome d'usuariu va xenerase automáticamente",
-    "Username (required)" : "Nome d'usuariu (obligatoriu)",
-    "New user" : "Usuariu nuevu",
-    "Groups (required)" : "Grupos (obligatorios)",
-    "Administered groups" : "Grupos alministraos",
-    "Set user quota" : "Afitar la cuota d'usuariu",
-    "Add new user" : "Amestar un usuariu nuevu",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuariu…","{userCount} usuarios…"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} usuariu","{userCount} usuarios"],
-    "Loading users …" : "Cargando los usuarios…",
-    "Username" : "Nome d'usuariu",
-    "User backend" : "Backend d'usuarios",
-    "User actions" : "Aiciones del ususariu",
-    "Add user to group" : "Amestar l'usuariu al grupu",
-    "Server error while trying to add WebAuthn device" : "Error del sirvidor mentanto s'amestaba'l preséu WebAuthn",
-    "Active accounts" : "Cuentes actives",
-    "Follow us on Twitter" : "Síguinos en Twitter"
+    "Open documentation" : "Abrir la documentación",
+    "Very weak password" : "La contraseña ye mui poco segura",
+    "Weak password" : "La contraseña ye poco segura",
+    "So-so password" : "La contraseña ye normal",
+    "Good password" : "La contraseña ye segura",
+    "Strong password" : "La contraseña ye mui segura",
+    "Group list is empty" : "La llista de grupos ta balera",
+    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
+    "Logged in account must be a subadmin" : "La cuenta qu'anició la sesión ha ser un soalministrador",
+    "Loading accounts …" : "Cargando les cuentes…",
+    "Loading account …" : "Cargando la cuenta…",
+    "Adding your device …" : "Amestando'l preséu…",
+    "Sending…" : "Unviando…",
+    "Email sent" : "Unvióse'l corréu electrónicu",
+    "None/STARTTLS" : "Nada/STARTTLS",
+    "SSL" : "SSL",
+    "SMTP Password" : "Contraseña de SMTP",
+    "Save" : "Guardar"
 },
 "nplurals=2; plural=(n != 1);");
