@@ -1,22 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Prevez",
-    "Local" : "Diabarzh",
-    "Federated" : "Kevredet",
-    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
-    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
-    "Verify" : "Gwiriañ",
-    "Verifying …" : "O wiriañ...",
-    "Unable to change password" : "N'eo ket  bet posupl cheñch ar ger-tremen",
-    "Very weak password" : "Ger-tremen skanv kenan",
-    "Weak password" : "Ger-tremen skanv",
-    "So-so password" : "Ger-tremen skañvig",
-    "Good password" : "Ger-tremen mat",
-    "Strong password" : "Ger-tremen kreñv",
-    "Groups" : "Strolladoù",
-    "Group list is empty" : "Listenn strollat goulo",
-    "Unable to retrieve the group list" : "Dibosupl eo adtapout al listenn strollad",
     "{actor} added you to group {group}" : "{actor} en deus ouzhpennet ac'hnnoc'h er strollad {group}",
     "You added {user} to group {group}" : "Ouzhpennet o peus {user} et strollad {group}",
     "{actor} added {user} to group {group}" : "{actor} En deus ouzhpennet {user} d'ar strollad {group}",
@@ -48,6 +32,7 @@ OC.L10N.register(
     "Settings" : "Arventennoù",
     "Wrong password" : "Ger-tremen fall",
     "Saved" : "Enrollet",
+    "Unable to change password" : "N'eo ket  bet posupl cheñch ar ger-tremen",
     "Authentication error" : "Fazi dilesa",
     "Wrong admin recovery password. Please check the password and try again." : "Ger-tremen adtapout ar merour fall. Gwiriit ar ger-tremen ha klaskit en dro.",
     "Administrator documentation" : "Dielvadur ar merour",
@@ -60,7 +45,7 @@ OC.L10N.register(
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ur gudenn a zo bet en ur kas ar bostel. Adstummit o stumm (Fazi : %s)",
     "Invalid mail address" : "Chom-lec'h postel fall",
     "Settings saved" : "Stummoù enrollet",
-    "Unable to change full name" : "Dibosupl cheñch tout an anv",
+    "Unable to change full name" : "N'haller ket cheñch an anv klok",
     "Unable to change email address" : "Dibosuple cheñch ar chom-lec'h postel",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Evit gwiriañ ho c'hont Twitter, kasit an tweet mañ war Twitter (bezit sur kas anezhañ hep teriñ al linenn) :",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Evit wiriañ ho Website, gwarnit an traoù goude en o gwrizienn-web e  '.well-known/CloudIdVerificationCode.txt' (bezit sur eo tout an destenn war ul linenn nemetken) :",
@@ -88,6 +73,7 @@ OC.L10N.register(
     "Administration" : "Merouriez",
     "Users" : "Implijer",
     "Additional settings" : "Stummoù ouzhpenn",
+    "Assistant" : "Skoazeller",
     "Groupware" : "Labour a stroll",
     "Overview" : "Taol-lagad",
     "Basic settings" : "Stummoù diazez",
@@ -99,12 +85,14 @@ OC.L10N.register(
     "Background jobs" : "Labour diadreñv",
     "Unlimited" : "Didermenet",
     "Verifying" : "O gwiriañ",
+    "Verifying …" : "O wiriañ...",
+    "Verify" : "Gwiriañ",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
     "Disabled" : "Disaotreañ",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Stumm ar sifrañ kostez ar servijour kozh a zo aotreet. Aliet eo hen disaotreañ.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
     "Supported" : "Douget",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù profil ha stummoù an etrefas.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
@@ -143,13 +131,14 @@ OC.L10N.register(
     "Results from other categories" : "Disoc'hoù evit rummadoù all",
     "No apps found for your version" : "Meziant ebet kavet evit ar stumm",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ"],
+    "Groups" : "Strolladoù",
     "Loading" : "Kargañ",
-    "Type" : "Stumm",
+    "Type" : "Seurt",
     "Learn more" : "Deskiñ muioc'h",
     "Confirm" : "Kadarnañ",
-    "Cancel" : "Arrest",
+    "Cancel" : "Nullañ",
     "Description" : "Deskrivadur",
-    "View in store" : "Gwellet er stall",
+    "View in store" : "Gwelet er stal",
     "Visit website" : "Mont war al lec'hienn",
     "Admin documentation" : "Dielvadur ar merour",
     "Developer documentation" : "Diellvadur an digeler",
@@ -158,13 +147,12 @@ OC.L10N.register(
     "Limit app usage to groups" : "Lakaat ar meziant da veza implijet gant ar strolladoù nemetken",
     "No results" : "Disoc'h ebet",
     "Update to {version}" : "Oc'h adneveziñ da {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "N'en deus ket ar meziant ur stumm izelañ evit Nextcloud. Ur fazi a vo en dazont.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ar meziant n'en deus ket ur stumm huela eus Nextcloud merked. Ur fazi vo en dazont.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "N'eo ket posupl staliañ ar meziant peogwir n'eo ket bet graet war dro an amzalc'hioù :",
     "Categories" : "Rummadoù",
     "Documentation" : "Diellvadur",
     "Report a bug" : "Dugas ur gudenn",
     "Google Chrome for Android" : "Google Chrome evit Android",
+    "{productName} Android app" : "{productName} Arload Android",
     "This session" : "An estez-mañ",
     "Marked for remote wipe" : "Market evit bezañ lamet a bell",
     "Device settings" : "Stummoù ardivink",
@@ -184,6 +172,7 @@ OC.L10N.register(
     "Password" : "Ger-tremen",
     "Show QR code for mobile apps" : "Diskouez ar c'hod QR evit ar meziant hezouk",
     "Use system cron service to call the cron.php file every 5 minutes." : "Implijit sevichoù ar sistem cron evit gervel restr cron.php pep 5 munutenn.",
+    "Profile" : "Profil",
     "Server-side encryption" : "Sifradur ar servijour-goztez",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sifradur kostez-srvijour aotre ar sifrañ restroù a vez pellkarget war ar servijour. Bevennet eo an ober, evel ur mont en dro gorekoc'h, n'a implijit se nemet m'az o peus ezhomm neuze.",
     "Enable server-side encryption" : "Aotrea sifradur kostez-servijour",
@@ -196,21 +185,21 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mat eo kaout ur vackup reoliek eus o roadennoù, ha e bezit sur ober ur vackup eus an alrv'hwez sifrañ gant o roadennoù sifret.",
     "This is the final warning: Do you really want to enable encryption?" : "Kemenadenn diwall divezhañ : Sur oc'h aotreañ ar sifrañ ?",
     "Submit" : "Kinnig",
-    "Remove group" : "Lemel strollad",
     "Current password" : "Ger-tremen hiziv",
     "New password" : "Ger-tremen nevez",
-    "Change password" : "Cheñch ger-tremen",
     "Picture provided by original account" : "Skeudenn roet gant ar c'hont orin",
+    "Unable to update date of birth" : "N'haller ket cheñch an deiziad ganedigezh",
+    "Enter your date of birth" : "Lakaat ho teiziad ganedigezh",
     "You are a member of the following groups:" : "Er strolladoù-mañ emaoc'h",
     "No email address set" : "Chom-lec'h postel ebet lakaet",
-    "Help translate" : "Sikour treiñ",
     "No language set" : "Yezh ebet lakaet",
+    "Help translate" : "Sikour treiñ",
+    "Week starts on {firstDayOfWeek}" : "Krog a ra ar sizunn gant {firstDayOfWeek}",
     "Your phone number" : "O niverenn pelgomzer",
-    "Add" : "Ouzhpennañ",
-    "Create" : "Krouiñ",
     "Change" : "Cheñch",
     "Delete" : "Dilemel",
     "Reshare" : "Adrannañ",
+    "School" : "Skol",
     "Default language" : "Yezh dre ziouer",
     "Common languages" : "Yezh boutiñ",
     "Password change is disabled because the master key is disabled" : "N'eo ket aotreet cheñch ger-tremen peogwir n'eo ket aotreet an alc'hwez meur",
@@ -224,15 +213,14 @@ OC.L10N.register(
     "Last login" : "Mont-tre divezhañ",
     "{size} used" : "{size} implijet",
     "Resend welcome email" : "Adkas ar postel degemer mat",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
     "Remote wipe of devices" : "Lemel a bell an ardivink",
     "Wipe {userid}'s devices" : "Lemel ardivink {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Lemet eo bet penn-da-benn kont {userid} gant pep restr personnel, roadennoù meziant, hag-all-hag-all.",
     "Account deletion" : "Lemel ar c'hont",
-    "Delete {userid}'s account" : "Lemel kont {userid}",
+    "Delete {userid}'s account" : "Dilemel kont {userid}",
     "Welcome mail sent!" : "Postel degemer kaset !",
     "Done" : "Graet",
-    "Edit" : "Cheñch",
+    "Edit" : "Embann",
     "Show storage path" : "Diskouez an hent klenkañ",
     "Show last login" : "Diskouez ar c'hennask diwezhañ",
     "Send email" : "Kas postel",
@@ -242,25 +230,43 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Ret eo kaout ur c'henstagadur sur evit un dilesa di-ger-tremen.",
     "Add WebAuthn device" : "Ouzhpenn ardivink WebAuthn",
     "Please authorize your WebAuthn device." : "Aotreit o ardivink WebAuthn.",
-    "Adding your device …" : "Ouehpennit ho ardivink ...",
     "Unnamed device" : "Ardivink hep anv",
     "Passwordless Authentication" : "Dilesa hep ger-tremen",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Lakaat o c'hont da implij an dilesa hap ger-tremen en ur heuliañ ar standart FIDO2.",
     "No devices configured." : "Ardivink stummet ebet.",
     "The following devices are configured for your account:" : "Stummet eo bet an ardivinkoù ma d'ho c'hont.",
     "Your browser does not support WebAuthn." : "Ne vez ket douget WebAuthn gant o furcher.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Pouezus eo stummañ ar servijour avit ma c'helfe kas posteloù, evit kemenadennoù pe posteloù evit cheñch ar ger-tremen.",
+    "Send mode" : "Mod kas",
+    "Encryption" : "Sifradur",
+    "Sendmail mode" : "Mod kas-postel",
+    "From address" : "Eus chom-lec'h",
+    "Domain" : "Domani",
+    "Server address" : "Chom-lec'h ar servijour",
+    "Host" : "Ostiz",
+    "Port" : "Porzh",
+    "Authentication required" : "Eus un dilesa ez eus ezhomp",
+    "Security & setup warnings" : "Kemmenadennoù suretez ha stumm",
+    "All checks passed." : "Pep gwiriekadenn tremenat.",
+    "There are some errors regarding your setup." : "Fazioù 'zo liammet do staliadur.",
+    "There are some warnings regarding your setup." : "Diwal a zo liammet d'o staliadur.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Evel ar merour eo posupl deoc'h stumañ pizh penaos e vez rannet. Sellit ouz an diellvadur evit muioc'h a ditouroù.",
+    "Apply" : "Lakaat",
     "Admins" : "Merourien",
-    "Sending…" : "O kas...",
-    "Email sent" : "Postel kaset",
     "Location" : "Lec'hiadur",
-    "Profile picture" : "Skeudenn trolinenn",
+    "Profile picture" : "Skeudenn brofil",
     "About" : "Diwar-benn",
-    "Full name" : "Tout an anv",
-    "Phone number" : "Niverenn pellgomzer",
+    "Date of birth" : "Deiziad ganedigezh",
+    "Full name" : "Anv klok",
+    "Phone number" : "Niverenn bellgomz",
     "Role" : "Roll",
-    "Website" : "Lec'hien web",
+    "Website" : "Lec'hienn web",
     "Locale" : "Diabarzh",
+    "Private" : "Prevez",
+    "Local" : "Diabarzh",
+    "Federated" : "Kevredet",
+    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
+    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
     "Your apps" : "Ho meziantoù",
     "Active apps" : "Meziantoù lakaet en dro",
     "Disabled apps" : "Meziantoù disaotreet",
@@ -270,7 +276,6 @@ OC.L10N.register(
     "Hide" : "Kouacha",
     "Download and enable" : "Pellgargañ ha aotreañ",
     "Disable" : "Disaotreañ",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
     "Unknown" : "Dianv",
     "Never" : "James",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aotreet eo bet ar meziant mes ezomm e deus bezhan adnevesaet. Kaset a voc'h d'ar bajenn adneveziñ a benn 5 eilenn.",
@@ -283,40 +288,33 @@ OC.L10N.register(
     "Error" : "Fazi",
     "Forum" : "Forum",
     "Legal notice" : "Meneg lezenn",
-    "Open documentation" : "Digeriñ an dielvadur",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Pouezus eo stummañ ar servijour avit ma c'helfe kas posteloù, evit kemenadennoù pe posteloù evit cheñch ar ger-tremen.",
-    "Send mode" : "Mod kas",
-    "Encryption" : "Sifradur",
-    "Sendmail mode" : "Mod kas-postel",
-    "From address" : "Eus chom-lec'h",
-    "Server address" : "Chom-lec'h ar servijour",
-    "Port" : "Porzh",
-    "Authentication required" : "Eus un dilesa ez eus ezhomp",
-    "Credentials" : "Kretaatoù",
-    "SMTP Password" : "Ger-tremen SMTP",
-    "Save" : "Enrollañ",
-    "Security & setup warnings" : "Kemmenadennoù suretez ha stumm",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
-    "All checks passed." : "Pep gwiriekadenn tremenat.",
-    "There are some errors regarding your setup." : "Fazioù 'zo liammet do staliadur.",
-    "There are some warnings regarding your setup." : "Diwal a zo liammet d'o staliadur.",
-    "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sellit ouzh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">sturier ar staliañ ↗</a>, ha gwiriit ne vefe fazi pe diwal ebet er <a href=\"%2$s\">gazetenn</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Gwiriit surentez ho Nextcoud war <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hon skan surentez ↗</a>.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Digelet gant {communityopen}kummuniezh NExtcloud{linkclose}, ar {githubopen}c'hod orin{linkclose} a zo dindan aotre {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Liamm d'hon bajenn Facebook",
     "Follow us on Mastodon" : "Heuliit arc'hanomp war Mastodon",
     "Check out our blog" : "Sellit ouzh hon vlog",
     "Subscribe to our newsletter" : "Koumannantit d'hon kemenadennoù nevesadur",
+    "Open documentation" : "Digeriñ an dielvadur",
     "Use a second factor besides your password to increase security for your account." : "Implijour un eil-elfenn d'ho ger-tremen a gwella urentez o c'hont.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankout a ra rollioù er roadenn-diaz. Abalamour e kemer amzer ouzhpennañ rollioù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-indices\" eo posupl ouzhpennañ ar rollioù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ar rollioù ouzhpennet, goulennoù savet d'an taolennoù a vo buanaet.",
-    "Set default expiration date for shares" : "Lakaat un deizat termen dre ziouer evit ar rannañ",
-    "New user" : "Implijer nevez",
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} implijer","{userCount} implijer","{userCount} implijer","{userCount} implijer","{userCount} implijer"],
-    "Username" : "anv implijer",
-    "User backend" : "Backen implijer",
-    "Server error while trying to add WebAuthn device" : "Ur fazi servijour a zo bet pa oa ouzhpennet an ardivink WebAuthn",
-    "Name your device" : "Anvit o ardivink",
-    "Follow us on Twitter" : "Heuliit ac'henomp war Twitter"
+    "Very weak password" : "Ger-tremen skanv kenan",
+    "Weak password" : "Ger-tremen skanv",
+    "So-so password" : "Ger-tremen skañvig",
+    "Good password" : "Ger-tremen mat",
+    "Strong password" : "Ger-tremen kreñv",
+    "Group list is empty" : "Listenn strollat goulo",
+    "Unable to retrieve the group list" : "Dibosupl eo adtapout al listenn strollad",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "N'en deus ket ar meziant ur stumm izelañ evit Nextcloud. Ur fazi a vo en dazont.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ar meziant n'en deus ket ur stumm huela eus Nextcloud merked. Ur fazi vo en dazont.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
+    "Adding your device …" : "Ouehpennit ho ardivink ...",
+    "Sending…" : "O kas...",
+    "Email sent" : "Postel kaset",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
+    "Credentials" : "Kretaatoù",
+    "SMTP Password" : "Ger-tremen SMTP",
+    "Save" : "Enrollañ",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
+    "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sellit ouzh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">sturier ar staliañ ↗</a>, ha gwiriit ne vefe fazi pe diwal ebet er <a href=\"%2$s\">gazetenn</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Gwiriit surentez ho Nextcoud war <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hon skan surentez ↗</a>."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
