@@ -1,18 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Local" : "Local",
-    "Federated" : "Federado",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando ...",
-    "Unable to change password" : "No fue posible cambiar la contraseña",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -26,6 +14,7 @@ OC.L10N.register(
     "Settings" : "Configuraciones ",
     "Wrong password" : "Contraseña incorrecta",
     "Saved" : "Guardado",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Authentication error" : "Error de autenticación",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
     "Administrator documentation" : "Documentación del adminsitrador",
@@ -75,6 +64,8 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando ...",
+    "Verify" : "Verificar",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
@@ -101,6 +92,8 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Groups" : "Grupos",
+    "Group name" : "Nombre del grupo",
     "Type" : "Tipo",
     "Display Name" : "Nombre a desplegar",
     "Learn more" : "Conoce más",
@@ -115,8 +108,6 @@ OC.L10N.register(
     "All" : "Todos",
     "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
     "Categories" : "Categorías",
     "Resources" : "Recursos",
@@ -127,9 +118,9 @@ OC.L10N.register(
     "Rate" : "Calificar",
     "Changelog" : "Bitácora de cambios",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} aplicación Android",
     "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
-    "Rename" : "Renombrar",
     "Revoke" : "Revocar",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
@@ -140,6 +131,7 @@ OC.L10N.register(
     "Create new app password" : "Crear una nueva contraseña de aplicación",
     "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
+    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
@@ -154,20 +146,17 @@ OC.L10N.register(
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
+    "Change password" : "Cambiar password",
     "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayuda a traducir",
     "Your phone number" : "Su número telefónico",
     "Your website" : "Tu sitio web",
-    "Add" : "Agregar",
-    "Create" : "Crear",
+    "Add" : "Guardar",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
-    "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
-    "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
     "Group admin for" : "Administrador del grupo para",
@@ -175,17 +164,30 @@ OC.L10N.register(
     "Last login" : "Último inicio de sesión",
     "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
-    "Done" : "Terminado",
     "Edit" : "Editar",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
+    "Send mode" : "Modo de envío",
+    "Encryption" : "Encripción",
+    "From address" : "De la dirección",
+    "Domain" : "Dominio",
+    "Server address" : "Dirección del servidor",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "Autenticación requerida",
+    "Saving…" : "Guardando...",
+    "Save settings" : "Guardar configuraciones",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Try again" : "Reintentar",
+    "All checks passed." : "Pasaron todas las verificaciones. ",
+    "There are some warnings regarding your setup." : "Hay advertencias respecto de la configuración.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
+    "Apply" : "Aplicar",
     "Admins" : "Administradores",
-    "Group name" : "Nombre del grupo",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
@@ -193,6 +195,9 @@ OC.L10N.register(
     "Phone number" : "Número de teléfono",
     "Website" : "Sitio web",
     "Locale" : "Región",
+    "Private" : "Privado",
+    "Local" : "Local",
+    "Federated" : "Federado",
     "Your apps" : "Tus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
     "Updates" : "Actualizaciones",
@@ -203,29 +208,24 @@ OC.L10N.register(
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
     "Forum" : "Foro",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
-    "Send mode" : "Modo de envío",
-    "Encryption" : "Encripción",
-    "From address" : "De la dirección",
-    "Server address" : "Dirección del servidor",
-    "Port" : "Puerto",
-    "Authentication" : "Autenticación",
-    "Authentication required" : "Autenticación requerida",
-    "Credentials" : "Credenciales",
-    "SMTP Password" : "Contraseña SMTP",
-    "Save" : "Guardar",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "All checks passed." : "Pasaron todas las verificaciones. ",
-    "There are some warnings regarding your setup." : "Hay advertencias respecto de la configuración.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revise la seguridad de su Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">el escáner de seguridad ↗</a>.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Username" : "Usuario",
-    "User backend" : "Backend del usuario",
-    "Follow us on Twitter" : "Síguenos en Twitter"
+    "Open documentation" : "Abrir documentación",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "SSL" : "SSL",
+    "Credentials" : "Credenciales",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revise la seguridad de su Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">el escáner de seguridad ↗</a>."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
