@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coincidan con la integración del número de teléfono a través de Talk en el móvil",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Sólo visible para personas en esta instancia e invitados",
-    "Federated" : "Federado",
-    "Only synchronize to trusted servers" : "Sincronizar sólo con servidores de confianza",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y con la libreta de direcciones global y pública",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando ...",
-    "Unable to change password" : "No fue posible cambiar la contraseña",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La lista de grupos está vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista de grupos",
     "{actor} added you to group {group}" : "{actor} te agregó al grupo {group}",
     "You added {user} to group {group}" : "Agregaste a {user} al grupo {group}",
     "{actor} added {user} to group {group}" : "{actor} agregó a {user} al grupo {group}",
@@ -57,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "No se pudo cambiar la contraseña personal",
     "Saved" : "Guardado",
     "No Login supplied" : "No se especificó un usuario",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Unable to change password. Password too long." : "No se pudo cambiar la contraseña. La contraseña es demasiado larga.",
     "Authentication error" : "Error de autenticación",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Por favor proporcioná una contraseña de recuperación de administrador; de lo contrario, toda la información de la cuenta se perderá.",
@@ -110,7 +92,7 @@ OC.L10N.register(
     "Administration" : "Administración",
     "Users" : "Usuarios",
     "Additional settings" : "Configuraciones adicionales",
-    "Artificial Intelligence" : "Inteligencia artificial",
+    "Assistant" : "Asistente",
     "Administration privileges" : "Privilegios de administración",
     "Groupware" : "Software colaborativo",
     "Overview" : "Visión general",
@@ -120,6 +102,7 @@ OC.L10N.register(
     "Calendar" : "Calendario",
     "Personal info" : "Información personal",
     "Mobile & desktop" : "Móvil & escritorio",
+    "Artificial Intelligence" : "Inteligencia artificial",
     "Email server" : "Servidor de correo electrónico",
     "Mail Providers" : "Proveedores de correo electrónico",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "El proveedor de correo electrónico permite enviar correos electrónicos directamente a través de la cuenta de correo personal del usuario. En la actualidad, esta funcionalidad se limita a las invitaciones de calendario. Requiere Nextcloud Mail 4.1 y una cuenta de correo electrónico en Nextcloud Mail que coincida con la dirección de correo electrónico del usuario en Nextcloud.",
@@ -130,6 +113,8 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando ...",
+    "Verify" : "Verificar",
     "Allowed admin IP ranges" : "Rangos de IP permitidos para administración",
     "Admin IP filtering isn't applied." : "No se ha aplicado ningún filtro de IP para administración.",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "El parámetro de configuración \"%1$s\" espera un array (se encontró %2$s). No se aplicará la validación de rangos de IP para administración.",
@@ -274,6 +259,7 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
     "Failed to create group" : "No se pudo crear el grupo",
+    "Groups" : "Grupos",
     "Creating group…" : "Creando grupo…",
     "Create group" : "Crear grupo",
     "Group name" : "Nombre del grupo",
@@ -291,10 +277,8 @@ OC.L10N.register(
     "Developer documentation" : "Documentación del desarrollador",
     "Details" : "Detalles",
     "All" : "Todos",
-    "No results" : "Sin resultados",
+    "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
     "Categories" : "Categoría",
     "Resources" : "Recursos",
@@ -305,6 +289,7 @@ OC.L10N.register(
     "Rate" : "Calificar",
     "Changelog" : "Bitácora de cambios",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} aplicación Android",
     "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
@@ -321,6 +306,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "No se pudo actualizar la configuración por defecto del perfil",
     "Profile" : "Perfil",
     "Enable or disable profile by default for new accounts." : "Habilitar o deshabilitar el perfil por defecto para cuentas nuevas.",
+    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
     "Failed to save setting" : "No se pudo guardar la configuración",
     "{app}'s declarative setting field: {name}" : "Campo de configuración declarativa de {app}: {name}",
     "Unable to update server side encryption config" : "No se pudo actualizar la configuración de cifrado en el servidor",
@@ -343,15 +329,11 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea crear copias de seguridad de tus datos, en el caso del cifrado asegurate de tener una copia de seguridad de las claves de cifrado junto con tus datos.",
     "Refer to the admin documentation on how to manually also encrypt existing files." : "Consultá la documentación del administrador para saber cómo cifrar manualmente también los archivos existentes.",
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final. ¿Realmente querés activar el cifrado?",
-    "Failed to remove group \"{group}\"" : "No se pudo eliminar el grupo \"{group}\"",
     "Please confirm the group removal" : "Por favor confirmá la eliminación del grupo",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Vas a eliminar el grupo {group}. Los usuarios NO serán eliminados.",
     "Submit" : "Enviar",
     "Rename group" : "Cambiar nombre del grupo",
-    "Remove group" : "Eliminar grupo",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
     "Choose your profile picture" : "Elegí tu foto del perfil",
     "Please select a valid png or jpg file" : "Por favor, seleccioná un archivo PNG o JPG válido",
     "Error setting profile picture" : "Error al establecer la foto del perfil",
@@ -373,6 +355,9 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Estás usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Sos miembro de los siguientes grupos:",
     "Your full name" : "Tu nombre completo",
+    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
+    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
+    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Email options" : "Opciones de correo electrónico",
     "Options for additional email address {index}" : "Opciones para la dirección de correo electrónico adicional {index}",
     "Remove primary email" : "Eliminar correo electrónico principal",
@@ -382,25 +367,22 @@ OC.L10N.register(
     "Set as primary email" : "Establecer como correo electrónico principal",
     "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
     "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
-    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
     "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
     "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
-    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
     "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer la contraseña y notificaciones",
-    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Your handle" : "Tu usuario",
     "Derived from your locale ({weekDayName})" : "Obtenido de tu locale ({weekDayName})",
     "Unable to update first day of week" : "No se pudo modificar el primer día de la semana",
     "Day to use as the first day of week" : "Primer día de la semana",
     "Your headline" : "Tu titular",
+    "No language set" : "No hay ningún idioma configurado",
     "Unable to update language" : "No se pudo actualizar tu idioma",
     "Languages" : "Idiomas",
     "Help translate" : "Ayudá a traducir",
-    "No language set" : "No hay ningún idioma configurado",
+    "No locale set" : "No hay ninguna configuración regional",
     "Unable to update locale" : "No se pudo actualizar la configuración regional",
     "Locales" : "Configuración regional",
     "Week starts on {firstDayOfWeek}" : "La semana empieza el {firstDayOfWeek}",
-    "No locale set" : "No hay ninguna configuración regional",
     "Your city" : "Tu ciudad",
     "Your organisation" : "Tu organización",
     "Your phone number" : "Tu número de teléfono",
@@ -413,13 +395,12 @@ OC.L10N.register(
     "he/him" : "él",
     "they/them" : "elle",
     "Your role" : "Tu rol",
+    "Timezone" : "Zona horaria",
     "Your X (formerly Twitter) handle" : "Tu usuario de X (anteriormente Twitter)",
     "Your website" : "Tu sitio web",
     "Add" : "Agregar",
-    "Create" : "Crear",
     "Change" : "Cambiar",
-    "Delete" : "Borrar",
-    "Display name" : "Nombre para mostrar",
+    "Delete" : "Eliminar",
     "Email" : "Correo electrónico",
     "Quota" : "Cuota",
     "Language" : "Idioma",
@@ -437,7 +418,6 @@ OC.L10N.register(
     "Disable account" : "Deshabilitar la cuenta",
     "Enable account" : "Habilitar la cuenta",
     "Resend welcome email" : "Volver a enviar el correo electrónico de bienvenida",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Funciona únicamente si los dispositivos están conectados a Internet.",
     "Remote wipe of devices" : "Borrado remoto de dispositivos",
     "Wipe {userid}'s devices" : "Borrar los dispositivos de {userid}",
     "Wiped {userid}'s devices" : "Se borraron los dispositivos de {userid}",
@@ -451,7 +431,6 @@ OC.L10N.register(
     "Email can't be empty" : "El correo electrónico no puede estar en blanco",
     "Email was successfully changed" : "El correo electrónico se cambió correctamente",
     "Welcome mail sent!" : "¡Correo electrónico de bienvenida enviado!",
-    "Loading account …" : "Cargando cuenta ...",
     "Change display name" : "Cambiar el nombre a mostrar",
     "Set new password" : "Establecer nueva contraseña",
     "You do not have permissions to see the details of this account" : "No tenés permisos para ver los detalles de esta cuenta",
@@ -484,13 +463,29 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
     "Add WebAuthn device" : "Agregar dispositivo WebAuthn",
     "Please authorize your WebAuthn device." : "Autorizá tu dispositivo WebAuthn.",
-    "Adding your device …" : "Agregando tu dispositivo...",
     "Unnamed device" : "Dispositivo sin nombre",
     "Passwordless Authentication" : "Autenticación sin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configurá tu cuenta para la autenticación sin contraseña siguiendo el estándar FIDO2.",
     "No devices configured." : "No hay ningún dispositivo configurado.",
     "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para tu cuenta:",
     "Your browser does not support WebAuthn." : "Tu navegador no admite WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
+    "Send mode" : "Modo de envío",
+    "Encryption" : "Cifrado",
+    "Sendmail mode" : "Modo Sendmail",
+    "From address" : "Desde la dirección",
+    "Domain" : "Dominio",
+    "Server address" : "Dirección del servidor",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "Autenticación requerida",
+    "Saving…" : "Guardando...",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Try again" : "Inténtalo de nuevo",
+    "All checks passed." : "Todas las verificaciones fueron exitosas.",
+    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
+    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, usted puede hacer ajustes finos al comportamiento de compartir. Favor de consultar la documentación para más información. ",
     "You need to enable the File sharing App." : "Tenés que habilitar la aplicación Compartir archivos.",
     "App Store" : "Tienda de aplicaciones",
@@ -499,13 +494,11 @@ OC.L10N.register(
     "Developer documentation ↗" : "Documentación del desarrollador ↗",
     "Version {version}, {license}-licensed" : "Versión {version}, bajo licencia {license}",
     "Version {version}" : "Versión {version}",
+    "Apply" : "Aplicar",
     "All accounts" : "Todas las cuentas",
     "Admins" : "Administradores",
     "Account group: {group}" : "Grupo de cuentas: {group}",
     "Account management" : "Administración de cuentas",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
-    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Por razones de rendimiento, cuando actives el cifrado en un servidor Nextcloud sólo se cifrarán los archivos nuevos y modificados.",
     "Location" : "Ubicación",
     "Profile picture" : "Foto del perfil",
     "About" : "Acerca de",
@@ -523,8 +516,16 @@ OC.L10N.register(
     "Profile visibility" : "Visibilidad del perfil",
     "Locale" : "Configuración regional",
     "First day of week" : "Primer día de la semana",
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coincidan con la integración del número de teléfono a través de Talk en el móvil",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No está disponible porque esta propiedad es necesaria para la funcionalidad básica, incluyendo el compartir archivos y las invitaciones de calendario",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Sólo visible para personas en esta instancia e invitados",
+    "Federated" : "Federado",
+    "Only synchronize to trusted servers" : "Sincronizar sólo con servidores de confianza",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "No está disponible porque la federación está deshabilitada para tu cuenta. Ponete en contacto con el administrador del sistema si tenés alguna duda.",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y con la libreta de direcciones global y pública",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "No está disponible porque no está permitida la publicación de datos específicos de cuentas en el servidor de búsqueda. Ponete en contacto con el administrador del sistema si tenés alguna duda",
     "Discover" : "Descubrí",
     "Your apps" : "Tus aplicaciones",
@@ -538,15 +539,12 @@ OC.L10N.register(
     "Show to logged in accounts only" : "Visible únicamente para usuarios conectados",
     "Hide" : "Invisible",
     "Manually installed apps cannot be updated" : "Las aplicaciones instaladas manualmente no pueden ser actualizadas",
-    "{progress}% Deploying …" : "Desplegando {progress}%",
-    "{progress}% Initializing …" : "Inicializando {progress}%",
     "Health checking" : "Revisión de salud del servidor",
     "Deploy and Enable" : "Desplegar y habilitar",
     "Download and enable" : "Descargar y habilitar",
     "Disable" : "Deshabilitar",
     "Allow untested app" : "Permitir aplicación no probada",
     "The app will be downloaded from the App Store" : "La aplicación será descargada de la tienda de aplicaciones",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continuás podrás instalar la aplicación, pero tené en cuenta que podría no funcionar según lo esperado.",
     "Unknown" : "Desconocido",
     "Never" : "Nunca",
     "Could not register device: Network error" : "No se pudo registrar el dispositivo: error de red",
@@ -572,31 +570,6 @@ OC.L10N.register(
     "General documentation" : "Documentación general",
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Políticas de privacidad",
-    "None/STARTTLS" : "Ninguno/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir la documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
-    "Send mode" : "Modo de envío",
-    "Encryption" : "Cifrado",
-    "Sendmail mode" : "Modo Sendmail",
-    "From address" : "Desde la dirección",
-    "Server address" : "Dirección del servidor",
-    "Port" : "Puerto",
-    "Authentication" : "Autenticación",
-    "Authentication required" : "Autenticación requerida",
-    "Credentials" : "Credenciales",
-    "SMTP Login" : "Inicio de sesión SMTP",
-    "SMTP Password" : "Contraseña SMTP",
-    "Save" : "Guardar",
-    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso estamos haciendo algunas comprobaciones automáticas. Consultá la documentación para mayor información.",
-    "All checks passed." : "Todas las verificaciones fueron exitosas.",
-    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
-    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
-    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, volvé a consultar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, y comprobá posibles errores y advertencias en el <a href=\"%2$s\">registro</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revisá la seguridad de tu Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escáner de seguridad ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Motivos para usar Nextcloud en tu organización",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Me gusta en nuestra página de Facebook",
@@ -605,39 +578,38 @@ OC.L10N.register(
     "Check out our blog" : "Visitá nuestro blog",
     "Subscribe to our newsletter" : "Suscribite a nuestro boletín",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
+    "Open documentation" : "Abrir la documentación",
     "Use a second factor besides your password to increase security for your account." : "Usá un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si usás aplicaciones de terceros para conectarte a Nextcloud, por favor asegurate de crear y configurar una contraseña de app para cada una antes de activar la autenticación en dos pasos.",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "Group list is empty" : "La lista de grupos está vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista de grupos",
     "Logged in account must be a subadmin" : "La cuenta conectada debe ser de un subadministrador",
-    "To allow this check to run you have to make sure that your webserver can connect to itself. Therefor it must be able to resolve and connect to at least one its `trusted_domains` or the `overwrite.cli.url`." : "Para permitir que este chequeo se lleve a cabo, tenés que asegurarte de que tu servidor pueda conectarse a sí mismo. Por tanto, este debe poder resolver y conectarse a alguno de sus `trusted_domains` o al url definido en `overwrite.cli.url`",
-    "Missing optional index \"%s\" in table \"%s\"." : "Falta el índice opcional \"%s\" en la tabla \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos le faltan algunos índices. Dado que agregar índices a tablas grandes puede llevar bastante tiempo, no se han agregado automáticamente. Ejecutando \"occ db:add-missing-indices\" se pueden agregar manualmente los índices faltantes mientras la instancia sigue corriendo. Una vez agregados los índices, las consultas a esas tablas suelen ser mucho más rápidas.",
-    "File locking" : "Bloqueo de archivos",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "El bloqueo transaccional de archivos está desactivado, lo que podría ocasionar problemas de race conditions. Habilitá \"filelocking.enabled\" en config.php para evitar estos problemas.",
-    "for WebAuthn passwordless login" : "para el inicio de sesión sin contraseña de WebAuthn",
-    "for WebAuthn passwordless login, and SFTP storage" : "para el inicio de sesión sin contraseña de WebAuthn y el almacenamiento SFTP",
-    "Your biography" : "Tu biografía",
-    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Establecer el administrador del usuario",
-    "Username will be autogenerated" : "El nombre del usuario se generará automáticamente",
-    "Username (required)" : "Nombre del usuario (requerido)",
-    "New user" : "Nuevo usuario",
-    "Groups (required)" : "Grupos (requerido)",
-    "Set user groups" : "Establecer grupos del usuario",
-    "Administered groups" : "Grupos administrados",
-    "Set user as admin for …" : "Establecer al usuario como administrador de...",
-    "Set user quota" : "Establecer la cuota del usuario",
-    "Add new user" : "Agregar un nuevo usuario",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuario...","{userCount} usuarios...","{userCount} usuarios..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} usuario","{userCount} usuarios","{userCount} usuarios"],
-    "Loading users …" : "Cargando usuarios...",
-    "Username" : "Nombre de usuario",
-    "User backend" : "Backend del usuario",
-    "User actions" : "Acciones de usuario",
-    "Add user to group" : "Agregar usuario al grupo",
-    "Server error while trying to add WebAuthn device" : "Error del servidor al intentar agregar el dispositivo WebAuthn",
-    "Name your device" : "Dale un nombre a tu dispositivo",
-    "Active accounts" : "Cuentas activas",
-    "Follow us on Twitter" : "Seguinos en Twitter"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Funciona únicamente si los dispositivos están conectados a Internet.",
+    "Loading account …" : "Cargando cuenta ...",
+    "Adding your device …" : "Agregando tu dispositivo...",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Por razones de rendimiento, cuando actives el cifrado en un servidor Nextcloud sólo se cifrarán los archivos nuevos y modificados.",
+    "{progress}% Deploying …" : "Desplegando {progress}%",
+    "{progress}% Initializing …" : "Inicializando {progress}%",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continuás podrás instalar la aplicación, pero tené en cuenta que podría no funcionar según lo esperado.",
+    "None/STARTTLS" : "Ninguno/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Credenciales",
+    "SMTP Login" : "Inicio de sesión SMTP",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
+    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso estamos haciendo algunas comprobaciones automáticas. Consultá la documentación para mayor información.",
+    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, volvé a consultar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, y comprobá posibles errores y advertencias en el <a href=\"%2$s\">registro</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revisá la seguridad de tu Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escáner de seguridad ↗</a>."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
