@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "No fue posible cambiar la contraseña",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La lista de grupos esta vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "{actor} added you to group {group}" : "{actor} te agregó al grupo {group}",
     "You added {user} to group {group}" : "Agregaste a {user} al grupo {group}",
     "{actor} added {user} to group {group}" : "{actor} agregó a {user} al grupo {group}",
@@ -46,6 +37,7 @@ OC.L10N.register(
     "Wrong password" : "Contraseña incorrecta",
     "Unable to change personal password" : "No se pudo cambiar la contraseña personal",
     "Saved" : "Guardado",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Unable to change password. Password too long." : "No se pudo cambiar la contraseña. La contraseña es demasiado larga.",
     "Authentication error" : "Error de autenticación",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
@@ -167,6 +159,7 @@ OC.L10N.register(
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
     "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
+    "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
     "Loading groups…" : "Cargando grupos...",
     "Loading" : "Cargando",
@@ -366,6 +359,20 @@ OC.L10N.register(
     "No devices configured." : "No hay dispositivos configurados.",
     "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para tu cuenta:",
     "Your browser does not support WebAuthn." : "Tu navegador no admite WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
+    "Send mode" : "Modo de envío",
+    "Encryption" : "Encripción",
+    "Sendmail mode" : "Modo Sendmail",
+    "Disable certificate verification (insecure)" : "Deshabilitar la verificación del certificado (inseguro)",
+    "From address" : "De la dirección",
+    "Domain" : "Dominio",
+    "Server address" : "Dirección del servidor",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "Autenticación requerida",
+    "Saving…" : "Guardando...",
+    "Save settings" : "Guardar configuraciones",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "Try again" : "Reintentar",
     "All checks passed." : "Pasaron todas las verificaciones. ",
@@ -375,8 +382,6 @@ OC.L10N.register(
     "You need to enable the File sharing App." : "Debes habilitar la aplicación Compartir archivos.",
     "Apply" : "Aplicar",
     "Admins" : "Administradores",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
@@ -425,22 +430,6 @@ OC.L10N.register(
     "Forum" : "Foro",
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Política de privacidad",
-    "None/STARTTLS" : "Ninguno/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
-    "Send mode" : "Modo de envío",
-    "Encryption" : "Encripción",
-    "Sendmail mode" : "Modo Sendmail",
-    "From address" : "De la dirección",
-    "Server address" : "Dirección del servidor",
-    "Port" : "Puerto",
-    "Authentication" : "Autenticación",
-    "Authentication required" : "Autenticación requerida",
-    "Credentials" : "Credenciales",
-    "SMTP Password" : "Contraseña SMTP",
-    "Save" : "Guardar",
-    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
     "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en tu organización",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
@@ -448,13 +437,29 @@ OC.L10N.register(
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
+    "Open documentation" : "Abrir documentación",
     "Use a second factor besides your password to increase security for your account." : "Utiliza un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilizas aplicaciones de terceros para conectarte a Nextcloud, asegúrate de crear y configurar una contraseña de aplicación para cada una antes de habilitar la autenticación de segundo factor.",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
     "Adding your device …" : "Agregando tu dispositivo ...",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continúas, aún podrás instalar la aplicación. Ten en cuenta que es posible que la aplicación no funcione como se espera.",
+    "None/STARTTLS" : "Ninguno/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Credenciales",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
+    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y el rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso, realizamos algunas comprobaciones automáticas. Consulta la documentación enlazada para obtener más información.",
     "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, revisa las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a> y verifica si hay errores o advertencias en el <a href=\"%2$s\">registro</a>.",
