@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "No fue posible cambiar la contraseña",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La lista de grupos esta vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -23,6 +14,7 @@ OC.L10N.register(
     "Settings" : "Configuraciones ",
     "Wrong password" : "Contraseña incorrecta",
     "Saved" : "Guardado",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Authentication error" : "Error de autenticación",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
     "Administrator documentation" : "Documentación del adminsitrador",
@@ -101,6 +93,7 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
     "Loading" : "Cargando",
     "Daemon" : "Demonio",
@@ -180,14 +173,24 @@ OC.L10N.register(
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
+    "Send mode" : "Modo de envío",
+    "Encryption" : "Encripción",
+    "From address" : "De la dirección",
+    "Domain" : "Dominio",
+    "Server address" : "Dirección del servidor",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "Autenticación requerida",
+    "Saving…" : "Guardando...",
+    "Save settings" : "Guardar configuraciones",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "Try again" : "Reintentar",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "Apply" : "Aplicar",
     "Admins" : "Administradores",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
@@ -209,24 +212,25 @@ OC.L10N.register(
     "Error" : "Error",
     "Forum" : "Foro",
     "Legal notice" : "Aviso legal",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
-    "Send mode" : "Modo de envío",
-    "Encryption" : "Encripción",
-    "From address" : "De la dirección",
-    "Server address" : "Dirección del servidor",
-    "Port" : "Puerto",
-    "Authentication" : "Autenticación",
-    "Authentication required" : "Autenticación requerida",
-    "Credentials" : "Credenciales",
-    "SMTP Password" : "Contraseña SMTP",
-    "Save" : "Guardar",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
+    "Open documentation" : "Abrir documentación",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro."
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "SSL" : "SSL",
+    "Credentials" : "Credenciales",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
