@@ -1,23 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Yksityinen",
-    "Local" : "Paikallinen",
-    "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
-    "Federated" : "Federoitu",
-    "Only synchronize to trusted servers" : "Synkronoi vain luotetulle palvelimelle",
-    "Published" : "Julkaistu",
-    "Verify" : "Vahvista",
-    "Verifying …" : "Vahvistetaan…",
-    "Unable to change password" : "Salasanan vaihto ei onnistunut",
-    "Very weak password" : "Erittäin heikko salasana",
-    "Weak password" : "Heikko salasana",
-    "So-so password" : "Kohtalainen salasana",
-    "Good password" : "Hyvä salasana",
-    "Strong password" : "Vahva salasana",
-    "Groups" : "Ryhmät",
-    "Group list is empty" : "Ryhmälista on tyhjä",
-    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
     "{actor} added you to group {group}" : "{actor} lisäsi sinut ryhmään {group}",
     "You added {user} to group {group}" : "Lisäsit käyttäjän {user} ryhmään {group}",
     "{actor} added {user} to group {group}" : "{actor} lisäsi käyttäjän {user} ryhmään {group}",
@@ -54,6 +37,7 @@ OC.L10N.register(
     "Wrong password" : "Väärä salasana",
     "Unable to change personal password" : "Henkilökohtaista salasanaa ei voitu vaihtaa",
     "Saved" : "Tallennettu",
+    "Unable to change password" : "Salasanan vaihto ei onnistunut",
     "Unable to change password. Password too long." : "Salasanaa ei voitu vaihtaa. Salasana on liian pitkä.",
     "Authentication error" : "Tunnistautumisvirhe",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
@@ -114,6 +98,8 @@ OC.L10N.register(
     "Background jobs" : "Taustatyöt",
     "Unlimited" : "Rajoittamaton",
     "Verifying" : "Vahvistetaan",
+    "Verifying …" : "Vahvistetaan…",
+    "Verify" : "Vahvista",
     "Code integrity" : "Koodin eheys",
     "Some files have not passed the integrity check. {link1} {link2}" : "Jotkin tiedostot eivät läpäisseet eheystarkistusta. {link1} {link2}",
     "Cron errors" : "Cron-virheet",
@@ -215,6 +201,7 @@ OC.L10N.register(
     "_Update_::_Update all_" : ["Päivitä","Päivitä kaikki"],
     "Failed to load groups" : "Ryhmien lataaminen epäonnistui",
     "Failed to create group" : "Ryhmän luonti epäonnistui",
+    "Groups" : "Ryhmät",
     "Creating group…" : "Luodaan ryhmä…",
     "Create group" : "Luo ryhmä",
     "Group name" : "Ryhmän nimi",
@@ -339,6 +326,8 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Käytössäsi on {s}{usage}{/s}/{s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
     "Your full name" : "Koko nimesi",
+    "Unable to update primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu päivittää",
+    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
     "Email options" : "Sähköpostiasetukset",
     "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
     "Delete email" : "Poista sähköposti",
@@ -347,18 +336,16 @@ OC.L10N.register(
     "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
     "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
     "Unable to delete primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu poistaa",
-    "Unable to update primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu päivittää",
     "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
-    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
     "Your headline" : "Otsikkosi",
+    "No language set" : "Kieltä ei ole asetettu",
     "Unable to update language" : "Kieltä ei voi päivittää",
     "Languages" : "Kielet",
     "Help translate" : "Auta kääntämisessä",
-    "No language set" : "Kieltä ei ole asetettu",
+    "No locale set" : "Maa-asetustoa ei ole asetettu",
     "Unable to update locale" : "Maa-asetuston päivittäminen ei onnistu",
     "Locales" : "Aluekohtaiset asetukset",
     "Week starts on {firstDayOfWeek}" : "Viikon ensimmäinen päivä on {firstDayOfWeek}",
-    "No locale set" : "Maa-asetustoa ei ole asetettu",
     "Your city" : "Kaupunkisi",
     "Your organisation" : "Organisaatiosi",
     "Your phone number" : "Puhelinnumerosi",
@@ -383,7 +370,6 @@ OC.L10N.register(
     "Common languages" : "Yleiset kielet",
     "Other languages" : "Muut kielet",
     "No accounts" : "Ei tilejä",
-    "Loading accounts …" : "Ladataan tilejä…",
     "Account name will be autogenerated" : "Tilin nimi luodaan automaattisesti",
     "Account name (required)" : "Tilin nimi (pakollinen)",
     "New account" : "Uusi tili",
@@ -397,7 +383,6 @@ OC.L10N.register(
     "Language" : "Kieli",
     "Set default language" : "Aseta oletuskieli",
     "Add new account" : "Lisää uusi tili",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} tili…","{userCount} tiliä…"],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} tili","{userCount} tiliä"],
     "Scroll to load more rows" : "Vieritä ladataksesi enemmän rivejä",
     "Avatar" : "Profiilikuva",
@@ -423,7 +408,6 @@ OC.L10N.register(
     "Email can't be empty" : "Sähköposti ei voi olla tyhjä",
     "Email was successfully changed" : "Sähköpostiosoite vaihdettiin onnistuneesti",
     "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
-    "Loading account …" : "Ladataan tiliä…",
     "Change display name" : "Vaihda näyttönimi",
     "Set new password" : "Aseta uusi salasana:",
     "Set new email address" : "Aseta uusi sähköpostiosoite",
@@ -447,13 +431,26 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Tunnistautuminen ilman salasanaa vaatii salatun yhteyden.",
     "Add WebAuthn device" : "Lisää WebAuthn-laite",
     "Please authorize your WebAuthn device." : "Valtuuta WebAuthn-laitteesi.",
-    "Adding your device …" : "Lisätään laitettasi…",
     "Unnamed device" : "Nimetön laite",
     "Passwordless Authentication" : "Tunnistautuminen ilman salasanaa",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Aseta tilillesi tunnistautuminen ilman salasanaa FIDO2-standardia seuraten.",
     "No devices configured." : "Laitteita ei ole määritetty.",
     "The following devices are configured for your account:" : "Seuraavat laitteet on määritetty tilillesi:",
     "Your browser does not support WebAuthn." : "Selaimesi ei tue WebAuthn-standardia.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
+    "Send mode" : "Lähetystila",
+    "Encryption" : "Salaus",
+    "Sendmail mode" : "Sendmail-tila",
+    "Disable certificate verification (insecure)" : "Poista käytöstä varmenteen varmistus (turvaton)",
+    "From address" : "Lähettäjän osoite",
+    "Domain" : "Domaini",
+    "Server address" : "Palvelimen osoite",
+    "Host" : "Palvelin",
+    "Port" : "Portti",
+    "Authentication" : "Tunnistautuminen",
+    "Authentication required" : "Tunnistautuminen vaaditaan",
+    "Saving…" : "Tallennetaan…",
+    "Save settings" : "Tallenna asetukset",
     "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
     "Try again" : "Yritä uudelleen",
     "All checks passed." : "Läpäistiin kaikki tarkistukset.",
@@ -470,8 +467,6 @@ OC.L10N.register(
     "Admins" : "Ylläpitäjät",
     "Account group: {group}" : "Tiliryhmä: {group}",
     "Account management" : "Tilihallinta",
-    "Sending…" : "Lähetetään…",
-    "Email sent" : "Sähköposti lähetetty",
     "Location" : "Sijainti",
     "Profile picture" : "Profiilikuva",
     "About" : "Tietoja",
@@ -484,11 +479,18 @@ OC.L10N.register(
     "Phone number" : "Puhelinnumero",
     "Role" : "Rooli",
     "X (formerly Twitter)" : "X (aiemmin Twitter)",
+    "Bluesky" : "Bluesky",
     "Website" : "Verkkosivusto",
     "Profile visibility" : "Profiilin näkyvyys",
     "Locale" : "Aluekohtainen asetus",
     "First day of week" : "Viikon ensimmäinen päivä",
     "timezone" : "aikavyöhyke",
+    "Private" : "Yksityinen",
+    "Local" : "Paikallinen",
+    "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
+    "Federated" : "Federoitu",
+    "Only synchronize to trusted servers" : "Synkronoi vain luotetulle palvelimelle",
+    "Published" : "Julkaistu",
     "Your apps" : "Sovelluksesi",
     "Active apps" : "Aktiiviset sovellukset",
     "Disabled apps" : "Käytöstä poistetut sovellukset",
@@ -524,21 +526,6 @@ OC.L10N.register(
     "General documentation" : "Yleinen dokumentaatio",
     "Legal notice" : "Lainopillinen huomautus",
     "Privacy policy" : "Tietosuojakäytäntö",
-    "SSL" : "SSL",
-    "Open documentation" : "Avaa dokumentaatio",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
-    "Send mode" : "Lähetystila",
-    "Encryption" : "Salaus",
-    "Sendmail mode" : "Sendmail-tila",
-    "From address" : "Lähettäjän osoite",
-    "Server address" : "Palvelimen osoite",
-    "Port" : "Portti",
-    "Authentication" : "Tunnistautuminen",
-    "Authentication required" : "Tunnistautuminen vaaditaan",
-    "Credentials" : "Tilitiedot",
-    "SMTP Password" : "SMTP-salasana",
-    "Save" : "Tallenna",
-    "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
     "Reasons to use Nextcloud in your organization" : "Nextcloudin käytön edut organisaatiossasi",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
     "Like our Facebook page" : "Tykkää Facebook-sivustamme",
@@ -546,17 +533,31 @@ OC.L10N.register(
     "Check out our blog" : "Lue blogia",
     "Subscribe to our newsletter" : "Tilaa uutiskirje",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
+    "Open documentation" : "Avaa dokumentaatio",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
-    "File locking" : "Tiedostolukitus",
-    "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
+    "Very weak password" : "Erittäin heikko salasana",
+    "Weak password" : "Heikko salasana",
+    "So-so password" : "Kohtalainen salasana",
+    "Good password" : "Hyvä salasana",
+    "Strong password" : "Vahva salasana",
+    "Group list is empty" : "Ryhmälista on tyhjä",
+    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
-    "Your biography" : "Sinun elämäkertasi",
-    "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
+    "Loading accounts …" : "Ladataan tilejä…",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} tili…","{userCount} tiliä…"],
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
+    "Loading account …" : "Ladataan tiliä…",
+    "Adding your device …" : "Lisätään laitettasi…",
+    "Sending…" : "Lähetetään…",
+    "Email sent" : "Sähköposti lähetetty",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
+    "SSL" : "SSL",
+    "Credentials" : "Tilitiedot",
+    "SMTP Password" : "SMTP-salasana",
+    "Save" : "Tallenna",
+    "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
     "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
