@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "לא ניתן לשנות את הססמה",
-    "Very weak password" : "סיסמא מאוד חלשה",
-    "Weak password" : "סיסמא חלשה",
-    "So-so password" : "סיסמא ככה-ככה",
-    "Good password" : "סיסמא טובה",
-    "Strong password" : "סיסמא חזקה",
-    "Groups" : "קבוצות",
-    "Group list is empty" : "רשימת הקבוצות ריקה",
-    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
     "{actor} added you to group {group}" : "נוספת לקבוצה {group} על ידי {actor}",
     "You added {user} to group {group}" : "הוספת את {user} לקבוצה {group}",
     "{actor} added {user} to group {group}" : "ההוספה של {user} לקבוצה {group} נעשתה על ידי {actor}",
@@ -41,6 +32,7 @@ OC.L10N.register(
     "Settings" : "הגדרות",
     "Wrong password" : "ססמה שגויה",
     "Saved" : "נשמר",
+    "Unable to change password" : "לא ניתן לשנות את הססמה",
     "Authentication error" : "שגיאת אימות",
     "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
     "Administrator documentation" : "תיעוד מנהל",
@@ -145,6 +137,7 @@ OC.L10N.register(
     "Results from other categories" : "תוצאות מקטגוריות אחרות",
     "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
     "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
+    "Groups" : "קבוצות",
     "Group name" : "שם קבוצה",
     "Loading groups…" : "הקבוצות נטענות…",
     "Loading" : "בטעינה",
@@ -265,16 +258,28 @@ OC.L10N.register(
     "No devices configured." : "לא הוגדרו התקנים.",
     "The following devices are configured for your account:" : "ההתקנים הבאים הוגדרו לחשבון שלך:",
     "Your browser does not support WebAuthn." : "הדפדפן שלך אינו תומך ב־WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "חשוב להגדיר את השרת הזה כדי שיתאפשר לשלוח דרכו הודעות דוא״ל, למשל כדי לאפס ססמה ולשלוח התרעות.",
+    "Send mode" : "מצב שליחה",
+    "Encryption" : "הצפנה",
+    "Sendmail mode" : "מצב Sendmail (שליחת דוא״ל)",
+    "Disable certificate verification (insecure)" : "השבתת אימות אישור אבטחה (פרוץ)",
+    "From address" : "מכתובת",
+    "Domain" : "שם תחום",
+    "Server address" : "כתובת שרת",
+    "Host" : "מארח",
+    "Port" : "שער",
+    "Authentication" : "אימות",
+    "Authentication required" : "נדרש אימות",
+    "Saving…" : "מתבצעת שמירה…",
     "Security & setup warnings" : "הזהרות אבטחה והתקנה",
     "Try again" : "ניסיון חוזר",
     "All checks passed." : "כל הבדיקות עברו",
     "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
     "There are some warnings regarding your setup." : "ישנן מגוון אזהרות על ההגדרות שלך.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "כמנהל יש לך אפשרות לכוונן את התנהגות השיתוף. נא לעיין בתיעוד לפרטים נוספים.",
+    "Version {version}" : "גרסה {version}",
     "Apply" : "החלה",
     "Admins" : "מנהלים",
-    "Sending…" : "בשליחה…",
-    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
     "Location" : "מיקום",
     "Profile picture" : "תמונת פרופיל",
     "About" : "על אודות",
@@ -309,33 +314,33 @@ OC.L10N.register(
     "Forum" : "פורום",
     "Legal notice" : "הצהרה משפטית",
     "Privacy policy" : "מדיניות פרטיות",
-    "SSL" : "SSL",
-    "Open documentation" : "תיעוד פתוח",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "חשוב להגדיר את השרת הזה כדי שיתאפשר לשלוח דרכו הודעות דוא״ל, למשל כדי לאפס ססמה ולשלוח התרעות.",
-    "Send mode" : "מצב שליחה",
-    "Encryption" : "הצפנה",
-    "Sendmail mode" : "מצב Sendmail (שליחת דוא״ל)",
-    "From address" : "מכתובת",
-    "Server address" : "כתובת שרת",
-    "Port" : "שער",
-    "Authentication" : "אימות",
-    "Authentication required" : "נדרש אימות",
-    "Credentials" : "פרטי גישה",
-    "SMTP Password" : "סיסמת SMTP",
-    "Save" : "שמור",
     "Reasons to use Nextcloud in your organization" : "סיבות להשתמש ב־Nextcloud בארגון שלך",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
     "Follow us on Mastodon" : "למעקב אחרינו ב־Mastodon",
     "Check out our blog" : "לעיין בבלוג שלנו",
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
+    "Open documentation" : "תיעוד פתוח",
     "Use a second factor besides your password to increase security for your account." : "ניתן להשתמש בגורם נוסף מלבד הססמה שלך כדי להגביר את אבטחת החשבון שלך.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
+    "Very weak password" : "סיסמא מאוד חלשה",
+    "Weak password" : "סיסמא חלשה",
+    "So-so password" : "סיסמא ככה-ככה",
+    "Good password" : "סיסמא טובה",
+    "Strong password" : "סיסמא חזקה",
+    "Group list is empty" : "רשימת הקבוצות ריקה",
+    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
     "Adding your device …" : "הוספת ההתקן שלך…",
+    "Sending…" : "בשליחה…",
+    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
+    "SSL" : "SSL",
+    "Credentials" : "פרטי גישה",
+    "SMTP Password" : "סיסמת SMTP",
+    "Save" : "שמור",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
     "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "נא לעיין היטב ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">מדריכי ההתקנה ↖️</a> ולחפש אם מופיעות שגיאות או אזהרות ב<a href=\"%2$s\">יומן</a>.",
