@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "Tidak dapat mengubah kata sandi",
-    "Very weak password" : "Kata sandi sangat lemah",
-    "Weak password" : "Kata sandi lemah",
-    "So-so password" : "Kata sandi lumayan",
-    "Good password" : "Kata sandi baik",
-    "Strong password" : "Kata sandi kuat",
-    "Groups" : "Grup",
-    "Group list is empty" : "Daftar grup kosong",
-    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "{actor} added you to group {group}" : "{actor} menambahkanmu ke grup {group}",
     "You added {user} to group {group}" : "Anda menambahkan {user} ke grup {group}",
     "{actor} added {user} to group {group}" : "{actor} menambahkan {user} kedalam grup {group}",
@@ -44,6 +35,7 @@ OC.L10N.register(
     "Wrong password" : "Kata sandi salah",
     "Unable to change personal password" : "Tidak dapat mengubah kata sandi pribadi",
     "Saved" : "Disimpan",
+    "Unable to change password" : "Tidak dapat mengubah kata sandi",
     "Unable to change password. Password too long." : "Tidak dapat berubah kata sandi. Kata sandi terlalu panjang.",
     "Authentication error" : "Terjadi kesalahan saat otentikasi",
     "Wrong admin recovery password. Please check the password and try again." : "Kata sandi pemulihan admin salah. Periksa kata sandi dan ulangi kembali.",
@@ -90,6 +82,7 @@ OC.L10N.register(
     "Overview" : "Ringkasan",
     "Basic settings" : "Setelan dasar",
     "Sharing" : "Berbagi",
+    "Availability" : "Ketersediaan",
     "Calendar" : "Kalender",
     "Personal info" : "Info pribadi",
     "Mobile & desktop" : "Mobil & desktop",
@@ -135,6 +128,7 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi unggulan dikembangkan oleh dan dalam komunitas. Mereka menawarkan fungsionalitas sentral dan mereka siap dipakai untuk produksi.",
     "Disable all" : "Matikan semua",
     "All apps are up-to-date." : "Semua aplikasi terkini.",
+    "Icon" : "Ikon",
     "Name" : "Nama",
     "Version" : "Versi",
     "Actions" : "Tindakan",
@@ -142,6 +136,7 @@ OC.L10N.register(
     "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
     "_%n app has an update available_::_%n apps have an update available_" : ["Ada pembaruan tersedia untuk %naplikasi"],
     "_Update_::_Update all_" : ["Perbarui semua"],
+    "Groups" : "Grup",
     "Group name" : "Nama grup",
     "Loading" : "Memuat",
     "Type" : "tipe",
@@ -206,6 +201,7 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Ingat bahwa enkripsi selalu menambah ukuran berkas.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Alangkah baiknya untuk membuat cadangan data secara rutin, dalam kasus enkripsi, pastikan untuk mencadangkan kunci enkripsi bersama dengan data Anda.",
     "This is the final warning: Do you really want to enable encryption?" : "Ini adalah peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
+    "Submit" : "Kirim",
     "Rename group" : "Ganti nama grup",
     "Current password" : "Kata sandi saat ini",
     "New password" : "Kata sandi baru",
@@ -237,7 +233,9 @@ OC.L10N.register(
     "Email" : "Email",
     "Quota" : "Kuota",
     "Language" : "Bahasa",
+    "Total rows summary" : "Ringkasan total baris",
     "Avatar" : "Avatar",
+    "Account name" : "Nama akun",
     "Group admin for" : "Grup admin untuk",
     "Storage location" : "Lokasi penyimpanan",
     "Last login" : "Log masuk terakhir",
@@ -254,14 +252,25 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Otentikasi tanpa kata sandi membutuhkan koneksi aman.",
     "Passwordless Authentication" : "Otentikasi Tanpa Kata Sandi",
     "No devices configured." : "Tidak ada perangkat yang dikonfigurasi.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Sangat penting untuk mengatur server ini untuk dapat mengirim surat, seperti melakukan reset kata sandi dan notifikasi.",
+    "Send mode" : "Modus kirim",
+    "Encryption" : "Enkripsi",
+    "Sendmail mode" : "Mode kirim email",
+    "From address" : "Dari alamat",
+    "Domain" : "Domain",
+    "Server address" : "Alamat server",
+    "Host" : "Host",
+    "Port" : "Port",
+    "Authentication" : "Otentikasi",
+    "Authentication required" : "Diperlukan otentikasi",
+    "Saving…" : "Menyimpan...",
     "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
+    "Try again" : "Coba lagi",
     "All checks passed." : "Semua pemeriksaan lulus.",
     "There are some errors regarding your setup." : "Terdapat beberapa galat terkait dengan setup Anda.",
     "There are some warnings regarding your setup." : "Terdapat beberapa peringatan terkait dengan setup Anda.",
     "Apply" : "Terapkan",
     "Admins" : "Admin",
-    "Sending…" : "Mengirim…",
-    "Email sent" : "Email terkirim",
     "Location" : "Lokasi",
     "Profile picture" : "Foto profil",
     "About" : "Tentang.",
@@ -299,29 +308,29 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Legal notice" : "Pemberitahuan hukum",
     "Privacy policy" : "Kebijakan privasi",
-    "SSL" : "SSL",
-    "Open documentation" : "Buka dokumentasi",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Sangat penting untuk mengatur server ini untuk dapat mengirim surat, seperti melakukan reset kata sandi dan notifikasi.",
-    "Send mode" : "Modus kirim",
-    "Encryption" : "Enkripsi",
-    "Sendmail mode" : "Mode kirim email",
-    "From address" : "Dari alamat",
-    "Server address" : "Alamat server",
-    "Port" : "Port",
-    "Authentication" : "Otentikasi",
-    "Authentication required" : "Diperlukan otentikasi",
-    "Credentials" : "Kredensial",
-    "SMTP Password" : "Kata sandi SMTP",
-    "Save" : "Simpan",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Dikembangkan oleh {communityopen}komunitas Nextcloud{linkclose}, {githubopen}sumber kode{linkclose} dilisensikan dibawah {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Sukai kami di halaman Facebook",
     "Follow us on Mastodon" : "Ikuti kami di Mastodon",
     "Check out our blog" : "Cek blog kami",
     "Subscribe to our newsletter" : "Berlangganan surat berita kami",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Rilis komunitas Nextcloud ini tidak didukung dan pemberitahuan instan tidak tersedia.",
+    "Open documentation" : "Buka dokumentasi",
+    "Very weak password" : "Kata sandi sangat lemah",
+    "Weak password" : "Kata sandi lemah",
+    "So-so password" : "Kata sandi lumayan",
+    "Good password" : "Kata sandi baik",
+    "Strong password" : "Kata sandi kuat",
+    "Group list is empty" : "Daftar grup kosong",
+    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
+    "Sending…" : "Mengirim…",
+    "Email sent" : "Email terkirim",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
+    "SSL" : "SSL",
+    "Credentials" : "Kredensial",
+    "SMTP Password" : "Kata sandi SMTP",
+    "Save" : "Simpan",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sangat penting sekali untuk semuanya diatur secara benar demi keamanan dan performa instansi Anda. Untuk membantu Anda dengan hal itu kami melakukan cek otomatis. Mohon melihat tautan dokumentasi untuk lebih lanjut.",
     "Checking for system and security issues." : "Mengecek isu sistem dan keamanan",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Mohon cek kembali Petunjuk pemasangan ↗, dan cek semua galat atau peringatan di <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">log<a href=\"%2$s\">.",
