@@ -1,18 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "პირადი",
-    "Local" : "ლოკალური",
-    "Federated" : "ფედერალური",
-    "Verify" : "დამოწმება",
-    "Verifying …" : "მოწმდება …",
-    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
-    "Very weak password" : "ძალიან სუსტი პაროლი",
-    "Weak password" : "სუსტი პაროლი",
-    "So-so password" : "ნორმალური პაროლი",
-    "Good password" : "კარგი პაროლი",
-    "Strong password" : "ძლიერი პაროლ",
-    "Groups" : "ჯგუფები",
     "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
     "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
     "Your password was reset by an administrator" : "თქვენი პაროლი ადმინისტრატორმა აღადგინა",
@@ -26,6 +14,7 @@ OC.L10N.register(
     "Settings" : "პარამეტრები",
     "Wrong password" : "არასწორი პაროლი",
     "Saved" : "დამახსოვრდა",
+    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
     "Authentication error" : "აუტენტიფიკაციის შეცდომა",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
     "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
@@ -76,6 +65,8 @@ OC.L10N.register(
     "Background jobs" : "ფონური საქმეები",
     "Unlimited" : "ულიმიტო",
     "Verifying" : "მოწმდება",
+    "Verifying …" : "მოწმდება …",
+    "Verify" : "დამოწმება",
     "Disabled" : "არაა მოქმედი",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
     "Supported" : "მხარდაჭერილია",
@@ -96,6 +87,7 @@ OC.L10N.register(
     "Default share permissions" : "საწყისი გაზიარების პარამეტრები",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
     "Save changes" : "ცვილებების შენახვა",
+    "Default" : "საწყისი პარამეტრები",
     "Remove" : "წაშლა",
     "Featured" : "გამორჩეულები",
     "Icon" : "პიქტოგრამა",
@@ -104,6 +96,7 @@ OC.L10N.register(
     "Level" : "დონე",
     "Actions" : "მოქმედებები",
     "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
+    "Groups" : "ჯგუფები",
     "Group name" : "ჯგუფის სახელი",
     "Daemon" : "დაემონი",
     "Display Name" : "დისპლეი სახელი",
@@ -119,8 +112,6 @@ OC.L10N.register(
     "All" : "ყველა",
     "No results" : "შედეგები არაა",
     "Update to {version}" : "განაახლეთ ვერსიაზე {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
     "Categories" : "კატეგორიები",
     "Resources" : "რესურსები",
@@ -131,6 +122,7 @@ OC.L10N.register(
     "Rate" : "შეაფასეთ",
     "Changelog" : "ცვლილებების ლოგი",
     "Google Chrome for Android" : "Google Chrome Android-ისთვის",
+    "{productName} Android app" : "{productName} Android აპლიკაცია",
     "This session" : "ეს სესია",
     "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
     "Rename" : "სახელის შეცვლა",
@@ -143,6 +135,7 @@ OC.L10N.register(
     "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
     "Login" : "ლოგინი",
     "Password" : "პაროლი",
+    "Password confirmation is required" : "საჭიროა პაროლის დამოწმება",
     "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
     "Enable server-side encryption" : "სერვერული-მხარის შიფრაციის ამოქმედება",
@@ -155,19 +148,15 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "ყოველთვის კარგია თქვენი მონაცემების დაზღვევა, შიფრაციის შემთხვევაში თვენს მონაცემებთან ერთად აუცილებლად დააზღვიეთ შიფრაციის გასაღებებიც.",
     "This is the final warning: Do you really want to enable encryption?" : "ეს ბოლო გაფრთხილებაა: ნამდვილად გსურთ შიფრაციის ამოქმედება?",
     "Submit" : "გაგზავნა",
-    "Current password" : "მიმდინარე პაროლი",
+    "Current password" : "ამჟამინდელი პაროლი",
     "New password" : "ახალი პაროლი",
-    "Change password" : "პაროლის შეცვლა",
     "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
     "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
     "Help translate" : "თარგმნის დახმარება",
     "Your phone number" : "თქვენი ტელეფონის ნომერი",
     "Your website" : "თქვენი ვებ-საიტი",
-    "Add" : "დამატება",
-    "Create" : "შექმნა",
     "Change" : "შეცვლა",
     "Delete" : "წაშლა",
-    "Display name" : "დისპლეი სახელი",
     "Email" : "ელ-ფოსტა",
     "Quota" : "ქვოტა",
     "Language" : "ენა",
@@ -178,22 +167,39 @@ OC.L10N.register(
     "Account actions" : "ანგარიშის ქმედებები",
     "{size} used" : "მოხმარებულია {size}",
     "Delete account" : "ანგარიშის გაუქმება",
-    "Done" : "დასრულებულია",
+    "Done" : "დასრულდა",
     "Edit" : "შეცვლა",
     "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
     "Send email" : "ელ-წერილის გაგზავნა",
     "Default quota" : "საწყისი კვოტა",
     "Unnamed device" : "უსახელო მოწყობილობა",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
+    "Send mode" : "გაგზავნის რეჟიმი",
+    "Encryption" : "შიფრაცია",
+    "From address" : "მისამართიდან",
+    "Domain" : "დომენი",
+    "Server address" : "სერვერის მისამართი",
+    "Host" : "ჰოსტი",
+    "Port" : "პორტი",
+    "Authentication" : "აუტენტიფიკაცია",
+    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
+    "Saving…" : "მიმდინარეობს დამახსოვრება...",
+    "Save settings" : "პარამეტრების შენახვა",
+    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
+    "Try again" : "სცადეთ ახლიდან",
+    "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
+    "Apply" : "გამოყენება",
     "Admins" : "ადმინისტრატორები",
-    "Sending…" : "იგზავნება…",
-    "Email sent" : "ელ-წერილი გაიგზავნა",
     "Location" : "ადგილმდებარეობა",
     "Profile picture" : "პროფილის სურათი",
     "About" : "შესახებ",
     "Full name" : "სრული სახელი",
     "Phone number" : "ტელეფონის ნომერი",
     "Website" : "ვებ-საიტი",
+    "Private" : "პირადი",
+    "Local" : "ლოკალური",
+    "Federated" : "ფედერალური",
     "Your apps" : "თქვენი აპლიკაციები",
     "Disabled apps" : "არამოქმედი აპლიკაციები",
     "Updates" : "განახლებები",
@@ -205,27 +211,23 @@ OC.L10N.register(
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
     "Error" : "შეცდომა",
     "Forum" : "ფორუმი",
-    "SSL" : "SSL",
-    "Open documentation" : "ღია დოკუმენტაცია",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
-    "Send mode" : "გაგზავნის რეჟიმი",
-    "Encryption" : "შიფრაცია",
-    "From address" : "მისამართიდან",
-    "Server address" : "სერვერის მისამართი",
-    "Port" : "პორტი",
-    "Authentication" : "აუტენტიფიკაცია",
-    "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
-    "Credentials" : "უფლებამოსილებანი",
-    "SMTP Password" : "SMTP მომხმარებლის პაროლი",
-    "Save" : "შენახვა",
-    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
-    "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "განავითარა {communityopen}Nextcloud საზოგადოებამ{linkclose}, {githubopen}კოდი{linkclose} is ლიცენზირებულია {licenseopen}AGPL ლიცენზიით{linkclose}.",
     "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
     "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
     "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
-    "Username" : "მომხმარებლის სახელი",
-    "User backend" : "მომხმარებელის ბექენდი",
-    "Follow us on Twitter" : "გამოგვყევით Twitter-ზე"
+    "Open documentation" : "ღია დოკუმენტაცია",
+    "Very weak password" : "ძალიან სუსტი პაროლი",
+    "Weak password" : "სუსტი პაროლი",
+    "So-so password" : "ნორმალური პაროლი",
+    "Good password" : "კარგი პაროლი",
+    "Strong password" : "ძლიერი პაროლ",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
+    "Sending…" : "იგზავნება…",
+    "Email sent" : "ელ-წერილი გაიგზავნა",
+    "SSL" : "SSL",
+    "Credentials" : "უფლებამოსილებანი",
+    "SMTP Password" : "SMTP მომხმარებლის პაროლი",
+    "Save" : "შენახვა"
 },
 "nplurals=2; plural=(n!=1);");
