@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privatus",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Matoma tik žmonėms, su kuriais pokalbių programėlėje mobiliajame įrenginyje buvo rasta atitiktis per telefono numerio integraciją",
-    "Local" : "Vietinis",
-    "Only visible to people on this instance and guests" : "Matoma tik žmonėms šiame egzemplioriuje ir svečiams",
-    "Federated" : "Federacinis",
-    "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
-    "Published" : "Paskelbtas",
-    "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
-    "Verify" : "Patikrinti",
-    "Verifying …" : "Tikrinama...",
-    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
-    "Very weak password" : "Labai silpnas slaptažodis",
-    "Weak password" : "Silpnas slaptažodis",
-    "So-so password" : "Neblogas slaptažodis",
-    "Good password" : "Geras slaptažodis",
-    "Strong password" : "Stiprus slaptažodis",
-    "Groups" : "Grupės",
-    "Group list is empty" : "Grupės sąrašas yra tuščias",
-    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
     "{actor} added you to group {group}" : "{actor} pridėjo jus į grupę {group}",
     "You added {user} to group {group}" : "Jūs pridėjote naudotoją {user} į grupę {group}",
     "{actor} added {user} to group {group}" : "{actor} pridėjo naudotoją {user} į grupę {group}",
@@ -54,6 +35,7 @@ OC.L10N.register(
     "Wrong password" : "Neteisingas slaptažodis",
     "Unable to change personal password" : "Nepavyko pakeisti asmeninio slaptažodžio",
     "Saved" : "Įrašyta",
+    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
     "Unable to change password. Password too long." : "Nepavyko pakeisti slaptažodžio. Slaptažodis per ilgas.",
     "Authentication error" : "Tapatybės nustatymo klaida",
     "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
@@ -101,7 +83,7 @@ OC.L10N.register(
     "Administration" : "Administravimas",
     "Users" : "Naudotojai",
     "Additional settings" : "Papildomi nustatymai",
-    "Artificial Intelligence" : "Dirbtinis intelektas",
+    "Assistant" : "Asistentas.",
     "Administration privileges" : "Administravimo teisės",
     "Groupware" : "Grupinio darbo įranga",
     "Overview" : "Apžvalga",
@@ -111,13 +93,17 @@ OC.L10N.register(
     "Calendar" : "Kalendorius",
     "Personal info" : "Asmeninė informacija",
     "Mobile & desktop" : "Mobilieji ir darbalaukiai",
+    "Artificial Intelligence" : "Dirbtinis intelektas",
     "Email server" : "El. pašto serveris",
     "User's email account" : "Naudotojo el. pašto paskyra",
     "Security & setup checks" : "Saugumo ir sąrankos patikrinimai",
     "Background jobs" : "Foninės užduotys",
     "Unlimited" : "Neribotai",
     "Verifying" : "Tikrinimas",
+    "Verifying …" : "Tikrinama...",
+    "Verify" : "Patikrinti",
     "Your remote address could not be determined." : "Nepavyko nustatyti jūsų nuotolinio adreso.",
+    "Data directory protected" : "Duomenų katalogas apsaugotas",
     "Debug mode" : "Derinimo veiksena",
     "Debug mode is disabled." : "Derinimo veiksena yra išjungta.",
     "Internet connectivity" : "Interneto ryšys",
@@ -129,6 +115,8 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
     "PHP modules" : "PHP moduliai",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulis nėra įkeltas. Geresniam našumui rekomenduojame įkelti šį modulį į savo PHP diegimą.",
+    "PHP version" : "PHP versija",
+    "Valid enterprise license" : "Galiojanti enterprise licencija",
     "Database version" : "Duomenų bazės versija",
     "Unknown database platform" : "Nežinoma duomenų bazės platforma",
     "Architecture" : "Architektūra",
@@ -137,6 +125,7 @@ OC.L10N.register(
     "Nextcloud settings" : "Nextcloud nustatymai",
     "Enable" : "Įjungti",
     "Here you can decide which group can access certain sections of the administration settings." : "Čia galite nuspręsti, kuri grupė galės gauti prieigą prie tam tikrų administravimo nustatymų sekcijų.",
+    "Unable to modify setting" : "Nepavyko modifikuoti nustatymo",
     "None" : "Nėra",
     "Could not set disclaimer text" : "Nepavyko nustatyti atsakomybės ribojimo teksto",
     "Allow apps to use the Share API" : "Leisti programėlėms naudoti bendrinimo API",
@@ -160,6 +149,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Dviejų faktorių tapatybės nustatymas nėra priverstinis šių grupių nariams.",
     "Excluded groups" : "Pašalintos grupės",
     "Save changes" : "Įrašyti pakeitimus",
+    "Default" : "Numatytasis",
     "Update to {update}" : "Atnaujinti į {update}",
     "Remove" : "Šalinti",
     "Featured" : "Siūlomos",
@@ -177,6 +167,12 @@ OC.L10N.register(
     "No apps found for your version" : "Jūsų versijai programėlių nėra",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n programėlei yra prieinamas atnaujinimas","%n programėlėms yra prieinamas atnaujinimas","%n programėlių yra prieinamas atnaujinimas","%n programėlei yra prieinamas atnaujinimas"],
     "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
+    "Failed to create group" : "Nepavyko sukurti grupės",
+    "Groups" : "Grupės",
+    "Creating group…" : "Kuriama grupė…",
+    "Create group" : "Sukurti grupę",
+    "Group name" : "Grupės pavadinimas",
+    "Loading groups…" : "Įkeliamos grupės…",
     "Nothing to show" : "Nėra ką rodyti",
     "Loading" : "Įkeliama",
     "Fetching the latest news…" : "Gaunamos paskiausios naujienos…",
@@ -187,6 +183,7 @@ OC.L10N.register(
     "Type" : "Tipas",
     "Display Name" : "Rodomas vardas",
     "Learn more" : "Sužinoti daugiau",
+    "Environment variables" : "Aplinkos kintamieji",
     "Read-only" : "Tik skaitymui",
     "Confirm" : "Patvirtinti",
     "Cancel" : "Atšaukti",
@@ -196,12 +193,10 @@ OC.L10N.register(
     "Admin documentation" : "Administratoriaus dokumentacija",
     "Developer documentation" : "Plėtotojo dokumentacija",
     "Details" : "Išsamiau",
-    "All" : "Viskas",
+    "All" : "Visos",
     "Limit app usage to groups" : "Programos panaudojimas ribojamas grupėms",
-    "No results" : "Rezultatų nėra",
+    "No results" : "Nieko nerasta",
     "Update to {version}" : "Atnaujinti į versiją {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
     "Author" : "Autorius",
     "Categories" : "Kategorijos",
@@ -247,6 +242,7 @@ OC.L10N.register(
     "Webcron" : "„Webcron“",
     "Cron (Recommended)" : "„Cron“ (Rekomenduojama)",
     "Profile" : "Profilis",
+    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
     "Failed to save setting" : "Nepavyko įrašyti nustatymo",
     "Server-side encryption" : "Šifravimas serverio pusėje",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifravimas serverio pusėje leidžia užšifruoti failus, kurie yra įkelti į serverį. Įjungti tik ik būtinais atvejais.",
@@ -260,15 +256,12 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Visada yra gerai daryti reguliarias atsargines duomenų kopijas. Esant šifravimui, nepamirškite kartu su savo duomenų atsargine kopija, pasidaryti ir šifravimo raktų atsarginę kopiją.",
     "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
-    "Failed to remove group \"{group}\"" : "Nepavyko pašalinti grupės „{group}“",
     "Please confirm the group removal" : "Patvirtinkite grupės pašalinimą",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Jūs ketinate pašalinti grupę „{group}“. Paskyros NEBUS ištrintos.",
     "Submit" : "Pateikti",
     "Rename group" : "Pervadinti grupę",
-    "Remove group" : "Šalinti grupę",
     "Current password" : "Dabartinis slaptažodis",
     "New password" : "Naujas slaptažodis",
-    "Change password" : "Pakeisti slaptažodį",
+    "Change password" : "Keisti slaptažodį",
     "Please select a valid png or jpg file" : "Pasirinkite tinkamą png ar jpg failą",
     "Error setting profile picture" : "Klaida nustatant profilio paveikslėlį",
     "Error cropping profile picture" : "Klaida apkerpant profilio paveikslėlį",
@@ -284,6 +277,9 @@ OC.L10N.register(
     "Enter your date of birth" : "Įveskite savo gimimo datą",
     "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
     "Your full name" : "Jūsų visas vardas",
+    "Unable to update primary email address" : "Nepavyko atnaujinti pirminio el. pašto adreso",
+    "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
+    "No email address set" : "Nenustatytas joks el. pašto adresas",
     "Email options" : "El. pašto parinktys",
     "Remove primary email" : "Šalinti pirminį el. paštą",
     "Delete email" : "Ištrinti el. paštą",
@@ -291,17 +287,14 @@ OC.L10N.register(
     "Set as primary email" : "Nustatyti kaip pirminį el. paštą",
     "Additional email address {index}" : "Papildomas el. pašto adresas {index}",
     "Unable to delete primary email address" : "Nepavyko ištrinti pirminio el. pašto adreso",
-    "Unable to update primary email address" : "Nepavyko atnaujinti pirminio el. pašto adreso",
     "Unable to add additional email address" : "Nepavyko pridėti papildomo el. pašto adreso",
     "Unable to update additional email address" : "Nepavyko atnaujinti papildomo el. pašto adreso",
-    "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
     "Primary email for password reset and notifications" : "Pirminis el. paštas, skirtas slaptažodžio atstatymui bei pranešimams",
-    "No email address set" : "Nenustatytas joks el. pašto adresas",
     "Your headline" : "Santrauka apie jus",
+    "No language set" : "Nenustatyta jokia kalba",
     "Unable to update language" : "Nepavyko atnaujinti kalbos",
     "Languages" : "Kalbos",
     "Help translate" : "Padėkite išversti",
-    "No language set" : "Nenustatyta jokia kalba",
     "Unable to update locale" : "Nepavyko atnaujinti lokalės",
     "Locales" : "Lokalės",
     "Week starts on {firstDayOfWeek}" : "Savaitės pradžia yra {firstDayOfWeek}",
@@ -312,6 +305,7 @@ OC.L10N.register(
     "Unable to update profile enabled state" : "Nepavyko atnaujinti profilio įjungimo būsenos",
     "Unable to update visibility of {displayId}" : "Nepavyko atnaujinti {displayId} matomumo",
     "Your role" : "Jūsų vaidmuo",
+    "Timezone" : "Laiko juosta",
     "Your website" : "Jūsų svetainė",
     "Unable to update {property}" : "Nepavyko atnaujinti {property}",
     "Add additional email" : "Pridėti papildomą el. paštą",
@@ -320,17 +314,16 @@ OC.L10N.register(
     "Change" : "Keisti",
     "Delete" : "Ištrinti",
     "Reshare" : "Pakartotinai bendrinti",
+    "School" : "Mokykla",
     "Default language" : "Numatytoji kalba",
     "Common languages" : "Bendrosios kalbos",
     "Other languages" : "Kitos kalbos",
     "Password change is disabled because the master key is disabled" : "Slaptažodžių keitimas išjungtas, nes yra išjungtas pagrindinis raktas",
-    "Loading accounts …" : "Įkeliamos paskyros ...",
     "New account" : "Nauja paskyra",
-    "Display name" : "Rodomas vardas",
     "Password (required)" : "Slaptažodis (būtina)",
     "Email (required)" : "El. paštas (būtina)",
     "Email" : "El. paštas",
-    "Quota" : "Limitas",
+    "Quota" : "Leidžiamas duomenų kiekis",
     "Language" : "Kalba",
     "Set default language" : "Nustatyti numatytąją kalbą",
     "Add new account" : "Pridėti naują paskyrą",
@@ -347,7 +340,6 @@ OC.L10N.register(
     "Disable account" : "Išjungti paskyrą",
     "Enable account" : "Įjungti paskyrą",
     "Resend welcome email" : "Siųsti dar kartą pasveikinimo el. laišką",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba pasikeitus darbo santykiams su organizacija, galima nuotoliniu būdu išvalyti „Nextcloud“ duomenis iš visų įrenginių, susietų su {userid}.  Veikia tik su prie interneto prijungtais įrenginiais.",
     "Remote wipe of devices" : "Nuotolinių duomenų įrenginiuose ištrynimas",
     "Wipe {userid}'s devices" : "Ištrinti duomenis naudotojo {userid} įrenginiuose",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Pilnai ištrinta {userid} paskyra, įskaitant visus asmeninius failus, programos duomenis ir pan. ",
@@ -356,7 +348,6 @@ OC.L10N.register(
     "Password was successfully changed" : "Slaptažodis buvo sėkmingai pakeistas",
     "Email was successfully changed" : "El. paštas buvo sėkmingai pakeistas",
     "Welcome mail sent!" : "Pasveikinimo laiškas išsiųstas!",
-    "Loading account …" : "Įkeliama paskyra…",
     "Set new password" : "Nustatyti naują slaptažodį",
     "You do not have permissions to see the details of this account" : "Jūs neturite leidimo matyti išsamesnę informaciją apie šią paskyrą",
     "Set new email address" : "Nustatyti naują el. pašto adresą",
@@ -377,23 +368,36 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Tapatybės nustatymas be slaptažodžio reikalauja saugaus ryšio.",
     "Add WebAuthn device" : "Pridėti WebAuthn įrenginį",
     "Please authorize your WebAuthn device." : "Prašome, autorizikuote savo WebAuthn įrenginį.",
-    "Adding your device …" : "Pridedamas jūsų įrenginys …",
     "Unnamed device" : "Įrenginys be pavadinimo",
     "Passwordless Authentication" : "Tapatybės nustatymas be slaptažodžio",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Nustatykite savo paskyrai tapatybės nustatymą be slaptažodžio, pagal FIDO2 standartą.",
     "No devices configured." : "Nėra sukonfiguruotų įrenginių.",
     "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
     "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Svarbu nustatyti šį serverį, kad galėtumėte siųsti el. laiškus, kaip, pavyzdžiui, slaptažodžio atstatymą ar pranešimus.",
+    "Send mode" : "Siuntimo veiksena",
+    "Encryption" : "Šifravimas",
+    "Sendmail mode" : "El. pašto siuntimo veiksena",
+    "Disable certificate verification (insecure)" : "Išjungti liudijimų tikrinimą (nesaugu)",
+    "From address" : "Siuntėjo adresas",
+    "Domain" : "Domenas",
+    "Server address" : "Serverio adresas",
+    "Host" : "Serveris",
+    "Port" : "Prievadas",
+    "Authentication" : "Tapatybės nustatymas",
+    "Authentication required" : "Reikalingas tapatybės nustatymas",
+    "Saving…" : "Įrašoma…",
+    "Save settings" : "Įrašyti nustatymus",
+    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
+    "Try again" : "Bandyti dar kartą",
+    "All checks passed." : "Visi patikros rezultatai teigiami.",
+    "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
+    "There are some warnings regarding your setup." : "Yra įspėjimų, susijusių su jūsų sąranka.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Būdami administratoriumi, galite reguliuoti bendrinimo elgseną. Išsamesnei informacijai, žiūrėkite dokumentaciją.",
     "Version {version}" : "Versija {version}",
+    "Apply" : "Taikyti",
     "All accounts" : "Visos paskyros",
     "Admins" : "Administratoriai",
-    "Failed to create group" : "Nepavyko sukurti grupės",
-    "Creating group…" : "Kuriama grupė…",
-    "Create group" : "Sukurti grupę",
-    "Group name" : "Grupės pavadinimas",
-    "Sending…" : "Siunčiama…",
-    "Email sent" : "El. paštas išsiųstas",
     "Location" : "Vieta",
     "Profile picture" : "Profilio paveikslėlis",
     "About" : "Apie",
@@ -408,6 +412,14 @@ OC.L10N.register(
     "Profile visibility" : "Profilio matomumas",
     "Locale" : "Lokalė",
     "First day of week" : "Pirmoji savaitės diena",
+    "Private" : "Privatus",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Matoma tik žmonėms, su kuriais pokalbių programėlėje mobiliajame įrenginyje buvo rasta atitiktis per telefono numerio integraciją",
+    "Local" : "Vietinis",
+    "Only visible to people on this instance and guests" : "Matoma tik žmonėms šiame egzemplioriuje ir svečiams",
+    "Federated" : "Federacinis",
+    "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
+    "Published" : "Paskelbtas",
+    "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
     "Your apps" : "Jūsų programėlės",
     "Active apps" : "Aktyvios programėlės",
     "Disabled apps" : "Išjungtos programėlės",
@@ -420,7 +432,6 @@ OC.L10N.register(
     "Download and enable" : "Atsisiųsti ir įjungti",
     "Disable" : "Išjungti",
     "The app will be downloaded from the App Store" : "Programėlė bus atsisiųsta iš programėlių parduotuvės",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
     "Unknown" : "Nežinoma",
     "Never" : "Niekada",
     "Could not register device: Network error" : "Nepavyko registruoti įrenginio: Tinklo klaida",
@@ -440,56 +451,39 @@ OC.L10N.register(
     "Forum" : "Forumas",
     "Legal notice" : "Teisinis pranešimas",
     "Privacy policy" : "Privatumo politika",
-    "None/STARTTLS" : "Nėra/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Atverti dokumentaciją",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Svarbu nustatyti šį serverį, kad galėtumėte siųsti el. laiškus, kaip, pavyzdžiui, slaptažodžio atstatymą ar pranešimus.",
-    "Send mode" : "Siuntimo veiksena",
-    "Encryption" : "Šifravimas",
-    "Sendmail mode" : "El. pašto siuntimo veiksena",
-    "From address" : "Siuntėjo adresas",
-    "Server address" : "Serverio adresas",
-    "Port" : "Prievadas",
-    "Authentication" : "Tapatybės nustatymas",
-    "Authentication required" : "Reikalingas tapatybės nustatymas",
-    "Credentials" : "Prisijungimo duomenys",
-    "SMTP Password" : "SMTP slaptažodis",
-    "Save" : "Įrašyti",
-    "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
-    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
-    "All checks passed." : "Visi patikros rezultatai teigiami.",
-    "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
-    "There are some warnings regarding your setup." : "Yra įspėjimų, susijusių su jūsų sąranka.",
-    "Checking for system and security issues." : "Tikrinamos sistemos ir saugumo problemos.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dar kartą peržiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">įdiegimo vadovą ↗</a> bei patikrinkite ar <a href=\"%2$s\">žurnale</a> nėra jokių klaidų ar įspėjimų.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Patikrinkite savo Nextcloud saugumą naudodamiesi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">mūsų saugumo nuskaitymu ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Priežastys, kodėl turėtumėte naudoti Nextcloud savo organizacijoje",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Spauskite „Patinka“ mūsų „Facebook“ puslapyje",
     "Follow us on Mastodon" : "Sekite mus Mastodon",
     "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
     "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
+    "Open documentation" : "Atverti dokumentaciją",
     "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Yra naudojama MariaDB versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MariaDB versijos ir reikalauja 10.2 ar naujesnės versijos.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Yra naudojama MySQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MySQL versijos ir reikalauja MySQL 8.0 arba MariaDB 10.2, ar naujesnės versijos.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Yra naudojama PostgreSQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios PostgreSQL versijos ir reikalauja PostgreSQL 9.6 ar naujesnės versijos.",
-    "Set default expiration date for shares" : "Nustatyti viešiniams numatytąją galiojimo pabaigos datą",
-    "Your biography" : "Jūsų biografija",
-    "You are using <strong>{usage}</strong>" : "Jūs naudojate <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Jūs naudojate <strong>{usage}</strong> iš <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Username will be autogenerated" : "Naudotojo vardas bus automatiškai sugeneruotas",
-    "Username (required)" : "Naudotojo vardas (būtina)",
-    "New user" : "Naujas naudotojas",
-    "Add new user" : "Pridėti naują naudotoją",
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} naudotojas","{userCount} naudotojai","{userCount} naudotojų","{userCount} naudotojas"],
-    "Loading users …" : "Įkeliami naudotojai…",
-    "Username" : "Naudotojo vardas",
-    "User backend" : "Naudotojo vidinė pusė",
-    "Add user to group" : "Pridėti naudotoją į grupę",
-    "Server error while trying to add WebAuthn device" : "Serverio klaida, bandant pridėti WbAuthn įrenginį",
-    "Name your device" : "Pavadinkite savo įrenginį",
-    "Active accounts" : "Aktyvios paskyros",
-    "Follow us on Twitter" : "Sekite mus Twitter"
+    "Very weak password" : "Labai silpnas slaptažodis",
+    "Weak password" : "Silpnas slaptažodis",
+    "So-so password" : "Neblogas slaptažodis",
+    "Good password" : "Geras slaptažodis",
+    "Strong password" : "Stiprus slaptažodis",
+    "Group list is empty" : "Grupės sąrašas yra tuščias",
+    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
+    "Loading accounts …" : "Įkeliamos paskyros ...",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba pasikeitus darbo santykiams su organizacija, galima nuotoliniu būdu išvalyti „Nextcloud“ duomenis iš visų įrenginių, susietų su {userid}.  Veikia tik su prie interneto prijungtais įrenginiais.",
+    "Loading account …" : "Įkeliama paskyra…",
+    "Adding your device …" : "Pridedamas jūsų įrenginys …",
+    "Sending…" : "Siunčiama…",
+    "Email sent" : "El. paštas išsiųstas",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
+    "None/STARTTLS" : "Nėra/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Prisijungimo duomenys",
+    "SMTP Password" : "SMTP slaptažodis",
+    "Save" : "Įrašyti",
+    "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
+    "Checking for system and security issues." : "Tikrinamos sistemos ir saugumo problemos.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dar kartą peržiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">įdiegimo vadovą ↗</a> bei patikrinkite ar <a href=\"%2$s\">žurnale</a> nėra jokių klaidų ar įspėjimų.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Patikrinkite savo Nextcloud saugumą naudodamiesi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">mūsų saugumo nuskaitymu ↗</a>."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
