@@ -1,19 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privāts",
-    "Local" : "Vietējs",
-    "Federated" : "Federated",
-    "Verify" : "Verificēt",
-    "Unable to change password" : "Nav iespējams nomainīt paroli",
-    "Very weak password" : "Ļoti vāja parole",
-    "Weak password" : "Vāja parole",
-    "So-so password" : "Viduvēja parole",
-    "Good password" : "Laba parole",
-    "Strong password" : "Spēcīga parole",
-    "Groups" : "Grupas",
-    "Group list is empty" : "Grupu saraksts ir tukšš",
-    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
     "{actor} changed your password" : "{actor} nomainīja Tavu paroli",
     "You changed your password" : "Tu nomainīji savu paroli",
     "{actor} changed your email address" : "{actor} nomainīja Tavu e-pasta adresi",
@@ -29,6 +16,7 @@ OC.L10N.register(
     "Could not update app." : "Lietotni nevarēja atjaunināt.",
     "Wrong password" : "Nepareiza parole",
     "Saved" : "Saglabāts",
+    "Unable to change password" : "Nav iespējams nomainīt paroli",
     "Authentication error" : "Autentificēšanās kļūda",
     "Wrong admin recovery password. Please check the password and try again." : "Nepareiza pārvaldītāja atkopes parole. Lūgums pārbaudītt paroli un mēģināt vēlreiz.",
     "Administrator documentation" : "Pārvaldītāja dokumentācija",
@@ -62,6 +50,7 @@ OC.L10N.register(
     "Mobile & desktop" : "Tālrunis un darbvirsma",
     "Email server" : "E-pasta serveris",
     "Unlimited" : "Neierobežota",
+    "Verify" : "Verificēt",
     "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nevarēja pārbaudīt, vai datu mape ir aizsargāta. Lūgums pašrocīgi pārbaudīt, ka serveris neļauj piekļūt datu mapei.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Datubāzē dažām kolonnām trūkst pārveidošana uz lieliem skaitļiem. Tā dēļ, ka kolonnu veida mainīšana lielās tabulās var aizņemt kādu laiku, tās netika mainītas automātiski. Izpildot \"occ db:convert-filecache-bigint\", šīs neveiktās izmaiņas var pielietot pašrocīgi. Šī darbība jāveic, kamēr serveris ir bezsaistē.",
     "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Vēl nav iestatīts e-pasta serveris vai apliecināta tā konfigurācija. Lūgums doties uz \"Pamata iestatījumi\", lai varētu to iestatīt. Pēc tam jāizmanto veidlapas apakšā esošā poga\"Nosūtīt e-pasta ziņojumu\", lai apliecinātu savus iestatījumus.",
@@ -100,6 +89,7 @@ OC.L10N.register(
     "No apps found for your version" : "Tavai versijai netika atrasta neviena lietotne",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n lietotnēm ir pieejams atjauninājums","%n lietotnei ir pieejams atjauninājums","%n lietotnēm ir pieejams atjauninājums"],
     "_Update_::_Update all_" : ["Atjaunināt visas","Atjaunināt","Atjaunināt visas"],
+    "Groups" : "Grupas",
     "Group name" : "Grupas nosaukums",
     "Could not load app discover section" : "Nevarēja ielādēt lietotņu atklāšanas sadaļu",
     "Loading" : "Ielādē",
@@ -163,14 +153,14 @@ OC.L10N.register(
     "You are using {s}{usage}{/s}" : "Tu izmanto {s}{usage}{/s}",
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Tu izmanto {s}{usage}{/s} no {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Tu esi zemāk uzskaitīto kopu dalībnieks:",
+    "No email address set" : "Nav norādīts e-pasts",
     "This address is not confirmed" : "Šī adrese nav apstiprināta",
     "Primary email for password reset and notifications" : "Galvenā e-pasta adrese paroles atiestatīšanai un paziņojumiem",
-    "No email address set" : "Nav norādīts e-pasts",
     "Help translate" : "Palīdzi tulkot",
+    "No locale set" : "Lokalizācija nav iestatīta",
     "Unable to update locale" : "Nevarēja atjaunināt lokalizāciju",
     "Locales" : "Lokalizācijas",
     "Week starts on {firstDayOfWeek}" : "Nedēļa sākas {firstDayOfWeek}",
-    "No locale set" : "Lokalizācija nav iestatīta",
     "Your phone number" : "Tavs tālruņa numurs",
     "Edit your Profile visibility" : "Labot sava profila redzamību",
     "Your role" : "Tava loma",
@@ -201,13 +191,24 @@ OC.L10N.register(
     "Send email" : "Nosūtīt e-pasta ziņojumu",
     "Send welcome email to new accounts" : "Nosūtīt sasveicināšanās e-pasta ziņojumu jauniem lietotājiem",
     "Default quota" : "Apjoms pēc noklusējuma",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ir svarīgi iestatīt šo serveri, lai varētu nosūtīt e-pasta ziņojumus, piemēram, paroles atiestatīšanai un paziņojumus.",
+    "Send mode" : "Sūtīšanas metode",
+    "Encryption" : "Šifrēšana",
+    "From address" : "No adreses",
+    "Domain" : "Domain",
+    "Server address" : "Servera adrese",
+    "Host" : "Resursdators",
+    "Port" : "Ports",
+    "Authentication" : "Autentifikācija",
+    "Authentication required" : "Nepieciešama autentifikācija",
+    "Saving…" : "Saglabā...",
+    "Save settings" : "Saglabāt iestatījumus",
     "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
     "All checks passed." : "Visas pārbaudes sekmīgas.",
+    "There are some warnings regarding your setup." : "Ir daži brīdinājumi saistībā ar šo serveri.",
     "Developer documentation ↗" : "Dokumentācija izstrādātājiem ↗",
     "Apply" : "Apstiprināt",
     "Admins" : "Pārvaldītāji",
-    "Sending…" : "Sūta …",
-    "Email sent" : "E-pasta ziņojums nosūtīts",
     "Location" : "Atrašanās vieta",
     "Profile picture" : "Profila attēls",
     "About" : "Par",
@@ -218,6 +219,9 @@ OC.L10N.register(
     "Website" : "Mājaslapa",
     "Locale" : "Lokalizācija",
     "First day of week" : "Pirmā nedēļas diena",
+    "Private" : "Privāts",
+    "Local" : "Vietējs",
+    "Federated" : "Federated",
     "Discover" : "Atklāt",
     "Your apps" : "Tavas lietotnes",
     "Active apps" : "Izmantotās lietotnes",
@@ -236,26 +240,24 @@ OC.L10N.register(
     "Forum" : "Forums",
     "Nextcloud help & privacy resources" : "Nextcloud palīdzība un privātuma līdzekļi",
     "Privacy policy" : "Privātuma politika",
-    "SSL" : "SSL",
-    "Open documentation" : "Atvērt dokumentāciju",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Ir svarīgi iestatīt šo serveri, lai varētu nosūtīt e-pasta ziņojumus, piemēram, paroles atiestatīšanai un paziņojumus.",
-    "Send mode" : "Sūtīšanas metode",
-    "Encryption" : "Šifrēšana",
-    "From address" : "No adreses",
-    "Server address" : "Servera adrese",
-    "Port" : "Ports",
-    "Authentication" : "Autentifikācija",
-    "Authentication required" : "Nepieciešama autentifikācija",
-    "Credentials" : "Akreditācijas dati",
-    "SMTP Password" : "SMTP parole",
-    "Save" : "Saglabāt",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
+    "Open documentation" : "Atvērt dokumentāciju",
     "Use a second factor besides your password to increase security for your account." : "Vēl viena apliecināšanas līdzekļa izmantošana papildus parolei, lai palielinātu sava konta drošību.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ja izmanto trešo pušu lietotnes, lai savienotos ar Nextcloud, lūgums ņemt vērā, ka pirms divpakāpju pieteikšanās iespējošanas katrai no tām ir nepieciešams izveidot un izmantot lietotnes paroli.",
-    "Your biography" : "Apraksts par sevi",
-    "You are using <strong>{usage}</strong>" : "Tu izmanto <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Tu izmanto <strong>{usage}</strong> no <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
+    "Very weak password" : "Ļoti vāja parole",
+    "Weak password" : "Vāja parole",
+    "So-so password" : "Viduvēja parole",
+    "Good password" : "Laba parole",
+    "Strong password" : "Spēcīga parole",
+    "Group list is empty" : "Grupu saraksts ir tukšš",
+    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pazaudētas ierīces vai apvienības pamešanas gadījumā šis var attālināti notīrīt Nextcloud datus visās ar {userid} saistītajās ierīcēs. Darbojas tikai tad, ja ierīces ir savienotas ar internetu.",
-    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Veiktspējas dēļ, kad Nextcloud serverī iespējo šifrēšanu, jaunās un izmainītās datnes tiek šīfrētas."
+    "Sending…" : "Sūta …",
+    "Email sent" : "E-pasta ziņojums nosūtīts",
+    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Veiktspējas dēļ, kad Nextcloud serverī iespējo šifrēšanu, jaunās un izmainītās datnes tiek šīfrētas.",
+    "SSL" : "SSL",
+    "Credentials" : "Akreditācijas dati",
+    "SMTP Password" : "SMTP parole",
+    "Save" : "Saglabāt"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
