@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privat",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
-    "Federated" : "Federat",
-    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
-    "Published" : "Publicat",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
-    "Verify" : "Verifică",
-    "Verifying …" : "Se verifică ...",
-    "Unable to change password" : "Imposibil de schimbat parola",
-    "Very weak password" : "Parolă foarte slabă",
-    "Weak password" : "Parolă slabă",
-    "So-so password" : "Parolă medie",
-    "Good password" : "Parolă bună",
-    "Strong password" : "Parolă puternică",
-    "Groups" : "Grupuri",
-    "Group list is empty" : "Lista de grupuri este goală",
-    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
     "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
     "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
     "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
@@ -52,6 +33,7 @@ OC.L10N.register(
     "Wrong password" : "Parolă greșită",
     "Unable to change personal password" : "Nu se poate schimba parola personală",
     "Saved" : "Salvat",
+    "Unable to change password" : "Imposibil de schimbat parola",
     "Authentication error" : "Eroare la autentificare",
     "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
     "Administrator documentation" : "Documentație pentru administrare",
@@ -90,6 +72,7 @@ OC.L10N.register(
     "Administration" : "Administrare",
     "Users" : "Utilizatori",
     "Additional settings" : "Setări adiționale",
+    "Assistant" : "Asistent",
     "Administration privileges" : "Privilegii de administrare",
     "Groupware" : "Articole de grup",
     "Overview" : "Prezentare generală",
@@ -102,6 +85,8 @@ OC.L10N.register(
     "Background jobs" : "Proces de fundal",
     "Unlimited" : "Nelimitată",
     "Verifying" : "Se verifică",
+    "Verifying …" : "Se verifică ...",
+    "Verify" : "Verifică",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Directorul de date și fișierele sunt probabil accesibile din Internet. Fișierul .htaccess nu este funcțional. Se recomandă puternic configurarea serverului web astfel încât directorul de date să nu mai fie accesibil astfel, sau mutați-l în afara rădăcinii documentelor a serverului web.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
@@ -137,6 +122,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Autentificarea cu doi factori nu este impusă pentru membrii următoarelor grupuri.",
     "Excluded groups" : "Grupuri excluse",
     "Save changes" : "Salvează modificările",
+    "Default" : "Implicită",
     "Remove" : "Șterge",
     "Featured" : "Recomandată",
     "Icon" : "Pictogramă",
@@ -145,6 +131,8 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acțiuni",
     "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "Groups" : "Grupuri",
+    "Group name" : "Numele grupului",
     "Type" : "Tip",
     "Learn more" : "Află mai mult",
     "Confirm" : "Confirmă",
@@ -168,10 +156,11 @@ OC.L10N.register(
     "Ask questions or discuss" : "Puneți întrebări sau participați la discuții",
     "Changelog" : "Listă modificări",
     "Google Chrome for Android" : "Google Chrome for Android",
+    "{productName} Android app" : "{productName} aplicație Android",
     "This session" : "Această sesiune",
     "Device settings" : "Setările dispozitivului",
     "Allow filesystem access" : "Permite accesul la fișierele de sistem",
-    "Rename" : "Redenumește",
+    "Rename" : "Redenumire",
     "Revoke" : "Revocă",
     "Device" : "Dispozitiv",
     "Last activity" : "Ultima activitate",
@@ -182,6 +171,7 @@ OC.L10N.register(
     "Create new app password" : "Crează o nouă parolă pentru aplicație",
     "Login" : "Autentificare",
     "Password" : "Parolă",
+    "Password confirmation is required" : "Confirmarea parolei este necesară",
     "Server-side encryption" : "Criptare la nivel de server",
     "Enable server-side encryption" : "Activează criptarea pe server",
     "Select default encryption module:" : "Selectează modulul implicit de criptare:",
@@ -189,22 +179,21 @@ OC.L10N.register(
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptarea, ca unică variantă, nu garantează securitatea sistemului. Consultați documentația pentru mai multe informații despre cum funcționează aplicația de criptare și variantele de utilizare acceptate.",
     "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
     "Submit" : "Trimite",
-    "Remove group" : "Înlătură grupul",
     "Current password" : "Parola curentă",
     "New password" : "Noua parolă",
-    "Change password" : "Schimbă parola",
     "No email address set" : "Fără adresă de email setată",
     "Help translate" : "Ajută la traducere",
+    "Week starts on {firstDayOfWeek}" : "Săptămâna începe {firstDayOfWeek}",
     "Your phone number" : "Numărul tău de telefon",
     "Add" : "Adaugă",
-    "Create" : "Creează",
+    "Create" : "Crează",
     "Change" : "Schimbă",
     "Delete" : "Șterge",
     "Reshare" : "Redistribuiți",
     "Default language" : "Limba implicită",
     "Display name" : "Nume afișat",
     "Email" : "Email",
-    "Quota" : "Cotă",
+    "Quota" : "Procent",
     "Language" : "Limba",
     "Total rows summary" : "Rezumat total rânduri",
     "Avatar" : "Avatar",
@@ -217,13 +206,23 @@ OC.L10N.register(
     "Send email" : "Expediază mesajul",
     "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
     "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
-    "Adding your device …" : "Adăugarea dispozitivului dvs ...",
     "Unnamed device" : "Dispozitiv fără nume",
     "Your browser does not support WebAuthn." : "Browserul dvs. nu acceptă WebAuthn.",
+    "Send mode" : "Modul de expediere",
+    "Encryption" : "Încriptare",
+    "From address" : "De la adresa",
+    "Domain" : "Domeniu",
+    "Server address" : "Adresa server-ului",
+    "Host" : "Gazdă",
+    "Port" : "Portul",
+    "Authentication" : "Autentificare",
+    "Authentication required" : "Autentificare necesară",
+    "Saving…" : "Se salvează...",
+    "Save settings" : "Salvează setări",
+    "Security & setup warnings" : "Alerte de securitate & configurare",
+    "All checks passed." : "Toate verificările s-au terminat fără erori.",
+    "Apply" : "Aplică",
     "Admins" : "Administratori",
-    "Group name" : "Numele grupului",
-    "Sending…" : "Se trimite...",
-    "Email sent" : "Mesajul a fost expediat",
     "Location" : "Locație",
     "Profile picture" : "Imagine de profil",
     "About" : "Despre",
@@ -233,6 +232,14 @@ OC.L10N.register(
     "Phone number" : "Număr telefon",
     "Role" : "Rol",
     "Website" : "Site web",
+    "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
+    "Federated" : "Federat",
+    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
+    "Published" : "Publicat",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
     "Your apps" : "Aplicațiile tale",
     "Disabled apps" : "Aplicații inactive",
     "Updates" : "Actualizări",
@@ -250,23 +257,21 @@ OC.L10N.register(
     "Error" : "Eroare",
     "Forum" : "Forum",
     "Legal notice" : "Aviz juridic",
-    "SSL" : "SSL",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
     "Open documentation" : "Deschide documentația",
-    "Send mode" : "Modul de expediere",
-    "Encryption" : "Încriptare",
-    "From address" : "De la adresa",
-    "Server address" : "Adresa server-ului",
-    "Port" : "Portul",
-    "Authentication" : "Autentificare",
-    "Authentication required" : "Autentificare necesară",
+    "Very weak password" : "Parolă foarte slabă",
+    "Weak password" : "Parolă slabă",
+    "So-so password" : "Parolă medie",
+    "Good password" : "Parolă bună",
+    "Strong password" : "Parolă puternică",
+    "Group list is empty" : "Lista de grupuri este goală",
+    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
+    "Adding your device …" : "Adăugarea dispozitivului dvs ...",
+    "Sending…" : "Se trimite...",
+    "Email sent" : "Mesajul a fost expediat",
+    "SSL" : "SSL",
     "Credentials" : "Detalii de autentificare",
     "SMTP Password" : "Parolă SMTP",
-    "Save" : "Salvează",
-    "Security & setup warnings" : "Alerte de securitate & configurare",
-    "All checks passed." : "Toate verificările s-au terminat fără erori.",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
-    "Username" : "Nume utilizator",
-    "Name your device" : "Numiți dispozitivul dvs."
+    "Save" : "Salvează"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
