@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privadu",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Visìbile isceti a is persones agatadas cun integratzione de su nùmeru de telèfonu tràmite Talk in mobile",
-    "Local" : "Locale",
-    "Only visible to people on this instance and guests" : "Visìbile isceti a is persones invitadas e a is de custa istàntzia",
-    "Federated" : "Federadu",
-    "Only synchronize to trusted servers" : "Sincroniza cun serbidores seguros ebbia",
-    "Published" : "Publicadu",
-    "Synchronize to trusted servers and the global and public address book" : "Sincroniza cun serbidores seguros e sa rubrica globale e pùblica",
-    "Verify" : "Avèrgua",
-    "Verifying …" : "Averguende ...",
-    "Unable to change password" : "Impossìbile a cambiare sa crae",
-    "Very weak password" : "Crae dèbile a beru",
-    "Weak password" : "Crae dèbile",
-    "So-so password" : "Crae aici aici",
-    "Good password" : "Crae bona",
-    "Strong password" : "Crae bona a beru",
-    "Groups" : "Grupos",
-    "Group list is empty" : "S'elencu de is grupos est bòida",
-    "Unable to retrieve the group list" : "Non faghet a recuperare s'elencu de is grupos",
     "{actor} added you to group {group}" : "{actor} t'at agiuntu a su grupu {group}",
     "You added {user} to group {group}" : "As agiuntu a {user} a su grupu {group}",
     "{actor} added {user} to group {group}" : "{actor} at agiuntu a {user} a su grupu {group}",
@@ -51,6 +32,7 @@ OC.L10N.register(
     "Settings" : "Cunfiguratziones",
     "Wrong password" : "Crae isballiada",
     "Saved" : "Sarvadu",
+    "Unable to change password" : "Impossìbile a cambiare sa crae",
     "Authentication error" : "Errore de autenticatzione",
     "Wrong admin recovery password. Please check the password and try again." : "Crae amministrativa de riprìstinu isballiada. Controlla·dda e torra a proare.",
     "Administrator documentation" : "Documentatzione amministratzione",
@@ -106,6 +88,8 @@ OC.L10N.register(
     "Background jobs" : "Atividades de background",
     "Unlimited" : "Chene lìmites",
     "Verifying" : "Averguende",
+    "Verifying …" : "Averguende ...",
+    "Verify" : "Avèrgua",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In sa base de datos mancat calicuna colunna optzionale. Agiùnghere is colunnas optzionale a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-columns\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is colunnas sunt agiuntas unas cantas funtzionalidades diant pòdere resurtare prus reativos o prus bellu a impreare. ",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In sa base de datos mancat calicuna crae primària. Agiùnghere is craes primàrias a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-primary-keys\". Si podent agiùnghere a manu is craes primàrias chi mancant in s'interis chi s'istàntzia est in funtzione.",
     "Disabled" : "Disativadu",
@@ -131,7 +115,6 @@ OC.L10N.register(
     "Enforce password protection" : "Impone sa bardiadura de sa crae",
     "Enforce expiration date" : "Impone data de iscadèntzia",
     "Set default expiration date for shares to other servers" : "Cunfigura sa data de iscadèntzia predefinida pro is cumpartziduras a àteros serbidores",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si sa cumponidura automàtica \"matessi grupu\" e \"integratzione de nùmeru de telèfonu\" sunt ativadas, una currispondèntzia in unu de is duas bastat a mustrare s'utente.",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mustra sa liberatòria in sa pàgina de carrigamentu de su ligòngiu pùblicu (mustradu isceti cando s'archìviu de sa lista est cuadu)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Custu testu s'at a mustrare in sa pàgina de carrigamentu de su ligòngiu pùblicu cando s'archìviu de sa lista est cuadu.",
     "Default share permissions" : "Permissos de cumpartzidura predefinidos",
@@ -144,6 +127,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "S'autenticatzione a duos fatores no est cunfigurada pro cumponentes de is grupos in fatu.",
     "Excluded groups" : "Grupos esclùdidos",
     "Save changes" : "Sarva càmbios",
+    "Default" : "Predefinidu",
     "Update to {update}" : "Agiorna a {update}",
     "Remove" : "Boga",
     "Featured" : "In evidèntzia",
@@ -158,13 +142,15 @@ OC.L10N.register(
     "Results from other categories" : "Resurtados dae àteras categorias",
     "No apps found for your version" : "Peruna aplicatzione agatada pro sa versione tua",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicatzione tenet un'agiornamentu a disponimentu","%n aplicatziones tenent un'agiornamentu a disponimentu"],
+    "Groups" : "Grupos",
+    "Loading groups…" : "Carrighende grupos...",
     "Nothing to show" : "Nudda de mustrare",
     "Loading" : "Carrighende",
     "Type" : "Genia",
     "Confirm" : "Cunfirma",
     "Cancel" : "Annulla",
     "Description" : "Descritzione",
-    "View in store" : "Càstia in s'archìviu",
+    "View in store" : "Visualiza in sa butega",
     "Visit website" : "Vìsita su situ",
     "Admin documentation" : "Documentatzione amministratzione",
     "Developer documentation" : "Documentatzione isvilupu",
@@ -173,14 +159,12 @@ OC.L10N.register(
     "Limit app usage to groups" : "Lìmita s'impreu de s'aplicatzione a grupos",
     "No results" : "Perunu resurtadu",
     "Update to {version}" : "Agiorna a  {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione mìnima de Nextcloud assignada. At a èssere unu problema in su benidore.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione màssima de Nextcloud assignada. At a èssere unu problema in su benidore.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Non faghet a installare custa aplicatzione ca is dipendèntzias in fatu non sunt  satisfatos:",
     "Author" : "Autoria",
     "Categories" : "Categ",
     "Resources" : "Risorsas",
     "Documentation" : "Documentatzione",
-    "Report a bug" : "Signala un'errore",
+    "Report a bug" : "Report a bug",
     "Request feature" : "Rechede funtzionalidade",
     "Ask questions or discuss" : "Faghe preguntas o discuti",
     "Rate" : "Vàluta",
@@ -195,7 +179,6 @@ OC.L10N.register(
     "Marked for remote wipe" : "Marcadu pro cantzelladura remota",
     "Device settings" : "Cunfiguratzione de su dispositivu",
     "Allow filesystem access" : "Permite s'intrada a su sistema de is archìvios",
-    "Rename" : "Torra a numenare",
     "Revoke" : "Rèvoca",
     "Wipe device" : "Cantzella dispositivu",
     "Device" : "Dispositivu",
@@ -224,7 +207,6 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Benit semper a bene a creare còpias de seguresa regulares de is datos tuos, in casu de tzifradura assegura•ti de creare còpia de is craes de tzfradura paris cun is datos tuos.",
     "This is the final warning: Do you really want to enable encryption?" : "Custu est s'ùrtimu avisu : a beru boles ativare sa tzifradura?",
     "Submit" : "Imbia",
-    "Remove group" : "Boga·nche grupu",
     "Current password" : "Crae currente",
     "New password" : "Crae noa",
     "Change password" : "Càmbia crae",
@@ -232,16 +214,16 @@ OC.L10N.register(
     "Picture provided by original account" : "Immàgine frunida dae su contu originale",
     "You are a member of the following groups:" : "Faghes parte de custos grupos:",
     "Your full name" : "Nùmene cumpletu",
+    "No email address set" : "Perunu indiritzu de posta eletrònica cunfiguradu",
     "Email options" : "Optziones de posta eletrònica",
     "Remove primary email" : "Boga•nche s'indiritzu de posta eletrònica printzipale",
     "Delete email" : "Cantzella indiritzu de posta eletrònica",
     "Additional email address {index}" : "Segundu indiritzu de posta eletrònica {index}",
     "Primary email for password reset and notifications" : "Indiritzu de posta eletrònica printzipale pro torrare a cunfigurare sa crae e retzire notìficas",
-    "No email address set" : "Perunu indiritzu de posta eletrònica cunfiguradu",
     "Your handle" : "Nùmene de utente tuo",
     "Your headline" : "Su tìtulu tuo",
-    "Help translate" : "Agiuda a tradùere",
     "No language set" : "Peruna limba cunfigurada",
+    "Help translate" : "Agiuda a tradùere",
     "Week starts on {firstDayOfWeek}" : "Sa chida cumintzat su {firstDayOfWeek}",
     "Your city" : "Sa tzitade tua",
     "Your organisation" : "S'organizatzione tua",
@@ -257,6 +239,7 @@ OC.L10N.register(
     "Change" : "Càmbia",
     "Delete" : "Cantzella",
     "Reshare" : "Torra a cumpartzire",
+    "School" : "Iscola",
     "Default language" : "Limba predefinida",
     "Common languages" : "Limbas comunes",
     "Password change is disabled because the master key is disabled" : "Su càmbiu de sa crae est disativadu ca sa crae printzipale est disativada",
@@ -274,7 +257,6 @@ OC.L10N.register(
     "{size} used" : "{size} impreadu",
     "Delete account" : "Cantzella contu",
     "Resend welcome email" : "Torra a imbiare su messàgiu de benebènnida",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In casu de pèrdida de su dispositivu o de essida dae s'organizatzione, custu podet cantzellare dae remotu is datos de Nextcloud dae totu is dispositivos assotziados cun {userid}. Funtzionat isceti si is dispositivos sunt collegados a internet. ",
     "Remote wipe of devices" : "Cantzelladura remota de is dispositivos",
     "Wipe {userid}'s devices" : "Cantzella is dispositivos de {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Cantzella su contu de {userid}, inclùdidos archìvios personales, datos de aplicatziones, etc.",
@@ -283,7 +265,6 @@ OC.L10N.register(
     "Welcome mail sent!" : "Messàgiu de benebènnida imbiadu!",
     "Set new password" : "Cunfigura una crae noa",
     "Set new email address" : "Cunfigura un'indiritzu nou de posta eletrònica",
-    "Done" : "Fatu",
     "Edit" : "Modìfica",
     "Show storage path" : "Mustra su percursu de archiviatzione",
     "Show last login" : "Mustra s'ùrtimu atzessu",
@@ -295,17 +276,32 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "S'autenticatzione chene crae rechedet una connessione segura.",
     "Add WebAuthn device" : "Agiunghe dispositivu WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza su dispositivu WebAuthn tuo.",
-    "Adding your device …" : "Agiunghende su dispositivu tuo ...",
-    "Unnamed device" : "Dispositivu chene nùmene",
+    "Unnamed device" : "Dispositivu sena nùmene",
     "Passwordless Authentication" : "Autenticatzione chene crae",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Cunfigura su contu tuo pro s'autenticatzione chene crae, sighende s'istandard FIDO2.",
     "No devices configured." : "Perunu dispositivu cunfiguradu.",
     "The following devices are configured for your account:" : "Is dispositivos in fatu sunt cunfigurados pro su contu tuo:",
     "Your browser does not support WebAuthn." : "Su serbidore tuo non suportat WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Est importante a cunfigurare custu serbidore pro imbiare messàgios de posta eletrònica, pro torrare a cunfigurare sa crae e pro is notìficas. ",
+    "Send mode" : "Modalidade de imbiu",
+    "Encryption" : "Tzifradura",
+    "Sendmail mode" : "Modalidade de imbiu de posta",
+    "Disable certificate verification (insecure)" : "Disativa sa verìfica de tzertificados (non seguru)",
+    "From address" : "Indiritzu de chie imbiat",
+    "Domain" : "Domìniu",
+    "Server address" : "Indiritzu de su serbidore",
+    "Host" : "Retzidore",
+    "Port" : "Porta",
+    "Authentication" : "Autenticatzione",
+    "Authentication required" : "Autenticatzione recherta",
+    "Saving…" : "Sarvende...",
+    "Security & setup warnings" : "Avisos de seguresa e cunfiguratzione",
+    "All checks passed." : "Passados totu is controllos.",
+    "There are some errors regarding your setup." : "B'at errores in sa cunfiguratzione tua.",
+    "There are some warnings regarding your setup." : "B'at avisos in sa cunfiguratzione tua",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Comente parte de s'amministratzione podes afinigare su cumportamentu de cumpartzidura. Càstia sa documentatzione pro àteras informatziones.",
+    "Apply" : "Àplica",
     "Admins" : "Amministratzione",
-    "Sending…" : "Imbiende...",
-    "Email sent" : "Messàgiu de posta imbiadu",
     "Location" : "Positzione",
     "Profile picture" : "Immàgine de profilu",
     "About" : "In contu de",
@@ -319,6 +315,14 @@ OC.L10N.register(
     "Website" : "Situ ìnternet",
     "Profile visibility" : "Visibilidade de su profilu",
     "Locale" : "Localizatzione",
+    "Private" : "Privadu",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Visìbile isceti a is persones agatadas cun integratzione de su nùmeru de telèfonu tràmite Talk in mobile",
+    "Local" : "Locale",
+    "Only visible to people on this instance and guests" : "Visìbile isceti a is persones invitadas e a is de custa istàntzia",
+    "Federated" : "Federadu",
+    "Only synchronize to trusted servers" : "Sincroniza cun serbidores seguros ebbia",
+    "Published" : "Publicadu",
+    "Synchronize to trusted servers and the global and public address book" : "Sincroniza cun serbidores seguros e sa rubrica globale e pùblica",
     "Your apps" : "Is aplicatziones tuas",
     "Active apps" : "Aplicatziones ativas",
     "Disabled apps" : "Aplicatziones disativadas",
@@ -331,7 +335,6 @@ OC.L10N.register(
     "Download and enable" : "Iscàrriga e ativa",
     "Disable" : "Disativa",
     "The app will be downloaded from the App Store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Custa aplicatzione no est marcada comente cumpatìbile cun sa versione tua de Nextcloud. Si sighis, as a pòdere installare s'aplicatzione. Càstia ca podet èssere chi non funtzionet comente prevìdidu.",
     "Unknown" : "Disconnotu",
     "Never" : "Mai",
     "Error: This app cannot be enabled because it makes the server unstable" : "Errore: Custa aplicatzione non si podet ativare ca faghet su serbidore no istàbile",
@@ -346,46 +349,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Legal notice" : "Avisu legale",
     "Privacy policy" : "Critèriu de riservadesa",
-    "Open documentation" : "Aberi documentatzione",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Est importante a cunfigurare custu serbidore pro imbiare messàgios de posta eletrònica, pro torrare a cunfigurare sa crae e pro is notìficas. ",
-    "Send mode" : "Modalidade de imbiu",
-    "Encryption" : "Tzifradura",
-    "Sendmail mode" : "Modalidade de imbiu de posta",
-    "From address" : "Indiritzu de chie imbiat",
-    "Server address" : "Indiritzu de su serbidore",
-    "Port" : "Porta",
-    "Authentication" : "Autenticatzione",
-    "Authentication required" : "Autenticatzione recherta",
-    "Credentials" : "Credentziales",
-    "SMTP Password" : "Crae SMTP",
-    "Save" : "Sarva",
-    "Security & setup warnings" : "Avisos de seguresa e cunfiguratzione",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Est importante pro sa seguresa e s'esecutzione de s'istàntzia tua chi totu siat cunfiguradu bene. Pro t'agiudare, semus faghende controllos automàticos. Càstia sa documentatzione in ligòngiu pro àteras informatziones.",
-    "All checks passed." : "Passados totu is controllos.",
-    "There are some errors regarding your setup." : "B'at errores in sa cunfiguratzione tua.",
-    "There are some warnings regarding your setup." : "B'at avisos in sa cunfiguratzione tua",
-    "Checking for system and security issues." : "Verìfica de is problemas de sistema e seguresa.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Càstia bene is <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">ghias de installatzione ↗</a>, e controlla is errores o is avisos in su <a href=\"%2$s\">registru</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla sa seguresa de Nextcloud in <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">s'iscansione nostra de seguresa ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Resones pro impreare Nextcloud in s'organizatzione tua",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Isvilupadu dae {communityopen}comunidadeNextcloud {linkclose}, su {githubopen}còdighe de orìgine{linkclose} est lissentziadu pro {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Pone•ddi M'agradat a sa pàgina Facebook nostra",
     "Follow us on Mastodon" : "Sighi·nos in Mastodon",
     "Check out our blog" : "Leghe·ti su blog nostru",
     "Subscribe to our newsletter" : "Iscrie·ti a sa lista de messàgios nostra",
+    "Open documentation" : "Aberi documentatzione",
     "Use a second factor besides your password to increase security for your account." : "Imprea unu segundu fatore a parte sa crae tua pro crèschere sa seguresa de su contu tuo.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si impreas aplicatziones de sa de tres partes pro ti connètere a Nextcloud, assegura•ti de creare e cunfigurare una crae pro cada aplicatzione antis de ativare su segundu fatore de autenticatzione.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
-    "Set default expiration date for shares" : "Cunfigura sa data de iscadèntzia predefinida pro is cumpartziduras",
-    "Your biography" : "Sa biografia tua",
-    "New user" : "Utèntzia noa",
-    "Add new user" : "Agiunghe utente nou",
-    "_{userCount} user_::_{userCount} users_" : ["{userCount}utente","{userCount} utentes"],
-    "Username" : "Nùmene utente",
-    "User backend" : "Motore utente",
-    "Add user to group" : "Agiunghe un'utente a unu grupu",
-    "Server error while trying to add WebAuthn device" : "Errore de su serbidore chirchende de agiùnghere su dispositivu WebAuthn",
-    "Name your device" : "Nùmena su dispositivu",
-    "Follow us on Twitter" : "Sighi•nosi in Twitter"
+    "Very weak password" : "Crae dèbile a beru",
+    "Weak password" : "Crae dèbile",
+    "So-so password" : "Crae aici aici",
+    "Good password" : "Crae bona",
+    "Strong password" : "Crae bona a beru",
+    "Group list is empty" : "S'elencu de is grupos est bòida",
+    "Unable to retrieve the group list" : "Non faghet a recuperare s'elencu de is grupos",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione mìnima de Nextcloud assignada. At a èssere unu problema in su benidore.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Custa aplicatzione non cuntenet sa versione màssima de Nextcloud assignada. At a èssere unu problema in su benidore.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In casu de pèrdida de su dispositivu o de essida dae s'organizatzione, custu podet cantzellare dae remotu is datos de Nextcloud dae totu is dispositivos assotziados cun {userid}. Funtzionat isceti si is dispositivos sunt collegados a internet. ",
+    "Adding your device …" : "Agiunta de su dispositivu tuo...",
+    "Sending…" : "Imbiende...",
+    "Email sent" : "Messàgiu de posta imbiadu",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Custa aplicatzione no est marcada comente cumpatìbile cun sa versione tua de Nextcloud. Si sighis, as a pòdere installare s'aplicatzione. Càstia ca podet èssere chi non funtzionet comente prevìdidu.",
+    "Credentials" : "Credentziales",
+    "SMTP Password" : "Crae SMTP",
+    "Save" : "Sarva",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Est importante pro sa seguresa e s'esecutzione de s'istàntzia tua chi totu siat cunfiguradu bene. Pro t'agiudare, semus faghende controllos automàticos. Càstia sa documentatzione in ligòngiu pro àteras informatziones.",
+    "Checking for system and security issues." : "Verìfica de is problemas de sistema e seguresa.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Càstia bene is <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">ghias de installatzione ↗</a>, e controlla is errores o is avisos in su <a href=\"%2$s\">registru</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla sa seguresa de Nextcloud in <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">s'iscansione nostra de seguresa ↗</a>."
 },
 "nplurals=2; plural=(n != 1);");
