@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "Ni mogoče spremeniti gesla",
-    "Very weak password" : "Zelo šibko geslo",
-    "Weak password" : "Slabo geslo",
-    "So-so password" : "Šibko geslo",
-    "Good password" : "Dobro geslo",
-    "Strong password" : "Odlično geslo",
     "{actor} added you to group {group}" : "{actor} vas doda v skupino {group}",
     "You added {user} to group {group}" : "Uporabnika {user} dodate v skupino {group}",
     "{actor} added {user} to group {group}" : "{actor} doda uporabnika {user} v skupino {group}",
@@ -44,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Ni mogoče spremeniti osebnega gesla.",
     "Saved" : "Shranjeno",
     "No Login supplied" : "Ni podane prijave",
+    "Unable to change password" : "Ni mogoče spremeniti gesla",
     "Unable to change password. Password too long." : "Gesla ni mogoče spremeniti. Geslo je predolgo.",
     "Authentication error" : "Napaka overjanja",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški računi izgubljeni.",
@@ -565,6 +560,20 @@ OC.L10N.register(
     "No devices configured." : "Ni nastavljenih naprav.",
     "The following devices are configured for your account:" : "Z vašim računom so povezane navedene naprave:",
     "Your browser does not support WebAuthn." : "Brskalnik ne podpira overitve WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Strežnik mora biti za pošiljanje sporočil ustrezno nastavljen. Velja tudi za pošiljanje povezav za ponastavitev gesla..",
+    "Send mode" : "Način pošiljanja",
+    "Encryption" : "Šifriranje",
+    "Sendmail mode" : "Način sendmail",
+    "Disable certificate verification (insecure)" : "Onemogoči overjanje potrdil (ni varen način)",
+    "From address" : "Naslov pošiljatelja",
+    "Domain" : "Domena",
+    "Server address" : "Naslov strežnika",
+    "Host" : "Gostitelj",
+    "Port" : "Vrata",
+    "Authentication" : "Overitev",
+    "Authentication required" : "Zahtevana je overitev",
+    "Saving…" : "Poteka shranjevanje ...",
+    "Save settings" : "Shrani nastavitve",
     "Security & setup warnings" : "Varnost in namestitvena opozorila",
     "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
     "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih nekaj napak namestitve.",
@@ -581,8 +590,6 @@ OC.L10N.register(
     "Admins" : "Skrbniki",
     "Account group: {group}" : "Skupina računov: {group}",
     "Account management" : "Upravljanje z računi",
-    "Sending…" : "Poteka pošiljanje ...",
-    "Email sent" : "Elektronsko sporočilo je poslano",
     "Location" : "Trenutno mesto",
     "Profile picture" : "Slika profila",
     "About" : "O meni",
@@ -645,23 +652,6 @@ OC.L10N.register(
     "General documentation" : "Splošna dokumentacija",
     "Legal notice" : "Pravno obvestilo",
     "Privacy policy" : "Pravila zasebnosti",
-    "None/STARTTLS" : "Brez/STARTTLS",
-    "SSL" : "Protokol SSL",
-    "Open documentation" : "Odprta dokumentacija",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Strežnik mora biti za pošiljanje sporočil ustrezno nastavljen. Velja tudi za pošiljanje povezav za ponastavitev gesla..",
-    "Send mode" : "Način pošiljanja",
-    "Encryption" : "Šifriranje",
-    "Sendmail mode" : "Način sendmail",
-    "From address" : "Naslov pošiljatelja",
-    "Server address" : "Naslov strežnika",
-    "Port" : "Vrata",
-    "Authentication" : "Overitev",
-    "Authentication required" : "Zahtevana je overitev",
-    "Credentials" : "Poverila",
-    "SMTP Login" : "Prijava SMTP",
-    "SMTP Password" : "Geslo SMTP",
-    "Save" : "Shrani",
-    "Test and verify email settings" : "Preizkusi in overi nastavitve elektronske pošte",
     "Reasons to use Nextcloud in your organization" : "Razlogi za uporabo oblaka Nextcloud v vaši organizaciji",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Okolje razvija {communityopen}skupnost Nextcloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena pod pogoji dovoljenja {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Spremljajte naš Facebook",
@@ -670,8 +660,14 @@ OC.L10N.register(
     "Check out our blog" : "Preverite naš blog",
     "Subscribe to our newsletter" : "Naročite se na novice",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ta objava oblaka Nextcloud ne vključuje podpore in hipna obvestila niso na voljo.",
+    "Open documentation" : "Odprta dokumentacija",
     "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
+    "Very weak password" : "Zelo šibko geslo",
+    "Weak password" : "Slabo geslo",
+    "So-so password" : "Šibko geslo",
+    "Good password" : "Dobro geslo",
+    "Strong password" : "Odlično geslo",
     "Group list is empty" : "Seznam skupin je prazen",
     "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
     "Logged in account must be a subadmin" : "Račun prijave mora imeti dovoljenja podpornega skrbnika",
@@ -684,7 +680,16 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
     "Loading account …" : "Poteka nalaganje računa ...",
     "Adding your device …" : "Poteka dodajanje naprave ..",
+    "Sending…" : "Poteka pošiljanje ...",
+    "Email sent" : "Elektronsko sporočilo je poslano",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
+    "None/STARTTLS" : "Brez/STARTTLS",
+    "SSL" : "Protokol SSL",
+    "Credentials" : "Poverila",
+    "SMTP Login" : "Prijava SMTP",
+    "SMTP Password" : "Geslo SMTP",
+    "Save" : "Shrani",
+    "Test and verify email settings" : "Preizkusi in overi nastavitve elektronske pošte",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je nujno, da je sistem posodobljen in pravilno nastavljen. Preverjanje poteka tako, da se nekateri preizkusi izvajajo sproti in samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
     "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
