@@ -1,18 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Private",
-    "Local" : "Lokale",
-    "Federated" : "Federated",
-    "Verify" : "Verifiko",
-    "Verifying …" : "Duke verifikuar ...",
-    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
-    "Very weak password" : "Fjalëkalim shumë i dobët",
-    "Weak password" : "Fjalëkalim i dobët",
-    "So-so password" : "Fjalëkalim çka",
-    "Good password" : "Fjalëkalim i mirë",
-    "Strong password" : "Fjalëkalim i fortë",
-    "Groups" : "Grupe",
     "{actor} changed your password" : "{actor} ndryshoi fjalëkalimin tuaj ",
     "You changed your password" : "Ju ndëruat fjalëkalimin",
     "Your password was reset by an administrator" : "Fjalëkalimi juaj është rivendosur nga administratori",
@@ -26,6 +14,7 @@ OC.L10N.register(
     "Settings" : "Rregullimet",
     "Wrong password" : "Fjalëkalim i gabuar",
     "Saved" : "U ruajt",
+    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
     "Authentication error" : "Gabim mirëfilltësimi",
     "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
     "Administrator documentation" : "Dokumentim për përgjegjës",
@@ -72,6 +61,8 @@ OC.L10N.register(
     "Background jobs" : "Punët në background",
     "Unlimited" : "E pakufizuar",
     "Verifying" : "Duke verifikuar",
+    "Verifying …" : "Duke verifikuar ...",
+    "Verify" : "Verifiko",
     "Disabled" : "I/E çaktivizuar",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP-ja nuk duket të jetë ngritur si duhet për të kërkuar ndryshore mjedisi sistemi. Testi me getenv(\"PATH\") kthen vetëm një përgjigje të zbrazët.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza juaj e të dhënave nuk ekzekutohet me nivelin \"READ COMMITED\" e izolimit për ndërveprimet. Kjo mund të shkaktojë probleme, kur kryhen paralelisht disa veprime njëherësh.",
@@ -88,6 +79,7 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Ky tekst do të shfaqet në linkun publik të faqes së ngarkuar kur lista e skedarit të jetë e fshehur.",
     "Limit to groups" : "Kufizo grupet",
     "Save changes" : "Ruaj ndryshimet",
+    "Default" : "Paraprake",
     "Remove" : "Hiqe",
     "Featured" : "I paraqitur",
     "Icon" : "Ikonë",
@@ -96,6 +88,8 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Veprimet",
     "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
+    "Groups" : "Grupe",
+    "Group name" : "Emër grupi",
     "Type" : "Tipi",
     "Display Name" : "Trego Emrin",
     "Learn more" : "Mësoni më shumë",
@@ -104,14 +98,12 @@ OC.L10N.register(
     "Description" : "Përshkrim",
     "View in store" : "Shiko në dyqan",
     "Visit website" : "Vizitoni sajtin",
-    "Admin documentation" : "Dokumentim për përgjegjësit",
-    "Developer documentation" : "Dokumentim për zhvillues",
-    "Details" : "Detaje",
-    "All" : "Krejt",
+    "Admin documentation" : "Dokumentacioni i administratorit",
+    "Developer documentation" : "Dokumentacioni e zhvilluesit",
+    "Details" : "Detajet",
+    "All" : "Të gjithë",
     "No results" : "Asnjë rezultat",
     "Update to {version}" : "Përditëso në {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
     "Categories" : "Kategoritë",
     "Resources" : "Burimet",
@@ -122,18 +114,20 @@ OC.L10N.register(
     "Rate" : "Vlerësoj",
     "Changelog" : "Katalogu i ndryshimeve",
     "Google Chrome for Android" : "Google Chrome për Android",
+    "{productName} Android app" : "{productName} Android app",
     "This session" : "Ky sesion",
     "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
-    "Rename" : "Rename",
+    "Rename" : "Riemërtoje",
     "Revoke" : "Anulo",
     "Device" : "Pajisje",
     "Last activity" : "Aktiviteti i fundit",
     "Web, desktop and mobile clients currently logged in to your account." : "Klientë në rrjet, desktop dhe celular kanë hyrë aktualisht në  llogarinë tuaj.",
     "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
-    "App name" : "Emër aplikacioni",
+    "App name" : "Emri i aplikacionit",
     "Create new app password" : "Krijoni fjalëkalim aplikacioni të ri",
     "Login" : "Hyrje",
     "Password" : "Fjalëkalim",
+    "Password confirmation is required" : "Kërkohet konfirmimi i fjalëkalimit",
     "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
     "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
@@ -146,20 +140,18 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
     "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
     "Submit" : "Dërgo",
-    "Remove group" : "Hiq grupin",
-    "Current password" : "Fjalëkalimi i tanishëm",
-    "New password" : "Fjalëkalimi i ri",
+    "Current password" : "Fjalëkalimi aktual",
+    "New password" : "Fjalëkalim i ri",
     "Change password" : "Ndrysho fjalëkalimin",
     "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
     "No email address set" : "S’është caktuar adresë email",
     "Help translate" : "Ndihmoni në përkthim",
     "Your phone number" : "Numri juaj i telefonit",
     "Your website" : "Website-i juaj",
-    "Add" : "Shto",
+    "Add" : "Shto ",
     "Create" : "Krijo",
     "Change" : "Ndrysho",
-    "Delete" : "Fshij",
-    "Display name" : "Shfaq emrin",
+    "Delete" : "Fshi",
     "Email" : "Email",
     "Quota" : "Kuota",
     "Language" : "Gjuhë",
@@ -175,19 +167,34 @@ OC.L10N.register(
     "Show last login" : "Shfaq hyrjen e fundit",
     "Send email" : "Dërgo email",
     "Default quota" : "Kuota Parazgjedhje",
-    "Adding your device …" : "Shtoni pajisjen tuaj ...",
     "Unnamed device" : "Paisje pa emër",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
+    "Send mode" : "Mënyrë dërgimi",
+    "Encryption" : "Fshehtëzim",
+    "From address" : "Nga adresa",
+    "Domain" : "Përkatësi",
+    "Server address" : "Adresë shërbyesi",
+    "Host" : "Strehë",
+    "Port" : "Portë",
+    "Authentication" : "Mirëfilltësim",
+    "Authentication required" : "Lypset mirëfilltësim",
+    "Saving…" : "Duke u ruajtur...",
+    "Save settings" : "Ruaj konfigurimet",
+    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
+    "Try again" : "Provo përsëri",
+    "All checks passed." : "I kaloi krejt kontrollet.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
+    "Apply" : "Apliko",
     "Admins" : "Administratorë",
-    "Group name" : "Emër grupi",
-    "Sending…" : "dërgim",
-    "Email sent" : "Email-i u dërgua",
     "Location" : "Vendndodhje",
     "Profile picture" : "Foto profili",
     "About" : "Rreth ",
     "Full name" : "Emër i plotë",
     "Phone number" : "Numri i telefonit",
     "Website" : "Faqe web-i",
+    "Private" : "Private",
+    "Local" : "Lokale",
+    "Federated" : "Federated",
     "Your apps" : "Aplikacionet tuaja ",
     "Active apps" : "Aplikacionet aktive",
     "Disabled apps" : "Aplikacionet pa aftësi ",
@@ -200,29 +207,24 @@ OC.L10N.register(
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
     "Error" : "Gabim",
     "Forum" : "Forum",
-    "SSL" : "SSL",
-    "Open documentation" : "Hapni dokumentimin",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
-    "Send mode" : "Mënyrë dërgimi",
-    "Encryption" : "Fshehtëzim",
-    "From address" : "Nga adresa",
-    "Server address" : "Adresë shërbyesi",
-    "Port" : "Portë",
-    "Authentication" : "Mirëfilltësim",
-    "Authentication required" : "Lypset mirëfilltësim",
-    "Credentials" : "Kredenciale",
-    "SMTP Password" : "Fjalëkalim SMTP",
-    "Save" : "Ruaj",
-    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
-    "All checks passed." : "I kaloi krejt kontrollet.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Zhvilluar nga {communityopen}komuniteti Nextcloud {linkclose},  {githubopen}kodi i hapur{linkclose} iështë licensuar sipar {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Pëlqeni faqen tonë në Facebook",
     "Check out our blog" : "Shikoni blogun tonë",
     "Subscribe to our newsletter" : "Abonohu në gazeten tonë",
-    "New user" : "Përdorues i ri",
-    "Username" : "Emër përdoruesi",
-    "User backend" : "Program klient i përdoruesit",
-    "Name your device" : "Emërtoni pajisjen tuaj",
-    "Follow us on Twitter" : "Na ndiqni në Twitter"
+    "Open documentation" : "Hapni dokumentimin",
+    "Very weak password" : "Fjalëkalim shumë i dobët",
+    "Weak password" : "Fjalëkalim i dobët",
+    "So-so password" : "Fjalëkalim çka",
+    "Good password" : "Fjalëkalim i mirë",
+    "Strong password" : "Fjalëkalim i fortë",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
+    "Adding your device …" : "Shtoni pajisjen tuaj ...",
+    "Sending…" : "dërgim",
+    "Email sent" : "Email-i u dërgua",
+    "SSL" : "SSL",
+    "Credentials" : "Kredenciale",
+    "SMTP Password" : "Fjalëkalim SMTP",
+    "Save" : "Ruaj"
 },
 "nplurals=2; plural=(n != 1);");
