@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "Kunde inte ändra lösenord",
-    "Very weak password" : "Väldigt svagt lösenord",
-    "Weak password" : "Svagt lösenord",
-    "So-so password" : "Okej lösenord",
-    "Good password" : "Bra lösenord",
-    "Strong password" : "Starkt lösenord",
-    "Groups" : "Grupper",
-    "Group list is empty" : "Grupplistan är tom",
-    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "{actor} added you to group {group}" : "{actor} adderade dig till gruppen {group}",
     "You added {user} to group {group}" : "Du adderade {user} till gruppen {group}",
     "{actor} added {user} to group {group}" : "{actor} adderade {user} till gruppen {group}",
@@ -47,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Kunde inte byta personligt lösenord",
     "Saved" : "Sparad",
     "No Login supplied" : "Ingen inloggning angiven",
+    "Unable to change password" : "Kunde inte ändra lösenord",
     "Unable to change password. Password too long." : "Kunde inte byta lösenord. Lösenord för långt.",
     "Authentication error" : "Fel vid autentisering",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Ange ett lösenord för administratörsåterställning; annars kommer all kontodata att gå förlorad.",
@@ -302,6 +294,7 @@ OC.L10N.register(
     "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
     "Failed to load groups" : "Kunde inte läsa in grupper",
     "Failed to create group" : "Det gick inte att skapa gruppen",
+    "Groups" : "Grupper",
     "Creating group…" : "Skapar grupp...",
     "Create group" : "Skapa grupp",
     "Group name" : "Gruppnamn",
@@ -590,6 +583,20 @@ OC.L10N.register(
     "No devices configured." : "Inga enheter konfigurerade.",
     "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
     "Your browser does not support WebAuthn." : "Din webbläsare stödjer inte WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
+    "Send mode" : "Sändningsläge",
+    "Encryption" : "Kryptering",
+    "Sendmail mode" : "Sendmail-läge",
+    "Disable certificate verification (insecure)" : "Använd inte certifikatsverifiering (osäkert)",
+    "From address" : "Från adress",
+    "Domain" : "Domän",
+    "Server address" : "Serveradress",
+    "Host" : "Server",
+    "Port" : "Port",
+    "Authentication" : "Autentisering",
+    "Authentication required" : "Autentisering krävs",
+    "Saving…" : "Sparar…",
+    "Save settings" : "Spara inställningar",
     "Security & setup warnings" : "Säkerhet & systemvarningar",
     "Try again" : "Försök igen",
     "All checks passed." : "Alla kontroller lyckades!",
@@ -608,8 +615,6 @@ OC.L10N.register(
     "Admins" : "Administratörer",
     "Account group: {group}" : "Kontogrupp: {group}",
     "Account management" : "Kontohantering",
-    "Sending…" : "Skickar...",
-    "Email sent" : "E-post skickad",
     "Location" : "Plats",
     "Profile picture" : "Profilbild",
     "About" : "Om",
@@ -677,23 +682,6 @@ OC.L10N.register(
     "General documentation" : "Dokumentationsöversikt",
     "Legal notice" : "Rättsligt meddelande",
     "Privacy policy" : "Integritetspolicy",
-    "None/STARTTLS" : "Ingen/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Öppna dokumentation",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
-    "Send mode" : "Sändningsläge",
-    "Encryption" : "Kryptering",
-    "Sendmail mode" : "Sendmail-läge",
-    "From address" : "Från adress",
-    "Server address" : "Serveradress",
-    "Port" : "Port",
-    "Authentication" : "Autentisering",
-    "Authentication required" : "Autentisering krävs",
-    "Credentials" : "Inloggningsuppgifter",
-    "SMTP Login" : "SMTP-inloggning",
-    "SMTP Password" : "SMTP-lösenord",
-    "Save" : "Spara",
-    "Test and verify email settings" : "Testa och verifiera e-postinställningar",
     "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utvecklat av {communityopen}Nextcloud-gemenskapen{linkclose}, {githubopen}källkoden{linkclose}  är licensierad enligt {licenseopen}AGPL-standard{linkclose}.",
     "Like our Facebook page" : "Gilla vår Facebook-sida",
@@ -702,8 +690,16 @@ OC.L10N.register(
     "Check out our blog" : "Kolla in vår blogg",
     "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
+    "Open documentation" : "Öppna dokumentation",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
+    "Very weak password" : "Väldigt svagt lösenord",
+    "Weak password" : "Svagt lösenord",
+    "So-so password" : "Okej lösenord",
+    "Good password" : "Bra lösenord",
+    "Strong password" : "Starkt lösenord",
+    "Group list is empty" : "Grupplistan är tom",
+    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
@@ -713,7 +709,16 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
     "Loading account …" : "Laddar konto ...",
     "Adding your device …" : "Lägger till din enhet ....",
+    "Sending…" : "Skickar...",
+    "Email sent" : "E-post skickad",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
+    "None/STARTTLS" : "Ingen/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Inloggningsuppgifter",
+    "SMTP Login" : "SMTP-inloggning",
+    "SMTP Password" : "SMTP-lösenord",
+    "Save" : "Spara",
+    "Test and verify email settings" : "Testa och verifiera e-postinställningar",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
     "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
