@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "ไม่สามารถเปลี่ยนรหัสผ่าน",
-    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
-    "Weak password" : "รหัสผ่านระดับต่ำ",
-    "So-so password" : "รหัสผ่านระดับปกติ",
-    "Good password" : "รหัสผ่านระดับดี",
-    "Strong password" : "รหัสผ่านระดับดีมาก",
-    "Groups" : "กลุ่ม",
-    "Group list is empty" : "รายชื่อกลุ่มว่างอยู่",
-    "Unable to retrieve the group list" : "ไม่สามารถดึงรายชื่อกลุ่ม",
     "{actor} added you to group {group}" : "{actor} เพิ่มคุณไปยังกลุ่ม {group}",
     "You added {user} to group {group}" : "คุณเพิ่ม {user} ไปยังกลุ่ม {group}",
     "{actor} added {user} to group {group}" : "{actor} เพิ่ม {user} ไปยังกลุ่ม {group}",
@@ -34,6 +25,7 @@ OC.L10N.register(
     "Settings" : "การตั้งค่า",
     "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
     "Saved" : "บันทึกแล้ว",
+    "Unable to change password" : "ไม่สามารถเปลี่ยนรหัสผ่าน",
     "Authentication error" : "เกิดข้อผิดพลาดในการตรวจสอบสิทธิ์",
     "Wrong admin recovery password. Please check the password and try again." : "รหัสผ่านกู้คืนของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง",
     "Administrator documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
@@ -94,6 +86,7 @@ OC.L10N.register(
     "Results from other categories" : "ผลลัพธ์จากหมวดหมู่อื่น ๆ",
     "No apps found for your version" : "ไม่พบแอปสำหรับรุ่นของคุณ",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n แอปมีอัปเดตใหม่"],
+    "Groups" : "กลุ่ม",
     "Group name" : "ชื่อกลุ่ม",
     "Loading" : "กำลังโหลด",
     "Type" : "ประเภท",
@@ -202,14 +195,24 @@ OC.L10N.register(
     "No devices configured." : "ไม่มีอุปกรณ์ที่กำหนดค่า",
     "The following devices are configured for your account:" : "อุปกรณ์เหล่านี้มีการกำหนดค่าสำหรับบัญชีของคุณแล้ว:",
     "Your browser does not support WebAuthn." : "เบราว์เซอร์ของคุณไม่รองรับ WebAuthn",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "การตั้งค่าให้เซิร์ฟเวอร์นี้ส่งอีเมลได้ เช่น อีเมลสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน เป็นสิ่งสำคัญ",
+    "Send mode" : "โหมดการส่ง",
+    "Encryption" : "การเข้ารหัส",
+    "Sendmail mode" : "โหมดส่งอีเมล",
+    "Disable certificate verification (insecure)" : "ปิดใช้งานการตรวจสอบใบรับรอง (ไม่ปลอดภัย)",
+    "From address" : "จากที่อยู่",
+    "Domain" : "โดเมน",
+    "Server address" : "ที่อยู่เซิร์ฟเวอร์",
+    "Host" : "โฮสต์",
+    "Port" : "พอร์ต",
+    "Authentication" : "การตรวจสอบสิทธิ์",
+    "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
     "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
     "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
     "There are some errors regarding your setup." : "มีข้อผิดพลาดบางอย่างเกี่ยวกับการติดตั้งของคุณ",
     "There are some warnings regarding your setup." : "มีคำเตือนบางอย่างเกี่ยวกับการติดตั้งของคุณ",
     "Apply" : "นำไปใช้",
     "Admins" : "ผู้ดูแลระบบ",
-    "Sending…" : "กำลังส่ง....",
-    "Email sent" : "ส่งอีเมลแล้ว",
     "Location" : "ตำแหน่ง",
     "Profile picture" : "รูปภาพโปรไฟล์",
     "About" : "เกี่ยวกับ",
@@ -246,27 +249,27 @@ OC.L10N.register(
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
     "Error" : "ข้อผิดพลาด",
     "Forum" : "ฟอรัม",
-    "SSL" : "SSL",
-    "Open documentation" : "เปิดเอกสารประกอบ",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "การตั้งค่าให้เซิร์ฟเวอร์นี้ส่งอีเมลได้ เช่น อีเมลสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน เป็นสิ่งสำคัญ",
-    "Send mode" : "โหมดการส่ง",
-    "Encryption" : "การเข้ารหัส",
-    "Sendmail mode" : "โหมดส่งอีเมล",
-    "From address" : "จากที่อยู่",
-    "Server address" : "ที่อยู่เซิร์ฟเวอร์",
-    "Port" : "พอร์ต",
-    "Authentication" : "การตรวจสอบสิทธิ์",
-    "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
-    "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
-    "SMTP Password" : "รหัสผ่าน SMTP",
-    "Save" : "บันทึก",
     "Reasons to use Nextcloud in your organization" : "เหตุผลที่ควรใช้ Nextcloud ในองค์กรของคุณ",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "รุ่นที่ออกโดยชุมชนของ Nextcloud นี้ไม่ได้รับการสนับสนุน และไม่สามารถใช้งานการแจ้งเตือนทันทีได้",
+    "Open documentation" : "เปิดเอกสารประกอบ",
+    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
+    "Weak password" : "รหัสผ่านระดับต่ำ",
+    "So-so password" : "รหัสผ่านระดับปกติ",
+    "Good password" : "รหัสผ่านระดับดี",
+    "Strong password" : "รหัสผ่านระดับดีมาก",
+    "Group list is empty" : "รายชื่อกลุ่มว่างอยู่",
+    "Unable to retrieve the group list" : "ไม่สามารถดึงรายชื่อกลุ่ม",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
     "Adding your device …" : "กำลังเพิ่มอุปกรณ์ …",
+    "Sending…" : "กำลังส่ง....",
+    "Email sent" : "ส่งอีเมลแล้ว",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "แอปนี้ยังไม่ถูกระบุว่ารองรับกับรุ่น Nextcloud ของคุณ หากคุณดำเนินการต่อ คุณจะสามารถติดตั้งแอปได้ แต่แอปอาจไม่ทำงานอย่างที่คาดหวังไว้",
+    "SSL" : "SSL",
+    "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
+    "SMTP Password" : "รหัสผ่าน SMTP",
+    "Save" : "บันทึก",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
     "Checking for system and security issues." : "กำลังตรวจสอบปัญหาระบบและความปลอดภัย",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "โปรดตรวจสอบ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">คู่มือการติดตั้ง ↗</a>ซ้ำ และตรวจสอบข้อผิดพลาดหรือคำเตือนใน<a href=\"%2$s\">บันทึก</a>",
