@@ -80,7 +80,7 @@ OC.L10N.register(
     "Search tag" : "Otsi silti",
     "Change tag color" : "Muuda sildi värvi",
     "Create new tag" : "Loo uus silt",
-    "Choose tags for the selected files" : "Määta sildid valitud failidele",
+    "Choose tags for the selected files" : "Määra sildid valitud failidele",
     "Cancel" : "Tühista",
     "Apply" : "Rakenda",
     "Failed to load selected tags" : "Valitud siltide laadimine ei õnnestu",
@@ -97,6 +97,7 @@ OC.L10N.register(
     "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Kui see eelistus on sisse lülitatud, siis vaid peakasutajad saavad luua ja muuta süsteemiüleseid silte. Kõik kasutajad saavad neid failidele lisada või sealt eemaldada.",
     "Restrict tag creation and editing to administrators" : "Luba vaid peakasutajatel luua süsteemiüleseid silte",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Ühistegevuslikud sildid on saadaval kõikide kasutajate jaoks. Piiratud sildid on kasutajatele nähtavad, kuid nad ei saa neid silte määrata. Nähtamatud sildid on sisemiseks kasutuseks ja kasutajad neid ei näe ega saa neid määrata.",
+    "Add tags" : "Lisa silte",
     "Assigned collaborative tags" : "Eelkirjeldatud ühistegevuslikud sildid",
     "Open in Files" : "Ava failirakenduses",
     "List of tags and their associated files and folders." : "Siltude ja nendega seotud failide ja kaustade loend.",
