@@ -50,6 +50,7 @@ OC.L10N.register(
     "Update" : "Update",
     "Delete" : "Verwijder",
     "Reset" : "Herstellen",
+    "Loading …" : "Aan het laden...",
     "Manage tags" : "Berichttags",
     "Search or create tag" : "Zoek of maak een tag",
     "Search tag" : "Zoek tag",
@@ -60,6 +61,7 @@ OC.L10N.register(
     "Failed to load tags" : "Kon tags niet laden",
     "Search or create collaborative tags" : "Zoek of maak een samenwerkingstags",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
+    "Add tags" : "Toevoegen tags",
     "Assigned collaborative tags" : "Samenwerkingstags toewijzen",
     "Open in Files" : "Open in Bestanden",
     "No tags found" : "Geen tags gevonden",
