@@ -22,15 +22,6 @@ OC.L10N.register(
     "Text" : "文本 ",
     "📝 Collaborative document editing" : "文档协作编辑",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
-    "Insert result" : "插入结果",
-    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
-    "Could not copy result to clipboard" : "无法复制结果至剪切板",
-    "Nextcloud Assistant" : "Nextcloud助手",
-    "Translate" : "翻译",
-    "Show assistant results" : "显示助手结果",
-    "Assistant results" : "助手结果",
-    "Show result" : "显示结果",
-    "Delete task" : "删除任务",
     "Overwrite the file and save the current changes" : "覆盖文件并保存当前更改",
     "Discard the current changes and load the latest version" : "放弃当前更改并加载最新版本",
     "Reload" : "重载",
@@ -39,26 +30,32 @@ OC.L10N.register(
     "Reconnect" : "重新连接",
     "You've been disconnected from the server." : "您已与服务器断开连接。",
     "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
-    "Close outline view" : "关闭大纲视图",
-    "Outline" : "大纲",
+    "Insert below" : "下方插入",
+    "Click for options, hold to drag" : "点击以查看选项，按住可拖动",
+    "Not connected. Cannot update guest name." : "未连接。无法更新访客名称。",
+    "Failed to update the guest name." : "无法更新访客名称。",
     "Enter your name so other people can see who is editing" : "输入你的名称来让其他用户可以看到是谁在编辑。",
-    "Edit guest name" : "编辑访客姓名",
+    "Enter your name" : "输入名称",
     "Guest" : "访客",
-    "Save guest name" : "保存访客姓名",
+    "submit" : "提交",
+    "you" : "您",
+    "edit" : "编辑",
     "Uploading multiple attachments failed." : "上传多个附件失败。",
     "Uploading attachment failed: {error}" : "上传附件失败：{error}",
     "Uploading attachment failed." : "上传附件失败。",
     "Insert an attachment" : "插入附件",
     "Failed to insert from Files" : "无法从文件插入",
+    "Failed to create attachment" : "无法创建附件",
+    "Offline since {time}." : "自 {time} 起离线。",
+    "Not connected to the cloud." : "未连接到云端。",
     "Preview options" : "预览选项",
     "Text only" : "仅文字",
     "Show link preview" : "显示链接预览",
     "Open in new tab" : "在新标签页中打开",
+    "Copy link" : "复制链接",
     "Remove link" : "删除链接",
     "Active people" : "活动用户",
     "guest" : "访客",
-    "Full width editor" : "全宽编辑器",
-    "Open the Smart Picker" : "打开智能选择器",
     "Offline" : "离线",
     "Offline, changes will be saved when online" : "离线，更改将会在上线后保存",
     "Saving …" : "保存中 …",
@@ -68,6 +65,9 @@ OC.L10N.register(
     "Unsaved changes" : "未保存的更改",
     "Save document" : "保存文档",
     "Last saved" : "最近保存",
+    "Close table of contents" : "关闭目录",
+    "Pin table of contents" : "固定目录",
+    "Table of contents" : "目录",
     "Formatting and shortcuts" : "排版和捷径",
     "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
@@ -115,23 +115,40 @@ OC.L10N.register(
     "Redo" : "重做",
     "Toggle outline" : "切换大纲",
     "Alt" : "Alt",
-    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
-    "Copy link to clipboard" : "复制链接到剪贴板",
+    "Open link" : "打开链接",
     "Edit link" : "编辑链接",
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Edit block formula" : "编辑块公式",
+    "Edit inline formula" : "编辑行内公式",
+    "LaTeX formula" : "LaTeX 公式",
+    "Save" : "保存",
+    "Disabled because you are currently offline." : "已禁用，因为您当前已离线。",
+    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "无法创建或上传附件，因为此文件是从另一个云共享的。",
     "Upload from computer" : "从电脑上传",
     "Insert from Files" : "从文件插入",
     "Formatting help" : "排版帮助",
     "Link to file or folder" : "链接至文件或文件夹",
     "Link to website" : "链接至网站",
     "Update link" : "更新链接",
+    "Open the Smart Picker" : "打开智能选择器",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
+    "Insert result" : "插入结果",
+    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
+    "Could not copy result to clipboard" : "无法复制结果至剪切板",
+    "Translate" : "翻译",
+    "Show assistant results" : "显示助手结果",
+    "Assistant results" : "助手结果",
+    "Nextcloud Assistant" : "Nextcloud助手",
+    "Show result" : "显示结果",
+    "Delete task" : "删除任务",
     "_%n word_::_%n words_" : ["%n 字"],
     "_%n char_::_%n chars_" : ["%n 字符"],
     "Remaining actions" : "重命名操作",
     "Editor actions" : "编辑器操作",
     "Formatting menu bar" : "格式化菜单栏",
+    "Full width editor" : "全宽编辑器",
     "Translate from {language}" : "翻译自 {language}",
     "Translate to {language}" : "翻译至 {language}",
     "Translation failed" : "翻译失败",
@@ -144,14 +161,15 @@ OC.L10N.register(
     "Translated text result" : "文字翻译结果",
     "Replace" : "替换",
     "Insert" : "插入",
+    "Edit" : "编辑",
     "No emoji found" : "找不到任何表情",
     "No command found" : "找不到任何命令",
     "No user found" : "找不到任何用户",
     "No suggestion found" : "找不到任何建议",
+    "Uploading attachments is disabled because the file is shared from another cloud." : "上传附件被禁用，因为该文件是从另一个云共享的。",
     "Upload" : "上传",
     "Insert Table" : "插入表格",
     "Smart Picker" : "智能选择器",
-    "Edit" : "编辑",
     "Copy code block" : "复制代码块",
     "Copy code" : "复制代码",
     "Code block options" : "代码块设置",
@@ -190,6 +208,8 @@ OC.L10N.register(
     "Increase indentation" : "增加缩进",
     "Decrease indentation" : "减少缩进",
     "Blocks" : "区块",
+    "Inline math" : "行内数学",
+    "Block math" : "块数学",
     "Info callout" : "信息标注",
     "Success callout" : "成功标注",
     "Warning callout" : "警告标注",
@@ -202,30 +222,23 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "选项",
     "Formatting" : "格式",
+    "Start writing or type '/' to add…" : "开始撰写或输入“/”以添加…",
     "Select file or folder to link to" : "选择需要链接的文件或文件夹",
+    "Choose" : "选择",
+    "Choose {file}" : "选择 {file}",
     "Add folder description" : "添加文件夹描述",
     "\"{name}\" already exist!" : "\"{name}\" 已存在！",
     "Created \"{name}\"" : "创建 \"{name}\"",
     "Copied to the clipboard" : "已复制到剪切板",
     "Could not copy to the clipboard" : "无法复制到剪切板",
     "Front matter" : "前言",
+    "A table was pasted into a table. Nested tables are not supported." : "表格被粘贴进另一个表格中，不支持嵌套表格。",
     "Link to this section" : "链接至本节",
-    "Use current version" : "使用当前版本",
-    "Use the saved version" : "使用保存的版本",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
-    "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
-    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
-    "Show author colors" : "显示作者颜色",
-    "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
-    "Connection failed." : "连接失败。",
-    "Detect language" : "检测语言",
-    "Callouts" : "标注",
-    "Info" : "信息",
-    "Success" : "成功",
-    "Warning" : "警告",
-    "Danger" : "重要",
-    "Control" : "控制",
-    "Add notes, lists or links …" : "添加笔记、列表或链接...",
-    "Start writing, or try '/' to add, '@' to mention…" : "开始写作，或尝试用 “/” 添加，用 “@” 提及…"
+    "Close outline view" : "关闭大纲视图",
+    "Outline" : "大纲",
+    "Edit guest name" : "编辑访客姓名",
+    "Save guest name" : "保存访客姓名",
+    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
+    "Copy link to clipboard" : "复制链接到剪贴板"
 },
 "nplurals=1; plural=0;");
