@@ -10,11 +10,10 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "بېرىلگەن مەخپىيەتلىك سىياسىتى ئادرېسى ئىناۋەتلىك URL ئەمەس",
     "The given slogan is too long" : "بېرىلگەن شۇئار بەك ئۇزۇن",
     "The given color is invalid" : "بېرىلگەن رەڭ ئىناۋەتسىز",
-    "Disable-user-theming should be true or false" : "چەكلەش-ئىشلەتكۈچى باش تېمىسى راست ياكى يالغان بولۇشى كېرەك",
+    "Invalid setting key" : "تەڭشەش كۇنۇپكىسى ئىناۋەتسىز",
     "Saved" : "ساقلاندى",
     "Invalid app given" : "ئىناۋەتسىز ئەپ بېرىلگەن",
     "Invalid type for setting \"defaultApp\" given" : "بېرىلگەن \"defaultApp\" نى تەڭشەشنىڭ ئىناۋەتسىز تىپى",
-    "Invalid setting key" : "تەڭشەش كۇنۇپكىسى ئىناۋەتسىز",
     "The file was uploaded" : "ھۆججەت يۈكلەندى",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "يۈكلەنگەن ھۆججەت php.ini دىكى upload_max_filesize كۆرسەتمىسىدىن ئېشىپ كەتتى",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "يۈكلەنگەن ھۆججەت HTML شەكلىدە كۆرسىتىلگەن MAX_FILE_SIZE كۆرسەتمىسىدىن ئېشىپ كەتتى",
@@ -51,63 +50,8 @@ OC.L10N.register(
     "Legal notice" : "قانۇن ئۇقتۇرۇشى",
     "Privacy policy" : "مەخپىيەتلىك تۈزۈمى",
     "Adjust the Nextcloud theme" : "Nextcloud تېمىسىنى تەڭشەڭ",
-    "Name" : "ئاتى",
-    "Web link" : "تور ئۇلىنىشى",
-    "a safe home for all your data" : "بارلىق سانلىق مەلۇماتلىرىڭىز ئۈچۈن بىخەتەر ئۆي",
-    "Slogan" : "شۇئار",
-    "Primary color" : "دەسلەپكى رەڭ",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "دەسلەپكى رەڭ مۇھىم كۇنۇپكىلارغا ئوخشاش ئېلېمېنتلارنى گەۋدىلەندۈرۈشكە ئىشلىتىلىدۇ. ئۇ ھازىرقى رەڭ لايىھىسىگە ئاساسەن ئازراق تەڭشىلىشى مۇمكىن.",
-    "Legal notice link" : "قانۇن ئۇقتۇرۇشى",
-    "Privacy policy link" : "مەخپىيەتلىك سىياسىتى ئۇلىنىشى",
-    "Header logo" : "بەت بەلگىسى",
-    "Upload new header logo" : "يېڭى ماۋزۇ بەلگىسىنى يۈكلەڭ",
-    "Favicon" : "لوگو",
-    "Upload new favicon" : "يېڭى favicon نى يۈكلەڭ",
-    "User settings" : "ئىشلەتكۈچى تەڭشەكلىرى",
-    "Disable user theming" : "ئىشلەتكۈچى باشتېمىسىنى چەكلەڭ",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "سىز ئۈلگىڭىزنى تاللىسىڭىز ۋە خاسلاشتۇرسىڭىزمۇ ، ئابونتلار ئۇلارنىڭ ئارقا كۆرۈنۈشى ۋە رەڭگىنى ئۆزگەرتەلەيدۇ. خاسلاشتۇرۇشنى ئىجرا قىلماقچى بولسىڭىز ، ئۇنى ئاچسىڭىز بولىدۇ.",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "تېمىڭىز سىزنىڭ قوللىشىڭىز ۋە قوللىغان خېرىدارلىرىڭىزنىڭ كۆرۈنۈشى ۋە ھېسسىياتىنى ئاسانلا خاسلاشتۇرالايدۇ. بۇ بارلىق ئىشلەتكۈچىلەر ئۈچۈن كۆرۈنىدۇ.",
-    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "تەگلىك رەسىمنىڭ ئورنىغا ئاددىي تەگلىك رەڭگىمۇ تەڭشىيەلەيسىز. تەگلىك سۈرىتىنى ئىشلەتسىڭىز بۇ رەڭنى ئۆزگەرتسىڭىز ئەپ تىزىملىكى سىنبەلگىسىنىڭ رەڭگىگە تەسىر كۆرسىتىدۇ.",
-    "Background color" : "تەگلىك رەڭگى",
-    "Upload new logo" : "يېڭى بەلگە يۈكلەڭ",
-    "Logo" : "لوگو",
-    "Upload new background and login image" : "يېڭى تەگلىك ۋە كىرىش سۈرىتىنى يۈكلەڭ",
-    "Background and login image" : "تەگلىك ۋە كىرىش سۈرىتى",
-    "Advanced options" : "ئىلغار تاللاشلار",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "يۈكلەنگەن لوگو ۋە رەڭگە ئاساسەن SVG رەسىملىرىنى قوللاپ ImageMagick PHP كېڭەيتىلمىسىنى قاچىلاڭ.",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "بىز ئۈچۈن ئومۇميۈزلۈك كىرىش ناھايىتى مۇھىم. بىز تور ئۆلچىمىگە ئەمەل قىلىمىز ۋە ھەممە نەرسىنى ماۋۇسسىز ۋە ئېكران ئوقۇغۇچ قاتارلىق ياردەمچى يۇمشاق دېتاللارسىز ئىشلىتىشكە بولىدىغان قىلىپ تەكشۈرىمىز. بىز AA دەرىجىسىدە {linkstart}تور مەزمۇنىغا ئېرىشىش كۆرسەتمىسى{linkend} 2.1 گە رىئايە قىلىشنى، ھەتتا AAA دەرىجىسىدىمۇ يۇقىرى كونتراستلىق تېمىغا ئەمەل قىلىشنى مەقسەت قىلىمىز.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "ئەگەر مەسىلىگە يولۇقسىڭىز ، ئىككىلەنمەستىن ئۇلارنى {issuetracker} بىزنىڭ مەسىلە ئىز قوغلاش {linkend} on غا دوكلات قىلىڭ. ئەگەر قاتناشماقچى بولسىڭىز ، {designteam} بىزنىڭ لايىھىلەش ئەترىتىمىز {linkend} join غا قوشۇلۇڭ.",
-    "Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى.",
-    "Appearance and accessibility settings" : "كۆرۈنۈش ۋە زىيارەت قىلىش تەڭشەكلىرى",
-    "Misc accessibility options" : "قولايلىق تاللاش تاللانمىلىرى",
-    "Enable blur background filter (may increase GPU load)" : "تۇتۇق تەگلىك سۈزگۈچنى قوزغىتىڭ (GPU يۈكىنى ئاشۇرۇشى مۇمكىن)",
-    "Customization has been disabled by your administrator" : "باشقۇرغۇچىڭىز تەرىپىدىن خاسلاشتۇرۇش چەكلەنگەن",
-    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "مۇھىم ئېلېمېنتلارنى گەۋدىلەندۈرۈش ئۈچۈن دەسلەپكى رەڭ بەلگىلەڭ. دەسلەپكى كۇنۇپكىلار قاتارلىق ئېلېمېنتلارغا ئىشلىتىلىدىغان رەڭ قولايلىق بولۇش تەلىپىنى قاندۇرۇش ئۈچۈن تەڭشەلگەندە ئازراق پەرقلىنىشى مۇمكىن.",
-    "Background and color" : "تەگلىك ۋە رەڭ",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "تەگلىك سۈكۈتتىكى سۈكۈتتىكى رەسىم ، ئىختىيارى يۈكلەنگەن رەسىم ياكى ئوچۇق رەڭگە تەڭشىلىدۇ.",
-    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "بەزى ئەھۋاللاردا كۇنۇپكا تاختىسىنىڭ تېزلەتمىلىرى قولايلىق قوراللارغا دەخلى قىلىدۇ. قورالىڭىزغا توغرا دىققەت قىلىش ئۈچۈن ، بۇ يەردىكى بارلىق كۇنۇپكا تاختىسىنى چەكلىيەلەيسىز. بۇ يەنە ئەپلەردىكى بارلىق تېزلەتمىلەرنى چەكلەيدۇ.",
-    "Disable all keyboard shortcuts" : "بارلىق كۇنۇپكا تاختىسىنى چەكلەڭ",
-    "Current selected app: {app}, position {position} of {total}" : "نۆۋەتتىكى تاللانغان ئەپ: {app} ، ئورنى {position} {total}",
-    "Move up" : "يۆتكەڭ",
-    "Move down" : "تۆۋەنگە يۆتكەڭ",
-    "Select a background from your files" : "ھۆججەتلىرىڭىزدىن تەگلىك تاللاڭ",
-    "Select background" : "تەگلىكنى تاللاڭ",
-    "No background has been selected" : "تەگلىك تاللانمىدى",
-    "Custom background" : "ئىختىيارى تەگلىك",
-    "Plain background" : "تۈزلەڭلىك تەگلىكى",
-    "Default background" : "سۈكۈتتىكى تەگلىك",
-    "Theme selection is enforced" : "باشتېما تاللاش ئىجرا قىلىنىدۇ",
-    "Could not set the app order" : "ئەپ تەرتىپىنى تەڭشىيەلمىدى",
-    "Could not reset the app order" : "ئەپ تەرتىپىنى ئەسلىگە كەلتۈرەلمىدى",
-    "Navigation bar settings" : "يولباشچى تاياقچە تەڭشىكى",
-    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "يولباشچى ستونىغا ئىشلىتىلىدىغان ئەپ تەرتىپىنى تەڭشىيەلەيسىز. بىرىنچى تۈر سۈكۈتتىكى ئەپ بولۇپ ، كىرگەندىن كېيىن ياكى بەلگىنى چەككەندە ئېچىلىدۇ.",
-    "The default app can not be changed because it was configured by the administrator." : "سۈكۈتتىكى ئەپنى باشقۇرغۇچى تەڭشىگەنلىكى ئۈچۈن ئۆزگەرتكىلى بولمايدۇ.",
-    "The app order was changed, to see it in action you have to reload the page." : "ئەپ تەرتىپى ئۆزگەرتىلدى ، ئۇنى ھەرىكەتتە كۆرۈش ئۈچۈن بەتنى قايتا يۈكلىشىڭىز كېرەك.",
-    "Reset default app order" : "كۆڭۈلدىكى ئەپ تەرتىپىنى ئەسلىگە كەلتۈرۈڭ",
-    "Could not set primary color" : "دەسلەپكى رەڭنى تەڭشىگىلى بولمىدى",
-    "Reset primary color" : "دەسلەپكى رەڭنى ئەسلىگە كەلتۈرۈڭ",
     "Could not set global default apps" : "يەرشارى سۈكۈتتىكى ئەپلەرنى تەڭشىيەلمىدى",
+    "Navigation bar settings" : "يولباشچى تاياقچە تەڭشىكى",
     "Default app" : "كۆڭۈلدىكى ئەپ",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "سۈكۈتتىكى ئەپ بولسا ئەپ. كىرگەندىن كېيىن ياكى تىزىملىكتىكى بەلگە چەككەندە ئېچىلدى.",
     "Use custom default app" : "ئىختىيارى كۆڭۈلدىكى ئەپنى ئىشلىتىڭ",
@@ -115,11 +59,68 @@ OC.L10N.register(
     "Global default apps" : "يەرشارىدىكى سۈكۈتتىكى ئەپلەر",
     "Default app priority" : "كۆڭۈلدىكى ئەپ ئەۋزەللىكى",
     "If an app is not enabled for a user, the next app with lower priority is used." : "ئەگەر بىر ئىشلەتكۈچى ئۈچۈن بىر ئەپ قوزغىتىلمىغان بولسا ، تۆۋەن ئورۇنغا قويۇلغان كېيىنكى ئەپ ئىشلىتىلىدۇ.",
-    "Select a custom color" : "ئىختىيارى رەڭنى تاللاڭ",
-    "Reset to default" : "سۈكۈتتىكى ھالىتىگە قايتىڭ",
-    "Upload" : "يۈكلە",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "تېمىڭىز سىزنىڭ قوللىشىڭىز ۋە قوللىغان خېرىدارلىرىڭىزنىڭ كۆرۈنۈشى ۋە ھېسسىياتىنى ئاسانلا خاسلاشتۇرالايدۇ. بۇ بارلىق ئىشلەتكۈچىلەر ئۈچۈن كۆرۈنىدۇ.",
+    "Name" : "ئاتى",
+    "Web link" : "تور ئۇلىنىشى",
+    "Slogan" : "شۇئار",
+    "a safe home for all your data" : "بارلىق سانلىق مەلۇماتلىرىڭىز ئۈچۈن بىخەتەر ئۆي",
+    "Legal notice link" : "قانۇن ئۇقتۇرۇشى",
+    "Privacy policy link" : "مەخپىيەتلىك سىياسىتى ئۇلىنىشى",
+    "Background and color" : "تەگلىك ۋە رەڭ",
+    "Primary color" : "دەسلەپكى رەڭ",
+    "Background color" : "تەگلىك رەڭگى",
     "Remove background image" : "تەگلىك سۈرىتىنى ئۆچۈرۈڭ",
+    "Background image" : "ئارقا كۆرۈنۈش رەسىمى",
+    "Favicon" : "لوگو",
+    "Logo" : "لوگو",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "سىز ئۈلگىڭىزنى تاللىسىڭىز ۋە خاسلاشتۇرسىڭىزمۇ ، ئابونتلار ئۇلارنىڭ ئارقا كۆرۈنۈشى ۋە رەڭگىنى ئۆزگەرتەلەيدۇ. خاسلاشتۇرۇشنى ئىجرا قىلماقچى بولسىڭىز ، ئۇنى ئاچسىڭىز بولىدۇ.",
+    "Disable user theming" : "ئىشلەتكۈچى باشتېمىسىنى چەكلەڭ",
+    "Current selected app: {app}, position {position} of {total}" : "نۆۋەتتىكى تاللانغان ئەپ: {app} ، ئورنى {position} {total}",
+    "Move up" : "يۆتكەڭ",
+    "Move down" : "تۆۋەنگە يۆتكەڭ",
+    "Theme selection is enforced" : "باشتېما تاللاش ئىجرا قىلىنىدۇ",
+    "Could not set the app order" : "ئەپ تەرتىپىنى تەڭشىيەلمىدى",
+    "Could not reset the app order" : "ئەپ تەرتىپىنى ئەسلىگە كەلتۈرەلمىدى",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "يولباشچى ستونىغا ئىشلىتىلىدىغان ئەپ تەرتىپىنى تەڭشىيەلەيسىز. بىرىنچى تۈر سۈكۈتتىكى ئەپ بولۇپ ، كىرگەندىن كېيىن ياكى بەلگىنى چەككەندە ئېچىلىدۇ.",
+    "The default app can not be changed because it was configured by the administrator." : "سۈكۈتتىكى ئەپنى باشقۇرغۇچى تەڭشىگەنلىكى ئۈچۈن ئۆزگەرتكىلى بولمايدۇ.",
+    "The app order was changed, to see it in action you have to reload the page." : "ئەپ تەرتىپى ئۆزگەرتىلدى ، ئۇنى ھەرىكەتتە كۆرۈش ئۈچۈن بەتنى قايتا يۈكلىشىڭىز كېرەك.",
+    "Reset default app order" : "كۆڭۈلدىكى ئەپ تەرتىپىنى ئەسلىگە كەلتۈرۈڭ",
+    "Select a background from your files" : "ھۆججەتلىرىڭىزدىن تەگلىك تاللاڭ",
+    "Select background" : "تەگلىكنى تاللاڭ",
+    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "تەگلىك سۈكۈتتىكى سۈكۈتتىكى رەسىم ، ئىختىيارى يۈكلەنگەن رەسىم ياكى ئوچۇق رەڭگە تەڭشىلىدۇ.",
+    "Custom background" : "ئىختىيارى تەگلىك",
+    "Plain background" : "تۈزلەڭلىك تەگلىكى",
+    "Default background" : "سۈكۈتتىكى تەگلىك",
+    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "بەزى ئەھۋاللاردا كۇنۇپكا تاختىسىنىڭ تېزلەتمىلىرى قولايلىق قوراللارغا دەخلى قىلىدۇ. قورالىڭىزغا توغرا دىققەت قىلىش ئۈچۈن ، بۇ يەردىكى بارلىق كۇنۇپكا تاختىسىنى چەكلىيەلەيسىز. بۇ يەنە ئەپلەردىكى بارلىق تېزلەتمىلەرنى چەكلەيدۇ.",
+    "Disable all keyboard shortcuts" : "بارلىق كۇنۇپكا تاختىسىنى چەكلەڭ",
+    "Could not set primary color" : "دەسلەپكى رەڭنى تەڭشىگىلى بولمىدى",
+    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "مۇھىم ئېلېمېنتلارنى گەۋدىلەندۈرۈش ئۈچۈن دەسلەپكى رەڭ بەلگىلەڭ. دەسلەپكى كۇنۇپكىلار قاتارلىق ئېلېمېنتلارغا ئىشلىتىلىدىغان رەڭ قولايلىق بولۇش تەلىپىنى قاندۇرۇش ئۈچۈن تەڭشەلگەندە ئازراق پەرقلىنىشى مۇمكىن.",
+    "Reset primary color" : "دەسلەپكى رەڭنى ئەسلىگە كەلتۈرۈڭ",
+    "Reset to default" : "سۈكۈتتىكى ھالىتىگە قايتىڭ",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "بىز ئۈچۈن ئومۇميۈزلۈك كىرىش ناھايىتى مۇھىم. بىز تور ئۆلچىمىگە ئەمەل قىلىمىز ۋە ھەممە نەرسىنى ماۋۇسسىز ۋە ئېكران ئوقۇغۇچ قاتارلىق ياردەمچى يۇمشاق دېتاللارسىز ئىشلىتىشكە بولىدىغان قىلىپ تەكشۈرىمىز. بىز AA دەرىجىسىدە {linkstart}تور مەزمۇنىغا ئېرىشىش كۆرسەتمىسى{linkend} 2.1 گە رىئايە قىلىشنى، ھەتتا AAA دەرىجىسىدىمۇ يۇقىرى كونتراستلىق تېمىغا ئەمەل قىلىشنى مەقسەت قىلىمىز.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "ئەگەر مەسىلىگە يولۇقسىڭىز ، ئىككىلەنمەستىن ئۇلارنى {issuetracker} بىزنىڭ مەسىلە ئىز قوغلاش {linkend} on غا دوكلات قىلىڭ. ئەگەر قاتناشماقچى بولسىڭىز ، {designteam} بىزنىڭ لايىھىلەش ئەترىتىمىز {linkend} join غا قوشۇلۇڭ.",
+    "Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى.",
+    "Appearance and accessibility settings" : "كۆرۈنۈش ۋە زىيارەت قىلىش تەڭشەكلىرى",
+    "Misc accessibility options" : "قولايلىق تاللاش تاللانمىلىرى",
+    "Enable blur background filter (may increase GPU load)" : "تۇتۇق تەگلىك سۈزگۈچنى قوزغىتىڭ (GPU يۈكىنى ئاشۇرۇشى مۇمكىن)",
+    "Customization has been disabled by your administrator" : "باشقۇرغۇچىڭىز تەرىپىدىن خاسلاشتۇرۇش چەكلەنگەن",
+    "Disable-user-theming should be true or false" : "چەكلەش-ئىشلەتكۈچى باش تېمىسى راست ياكى يالغان بولۇشى كېرەك",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "دەسلەپكى رەڭ مۇھىم كۇنۇپكىلارغا ئوخشاش ئېلېمېنتلارنى گەۋدىلەندۈرۈشكە ئىشلىتىلىدۇ. ئۇ ھازىرقى رەڭ لايىھىسىگە ئاساسەن ئازراق تەڭشىلىشى مۇمكىن.",
+    "Header logo" : "بەت بەلگىسى",
+    "Upload new header logo" : "يېڭى ماۋزۇ بەلگىسىنى يۈكلەڭ",
+    "Upload new favicon" : "يېڭى favicon نى يۈكلەڭ",
+    "User settings" : "ئىشلەتكۈچى تەڭشەكلىرى",
+    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "تەگلىك رەسىمنىڭ ئورنىغا ئاددىي تەگلىك رەڭگىمۇ تەڭشىيەلەيسىز. تەگلىك سۈرىتىنى ئىشلەتسىڭىز بۇ رەڭنى ئۆزگەرتسىڭىز ئەپ تىزىملىكى سىنبەلگىسىنىڭ رەڭگىگە تەسىر كۆرسىتىدۇ.",
+    "Upload new logo" : "يېڭى بەلگە يۈكلەڭ",
+    "Upload new background and login image" : "يېڭى تەگلىك ۋە كىرىش سۈرىتىنى يۈكلەڭ",
+    "Background and login image" : "تەگلىك ۋە كىرىش سۈرىتى",
+    "Advanced options" : "ئىلغار تاللاشلار",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "يۈكلەنگەن لوگو ۋە رەڭگە ئاساسەن SVG رەسىملىرىنى قوللاپ ImageMagick PHP كېڭەيتىلمىسىنى قاچىلاڭ.",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ھەممىباب زىيارەت قىلىش بىز ئۈچۈن ئىنتايىن مۇھىم. بىز تور ئۆلچىمىگە ئەمەل قىلىپ ، مائۇسسىز ۋە ئېكران ئوقۇغۇچ قاتارلىق ياردەمچى يۇمشاق دېتاللارنىڭ ھەممىسىنى ئىشلىتىشكە بولىدىغانلىقىنى تەكشۈرۈپ تۇرىمىز. بىز AA سەۋىيىسىدىكى {guidelines} تور مەزمۇنىنىڭ زىيارەت قىلىش قوللانمىسى {linkend} 2.1 گە ماسلىشىشنى مەقسەت قىلىمىز ، يۇقىرى سېلىشتۇرما تېمىسى ھەتتا AAA سەۋىيىسىدە.",
-    ". Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى."
+    ". Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى.",
+    "No background has been selected" : "تەگلىك تاللانمىدى",
+    "Select a custom color" : "ئىختىيارى رەڭنى تاللاڭ",
+    "Upload" : "يۈكلە"
 },
 "nplurals=2; plural=(n != 1);");
