@@ -10,11 +10,12 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "Зазначена адреса з інформацією про конфіденційність не є правильним посиланням",
     "The given slogan is too long" : "Зазначене гасло є задовгим",
     "The given color is invalid" : "Зазначений колір є неправильним",
-    "Disable-user-theming should be true or false" : "Вимкнення можливості користувачів змінювати оформлення має мати значення так або ні",
+    "%1$s should be true or false" : "%1$s має бути правда або неправда",
+    "%1$s can only be set to %2$s through the API" : "%1$s може бути встановлене значення у %2$s через API",
+    "Invalid setting key" : "Неправильний ключ налаштувань",
     "Saved" : "Збережено",
     "Invalid app given" : "Зазначено неправильний застосунок",
     "Invalid type for setting \"defaultApp\" given" : "Зазначено неправильний тип у налаштуваннях \"defaultApp\"",
-    "Invalid setting key" : "Неправильний ключ налаштувань",
     "The file was uploaded" : "Файл завантажено",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
@@ -51,63 +52,8 @@ OC.L10N.register(
     "Legal notice" : "Правові застереження",
     "Privacy policy" : "Політика конфіденційності",
     "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
-    "Name" : "Ім’я",
-    "Web link" : "Посилання",
-    "a safe home for all your data" : "безпечна домівка для ваших даних",
-    "Slogan" : "Гасло",
-    "Primary color" : "Основний колір",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Основний колір використовується для підсвічування елементів, напр., важливих кнопок. Цей колір підлаштовується під вибрану схему кольорів.",
-    "Legal notice link" : "Посилання на правову інформацію",
-    "Privacy policy link" : "Посилання на політику конфіденційності",
-    "Header logo" : "Логотип заголовка",
-    "Upload new header logo" : "Завантажити новий логотип заголовка",
-    "Favicon" : "Значок сайту",
-    "Upload new favicon" : "Завантажити новий значок",
-    "User settings" : "Налаштування користувача",
-    "Disable user theming" : "Вимкнути можливість користувачів змінювати оформлення",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "На додаток до встановлення оформлення вашої хмари користувачі також можуть змінювати тло та кольорову гаму. Тут ви можете встановити оформлення однаковим для всіх користувачів.",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
-    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Замість зображень тла ви можете вибрати просту заливку кольором. Якщо ви використовуватимете зображення, то зміна кольору автоматично вплине на колір значків застосунків у меню.",
-    "Background color" : "Колір тла",
-    "Upload new logo" : "Завантажити новий логотип",
-    "Logo" : "Логотип",
-    "Upload new background and login image" : "Завантажити нове зображення тла та логотип сторінки авторизації",
-    "Background and login image" : "Зображення тла та логотипу організації на сторінці авторизації",
-    "Advanced options" : "Розширені налаштування",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення  ImageMagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки на основі завантаженого логотипа і кольору.",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогою допоміжного програмного забезпечення, наприклад, застосунки зчитування з екрана. Ми прагнемо відповідати {linkstart}Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви виявите будь-які проблеми, не соромтеся повідомити про них на {issuetracker}нашій системі відстеження проблем{linkend}. І якщо ви хочете взяти участь, приєднуйтесь до {designteam}нашої команди дизайнерів{linkend}!",
-    "Unable to apply the setting." : "Не вдалося застосувати налаштування.",
-    "Appearance and accessibility settings" : "Налаштування оформлення та доступности",
-    "Misc accessibility options" : "Різні налаштування доступності",
-    "Enable blur background filter (may increase GPU load)" : "Увімкнути фільтр розмиття тла (матиме додаткове навантаження на GPU)",
-    "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
-    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Встановіть основний колір для підсвічування важливих елементів. Колір, який використовується для таких елементів, як основні кнопки, може частково відрізнятися, залежно від вимог доступності.",
-    "Background and color" : "Тло та колір",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Зображення тла можна вибрати з попередньо встановлених зображень, завантажити власне або використати просту заливку кольором.",
-    "Keyboard shortcuts" : "Скорочення",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У деяких випадках комбінації клавіш можуть заважати роботі з інструментами доступності. Щоб правильно зосередитися на інструменті, ви можете вимкнути всі комбінації клавіш тут. Це також вимкне всі доступні комбінації клавіш у застосунках.",
-    "Disable all keyboard shortcuts" : "Вимкнути всі комбінації клавіш",
-    "Current selected app: {app}, position {position} of {total}" : "Вибрано застосунок: {app}, позиція {position} із {total}.",
-    "Move up" : "Пересунуту догори",
-    "Move down" : "Пересунути вниз",
-    "Select a background from your files" : "Виберіть зображення тла з ваших файлів",
-    "Select background" : "Виберіть тло",
-    "No background has been selected" : "Не вибрано тло",
-    "Custom background" : "Користувацьке тло",
-    "Plain background" : "Однокольорове тло",
-    "Default background" : "Типове тло",
-    "Theme selection is enforced" : "Вибір теми виконується примусово",
-    "Could not set the app order" : "Не вдалося встановити порядок розташування застосунків",
-    "Could not reset the app order" : "Не вдалося скинути порядок розташування застосунків",
-    "Navigation bar settings" : "Налаштування панелі навігації",
-    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Ви можете налаштувати порядок розташування застосунків у панелі навігації. Першим записом має йти типовий застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
-    "The default app can not be changed because it was configured by the administrator." : "Неможливо змінити типовий застосунок, оскільки його було налаштовано адміністратором.",
-    "The app order was changed, to see it in action you have to reload the page." : "Порядок розташування застосунків змінено. Будь ласка, оновіть сторінку, щоби побачити оновлене розташування елементів.",
-    "Reset default app order" : "Скинути до попередньо визначеного порядку розташування застосунків",
-    "Could not set primary color" : "Не вдалося встановити основний колір",
-    "Reset primary color" : "Скинути налаштування основного кольору",
     "Could not set global default apps" : "Не вдалося встановити системний типовий застосунок",
+    "Navigation bar settings" : "Налаштування панелі навігації",
     "Default app" : "Типовий застосунок",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Типовий застосунок - це застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
     "Use custom default app" : "Використосувати власний типовий застосунок",
@@ -115,16 +61,78 @@ OC.L10N.register(
     "Global default apps" : "Системні типові застосунки",
     "Default app priority" : "Типовий пріоритет застосунків",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Якщо застосунок не увімкнено для певного користувача, то наступний застосунок з нижчим пріоритетом буде використано.",
-    "Select a custom color" : "Виберіть власний колір",
-    "Reset to default" : "Скинути до типового",
-    "Upload" : "Завантажити",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
+    "Name" : "Ім’я",
+    "Web link" : "Посилання",
+    "Slogan" : "Гасло",
+    "a safe home for all your data" : "безпечна домівка для ваших даних",
+    "Legal notice link" : "Посилання на правову інформацію",
+    "Privacy policy link" : "Посилання на політику конфіденційності",
+    "Background and color" : "Тло та колір",
+    "Primary color" : "Основний колір",
+    "Set the default primary color, used to highlight important elements." : "Встановити основний колір, який використовується для виділення важливих елементів.",
+    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Колір, який використовується для таких елементів, як основні кнопки, може незначно відрізнятися, оскільки узгоджуватиметься з вимогами доступности. ",
+    "Background color" : "Колір тла",
+    "When no background image is set the background color will be used." : "Якщо не встановлено зображення тла, то використовуватиметься колір тла.",
+    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "В іншому випадку колір тла визначатиметься типово на основі зображення тла, але може підлаштовуватися під колір піктограм елементів навігації.",
+    "Use a plain background color instead of a background image." : "Використовувати простий колір тла замість зображення тла.",
     "Remove background image" : "Вилучити зображення тла",
-    "Color" : "Колір",
+    "Background image" : "Фонове зображення",
+    "Favicon" : "Значок сайту",
+    "Logo" : "Логотип",
+    "Navigation bar logo" : "Логотип панелі навігації",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "На додаток до встановлення оформлення вашої хмари користувачі також можуть змінювати тло та кольорову гаму. Тут ви можете встановити оформлення однаковим для всіх користувачів.",
+    "Disable user theming" : "Вимкнути можливість користувачів змінювати оформлення",
+    "Current selected app: {app}, position {position} of {total}" : "Вибрано застосунок: {app}, позиція {position} із {total}.",
+    "Navigation bar app order" : "Порядок застосунків на панелі навігації",
+    "Move up" : "Пересунуту догори",
+    "Move down" : "Пересунути вниз",
+    "Theme selection is enforced" : "Вибір теми виконується примусово",
+    "Could not set the app order" : "Не вдалося встановити порядок розташування застосунків",
+    "Could not reset the app order" : "Не вдалося скинути порядок розташування застосунків",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Ви можете налаштувати порядок розташування застосунків у панелі навігації. Першим записом має йти типовий застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
+    "The default app can not be changed because it was configured by the administrator." : "Неможливо змінити типовий застосунок, оскільки його було налаштовано адміністратором.",
+    "The app order was changed, to see it in action you have to reload the page." : "Порядок розташування застосунків змінено. Будь ласка, оновіть сторінку, щоби побачити оновлене розташування елементів.",
+    "Reset default app order" : "Скинути до попередньо визначеного порядку розташування застосунків",
+    "Select a background from your files" : "Виберіть зображення тла з ваших файлів",
+    "Select background" : "Виберіть тло",
+    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Зображення тла можна вибрати з попередньо встановлених зображень, завантажити власне або використати просту заливку кольором.",
+    "Custom background" : "Користувацьке тло",
+    "Plain background" : "Однокольорове тло",
+    "Default background" : "Типове тло",
+    "Default shipped background images" : "Типово визначені зображення тла",
+    "Keyboard shortcuts" : "Скорочення",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У деяких випадках комбінації клавіш можуть заважати роботі з інструментами доступності. Щоб правильно зосередитися на інструменті, ви можете вимкнути всі комбінації клавіш тут. Це також вимкне всі доступні комбінації клавіш у застосунках.",
+    "Disable all keyboard shortcuts" : "Вимкнути всі комбінації клавіш",
+    "Could not set primary color" : "Не вдалося встановити основний колір",
+    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Встановіть основний колір для підсвічування важливих елементів. Колір, який використовується для таких елементів, як основні кнопки, може частково відрізнятися, залежно від вимог доступності.",
+    "Reset primary color" : "Скинути налаштування основного кольору",
+    "Reset to default" : "Скинути до типового",
+    "Non image file selected" : "Вибрано файл, який не є зображенням",
+    "Preview of the selected image" : "Попередній вигляд вибраного зображення",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогою допоміжного програмного забезпечення, наприклад, застосунки зчитування з екрана. Ми прагнемо відповідати {linkstart}Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви виявите будь-які проблеми, не соромтеся повідомити про них на {issuetracker}нашій системі відстеження проблем{linkend}. І якщо ви хочете взяти участь, приєднуйтесь до {designteam}нашої команди дизайнерів{linkend}!",
+    "Unable to apply the setting." : "Не вдалося застосувати налаштування.",
+    "Appearance and accessibility settings" : "Налаштування оформлення та доступности",
+    "Misc accessibility options" : "Різні налаштування доступності",
+    "Enable blur background filter (may increase GPU load)" : "Увімкнути фільтр розмиття тла (матиме додаткове навантаження на GPU)",
+    "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
+    "Disable-user-theming should be true or false" : "Вимкнення можливості користувачів змінювати оформлення має мати значення так або ні",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Основний колір використовується для підсвічування елементів, напр., важливих кнопок. Цей колір підлаштовується під вибрану схему кольорів.",
+    "Header logo" : "Логотип заголовка",
+    "Upload new header logo" : "Завантажити новий логотип заголовка",
+    "Upload new favicon" : "Завантажити новий значок",
+    "User settings" : "Налаштування користувача",
+    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Замість зображень тла ви можете вибрати просту заливку кольором. Якщо ви використовуватимете зображення, то зміна кольору автоматично вплине на колір значків застосунків у меню.",
+    "Upload new logo" : "Завантажити новий логотип",
+    "Upload new background and login image" : "Завантажити нове зображення тла та логотип сторінки авторизації",
+    "Background and login image" : "Зображення тла та логотипу організації на сторінці авторизації",
+    "Advanced options" : "Розширені налаштування",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення  ImageMagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки на основі завантаженого логотипа і кольору.",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогою допоміжного програмного забезпечення, наприклад, застосунки зчитування з екрана. Ми прагнемо відповідати {guidelines} Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
     ". Unable to apply the setting." : ". Не вдалося застосувати налаштування.",
-    "Background" : "Тло",
-    "Set a custom background" : "Встановити спеціальне зображення тла",
-    "Change color" : "Змінити колір",
-    "No background" : "Без тла"
+    "No background has been selected" : "Не вибрано тло",
+    "Select a custom color" : "Виберіть власний колір",
+    "Upload" : "Завантажити"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
