@@ -10,6 +10,7 @@ OC.L10N.register(
     "Out of office" : "Kontorist väljas",
     "Working remotely" : "Kaugtööl",
     "In a call" : "Kõnes",
+    "Be right back" : "Kohe jõuan tagasi",
     "User status" : "Kasutaja olek",
     "Clear status after" : "Eemalda olekuteade peale",
     "Emoji for your status message" : "Sinu olekuteate emoji",
@@ -23,7 +24,6 @@ OC.L10N.register(
     "There was an error saving the status" : "Oleku salvestamisel tekkis viga",
     "There was an error clearing the status" : "Oleku eemaldamisel tekkis viga",
     "There was an error reverting the status" : "Oleku taastamisel tekkis viga",
-    "Set status" : "Määra olek",
     "Online status" : "Olek võrgus",
     "Status message" : "Olekuteade",
     "Set absence period" : "Määra eemaloleku periood",
@@ -31,18 +31,20 @@ OC.L10N.register(
     "Your status was set automatically" : "Su olek määrati automaatselt",
     "Clear status message" : "Eemalda olekuteade",
     "Set status message" : "Lisa olekusõnum",
-    "Don't clear" : "Ära tühjenda",
-    "Today" : "Täna",
-    "This week" : "Käesolev nädal",
     "Online" : "Võrgus",
     "Away" : "Eemal",
+    "Busy" : "Hõivatud",
     "Do not disturb" : "Ära sega",
     "Invisible" : "Nähtamatu",
     "Offline" : "Pole võrgus",
+    "Set status" : "Määra olek",
     "There was an error saving the new status" : "Uue oleku salvestamisel esines viga",
+    "Don't clear" : "Ära kustuta",
     "30 minutes" : "30 minutit",
-    "1 hour" : "1 tund",
+    "1 hour" : "1 tundi",
     "4 hours" : "4 tundi",
+    "Today" : "Täna",
+    "This week" : "Käesoleval nädalal",
     "Mute all notifications" : "Sellega summutad teavitused",
     "Appear offline" : "Sellega paistad olema võrgust väljas"
 },
