@@ -190,12 +190,15 @@ OC.L10N.register(
     "Please reload the page." : "Перазагрузіце старонку.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Абнаўленне было няўдалым. Дадатковая інфармацыя – у прысвечаным гэтаму пытанню паведамленні на <a href=\"{url}\">нашым форуме</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Абнаўленне было няўдалым. Паведаміце пра гэту праблему <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">супольнасці Nextcloud</a>.",
+    "Done" : "Гатова",
     "Applications menu" : "Меню праграм",
     "Apps" : "Праграмы",
     "More apps" : "Болей праграм",
     "_{count} notification_::_{count} notifications_" : ["{count} апавяшчэнне","{count} апавяшчэнні","{count} апавяшчэнняў","{count} апавяшчэнняў"],
     "No" : "Не",
     "Yes" : "Так",
+    "App password" : "Пароль праграмы",
+    "Grant access" : "Дазволіць доступ",
     "The remote URL must include the user." : "Аддалены URL-адрас павінен уключаць карыстальніка.",
     "Invalid remote URL." : "Памылковы аддалены URL.",
     "Failed to add the public link to your Nextcloud" : "Не ўдалося дадаць публічную спасылку ў ваш Nextcloud",
@@ -271,6 +274,13 @@ OC.L10N.register(
     "Skip" : "Прапусціць",
     "Installing apps …" : "Усталяванне праграм …",
     "Install recommended apps" : "Усталяваць рэкамендаваныя праграмы",
+    "Online" : "У сетцы",
+    "Away" : "Адышоў",
+    "Busy" : "Заняты",
+    "Do not disturb" : "Не турбаваць",
+    "Mute all notifications" : "Адключыць усе апавяшчэнні",
+    "Invisible" : "Нябачны",
+    "Appear offline" : "Паказваць \"Па-за сеткай\"",
     "Avatar of {displayName}" : "Аватар карыстальніка {displayName}",
     "Settings menu" : "Меню налад",
     "Loading your contacts …" : "Загрузка вашых кантактаў …",
@@ -295,10 +305,20 @@ OC.L10N.register(
     "Back" : "Назад",
     "Login form is disabled." : "Форма ўваходу адключана.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форма ўваходу ў Nextcloud адключана. Скарыстайцеся іншым варыянтам уваходу, калі ён даступны, або звярніцеся да адміністратара.",
+    "Security warning" : "Папярэджанне бяспекі",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Калі вы не спрабуеце наладзіць новую прыладу або праграму, значыць, хтосьці спрабуе падмануць вас, каб атрымаць доступ да вашых даных. У гэтым выпадку не працягвайце і звярніцеся да сістэмнага адміністратара.",
+    "You can close this window." : "Вы можаце закрыць гэта акно.",
+    "Account access" : "Доступ да ўліковага запісу",
     "More actions" : "Больш дзеянняў",
     "User menu" : "Меню карыстальніка",
     "Set public name" : "Задаць публічнае імя",
     "Change public name" : "Змяніць публічнае імя",
+    "The password is wrong or expired. Please try again or request a new one." : "Пароль няправільны або скончыўся тэрмін яго дзеяння. Паспрабуйце яшчэ раз або запытайце новы.",
+    "Submit" : "Адправіць",
+    "Please type in your email address to request a temporary password" : "Увядзіце свой адрас электроннай пошты, каб запытаць часовы пароль",
+    "Password sent!" : "Пароль адпраўлены!",
+    "Email address" : "Адрас электроннай пошты",
+    "Request password" : "Запытаць пароль",
     "Password is too weak" : "Пароль занадта слабы",
     "Password is weak" : "Пароль слабы",
     "Password is average" : "Пароль абы-які",
@@ -309,7 +329,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог даных і файлы, верагодна, даступныя з Інтэрнэту, таму што файл <code>.htaccess</code> не працуе.",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Каб даведацца, як правільна наладзіць сервер, {linkStart}глядзіце дакументацыю{linkEnd}",
     "Autoconfig file detected" : "Выяўлены файл аўтаканфігурацыі",
-    "Security warning" : "Папярэджанне бяспекі",
     "Create administration account" : "Стварыце ўліковы запіс адміністратара",
     "Administration account name" : "Імя ўліковага запісу адміністратара",
     "Administration account password" : "Пароль уліковага запісу адміністратара",
@@ -360,6 +379,8 @@ OC.L10N.register(
     "({count} selected)" : "(выбрана {count})",
     "Error loading file exists template" : "Памылка загрузкі шаблона",
     "Saving …" : "Захаванне …",
+    "Groups" : "Групы",
+    "Group list is empty" : "Спіс груп пусты",
     "seconds ago" : "с таму",
     "Connection to server lost" : "Злучэнне з серверам страчана",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Праблема з загрузкай старонкі, перазагрузка праз %n секунду","Праблема з загрузкай старонкі, перазагрузка праз %n секунды","Праблема з загрузкай старонкі, перазагрузка праз %n секунд","Праблема з загрузкай старонкі, перазагрузка праз %n секунд"],
@@ -404,19 +425,7 @@ OC.L10N.register(
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не атрымалася выдаліць CAN_INSTALL з папкі канфігурацыі. Выдаліце ​​гэты файл уручную.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для карэктнай працы гэтай праграмы патрабуецца JavaScript. {linkstart}Уключыце JavaScript{linkend} і перазагрузіце старонку.",
     "Go to %s" : "Перайсці да %s",
-    "Please log in before granting %1$s access to your %2$s account." : "Увайдзіце ў сістэму, перш чым даць %1$s доступ да вашага ўліковага запісу %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Калі вы не спрабуеце наладзіць новую прыладу або праграму, значыць, хтосьці спрабуе падмануць вас, каб атрымаць доступ да вашых даных. У гэтым выпадку не працягвайце і звярніцеся да сістэмнага адміністратара.",
-    "App password" : "Пароль праграмы",
-    "Grant access" : "Дазволіць доступ",
-    "Account access" : "Доступ да ўліковага запісу",
-    "Currently logged in as %1$s (%2$s)." : "Вы ўвайшлі як %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s.",
-    "You can close this window." : "Вы можаце закрыць гэта акно.",
     "Previous" : "Папярэдняя",
-    "The password is wrong or expired. Please try again or request a new one." : "Пароль няправільны або скончыўся тэрмін яго дзеяння. Паспрабуйце яшчэ раз або запытайце новы.",
-    "Please type in your email address to request a temporary password" : "Увядзіце свой адрас электроннай пошты, каб запытаць часовы пароль",
-    "Email address" : "Адрас электроннай пошты",
-    "Password sent!" : "Пароль адпраўлены!",
     "Two-factor authentication" : "Двухфактарная аўтэнтыфікацыя",
     "Cancel login" : "Скасаваць уваход",
     "Access through untrusted domain" : "Доступ праз ненадзейны дамен",
@@ -460,7 +469,6 @@ OC.L10N.register(
     "No action available" : "Няма даступных дзеянняў",
     "Non-existing tag #{tag}" : "Неіснуючы тэг #{tag}",
     "Restricted" : "Абмежавана",
-    "Invisible" : "Нябачны",
     "Delete" : "Выдаліць",
     "Rename" : "Перайменаваць",
     "Collaborative tags" : "Супольныя тэгі",
@@ -475,6 +483,9 @@ OC.L10N.register(
     "Configure the database" : "Наладзіць базу даных",
     "Only %s is available." : "Даступна толькі %s.",
     "Database account" : "Уліковы запіс базы даных",
-    "Installing …" : "Усталяванне …"
+    "Installing …" : "Усталяванне …",
+    "Please log in before granting %1$s access to your %2$s account." : "Увайдзіце ў сістэму, перш чым даць %1$s доступ да вашага ўліковага запісу %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Вы ўвайшлі як %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
