@@ -18,17 +18,15 @@ OC.L10N.register(
     "Unknown filetype" : "Неизвестен тип файл",
     "An error occurred. Please contact your admin." : "Възникна неизвестна грешка. Свържете с администратора.",
     "Invalid image" : "Невалидно изображение",
-    "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
-    "No crop data provided" : "Липсват данни за изрязването",
-    "No valid crop data provided" : "Данни за изрязването са невалидни",
-    "Crop is not square" : "Областта не е квадратна",
     "State token does not match" : "Маркер на състояние не съвпада",
     "Invalid app password" : "Невалидна парола за приложението",
     "Could not complete login" : "Не може да завърши влизането",
     "State token missing" : "Липсва токен/маркер/ на състоянието",
     "Your login token is invalid or has expired" : "Вашият маркер за вход е невалиден или е изтекъл",
+    "Please use original client" : "Моля, използвайте оригиналния клиент.",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Тази общностна версия на Nextcloud не се поддържа и push известия са ограничени.",
     "Login" : "Вписване",
+    "Unsupported email length (>255)" : "Дължината на е-мейлът не се поддържа (>255 символа)",
     "Password reset is disabled" : "Възстановяването на пароли е забранено",
     "Could not reset password because the token is expired" : "Възстановяването на паролата е неуспешно, защото токенът е с изтекла валидност",
     "Could not reset password because the token is invalid" : "Възстановяването на паролата е неуспешно, защото токенът е невалиден",
@@ -38,23 +36,28 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следния бутон, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следната връзка, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Reset your password" : "Възстановяване на вашата парола",
+    "The given provider is not available" : "Доставчикът не е наличен",
+    "Task not found" : "Задачата не е открита",
     "Internal error" : "Вътрешна грешка",
     "Not found" : "Не е намерен",
+    "Node is locked" : "Точката е заключена (Node is locked)",
+    "Bad request" : "Лоша заявка",
+    "Requested task type does not exist" : "Заявената задача не съществува",
     "Image not found" : "Изображението не е открито",
     "No translation provider available" : "Няма наличен доставчик на преводи",
     "Could not detect language" : "Не можа да се установи езика",
     "Unable to translate" : "Не може да се преведе",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Стъпка на поправка:",
+    "Repair info:" : "Информация за поправка:",
+    "Repair warning:" : "Предупреждение при поправка:",
+    "Repair error:" : "Грешка при поправка:",
     "Nextcloud Server" : "Nextcloud сървър",
     "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Въведете своя абонаментен ключ в приложението за поддръжка, за да увеличите лимита на акаунта.  Това също ви предоставя всички допълнителни предимства, които Nextcloud Enterprise предлага и е силно препоръчително за работа в компании.",
     "Learn more ↗" : "Научете повече ↗",
     "Preparing update" : "Подготовка за актуализиране",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Стъпка на поправка:",
-    "Repair info:" : "Информация за поправка:",
-    "Repair warning:" : "Предупреждение при поправка:",
-    "Repair error:" : "Грешка при поправка:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Моля, използвайте програмата за актуализиране от командния ред, тъй като актуализирането чрез браузъра е забранено в config.php.",
     "Turned on maintenance mode" : "Режимът за поддръжка е включен",
     "Turned off maintenance mode" : "Режимът за поддръжка е изключен",
@@ -71,16 +74,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (несъвместим)",
     "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
     "Already up to date" : "Актуално",
-    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здравей Свят!",
-    "sunny" : "слънчево",
-    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
-    "Hello {name}" : "Здравейте, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
-    "new" : "нов",
-    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
+    "Unknown" : "Неизвестен",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
     "Update to {version}" : "Актуализирай до {version}",
     "An error occurred." : "Възникна грешка.",
@@ -89,30 +83,39 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Актуализирането беше неуспешно. Моля отнесете този проблем към <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> Nextcloud общността</a>.",
     "Continue to {productName}" : "Продължаване към {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Актуализацията беше успешна. Пренасочване към {productName} след %n секунди.","Актуализацията беше успешна. Пренасочване към {productName} след %n секунди."],
+    "Done" : "Завършено",
     "Apps" : "Приложения",
     "More apps" : "Още приложения",
     "_{count} notification_::_{count} notifications_" : ["{count} известие","{count} известия"],
     "No" : "Не",
     "Yes" : "Да",
+    "Grant access" : "Разреши достъпa",
     "Invalid remote URL." : "невалиден отдалечен URL(адрес)",
     "Failed to add the public link to your Nextcloud" : "Неуспешно добавяне на публичната връзка към вашия Nextcloud",
     "Create share" : "Създаване на споделяне",
-    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
     "Please copy the link manually:" : "Моля копирайте адреса ръчно:",
-    "Searching …" : "Търсене ...",
+    "Search in date range" : "Търси във времеви период",
+    "Search in current app" : "Търси в настоящето приложение",
+    "Clear search" : "Изчисти търсенето",
+    "Search everywhere" : "Търси навсякъде",
     "Start typing to search" : "Започнете да пишете, за търсене",
     "Today" : "Днес",
+    "Last 7 days" : "Последните 7 дни",
+    "Last 30 days" : "Последните 30 дни",
     "This year" : "Тази година",
     "Last year" : "Миналата година",
+    "Unified search" : "Глобално търсене",
+    "Search apps, files, tags, messages" : "Търси приложения, файлове, тагове, съобщения",
     "Places" : "Места",
     "Date" : "Дата",
+    "Search people" : "Търси хора",
     "People" : "Хора",
     "Results" : "Резултати",
     "Load more results" : "Зареждане на още резултати",
+    "Search in" : "Търси в",
     "Log in" : "Вписване",
-    "Logging in …" : "Вписване ...",
     "Log in to {productName}" : "Вписване в {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
+    "This account is disabled" : "Профилът е неактивен",
     "Account name or email" : "Име на профил или имейл",
     "Account name" : "Име на профил",
     "Server side authentication failed!" : "Неуспешно удостоверяването от страна на сървъра!",
@@ -122,14 +125,14 @@ OC.L10N.register(
     "Password" : "Парола",
     "Log in with a device" : "Вписване с устройство",
     "Your account is not setup for passwordless login." : "Вашият профил не е настроен за влизане без парола.",
-    "Browser not supported" : "Браузърът не се поддържа",
-    "Passwordless authentication is not supported in your browser." : "Удостоверяването без парола не се поддържа във вашия браузър.",
     "Your connection is not secure" : "Връзката ви не е сигурна",
     "Passwordless authentication is only available over a secure connection." : "Удостоверяването без парола е достъпно само чрез защитена връзка.",
+    "Browser not supported" : "Браузърът не се поддържа",
+    "Passwordless authentication is not supported in your browser." : "Удостоверяването без парола не се поддържа във вашия браузър.",
     "Reset password" : "Възстановяване на паролата",
+    "Back to login" : "Обратно към вписване",
     "Couldn't send reset email. Please contact your administrator." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, свържете се с вашия администратор.",
     "Password cannot be changed. Please contact your administrator." : "Паролата не може да бъде променена. Моля, свържете се с вашия администратор.",
-    "Back to login" : "Обратно към вписване",
     "New password" : "Нова парола",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашите файлове са криптирани. След като паролата ви бъде нулирана, няма да можете да си върнете данните. Ако не сте сигурни какво да правите, моля, свържете се с вашия администратор, преди да продължите. Наистина ли искате да продължите?",
     "I know what I'm doing" : "Знам какво правя",
@@ -140,20 +143,20 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
     "Distraction free note taking app." : "Приложение за водене на бележки без разсейване.",
     "Recommended apps" : "Препоръчани приложения",
-    "Loading apps …" : "Зареждане на приложения ...",
     "Could not fetch list of apps from the App Store." : "Списъкът с приложения не можа да се извлече от App Store.",
     "App download or installation failed" : "Изтеглянето или инсталирането на приложението беше неуспешно",
     "Cannot install this app because it is not compatible" : "Това приложение не може да се инсталира, защото е несъвместимо",
     "Cannot install this app" : "Това приложение не може да се инсталира",
     "Skip" : "Пропускане",
-    "Installing apps …" : "Инсталиране на приложения ...",
     "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
+    "Online" : "На линия /онлайн/",
+    "Away" : "Винаги",
+    "Busy" : "Зает",
+    "Do not disturb" : "Не безпокой",
+    "Invisible" : "Невидим",
     "Settings menu" : "Настройки",
-    "Loading your contacts …" : "Зареждане на контактите ...",
-    "Looking for {term} …" : "Търси се {term} …",
-    "Search contacts" : "Търсене на/в/ контакти",
-    "Reset search" : "Рестартирай търсенето",
-    "Search contacts …" : "Търсене в контактите ...",
+    "Search contacts" : "Търсене в контакти",
+    "Reset search" : "Ново търсене",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
     "No contacts found" : "Няма намерени контакти",
     "Show all contacts" : "Показване на всички контакти",
@@ -165,19 +168,53 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Търсенето започва, след като започнете да пишете, а до резултатите можете да стигнете с клавишите със стрелки.",
     "Search for {name} only" : "Търсене само за {name}",
-    "Loading more results …" : "Зарежда още резултати…",
     "Forgot password?" : "Забравена парола?",
     "Back" : "Назад",
     "Login form is disabled." : "Формулярът за вход е деактивиран",
+    "Connect to your account" : "Свързване към вашия профил",
+    "Security warning" : "Предупреждение за сигурност",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
+    "Account connected" : "Профилът е свързан",
+    "Your client should now be connected!" : "Клиентът ви вече трябва да е свързан!",
+    "You can close this window." : "Можеш да затвориш този прозорец.",
+    "Account access" : "Достъп до профил",
     "More actions" : "Повече действия",
+    "This share is password-protected" : "Тази зона е защитена с парола.",
+    "The password is wrong or expired. Please try again or request a new one." : "Паролата е грешна или е изтекла. Моля, опитайте отново или поискайте нова.",
+    "Submit" : "Изпращане",
+    "Please type in your email address to request a temporary password" : "Моля, въведете имейл адреса си, за да поискате временна парола",
+    "Password sent!" : "Паролата е изпратена!",
+    "You are not authorized to request a password for this share" : "Не сте упълномощени да искате парола за това споделяне",
+    "Email address" : "Имейл адрес",
+    "Request password" : "Заявка за парола",
+    "Forgot password" : "Забравена парола",
+    "Storage & database" : "Хранилища и бази данни",
+    "Data folder" : "Директория за данни",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
+    "For more details check out the documentation." : "За повече информация проверете документацията.",
+    "Performance warning" : "Предупреждение за производителността",
+    "You chose SQLite as database." : "Избрахте база данни SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite трябва да се използва само за минимални екземпляри и екземпляри за разработка. За производство препоръчваме различен сървър на базата данни.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако използвате клиенти за синхронизиране на файлове, използването на SQLite не се препоръчва.",
+    "Database user" : "Потребител за базата данни",
+    "Database password" : "Парола за базата данни",
+    "Database name" : "Име на базата данни",
+    "Database tablespace" : "Tablespace на базата данни",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
+    "Database host" : "Хост",
+    "Install" : "Инсталиране",
+    "Need help?" : "Нуждаете се от помощ?",
+    "See the documentation" : "Прегледайте документацията",
     "{name} version {version} and above" : "{name} версия {version} и по-нови",
     "This browser is not supported" : "Този браузър не се поддържа",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
-    "Search {types} …" : "Търсене на  {types}  ...",
+    "Choose {file}" : "Изберете {file}",
     "Choose" : "Избор",
+    "Copy to {target}" : "Копиране в {target}",
     "Copy" : "Копирай",
+    "Move to {target}" : "Преместване на {target}",
     "Move" : "Премести",
     "OK" : "Добре",
     "read-only" : "Само за четене",
@@ -192,7 +229,10 @@ OC.L10N.register(
     "(all selected)" : "(всички избрани)",
     "({count} selected)" : "({count} избрани)",
     "Error loading file exists template" : "Грешка при зареждането на шаблона за вече съществуващ файл",
-    "Saving …" : "Записване …",
+    "Saving …" : "Запазване ...",
+    "Groups" : "Групи",
+    "Group list is empty" : "Списъкът с групи е празен",
+    "Unable to retrieve the group list" : "Не може да се извлече списъкът с групи",
     "seconds ago" : "преди секунди",
     "Connection to server lost" : "Няма връзка със сървъра",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
@@ -207,28 +247,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
     "New in" : "Ново в",
     "View changelog" : "Преглед на списъка с промени",
-    "Very weak password" : "Много проста парола",
-    "Weak password" : "Проста парола",
-    "So-so password" : "Не особено добра парола",
-    "Good password" : "Добра парола",
-    "Strong password" : "Сложна парола",
-    "No action available" : "Няма налични действия",
-    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Close \"{dialogTitle}\" dialog" : "Затваряне на диалогов прозорец \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
-    "Restricted" : "Ограничен",
-    "Invisible" : "Невидим",
-    "Delete" : "Изтрий",
-    "Rename" : "Преименувай",
-    "Collaborative tags" : "Съвместни етикети",
-    "No tags found" : "Не са открити етикети",
     "Personal" : "Лични",
+    "Accounts" : "Профили",
     "Admin" : "Админ",
     "Help" : "Помощ",
     "Access forbidden" : "Достъпът е забранен",
+    "Back to %s" : "Обратно към %s",
     "Page not found" : "Страницата не е намерена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страницата не може да бъде намерена на сървъра или може да не ви е позволено да я видите.",
-    "Back to %s" : "Обратно към %s",
     "Too many requests" : "Твърде много заявки",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
     "Error" : "Грешка",
@@ -245,30 +272,6 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Ред: %s",
     "Trace" : "Проследяване на грешките",
-    "Security warning" : "Предупреждение за сигурност",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
-    "Show password" : "Покажи парола",
-    "Toggle password visibility" : "Превключване на видимостта на парола",
-    "Storage & database" : "Хранилища и бази данни",
-    "Data folder" : "Директория за данни",
-    "Configure the database" : "Конфигуриране на базата данни",
-    "Only %s is available." : "Само %s е наличен.",
-    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирайте допълнителни PHP модули, за да изберете други видове бази данни.",
-    "For more details check out the documentation." : "За повече информация проверете документацията.",
-    "Database password" : "Парола за базата данни",
-    "Database name" : "Име на базата данни",
-    "Database tablespace" : "Tablespace на базата данни",
-    "Database host" : "Хост",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
-    "Performance warning" : "Предупреждение за производителността",
-    "You chose SQLite as database." : "Избрахте база данни SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite трябва да се използва само за минимални екземпляри и екземпляри за разработка. За производство препоръчваме различен сървър на базата данни.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако използвате клиенти за синхронизиране на файлове, използването на SQLite не се препоръчва.",
-    "Install" : "Инсталиране",
-    "Installing …" : "В процес на инсталиране…",
-    "Need help?" : "Нуждаете се от помощ?",
-    "See the documentation" : "Прегледайте документацията",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Изглежда, че се опитвате да преинсталирате Nextcloud. Файлът CAN_INSTALL обаче липсва във вашата конфигурационна директория. Моля, създайте файла CAN_INSTALL във вашата конфигурационна папка, за да продължите.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL не можа да се премахне от конфигурационната папка. Моля, премахнете този файл ръчно.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Приложението изисква JavaScript. Моля, {linkstart}включете JavaScript{linkend} и презаредете страницата.",
@@ -276,23 +279,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Преминаване към навигация на приложението",
     "Go to %s" : "Отидете на %s",
     "Get your own free account" : "Вземете свой собствен безплатен профил",
-    "Connect to your account" : "Свързване към вашия профил",
-    "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
-    "Grant access" : "Разреши достъпa",
-    "Account access" : "Достъп до профил",
-    "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил.",
-    "Account connected" : "Профилът е свързан",
-    "Your client should now be connected!" : "Клиентът ви вече трябва да е свързан!",
-    "You can close this window." : "Можеш да затвориш този прозорец.",
     "Previous" : "Предишен ",
-    "This share is password-protected" : "Тази зона е защитена с парола.",
-    "The password is wrong or expired. Please try again or request a new one." : "Паролата е грешна или е изтекла. Моля, опитайте отново или поискайте нова.",
-    "Please type in your email address to request a temporary password" : "Моля, въведете имейл адреса си, за да поискате временна парола",
-    "Email address" : "Имейл адрес",
-    "Password sent!" : "Паролата е изпратена!",
-    "You are not authorized to request a password for this share" : "Не сте упълномощени да искате парола за това споделяне",
     "Two-factor authentication" : "Двустепенно удостоверяване",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повишената сигурност е активирана за вашия профил. Изберете втори фактор за удостоверяване .",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Невъзможно да се зареди поне един от вашите активирани двустепенни методи за удостоверяване. Моля, свържете се с вашия администратор.",
@@ -324,15 +311,53 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
-    "Currently open" : "В момента са отворени",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
-    "You have not added any info yet" : "Все още не сте добавили никаква информация",
-    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
-    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
-    "Edit Profile" : "Редактиране на профил",
-    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
-    "Error loading message template: {error}" : "Грешка при зареждането на шаблона за съобщения: {error}",
-    "Profile not found" : "Профилът не е намерен",
-    "The profile does not exist." : "Профилът не съществува."
+    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здравей Свят!",
+    "sunny" : "слънчево",
+    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
+    "Hello {name}" : "Здравейте, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
+    "new" : "нов",
+    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
+    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
+    "Searching …" : "Търсене ...",
+    "Logging in …" : "Вписване ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
+    "Loading apps …" : "Зареждане на приложения ...",
+    "Installing apps …" : "Инсталиране на приложения ...",
+    "Loading your contacts …" : "Зареждане на контактите ...",
+    "Looking for {term} …" : "Търси се {term} …",
+    "Search contacts …" : "Търсене в контактите ...",
+    "Loading more results …" : "Зарежда още резултати…",
+    "Search {types} …" : "Търсене на  {types}  ...",
+    "Saving …" : "Записване …",
+    "Very weak password" : "Много проста парола",
+    "Weak password" : "Проста парола",
+    "So-so password" : "Не особено добра парола",
+    "Good password" : "Добра парола",
+    "Strong password" : "Сложна парола",
+    "No action available" : "Няма налични действия",
+    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
+    "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
+    "Restricted" : "Ограничен",
+    "Delete" : "Изтрий",
+    "Rename" : "Преименувай",
+    "Collaborative tags" : "Съвместни етикети",
+    "No tags found" : "Не са открити етикети",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Създай администраторски профил</strong>",
+    "New admin account name" : "Ново име на администраторския профил",
+    "Show password" : "Покажи парола",
+    "Toggle password visibility" : "Превключване на видимостта на парола",
+    "Configure the database" : "Конфигуриране на базата данни",
+    "Only %s is available." : "Само %s е наличен.",
+    "Database account" : "Профил за база данни",
+    "Installing …" : "В процес на инсталиране…",
+    "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
+    "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил."
 },
 "nplurals=2; plural=(n != 1);");
