@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizace nebyla úspěšná. Prosím nahlaste tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitě projektu Nextcloud</a>",
     "Continue to {productName}" : "Pokračujte k {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizace proběhla úspěšně. Za %n sekundu budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekund budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}"],
+    "Done" : "Dokončeno",
     "Applications menu" : "Nabídka aplikací",
     "Apps" : "Aplikace",
     "More apps" : "Více aplikací",
     "_{count} notification_::_{count} notifications_" : ["{count} upozornění","{count} upozornění","{count} upozornění","{count} upozornění"],
     "No" : "Ne",
     "Yes" : "Ano",
+    "App password" : "Heslo pro aplikaci",
+    "Grant access" : "Udělit přístup",
     "The remote URL must include the user." : "Je třeba, aby vzdálená URL obsahovala uživatele.",
     "Invalid remote URL." : "Neplatná vzdálená URL.",
     "Failed to add the public link to your Nextcloud" : "Nepodařilo se přidání veřejného odkazu do Nextcloud",
@@ -248,12 +251,13 @@ OC.L10N.register(
     "Results" : "Výsledky",
     "Load more results" : "Načíst další výsledky",
     "Search in" : "Hledat v",
+    "Partial matches" : "Částečné shody",
     "Log in" : "Přihlásit",
     "Logging in …" : "Přihlašování …",
     "Log in to {productName}" : "Přihlásit se do {productName}",
     "Wrong login or password." : "Nesprávné přihlašovací jméno nebo heslo",
     "This account is disabled" : "Účet je znepřístupněn",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o přihlášeni z vaší IP adresy. Další přihlášení bude možné za 30 sekund.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Příliš mnoho nesprávných pokusů o přihlášení. Zkuste to znovu za 30 sekund.",
     "Account name or email" : "Název účtu nebo e-mail",
     "Account name" : "Název účtu",
     "Server side authentication failed!" : "Ověření se na straně serveru se nezdařilo!",
@@ -287,21 +291,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
     "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Recommended apps" : "Doporučené aplikace",
-    "Loading apps …" : "Načítání aplikací …",
+    "Loading apps …" : "Načítání aplikací …",
     "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
     "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
     "Cannot install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
     "Cannot install this app" : "Tuto aplikaci nelze nainstalovat",
     "Skip" : "Přeskočit",
-    "Installing apps …" : "Instalace aplikací …",
+    "Installing apps …" : "Instalace aplikací …",
     "Install recommended apps" : "Nainstalovat doporučené aplikace",
+    "Online" : "Online",
+    "Away" : "Pryč",
+    "Busy" : "Zaneprázdněn(a)",
+    "Do not disturb" : "Nerušit",
+    "Mute all notifications" : "Ztlumit veškerá upozornění",
+    "Invisible" : "Není vidět",
+    "Appear offline" : "Jevit se offline",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
     "Settings menu" : "Nabídka nastavení",
-    "Loading your contacts …" : "Načítání vašich kontaktů …",
-    "Looking for {term} …" : "Hledání {term} …",
+    "Loading your contacts …" : "Načítání vašich kontaktů …",
+    "Looking for {term} …" : "Hledání {term} …",
     "Search contacts" : "Hledat v kontaktech",
     "Reset search" : "Resetovat hledání",
-    "Search contacts …" : "Hledat v kontaktech …",
+    "Search contacts …" : "Hledat v kontaktech …",
     "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
     "No contacts found" : "Nenalezeny žádné kontakty",
     "Show all contacts" : "Zobrazit všechny kontakty",
@@ -313,18 +324,35 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
     "Search for {name} only" : "Hledat pouze {name}",
-    "Loading more results …" : "Načítání dalších výsledků …",
+    "Loading more results …" : "Načítání dalších výsledků …",
     "Forgot password?" : "Zapomněli jste heslo?",
     "Back to login form" : "Zpět na formulář pro přihlášení",
     "Back" : "Zpět",
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
+    "Connect to your account" : "Propojit s vaším účtem",
+    "Security warning" : "Varování ohledně zabezpečení",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Pokud se nepokoušíte nastavit nové zařízení či aplikaci, někdo se pokouší vás ošálit a získat tak přístup k vašim datům. V takovém případě nepokračujte a obraťte se na svého správce systémů.",
+    "Alternative log in using app password" : "Alternativní přihlášení pomocí hesla pro aplikaci",
+    "Account connected" : "Účet připojen",
+    "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
+    "You can close this window." : "Toto okno je možné zavřít.",
+    "Account access" : "Přístup k účtu",
     "More actions" : "Další akce",
     "User menu" : "Nabídka uživatele",
     "Your guest name: {user}" : "Vaše jméno, coby hosta: {user}",
     "You are currently not identified." : "V tuto chvíli nejste identifikováni.",
     "Set public name" : "Nastavit veřejné jméno",
     "Change public name" : "Změnit veřejné jméno",
+    "This share is password-protected" : "Toto sdílení je chráněno heslem",
+    "The password is wrong or expired. Please try again or request a new one." : "Nesprávné heslo nebo jeho platnost skončila. Prosím zkuste to znovu nebo si zažádejte o nové.",
+    "Submit" : "Odeslat",
+    "Please type in your email address to request a temporary password" : "Pokud si chcete požádat o dočasné heslo, zadejte svou e-mailovou adresu",
+    "Password sent!" : "Heslo zasláno!",
+    "You are not authorized to request a password for this share" : "Nejste oprávněni vyžádat si heslo pro toto sdílení",
+    "Email address" : "E-mailová adresa",
+    "Request password" : "Vyžádat si heslo",
+    "Forgot password" : "Zapomenuté heslo",
     "Password is too weak" : "Heslo je příliš snadno prolomitelné",
     "Password is weak" : "Heslo je snadno prolomitelné",
     "Password is average" : "Heslo je postačující",
@@ -336,7 +364,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informace o tom, jak správně nastavit váš server, naleznete v {linkStart}dokumentaci{linkEnd}",
     "Autoconfig file detected" : "Zjištěn soubor s automatického nastavení",
     "The setup form below is pre-filled with the values from the config file." : "Níže uvedený formulář nastavení je předvyplněný hodnotami ze souboru s nastaveními.",
-    "Security warning" : "Varování ohledně zabezpečení",
     "Create administration account" : "Vytvořit účet pro správnu",
     "Administration account name" : "Název účtu pro správu",
     "Administration account password" : "Heslo k účtu pro správu",
@@ -359,7 +386,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
     "Database host" : "Stroj na kterém se nachází databáze",
     "localhost" : "localhost",
-    "Installing …" : "Instalace …",
+    "Installing …" : "Instalace …",
     "Install" : "Nainstalovat",
     "Need help?" : "Potřebujete nápovědu?",
     "See the documentation" : "Viz dokumentace",
@@ -368,7 +395,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
-    "Search {types} …" : "Hledat {types} …",
+    "Search {types} …" : "Hledat {types} …",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
     "Copy to {target}" : "Zkopírovat do {target}",
@@ -388,7 +415,10 @@ OC.L10N.register(
     "(all selected)" : "(vše vybrané)",
     "({count} selected)" : "(vybráno {count})",
     "Error loading file exists template" : "Chyba při načítání šablony existence souboru",
-    "Saving …" : "Ukládání…",
+    "Saving …" : "Ukládání …",
+    "Groups" : "Skupiny",
+    "Group list is empty" : "Seznam skupin je prázdný.",
+    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
     "seconds ago" : "před několika sekundami",
     "Connection to server lost" : "Připojení k serveru ztraceno",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
@@ -439,25 +469,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Přeskočit na navigaci aplikace",
     "Go to %s" : "Jít na %s",
     "Get your own free account" : "Získejte svůj vlastní účet zdarma",
-    "Connect to your account" : "Propojit s vaším účtem",
-    "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Pokud se nepokoušíte nastavit nové zařízení či aplikaci, někdo se pokouší vás ošálit a získat tak přístup k vašim datům. V takovém případě nepokračujte a obraťte se na svého správce systémů.",
-    "App password" : "Heslo pro aplikaci",
-    "Grant access" : "Udělit přístup",
-    "Alternative log in using app password" : "Alternativní přihlášení pomocí hesla pro aplikaci",
-    "Account access" : "Přístup k účtu",
-    "Currently logged in as %1$s (%2$s)." : "Nyní jste přihlášeni jako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu.",
-    "Account connected" : "Účet připojen",
-    "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
-    "You can close this window." : "Toto okno je možné zavřít.",
     "Previous" : "Předchozí",
-    "This share is password-protected" : "Toto sdílení je chráněno heslem",
-    "The password is wrong or expired. Please try again or request a new one." : "Nesprávné heslo nebo jeho platnost skončila. Prosím zkuste to znovu nebo si zažádejte o nové.",
-    "Please type in your email address to request a temporary password" : "Pokud si chcete požádat o dočasné heslo, zadejte svou e-mailovou adresu",
-    "Email address" : "E-mailová adresa",
-    "Password sent!" : "Heslo zasláno!",
-    "You are not authorized to request a password for this share" : "Nejste oprávněni vyžádat si heslo pro toto sdílení",
     "Two-factor authentication" : "Dvoufaktorové přihlášení",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Zvolte druhý faktor pro ověřování:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedaří se načíst ani jednu ze zapnutých metod dvouúrovňového ověřování. Obraťte se na svého správce.",
@@ -501,16 +513,17 @@ OC.L10N.register(
     "new" : "nový",
     "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
     "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
-    "Searching …" : "Hledání…",
-    "Logging in …" : "Přihlašování…",
-    "Loading apps …" : "Načítání aplikací…",
-    "Installing apps …" : "Instalace aplikací…",
-    "Loading your contacts …" : "Načítání vašich kontaktů…",
-    "Looking for {term} …" : "Hledání {term}…",
-    "Search contacts …" : "Hledat v kontaktech…",
-    "Loading more results …" : "Načítání dalších výsledků…",
-    "Search {types} …" : "Hledat {types}…",
-    "Saving …" : "Ukládání…",
+    "Searching …" : "Hledání …",
+    "Logging in …" : "Přihlašování …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o přihlášeni z vaší IP adresy. Další přihlášení bude možné za 30 sekund.",
+    "Loading apps …" : "Načítání aplikací …",
+    "Installing apps …" : "Instalace aplikací …",
+    "Loading your contacts …" : "Načítání vašich kontaktů …",
+    "Looking for {term} …" : "Hledání {term} …",
+    "Search contacts …" : "Hledat v kontaktech …",
+    "Loading more results …" : "Načítání dalších výsledků …",
+    "Search {types} …" : "Hledat {types} …",
+    "Saving …" : "Ukládání …",
     "Very weak password" : "Velmi snadno prolomitelné heslo",
     "Weak password" : "Snadno prolomitelné heslo",
     "So-so password" : "Ještě použitelné heslo",
@@ -520,7 +533,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
     "Restricted" : "Omezeno",
-    "Invisible" : "Není vidět",
     "Delete" : "Smazat",
     "Rename" : "Přejmenovat",
     "Collaborative tags" : "Štítky pro spolupráci",
@@ -535,6 +547,9 @@ OC.L10N.register(
     "Configure the database" : "Nastavit databázi",
     "Only %s is available." : "Je k dispozici pouze %s.",
     "Database account" : "Účet do databáze",
-    "Installing …" : "Instalace…"
+    "Installing …" : "Instalace …",
+    "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
+    "Currently logged in as %1$s (%2$s)." : "Nyní jste přihlášeni jako %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
