@@ -205,12 +205,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud fællesskabet</a>.",
     "Continue to {productName}" : "Fortsæt til {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekund.","Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekunder."],
+    "Done" : "Færdig",
     "Applications menu" : "App menu",
     "Apps" : "Apps",
     "More apps" : "Flere apps",
     "_{count} notification_::_{count} notifications_" : ["{count} underretning","{count} underretninger"],
     "No" : "Nej",
     "Yes" : "Ja",
+    "App password" : "App adgangskode",
+    "Grant access" : "Giv adgang",
     "The remote URL must include the user." : "Fjern-URL'en skal omfatte brugeren.",
     "Invalid remote URL." : "Ugyldig fjern webadresse.",
     "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
@@ -252,7 +255,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Log ind på {productName}",
     "Wrong login or password." : "Forkert brugernavn eller adgangskode.",
     "This account is disabled" : "Denne konto er deaktiveret",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har registreret flere ugyldige loginforsøg fra din IP. Derfor bliver din næste login sat op til 30 sekunder.",
     "Account name or email" : "Brugernavn eller e-mail",
     "Account name" : "Kontonavn",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
@@ -324,12 +326,29 @@ OC.L10N.register(
     "Back" : "Tilbage",
     "Login form is disabled." : "Loginformularen er deaktiveret.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-loginformularen er deaktiveret. Brug en anden login-mulighed, hvis den er tilgængelig, eller kontakt din administration.",
+    "Connect to your account" : "Forbind til din konto",
+    "Security warning" : "Sikkerheds advarsel",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke er igang med at konfigurerer en ny enhed eller app, så er der nogen som forsøger at snyde dig til at give dem adgang til dine data. I dette filfælde skal du ikke forsætte, men istedet kontakte din system administrator.",
+    "Alternative log in using app password" : "Alternativ login med app adgangskode",
+    "Account connected" : "Kontoen er tilknyttet",
+    "Your client should now be connected!" : "Din klient burde være forbundet nu!",
+    "You can close this window." : "Du kan lukke dette vindue",
+    "Account access" : "Konto adgang",
     "More actions" : "Flere handlinger",
     "User menu" : "Brugermenu",
     "Your guest name: {user}" : "Dit gæstenavn: {user}",
     "You are currently not identified." : "Du er aktuelt ikke identificeret.",
     "Set public name" : "Angiv offentligt navn",
     "Change public name" : "Skift offentligt navn",
+    "This share is password-protected" : "Delingen er beskyttet af kodeord",
+    "The password is wrong or expired. Please try again or request a new one." : "Adgangskoden er forkert eller udløbet. Forsøg venligst igen eller anmod om et nyt.",
+    "Submit" : "Send",
+    "Please type in your email address to request a temporary password" : "Indtast venligst din e-mailadresse for at anmode om en midlertidigt adgangskode",
+    "Password sent!" : "Adgangskode sendt!",
+    "You are not authorized to request a password for this share" : "Du er ikke godkendt til at anmode om en adgangskode til denne delte mappe",
+    "Email address" : "Email adresse",
+    "Request password" : "Anmod om adgangskode",
+    "Forgot password" : "Glemt adgangskode",
     "Password is too weak" : "Adgangskoden er for svag",
     "Password is weak" : "Adgangskoden er svag",
     "Password is average" : "Adgangskoden er middel",
@@ -341,7 +360,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information om hvordan du konfigurerer din server korrekt, {linkStart}se venligst dokumentationen{linkEnd}",
     "Autoconfig file detected" : "Autoconfig fil detekteret",
     "The setup form below is pre-filled with the values from the config file." : "Opsætningsformularen nedenfor er præudfyldt med værdierne fra config filen.",
-    "Security warning" : "Sikkerheds advarsel",
     "Create administration account" : "Opret administrationkonto",
     "Administration account name" : "Administrationskontonavn",
     "Administration account password" : "Administrationskonto adgangskode",
@@ -394,6 +412,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} valgt)",
     "Error loading file exists template" : "Fejl ved indlæsning af 'fil eksisterer' skabelon",
     "Saving …" : "Gemmer …",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Gruppelisten er tom",
+    "Unable to retrieve the group list" : "Kan ikke hente gruppelisten",
     "seconds ago" : "få sekunder siden",
     "Connection to server lost" : "Forbindelsen til serveren er tabt",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Der opstod et problem med at hente siden, prøver igen om %n sekund","Der opstod et problem med at hente siden, prøver igen om %n sekunder"],
@@ -444,25 +465,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Skip til navigation af app",
     "Go to %s" : "Gå til %s",
     "Get your own free account" : "Få din egen gratis konto",
-    "Connect to your account" : "Forbind til din konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Log venligst ind for at tildele %1$s adgang til din %2$s konto.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke er igang med at konfigurerer en ny enhed eller app, så er der nogen som forsøger at snyde dig til at give dem adgang til dine data. I dette filfælde skal du ikke forsætte, men istedet kontakte din system administrator.",
-    "App password" : "App adgangskode",
-    "Grant access" : "Giv adgang",
-    "Alternative log in using app password" : "Alternativ login med app adgangskode",
-    "Account access" : "Konto adgang",
-    "Currently logged in as %1$s (%2$s)." : "Logget ind som %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du er ved at tildele %1$s adgang til din %2$s konto.",
-    "Account connected" : "Kontoen er tilknyttet",
-    "Your client should now be connected!" : "Din klient burde være forbundet nu!",
-    "You can close this window." : "Du kan lukke dette vindue",
     "Previous" : "Tidligere",
-    "This share is password-protected" : "Delingen er beskyttet af kodeord",
-    "The password is wrong or expired. Please try again or request a new one." : "Adgangskoden er forkert eller udløbet. Forsøg venligst igen eller anmod om et nyt.",
-    "Please type in your email address to request a temporary password" : "Indtast venligst din e-mailadresse for at anmode om en midlertidigt adgangskode",
-    "Email address" : "Email adresse",
-    "Password sent!" : "Adgangskode sendt!",
-    "You are not authorized to request a password for this share" : "Du er ikke godkendt til at anmode om en adgangskode til denne delte mappe",
     "Two-factor authentication" : "To-faktor autentificering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Forbedret sikkerhed er aktiveret for din konto. Vælg en nummer to faktor til autentifikation.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunne ikke indlæse mindst en af dine aktiverede to-faktor adgangsmetoder. Kontakt venligst din administrator.",
@@ -508,6 +511,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Direkte link kopieret til udklipsholder",
     "Searching …" : "Søger …",
     "Logging in …" : "Logger ind …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har registreret flere ugyldige loginforsøg fra din IP. Derfor bliver din næste login sat op til 30 sekunder.",
     "Loading apps …" : "Henter apps ...",
     "Installing apps …" : "Installerer apps ...",
     "Loading your contacts …" : "Henter dine kontakter …",
@@ -539,6 +543,9 @@ OC.L10N.register(
     "Configure the database" : "Konfigurer databasen",
     "Only %s is available." : "Kun %s er tilgængelig.",
     "Database account" : "Database konto",
-    "Installing …" : "Installerer..."
+    "Installing …" : "Installerer...",
+    "Please log in before granting %1$s access to your %2$s account." : "Log venligst ind for at tildele %1$s adgang til din %2$s konto.",
+    "Currently logged in as %1$s (%2$s)." : "Logget ind som %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Du er ved at tildele %1$s adgang til din %2$s konto."
 },
 "nplurals=2; plural=(n != 1);");
