@@ -74,11 +74,13 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
     "Continue to {productName}" : "Continuar a {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundo.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos."],
+    "Done" : "Hecho",
     "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
     "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
     "No" : "No",
     "Yes" : "Sí",
+    "Grant access" : "Conceder acceso",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el enlace público a tu Nextcloud",
     "Create share" : "Crear compartición",
     "Start typing to search" : "Empieza a escribir para buscar",
@@ -91,7 +93,6 @@ OC.L10N.register(
     "Load more results" : "Cargar más resultados",
     "Log in" : "Ingresar",
     "Log in to {productName}" : "Iniciar sesión en {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Account name or email" : "Nombre de cuenta o correo electrónico",
     "Account name" : "Nombre de la cuenta",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
@@ -150,8 +151,23 @@ OC.L10N.register(
     "Back to login form" : "Volver al formulario de inicio de sesión",
     "Back" : "Atrás",
     "Login form is disabled." : "El formulario de inicio de sesión está desactivado.",
-    "More actions" : "Más acciones",
+    "Connect to your account" : "Conectate a tu cuenta",
     "Security warning" : "Advertencia de seguridad",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no estás intentando configurar un nuevo dispositivo o aplicación, alguien está tratando de engañarte para que les otorgues acceso a tus datos. En este caso, no continúes y, en su lugar, contacta a tu administrador del sistema.",
+    "Account connected" : "Cuenta conectada",
+    "Your client should now be connected!" : "¡Tu cliente ahora debería estar conectado!",
+    "You can close this window." : "Puedes cerrar esta ventana.",
+    "Account access" : "Acceo de cuenta",
+    "More actions" : "Más acciones",
+    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
+    "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtalo de nuevo o solicita una nueva.",
+    "Submit" : "Enviar",
+    "Please type in your email address to request a temporary password" : "Por favor, ingresa tu dirección de correo electrónico para solicitar una contraseña temporal",
+    "Password sent!" : "¡Contraseña enviada!",
+    "You are not authorized to request a password for this share" : "No estás autorizado para solicitar una contraseña para esta compartición",
+    "Email address" : "Dirección de correo electrónico",
+    "Request password" : "Solicitar contraseña",
+    "Forgot password" : "Olividaste tu contraseña",
     "Storage & database" : "Almacenamiento & base de datos",
     "Data folder" : "Carpeta de datos",
     "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
@@ -191,6 +207,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
     "Saving …" : "Guardando...",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
@@ -237,23 +256,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Saltar a la navegación de la aplicación",
     "Go to %s" : "Ir a %s",
     "Get your own free account" : "Obtén tu propia cuenta gratuita",
-    "Connect to your account" : "Conectate a tu cuenta",
-    "Please log in before granting %1$s access to your %2$s account." : "Inicia sesión antes de otorgar acceso a %1$s a tu cuenta de %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no estás intentando configurar un nuevo dispositivo o aplicación, alguien está tratando de engañarte para que les otorgues acceso a tus datos. En este caso, no continúes y, en su lugar, contacta a tu administrador del sistema.",
-    "Grant access" : "Conceder acceso",
-    "Account access" : "Acceo de cuenta",
-    "Currently logged in as %1$s (%2$s)." : "Actualmente iniciado sesión como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de otorgar acceso a %1$s a tu cuenta de %2$s.",
-    "Account connected" : "Cuenta conectada",
-    "Your client should now be connected!" : "¡Tu cliente ahora debería estar conectado!",
-    "You can close this window." : "Puedes cerrar esta ventana.",
     "Previous" : "Previo",
-    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
-    "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtalo de nuevo o solicita una nueva.",
-    "Please type in your email address to request a temporary password" : "Por favor, ingresa tu dirección de correo electrónico para solicitar una contraseña temporal",
-    "Email address" : "Dirección de correo electrónico",
-    "Password sent!" : "¡Contraseña enviada!",
-    "You are not authorized to request a password for this share" : "No estás autorizado para solicitar una contraseña para esta compartición",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Se ha habilitado una seguridad mejorada para tu cuenta. Elige un segundo factor para la autenticación:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No se pudieron cargar al menos uno de tus métodos de autenticación de dos factores habilitados. Por favor, contacta a tu administrador.",
@@ -297,6 +300,7 @@ OC.L10N.register(
     "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
     "Searching …" : "Buscando...",
     "Logging in …" : "Iniciando sesión ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Loading apps …" : "Cargando aplicaciones...",
     "Installing apps …" : "Instalando aplicaciones...",
     "Loading your contacts …" : "Cargando sus contactos ... ",
@@ -324,6 +328,9 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar visibilidad de contraseña",
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Sólo %s está disponible.",
-    "Installing …" : "Instalando..."
+    "Installing …" : "Instalando...",
+    "Please log in before granting %1$s access to your %2$s account." : "Inicia sesión antes de otorgar acceso a %1$s a tu cuenta de %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Actualmente iniciado sesión como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de otorgar acceso a %1$s a tu cuenta de %2$s."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
