@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
     "Invalid image" : "Imagen inválida",
-    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
-    "No crop data provided" : "No se han proporcionado datos del recorte",
-    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
-    "Crop is not square" : "El recorte no es cuadrado",
     "State token does not match" : "La ficha de estado no corresponde",
     "Invalid app password" : "Contraseña de app inválida",
     "Could not complete login" : "No se pudo completar el inicio de sesión",
@@ -81,16 +77,6 @@ OC.L10N.register(
     "Already up to date" : "Ya está actualizado",
     "Unknown" : "Desconocido",
     "PNG image" : "Imagen PNG",
-    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles, consulte la {linkstart}documentación ↗{linkend}.",
-    "unknown text" : "texto desconocido",
-    "Hello world!" : "¡Hola mundo!",
-    "sunny" : "soleado",
-    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
-    "Hello {name}" : "Hola {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
-    "new" : "nuevo",
-    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
     "Update to {version}" : "Actualizar a {version}",
     "An error occurred." : "Se presentó un error.",
@@ -99,12 +85,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
     "Continue to {productName}" : "Continuar a {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización fue exitosa. Redireccionando a {productName} en %n segundo.","La actualización fue exitosa. Redireccionando a {productName} en %n segundos.","La actualización fue exitosa. Redireccionando a {productName} en %n segundos."],
+    "Done" : "Terminado",
     "Applications menu" : "Menú de aplicaciones",
     "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
     "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
     "No" : "No",
     "Yes" : "Sí",
+    "App password" : "Contraseña de la aplicación",
+    "Grant access" : "Conceder acceso",
     "The remote URL must include the user." : "La URL remota debe incluir el usuario.",
     "Invalid remote URL." : "URL remota inválida.",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
@@ -119,7 +108,6 @@ OC.L10N.register(
     "Search in current app" : "Buscar en la aplicación actual",
     "Clear search" : "Limpiar búsqueda",
     "Search everywhere" : "Buscar en todas partes",
-    "Searching …" : "Buscando  …",
     "Start typing to search" : "Empiece a escribir para buscar",
     "No matching results" : "No se encontraron coincidencias",
     "Today" : "Hoy",
@@ -138,11 +126,9 @@ OC.L10N.register(
     "Load more results" : "Cargar más resultados",
     "Search in" : "Buscar en",
     "Log in" : "Ingresar",
-    "Logging in …" : "Iniciando sesión ...",
     "Log in to {productName}" : "Iniciar sesión en {productName}",
     "Wrong login or password." : "Nombre de usuario o contraseña equivocado. ",
     "This account is disabled" : "Esta cuenta está deshabilitada",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Account name or email" : "Nombre de cuenta o correo electrónico",
     "Account name" : "Nombre de cuenta",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
@@ -173,21 +159,23 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, creados en Collabora Online.",
     "Distraction free note taking app." : "Aplicación de notas sin distracciones.",
     "Recommended apps" : "Aplicaciones recomendadas",
-    "Loading apps …" : "Cargando aplicaciones ...",
     "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de aplicaciones de la App Store.",
     "App download or installation failed" : "Error al descargar o instalar la aplicación",
     "Cannot install this app because it is not compatible" : "No se puede instalar esta aplicación porque no es compatible",
     "Cannot install this app" : "No se puede instalar esta aplicación",
     "Skip" : "Saltar",
-    "Installing apps …" : "Instalando aplicaciones ...",
     "Install recommended apps" : "Instalar las aplicaciones recomendadas",
+    "Online" : "En línea",
+    "Away" : "Ausente",
+    "Busy" : "Ocupado",
+    "Do not disturb" : "No molestar",
+    "Mute all notifications" : "Silenciar todas las notificaciones",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Aparecer como desconectado",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menú de Configuraciones",
-    "Loading your contacts …" : "Cargando sus contactos ... ",
-    "Looking for {term} …" : "Buscando {term} ...",
     "Search contacts" : "Buscar contactos",
     "Reset search" : "Reestablecer búsqueda",
-    "Search contacts …" : "Buscar contactos ...",
     "Could not load your contacts" : "No fue posible cargar tus contactos",
     "No contacts found" : "No se encontraron contactos",
     "Show all contacts" : "Mostrar todos los contactos",
@@ -199,14 +187,28 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Ocurrió un error mientras se buscaba {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La búsqueda empieza una vez que comienza a escribir y los resultados pueden seleccionarse con las teclas direccionales",
     "Search for {name} only" : "Buscar sólo por {name}",
-    "Loading more results …" : "Cargando más resultados ...",
     "Forgot password?" : "¿Olvidaste tu contraseña?",
     "Back to login form" : "Regresar al inicio de sesión",
     "Back" : "Atrás",
     "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulario de inicio de sesión de Nextcloud está deshabilitado. Use otro medio de inicio de sesión disponible o contacte a su administración.",
-    "More actions" : "Más acciones",
+    "Connect to your account" : "Conectate a tu cuenta",
     "Security warning" : "Advertencia de seguridad",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no está intentando configurar un nuevo dispositivo o aplicación, alguien está tratando de engañarlo para que le otorgue acceso a sus datos. En este caso, no continúe y, en su lugar, contacte a su administrador del sistema.",
+    "Alternative log in using app password" : "Inicio de sesión alternativo usando la contraseña de la aplicación",
+    "Account connected" : "Cuenta conectada",
+    "Your client should now be connected!" : "¡Su cliente ahora debería estar conectado ahora!",
+    "You can close this window." : "Puede cerrar esta ventana.",
+    "Account access" : "Acceo de cuenta",
+    "More actions" : "Más acciones",
+    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
+    "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtelo de nuevo o solicite una nueva.",
+    "Submit" : "Enviar",
+    "Please type in your email address to request a temporary password" : "Por favor, ingrese su dirección de correo electrónico para solicitar una contraseña temporal",
+    "Password sent!" : "¡Contraseña enviada!",
+    "You are not authorized to request a password for this share" : "No está autorizado para solicitar una contraseña para este recurso compartido",
+    "Email address" : "Dirección de correo electrónico",
+    "Forgot password" : "Olividaste tu contraseña",
     "Storage & database" : "Almacenamiento & base de datos",
     "Data folder" : "Carpeta de datos",
     "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
@@ -221,7 +223,6 @@ OC.L10N.register(
     "Database tablespace" : "Espacio de tablas en la base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
     "Database host" : "Servidor de base de datos",
-    "Installing …" : "Instalando ...",
     "Install" : "Instalar",
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
@@ -230,7 +231,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualícelo a una versión más nueva o una soportada.",
     "Continue with this unsupported browser" : "Continuar con este navegador no soportado",
     "Supported versions" : "Versiones soportadas",
-    "Search {types} …" : "Buscar {types} ...",
     "Choose {file}" : "Elegir {file}",
     "Choose" : "Seleccionar",
     "Copy to {target}" : "Copiar a {target}",
@@ -250,7 +250,9 @@ OC.L10N.register(
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
-    "Saving …" : "Guardando ...",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La lista de Grupo está vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
@@ -265,17 +267,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escriba para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver el registro de cambios",
-    "No action available" : "No hay acciones disponibles",
-    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "La longitud de correo electrónico está en su límite (255)",
-    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "Restricted" : "Restringido",
-    "Invisible" : "Invisible",
-    "Delete" : "Borrar",
-    "Rename" : "Renombrar",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "No se encontraron etiquetas",
     "Clipboard not available, please copy manually" : "Portapapeles no disponible, por favor copie manualmente",
     "Personal" : "Personal",
     "Accounts" : "Cuentas",
@@ -309,25 +302,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Saltar a la navegación de la aplicación",
     "Go to %s" : "Ir a %s",
     "Get your own free account" : "Obtenga su propia cuenta gratuita",
-    "Connect to your account" : "Conectate a tu cuenta",
-    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no está intentando configurar un nuevo dispositivo o aplicación, alguien está tratando de engañarlo para que le otorgue acceso a sus datos. En este caso, no continúe y, en su lugar, contacte a su administrador del sistema.",
-    "App password" : "Contraseña de la aplicación",
-    "Grant access" : "Conceder acceso",
-    "Alternative log in using app password" : "Inicio de sesión alternativo usando la contraseña de la aplicación",
-    "Account access" : "Acceo de cuenta",
-    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Está a punto de conceder a %1$s acceso a su cuenta %2$s.",
-    "Account connected" : "Cuenta conectada",
-    "Your client should now be connected!" : "¡Su cliente ahora debería estar conectado ahora!",
-    "You can close this window." : "Puede cerrar esta ventana.",
     "Previous" : "Previo",
-    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
-    "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtelo de nuevo o solicite una nueva.",
-    "Please type in your email address to request a temporary password" : "Por favor, ingrese su dirección de correo electrónico para solicitar una contraseña temporal",
-    "Email address" : "Dirección de correo electrónico",
-    "Password sent!" : "¡Contraseña enviada!",
-    "You are not authorized to request a password for this share" : "No está autorizado para solicitar una contraseña para este recurso compartido",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguridad mejorada está habilitada para su cuenta. Elija una segunda forma de autentificación:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No se pudo cargar al menos uno de sus métodos de autentificación de dos factores. Por favor, contacte a su administrador.",
@@ -360,19 +335,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones en línea y conferencias web – en su navegador y aplicaciones móviles.",
-    "You have not added any info yet" : "Aún no has añadido información",
-    "{user} has not added any info yet" : "{user} aún no añade información",
-    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
-    "Edit Profile" : "Editar perfil",
-    "The headline and about sections will show up here" : "El encabezado y la sección Acerca de aparecerán aquí",
+    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles, consulte la {linkstart}documentación ↗{linkend}.",
+    "unknown text" : "texto desconocido",
+    "Hello world!" : "¡Hola mundo!",
+    "sunny" : "soleado",
+    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
+    "Hello {name}" : "Hola {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
+    "new" : "nuevo",
+    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
+    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles",
+    "Searching …" : "Buscando  …",
+    "Logging in …" : "Iniciando sesión ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
+    "Loading apps …" : "Cargando aplicaciones ...",
+    "Installing apps …" : "Instalando aplicaciones ...",
+    "Loading your contacts …" : "Cargando sus contactos ... ",
+    "Looking for {term} …" : "Buscando {term} ...",
+    "Search contacts …" : "Buscar contactos ...",
+    "Loading more results …" : "Cargando más resultados ...",
+    "Search {types} …" : "Buscar {types} ...",
+    "Saving …" : "Guardando ...",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe.",
+    "No action available" : "No hay acciones disponibles",
+    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
+    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
+    "Restricted" : "Restringido",
+    "Delete" : "Borrar",
+    "Rename" : "Renombrar",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "No se encontraron etiquetas",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "Show password" : "Mostrar contraseña",
@@ -380,6 +377,9 @@ OC.L10N.register(
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Sólo %s está disponible.",
     "Database account" : "Cuenta de la base de datos",
-    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles"
+    "Installing …" : "Instalando ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Está a punto de conceder a %1$s acceso a su cuenta %2$s."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
