@@ -344,6 +344,15 @@ OC.L10N.register(
     "You are currently not identified." : "Une honetan identifikatu gabe zaude.",
     "Set public name" : "Ezarri izen publikoa",
     "Change public name" : "Aldatu izen publikoa",
+    "This share is password-protected" : "Partekatze hau pasahitzez babestua dago.",
+    "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
+    "Submit" : "Bidali",
+    "Please type in your email address to request a temporary password" : "Idatzi zure helbide elektronikoa aldi baterako pasahitza eskatzeko",
+    "Password sent!" : "Pasahitza bidalita!",
+    "You are not authorized to request a password for this share" : "Ez duzu baimenik partekatze honetarako pasahitza eskatzeko",
+    "Email address" : "Helbide elektronikoa",
+    "Request password" : "Eskatu pasahitza",
+    "Forgot password" : "Pasahitza ahaztu",
     "Password is too weak" : "Pasahitza oso ahula da",
     "Password is weak" : "Pasahitza ahula da",
     "Password is average" : "Pasahitzak tarteko indarra du",
@@ -461,12 +470,6 @@ OC.L10N.register(
     "Go to %s" : "Joan %s-ra",
     "Get your own free account" : "Eskuratu zure kontu propioa doan",
     "Previous" : "Aurrekoa",
-    "This share is password-protected" : "Partekatze hau pasahitzez babestua dago.",
-    "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
-    "Please type in your email address to request a temporary password" : "Idatzi zure helbide elektronikoa aldi baterako pasahitza eskatzeko",
-    "Email address" : "Helbide elektronikoa",
-    "Password sent!" : "Pasahitza bidalita!",
-    "You are not authorized to request a password for this share" : "Ez duzu baimenik partekatze honetarako pasahitza eskatzeko",
     "Two-factor authentication" : "Bi faktoreko autentifikazioa",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Segurtasun hobetua gaituta dago zure kontuan. Aukeratu autentifikaziorako bigarren faktore bat:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ezin izan da kargatu zure bi faktoreko autentifikazio metodoetako bat gutxienez. Jarri harremanetan zure administratzailearekin.",
