@@ -203,12 +203,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
     "Continue to {productName}" : "به {productName} ادامه دهید.",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید.","به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید."],
+    "Done" : "Done",
     "Applications menu" : "منو برنامه‌ها.",
     "Apps" : "  برنامه ها",
     "More apps" : "برنامه های بیشتر",
     "_{count} notification_::_{count} notifications_" : ["{count} اعلان.","{count} اعلان."],
     "No" : "نه",
     "Yes" : "بله",
+    "App password" : "گذرواژه برنامه",
+    "Grant access" : " مجوز اعطا دسترسی",
     "The remote URL must include the user." : "آدرس URL راه دور باید شامل کاربر باشد.",
     "Invalid remote URL." : "آدرس URL راه دور نامعتبر است.",
     "Failed to add the public link to your Nextcloud" : "خطا در افزودن آدرس عمومی به نکست‌کلود شما.",
@@ -223,6 +226,7 @@ OC.L10N.register(
     "Search in current app" : "جستجو در برنامه فعلی.",
     "Clear search" : "پاک کردن جستجو.",
     "Search everywhere" : "جستجو در هر کجا.",
+    "Searching …" : "درحال جستجو",
     "Start typing to search" : "برای جستجو شروع به تایپ کنید.",
     "No matching results" : "نتیجه مطابق یافت نشد.",
     "Today" : "امروز.",
@@ -244,7 +248,6 @@ OC.L10N.register(
     "Log in to {productName}" : "ورود به {productName}.",
     "Wrong login or password." : "نام کاربری یا رمز عبور اشتباه است.",
     "This account is disabled" : "این حساب کاربری غیرفعال است.",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
     "Account name or email" : "نام کاربری یا آدرس ایمیل.",
     "Account name" : "نام حساب.",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
@@ -283,6 +286,13 @@ OC.L10N.register(
     "Cannot install this app" : "نمی توان این برنامه را نصب کرد.",
     "Skip" : "پرش.",
     "Install recommended apps" : "نصب کاره‌های پیشنهادی.",
+    "Online" : "برخط",
+    "Away" : "دور از دسترس",
+    "Busy" : "مشغول",
+    "Do not disturb" : "مزاحم نشوید",
+    "Mute all notifications" : "خاموش کردن همه اعلانات",
+    "Invisible" : "غیر قابل مشاهده",
+    "Appear offline" : "نمایش آفلاین",
     "Avatar of {displayName}" : "نمایه {displayName}.",
     "Settings menu" : "فهرست تنظیمات.",
     "Search contacts" : "جستجوی مخاطبین.",
@@ -303,7 +313,24 @@ OC.L10N.register(
     "Back" : "بازگشت.",
     "Login form is disabled." : "فرم ورود غیرفعال است.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "فرم ورود Nextcloud غیرفعال است. در صورت امکان از گزینه ورود دیگری استفاده کنید یا با مدیریت خود تماس بگیرید.",
+    "Connect to your account" : "به حساب کاربری خود متصل شوید",
+    "Security warning" : "اخطار امنیتی",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "اگر قصد راه‌اندازی دستگاه یا برنامه جدیدی را ندارید، شخصی در تلاش است تا شما را فریب دهد تا به داده‌هایتان دسترسی پیدا کند. در این صورت ادامه ندهید و به جای آن با مدیر سیستم خود تماس بگیرید.",
+    "Alternative log in using app password" : "ورود جایگزین با استفاده از گذرواژه برنامه",
+    "Account connected" : "حساب کاربری متصل شد",
+    "Your client should now be connected!" : "اکنون مشتری شما باید متصل شده باشد!",
+    "You can close this window." : "می‌توانید این پنجره را ببندید.",
+    "Account access" : "دسترسی به حساب",
     "More actions" : "اقدامات بیشتر.",
+    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
+    "The password is wrong or expired. Please try again or request a new one." : "رمز عبور اشتباه است یا منقضی شده است. لطفا دوباره تلاش کنید یا رمز عبور جدیدی درخواست دهید.",
+    "Submit" : "ارسال",
+    "Please type in your email address to request a temporary password" : "لطفاً آدرس ایمیل خود را برای درخواست گذرواژه موقت وارد کنید",
+    "Password sent!" : "گذرواژه ارسال شد!",
+    "You are not authorized to request a password for this share" : "شما مجاز به درخواست گذرواژه برای این اشتراک نیستید",
+    "Email address" : "آدرس ایمیل",
+    "Request password" : "Request password",
+    "Forgot password" : "فراموشی رمز عبور",
     "Password is too weak" : "رمز عبور بسیار ضعیف است.",
     "Password is weak" : "رمز عبور ضعیف است.",
     "Password is average" : "رمز عبور متوسط است.",
@@ -315,7 +342,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "برای اطلاعات بیشتر در مورد نحوه پیکربندی صحیح سرور خود، لطفاً {linkStart}مستندات را ببینید{linkEnd}.",
     "Autoconfig file detected" : "فایل تنظیم خودکار شناسایی شد.",
     "The setup form below is pre-filled with the values from the config file." : "فرم تنظیمات زیر با مقادیر موجود در فایل پیکربندی از قبل پر شده است.",
-    "Security warning" : "اخطار امنیتی",
     "Create administration account" : "ایجاد حساب کاربری مدیریت.",
     "Administration account name" : "نام حساب کاربری مدیریت.",
     "Administration account password" : "رمز عبور حساب کاربری مدیریت.",
@@ -364,6 +390,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} انتخاب شده)",
     "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
     "Saving …" : "در حال ذخیره",
+    "Groups" : "گروه ها",
+    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
+    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
     "seconds ago" : "ثانیه‌ها پیش",
     "Connection to server lost" : "اتصال به سرور از دست رفته است",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
@@ -413,25 +442,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "پرش به ناوبری برنامه",
     "Go to %s" : "برو به %s",
     "Get your own free account" : "حساب کاربری رایگان خود را دریافت کنید",
-    "Connect to your account" : "به حساب کاربری خود متصل شوید",
-    "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "اگر قصد راه‌اندازی دستگاه یا برنامه جدیدی را ندارید، شخصی در تلاش است تا شما را فریب دهد تا به داده‌هایتان دسترسی پیدا کند. در این صورت ادامه ندهید و به جای آن با مدیر سیستم خود تماس بگیرید.",
-    "App password" : "گذرواژه برنامه",
-    "Grant access" : " مجوز اعطا دسترسی",
-    "Alternative log in using app password" : "ورود جایگزین با استفاده از گذرواژه برنامه",
-    "Account access" : "دسترسی به حساب",
-    "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
-    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید.",
-    "Account connected" : "حساب کاربری متصل شد",
-    "Your client should now be connected!" : "اکنون مشتری شما باید متصل شده باشد!",
-    "You can close this window." : "می‌توانید این پنجره را ببندید.",
     "Previous" : "قبلی",
-    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
-    "The password is wrong or expired. Please try again or request a new one." : "رمز عبور اشتباه است یا منقضی شده است. لطفا دوباره تلاش کنید یا رمز عبور جدیدی درخواست دهید.",
-    "Please type in your email address to request a temporary password" : "لطفاً آدرس ایمیل خود را برای درخواست گذرواژه موقت وارد کنید",
-    "Email address" : "آدرس ایمیل",
-    "Password sent!" : "گذرواژه ارسال شد!",
-    "You are not authorized to request a password for this share" : "شما مجاز به درخواست گذرواژه برای این اشتراک نیستید",
     "Two-factor authentication" : "احراز هویت دو مرحله‌ای",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "امنیت پیشرفته برای حساب شما فعال شده است. عامل دوم را برای احراز هویت انتخاب کنید:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "حداقل یکی از روش‌های احراز هویت دو عاملی فعال شما بارگذاری نشد. لطفاً با مدیر خود تماس بگیرید.",
@@ -476,6 +487,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "لینک مستقیم در کلیپ‌بورد کپی شد.",
     "Searching …" : "جستجوکردن …",
     "Logging in …" : "ورود به سیستم ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
     "Loading apps …" : "در حال بارگذاری برنامه ها... .",
     "Installing apps …" : "در حال نصب برنامه.",
     "Loading your contacts …" : "بارگیری مخاطبین شما ...",
@@ -493,7 +505,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
     "Restricted" : "محدود شده",
-    "Invisible" : "غیر قابل مشاهده",
     "Delete" : "حذف",
     "Rename" : "تغییرنام",
     "Collaborative tags" : "برچسب های همکاری",
@@ -508,6 +519,9 @@ OC.L10N.register(
     "Configure the database" : "پایگاه داده برنامه ریزی شدند",
     "Only %s is available." : "تنها %s موجود است.",
     "Database account" : "حساب پایگاه داده",
-    "Installing …" : "درحال نصب..."
+    "Installing …" : "درحال نصب...",
+    "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
+    "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
+    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید."
 },
 "nplurals=2; plural=(n > 1);");
