@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
     "Invalid image" : "Virheellinen kuva",
-    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
-    "No crop data provided" : "Leikkaustietoa ei annettu",
-    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
-    "Crop is not square" : "Leikkaus ei ole neliö",
     "State token does not match" : "Tilapoletti ei täsmää",
     "Invalid app password" : "Virheellinen sovellussalasana",
     "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
@@ -42,21 +38,23 @@ OC.L10N.register(
     "Internal error" : "Sisäinen virhe",
     "Not found" : "Ei löytynyt",
     "Bad request" : "Virheellinen pyyntö",
+    "Input text is too long" : "Syöteteksti on liian pitkä",
+    "Requested task type does not exist" : "Pyydettyä tehtävätyyppiä ei ole olemassa",
     "Image not found" : "Kuvaa ei löytynyt",
     "No translation provider available" : "Käännöksen palveluntarjoaja ei ole saatavilla",
     "Could not detect language" : "Kielen havaitseminen ei onnistunut",
     "Unable to translate" : "Kääntäminen ei onnistu",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Korjausvaihe:",
+    "Repair info:" : "Korjaustiedot:",
+    "Repair warning:" : "Korjausvaroitus:",
+    "Repair error:" : "Korjausvirhe:",
     "Nextcloud Server" : "Nextcloud-palvelin",
     "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
     "The account limit of this instance is reached." : "Tämän instanssin tiliraja on täynnä.",
     "Learn more ↗" : "Lue lisää ↗",
     "Preparing update" : "Valmistellaan päivitystä",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Korjausvaihe:",
-    "Repair info:" : "Korjaustiedot:",
-    "Repair warning:" : "Korjausvaroitus:",
-    "Repair error:" : "Korjausvirhe:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Käytä komentorivipäivitintä, koska päivitys selainkäyttöliittymällä on estetty config.php-asetustiedostossa.",
     "Turned on maintenance mode" : "Siirrytty huoltotilaan",
     "Turned off maintenance mode" : "Poistuttu huoltotilasta",
@@ -73,16 +71,96 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ei yhteensopiva)",
     "The following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
     "Already up to date" : "Kaikki on jo ajan tasalla",
-    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Lue lisätietoja {linkstart}dokumentaatiosta ↗{linkend}.",
-    "unknown text" : "tuntematon teksti",
-    "Hello world!" : "Hei maailma!",
-    "sunny" : "aurinkoinen",
-    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
-    "Hello {name}" : "Hei {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
-    "new" : "uusi",
-    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
+    "TrueType Font Collection" : "TrueType-fonttikokoelma",
+    "Gzip archive" : "Gzip-arkisto",
+    "Adobe Illustrator document" : "Adobe Illustrator -asiakirja",
+    "Java source code" : "Java-lähdekoodi ",
+    "JavaScript source code" : "JavaScript-lähdekoodi",
+    "JSON document" : "JSON-dokumentti",
+    "Microsoft Access database" : "Microsoft Access -tietokanta",
+    "Microsoft OneNote document" : "Microsoft OneNote -asiakirja",
+    "Microsoft Word document" : "Microsoft Word -asiakirja",
+    "Unknown" : "Tuntematon",
+    "PDF document" : "PDF-asiakirja",
+    "PostScript document" : "PostScript-asiakirja",
+    "Android package" : "Android-paketti",
+    "Lotus Word Pro document" : "Lotus Word Pro -asiakirja",
+    "Excel spreadsheet" : "Excel-taulukko",
+    "Excel add-in" : "Excel-lisäosa",
+    "Excel spreadsheet template" : "Excel-taulukkopohja",
+    "Outlook Message" : "Outlook-viesti",
+    "PowerPoint presentation" : "PowerPoint-esitys",
+    "PowerPoint add-in" : "PowerPoint-lisäosa",
+    "PowerPoint presentation template" : "PowerPoint-esityspohja",
+    "Word document" : "Word-asiakirja",
+    "ODG drawing" : "ODG-piirros",
+    "ODG template" : "ODG-mallipohja",
+    "ODP presentation" : "ODP-esitys",
+    "ODP template" : "ODP-mallipohja",
+    "ODS spreadsheet" : "ODS-taulukko",
+    "ODS template" : "ODS-mallipohja",
+    "ODT document" : "ODT-asiakirja",
+    "ODT template" : "ODT-mallipohja",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 -esitys",
+    "Excel 2007 spreadsheet" : "Excel 2007 -taulukko",
+    "Word 2007 document" : "Word 2007 -asiakirja",
+    "Microsoft Visio document" : "Microsoft Visio -asiakirja",
+    "WordPerfect document" : "WordPerfect-asiakirja",
+    "7-zip archive" : "7-zip-arkisto",
+    "Bzip2 archive" : "Bzip2-arkisto",
+    "Debian package" : "Debian-paketti",
+    "FictionBook document" : "FictionBook-asiakirja",
+    "Unknown font" : "Tuntematon fontti",
+    "Krita document" : "Krita-asiakirja",
+    "Windows Installer package" : "Windows Installer -paketti",
+    "Perl script" : "Perl-skripti ",
+    "PHP script" : "PHP-skripti",
+    "Tar archive" : "Tar-arkisto",
+    "XML document" : "XML-asiakirja",
+    "YAML document" : "YAML-asiakirja",
+    "Zip archive" : "Zip-arkisto",
+    "AAC audio" : "AAC-ääni",
+    "FLAC audio" : "FLAC-ääni",
+    "MPEG-4 audio" : "MPEG-4-ääni",
+    "MP3 audio" : "MP3-ääni",
+    "Ogg audio" : "Ogg-ääni",
+    "WebM audio" : "WebM-ääni",
+    "Windows BMP image" : "Windows BMP -kuva",
+    "EMF image" : "EMF-kuva",
+    "GIF image" : "GIF-kuva",
+    "HEIC image" : "HEIC-kuva",
+    "HEIF image" : "HEIF-kuva",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 -kuva",
+    "JPEG image" : "JPEG-kuva",
+    "PNG image" : "PNG-kuva",
+    "SVG image" : "SVG-kuva",
+    "Truevision Targa image" : "Truevision Targa -kuva",
+    "TIFF image" : "TIFF-kuva",
+    "WebP image" : "WebP-kuva",
+    "Windows Icon" : "Windows-kuvake",
+    "Email message" : "Sähköpostiviesti",
+    "VCS/ICS calendar" : "VCS/ICS-kalenteri",
+    "CSS stylesheet" : "CSS-tyylisivu",
+    "CSV document" : "CSV-asiakirja",
+    "HTML document" : "HTML-asiakirja",
+    "Markdown document" : "Markdown-asiakirja",
+    "Electronic business card" : "Sähköinen käyntikortti",
+    "C++ source code" : "C++-lähdekoodi",
+    "LDIF address book" : "LDIF-osoitekirja",
+    "NFO document" : "NFO-asiakirja",
+    "PHP source" : "PHP-lähde",
+    "Python script" : "Python-skripti",
+    "ReStructuredText document" : "ReStructuredText-asiakirja",
+    "3GPP multimedia file" : "3GPP-multimediatiedosto",
+    "MPEG video" : "MPEG-video",
+    "MPEG-4 video" : "MPEG-4-video",
+    "Ogg video" : "Ogg-video",
+    "QuickTime video" : "QuickTime-video",
+    "WebM video" : "WebM-video",
+    "Flash video" : "Flash-video",
+    "Matroska video" : "Matroska-video",
+    "Windows Media video" : "Windows Media -video",
+    "AVI video" : "AVI-video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
     "Update to {version}" : "Päivitä versioon {version}",
     "An error occurred." : "Tapahtui virhe.",
@@ -91,17 +169,20 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
     "Continue to {productName}" : "Jatka {productName}iin",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
+    "Done" : "Valmis",
     "Applications menu" : "Sovellusten valikko",
     "Apps" : "Sovellukset",
     "More apps" : "Lisää sovelluksia",
     "_{count} notification_::_{count} notifications_" : ["{count} ilmoitus","{count} ilmoitusta"],
     "No" : "Ei",
     "Yes" : "Kyllä",
+    "App password" : "Sovellussalasana",
+    "Grant access" : "Myönnä pääsy",
     "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
     "Federated user" : "Federoitu käyttäjä",
     "user@your-nextcloud.org" : "käyttäjä@oma-nextcloud.org",
     "Create share" : "Luo jako",
-    "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle",
+    "Direct link copied" : "Suora linkki kopioitu",
     "Please copy the link manually:" : "Kopioi linkki manuaalisesti:",
     "Custom date range" : "Mukautettu päivämääräväli",
     "Pick start date" : "Valitse aloituspäivä",
@@ -110,7 +191,7 @@ OC.L10N.register(
     "Search in current app" : "Etsi nykyisessä sovelluksessa",
     "Clear search" : "Tyhjennä haku",
     "Search everywhere" : "Etsi kaikkialta",
-    "Searching …" : "Haetaan…",
+    "Searching …" : "Haetaan …",
     "Start typing to search" : "Aloita kirjoittaminen hakeaksesi",
     "No matching results" : "Ei tuloksia",
     "Today" : "Tänään",
@@ -118,6 +199,7 @@ OC.L10N.register(
     "Last 30 days" : "Edelliset 30 päivää",
     "This year" : "Tämä vuosi",
     "Last year" : "Viime vuosi",
+    "Between {startDate} and {endDate}" : "Välillä {startDate} ja {endDate}",
     "Unified search" : "Yhdistetty haku",
     "Search apps, files, tags, messages" : "Etsi sovelluksia, tiedostoja, tunnisteita, viestejä",
     "Places" : "Sijainnit",
@@ -129,11 +211,10 @@ OC.L10N.register(
     "Load more results" : "Lataa lisää tuloksia",
     "Search in" : "Etsi kohteesta",
     "Log in" : "Kirjaudu sisään",
-    "Logging in …" : "Kirjaudutaan sisään...",
+    "Logging in …" : "Kirjaudutaan …",
     "Log in to {productName}" : "Kirjaudu palveluun {productName}",
     "Wrong login or password." : "Väärä käyttäjätunnus tai salasana.",
     "This account is disabled" : "Tämä tili on poistettu käytöstä",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
     "Account name or email" : "Tilin nimi tai sähköpostiosoite",
     "Account name" : "Tilin nimi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
@@ -143,6 +224,7 @@ OC.L10N.register(
     "An internal error occurred." : "Tapahtui sisäinen virhe.",
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
     "Password" : "Salasana",
+    "Remember me" : "Muista minut",
     "Log in with a device" : "Kirjaudu laitteella",
     "Login or email" : "Käyttäjätunnus tai sähköposti",
     "Your account is not setup for passwordless login." : "Käyttäjääsi ei ole kytketty käyttämään salasanatonta kirjautumista.",
@@ -165,20 +247,24 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
     "Distraction free note taking app." : "Häiriötön mustiinpanosovellus.",
     "Recommended apps" : "Suositellut sovellukset",
-    "Loading apps …" : "Ladataan sovelluksia…",
+    "Loading apps …" : "Ladataan sovelluksia …",
     "Could not fetch list of apps from the App Store." : "Sovelluskaupasta ei voitu noutaa listaa sovelluksista.",
     "App download or installation failed" : "Sovelluksen lataus tai asennus epäonnistui",
     "Cannot install this app because it is not compatible" : "Tätä sovellusta ei voi asentaa, koska se ei ole yhteensopiva",
     "Cannot install this app" : "Tätä sovellusta ei voi asentaa",
     "Skip" : "Ohita",
-    "Installing apps …" : "Asennetaan sovelluksia…",
+    "Installing apps …" : "Asennetaan sovelluksia …",
     "Install recommended apps" : "Asenna suositellut sovellukset",
+    "Online" : "Online",
+    "Away" : "Poissa",
+    "Busy" : "Varattu",
+    "Do not disturb" : "Älä häiritse",
+    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
+    "Invisible" : "Näkymätön",
+    "Appear offline" : "Näytä olevan poissa",
     "Settings menu" : "Asetusvalikko",
-    "Loading your contacts …" : "Ladataan yhteystietojasi…",
-    "Looking for {term} …" : "Etsii {term}…",
     "Search contacts" : "Etsi yhteystietoja",
     "Reset search" : "Tyhjennä haku",
-    "Search contacts …" : "Etsi yhteystietoja…",
     "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
     "No contacts found" : "Yhteystietoja ei löytynyt",
     "Show all contacts" : "Näytä kaikki kontaktit",
@@ -190,13 +276,34 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Haku alkaa kun aloitat kirjoittamisen. Tuloksiin on mahdollista siirtyä nuolinäppäimillä",
     "Search for {name} only" : "Etsi vain {name}",
-    "Loading more results …" : "Ladataan lisää tuloksia…",
+    "Loading more results …" : "Ladataan lisää tuloksia …",
     "Forgot password?" : "Unohditko salasanasi?",
     "Back to login form" : "Takaisin kirjautumisnäkymään",
     "Back" : "Takaisin",
     "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudin kirjautumislomake on poistettu käytöstä. Käytä toista kirjautumistapaa tai ota yhteys ylläpitoon.",
+    "Connect to your account" : "Yhdistä tiliisi",
+    "Security warning" : "Turvallisuusvaroitus",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
+    "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
+    "Account connected" : "Tili yhdistetty",
+    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
+    "You can close this window." : "Voit sulkea tämän ikkunan.",
+    "Account access" : "Tilin käyttö",
     "More actions" : "Lisää toimintoja",
+    "User menu" : "Käyttäjävalikko",
+    "Your guest name: {user}" : "Vierasnimesi: {user}",
+    "Set public name" : "Aseta julkinen nimi",
+    "Change public name" : "Vaihda julkinen nimi",
+    "This share is password-protected" : "Jako on salasanasuojattu",
+    "The password is wrong or expired. Please try again or request a new one." : "Salasana on väärä tai vanhentunut. Yritä uudelleen tai pyydä uusi salasana.",
+    "Submit" : "Lähetä",
+    "Please type in your email address to request a temporary password" : "Kirjoita sähköpostiosoitteesi pyytääksesi väliaikaista salasanaa",
+    "Password sent!" : "Salasana lähetetty!",
+    "You are not authorized to request a password for this share" : "Sinulla ei ole valtuutta pyytää salasanaa tähän jakoon",
+    "Email address" : "Sähköpostiosoite",
+    "Request password" : "Pyydä salasanaa",
+    "Forgot password" : "Unohditko salasanan?",
     "Password is too weak" : "Salasana on liian heikko",
     "Password is weak" : "Salasana on heikko",
     "Password is average" : "Salasana on keskiverto",
@@ -204,13 +311,15 @@ OC.L10N.register(
     "Password is very strong" : "Salasana on hyvin vahva",
     "Password is extremely strong" : "Salasana on erittäin vahva",
     "Unknown password strength" : "Tuntematon salasanan vahvuus",
-    "Security warning" : "Turvallisuusvaroitus",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Datahakemistosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska <code>.htaccess</code>-tiedosto ei toimi.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Lisätietoja oikeaoppisesta palvelimen määrityksestä on saatavilla {linkStart}dokumentaatiossa{linkEnd}",
     "Create administration account" : "Luo ylläpitäjätili",
     "Administration account name" : "Ylläpitäjätilin nimi",
     "Administration account password" : "Ylläpitäjätilin salasana",
     "Storage & database" : "Tallennus ja tietokanta",
     "Data folder" : "Datakansio",
     "Database configuration" : "Tietokannan kokoonpano",
+    "Database type" : "Tietokannan tyyppi",
     "Only {firstAndOnlyDatabase} is available." : "Vain {firstAndOnlyDatabase} on käytettävissä.",
     "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
     "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
@@ -218,13 +327,14 @@ OC.L10N.register(
     "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
+    "Database connection" : "Tietokantayhteys",
     "Database user" : "Tietokannan käyttäjä",
     "Database password" : "Tietokannan salasana",
     "Database name" : "Tietokannan nimi",
     "Database tablespace" : "Tietokannan taulukkotila",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
     "Database host" : "Tietokantapalvelin",
-    "Installing …" : "Asennetaan …",
+    "Installing …" : "Asennetaan …",
     "Install" : "Asenna",
     "Need help?" : "Tarvitsetko apua?",
     "See the documentation" : "Tutustu ohjeisiin",
@@ -233,7 +343,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
     "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
     "Supported versions" : "Tuetut versiot",
-    "Search {types} …" : "Etsi {types}…",
+    "Search {types} …" : "Etsi {types} …",
     "Choose {file}" : "Valitse {file}",
     "Choose" : "Valitse",
     "Copy to {target}" : "Kopioi kohteeseen {target}",
@@ -253,7 +363,10 @@ OC.L10N.register(
     "(all selected)" : "(kaikki valittu)",
     "({count} selected)" : "({count} valittu)",
     "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
-    "Saving …" : "Tallennetaan…",
+    "Saving …" : "Tallennetaan …",
+    "Groups" : "Ryhmät",
+    "Group list is empty" : "Ryhmälista on tyhjä",
+    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
     "seconds ago" : "sekunteja sitten",
     "Connection to server lost" : "Yhteys palvelimelle katkesi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
@@ -268,26 +381,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
     "New in" : "Uutta versiossa",
     "View changelog" : "Katso muutosloki",
-    "No action available" : "Toimintoa ei saatavilla",
-    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
     "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
     "Email length is at max (255)" : "Sähköpostin pituus on maksimissaan (255)",
-    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
-    "Restricted" : "Rajoitettu",
-    "Invisible" : "Näkymätön",
-    "Delete" : "Poista",
-    "Rename" : "Nimeä uudelleen",
-    "Collaborative tags" : "Yhteistyölliset tunnisteet",
-    "No tags found" : "Tunnisteita ei löytynyt",
     "Clipboard not available, please copy manually" : "Leikepöytä ei ole saatavilla, kopioi manuaalisesti",
     "Personal" : "Henkilökohtainen",
     "Accounts" : "Tilit",
     "Admin" : "Ylläpito",
     "Help" : "Ohje",
     "Access forbidden" : "Pääsy estetty",
+    "You are not allowed to access this page." : "Oikeutesi eivät riitä tämän sivun käyttämiseksi.",
+    "Back to %s" : "Takaisin kohtaan %s",
     "Page not found" : "Sivua ei löytynyt",
     "The page could not be found on the server or you may not be allowed to view it." : "Sivua ei löytynyt palvelimelta, tai sinulla ei ole oikeutta nähdä sitä.",
-    "Back to %s" : "Takaisin kohtaan %s",
     "Too many requests" : "Liian monta pyyntöä",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
     "Error" : "Virhe",
@@ -312,23 +417,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Hyppää sovelluksen navigointiin.",
     "Go to %s" : "Siirry %s§",
     "Get your own free account" : "Hanki ilmainen tili itsellesi",
-    "Connect to your account" : "Yhdistä tiliisi",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
-    "App password" : "Sovellussalasana",
-    "Grant access" : "Myönnä pääsy",
-    "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
-    "Account access" : "Tilin käyttö",
-    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s).",
-    "Account connected" : "Tili yhdistetty",
-    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
-    "You can close this window." : "Voit sulkea tämän ikkunan.",
     "Previous" : "Edellinen",
-    "This share is password-protected" : "Jako on salasanasuojattu",
-    "The password is wrong or expired. Please try again or request a new one." : "Salasana on väärä tai vanhentunut. Yritä uudelleen tai pyydä uusi salasana.",
-    "Please type in your email address to request a temporary password" : "Kirjoita sähköpostiosoitteesi pyytääksesi väliaikaista salasanaa",
-    "Email address" : "Sähköpostiosoite",
-    "Password sent!" : "Salasana lähetetty!",
-    "You are not authorized to request a password for this share" : "Sinulla ei ole valtuutta pyytää salasanaa tähän jakoon",
     "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
@@ -359,22 +448,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
     "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
-    "Currently open" : "Parhaillaan avoinna",
-    "Login with username or email" : "Kirjaudu käyttäjätunnuksella tai sähköpostiosoitteella",
-    "Login with username" : "Kirjaudu käyttäjätunnuksella",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit - selaimessasi ja puhelinsovelluksilla.",
-    "You have not added any info yet" : "Et ole lisännyt tietoja vielä",
-    "{user} has not added any info yet" : "{user} ei ole lisännyt tietoja vielä",
-    "Edit Profile" : "Muokkaa profiilia",
-    "The headline and about sections will show up here" : "Otsikko ja listätieto-osiot näkyvät tässä",
-    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
+    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Lue lisätietoja {linkstart}dokumentaatiosta ↗{linkend}.",
+    "unknown text" : "tuntematon teksti",
+    "Hello world!" : "Hei maailma!",
+    "sunny" : "aurinkoinen",
+    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
+    "Hello {name}" : "Hei {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
+    "new" : "uusi",
+    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
+    "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle",
+    "Searching …" : "Haetaan…",
+    "Logging in …" : "Kirjaudutaan sisään...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
+    "Loading apps …" : "Ladataan sovelluksia…",
+    "Installing apps …" : "Asennetaan sovelluksia…",
+    "Loading your contacts …" : "Ladataan yhteystietojasi…",
+    "Looking for {term} …" : "Etsii {term}…",
+    "Search contacts …" : "Etsi yhteystietoja…",
+    "Loading more results …" : "Ladataan lisää tuloksia…",
+    "Search {types} …" : "Etsi {types}…",
+    "Saving …" : "Tallennetaan…",
     "Very weak password" : "Erittäin heikko salasana",
     "Weak password" : "Heikko salasana",
     "So-so password" : "Kohtalainen salasana",
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
-    "Profile not found" : "Profiilia ei löytynyt",
-    "The profile does not exist." : "Profiilia ei ole olemassa",
+    "No action available" : "Toimintoa ei saatavilla",
+    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
+    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
+    "Restricted" : "Rajoitettu",
+    "Delete" : "Poista",
+    "Rename" : "Nimeä uudelleen",
+    "Collaborative tags" : "Yhteistyölliset tunnisteet",
+    "No tags found" : "Tunnisteita ei löytynyt",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Luo ylläpitäjän tili</strong>",
@@ -384,6 +492,8 @@ OC.L10N.register(
     "Toggle password visibility" : "Näytä/piilota salasana",
     "Configure the database" : "Määritä tietokanta",
     "Only %s is available." : "Vain %s on käytettävissä.",
-    "Database account" : "Tietokantatili"
+    "Database account" : "Tietokantatili",
+    "Installing …" : "Asennetaan …",
+    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s)."
 },
 "nplurals=2; plural=(n != 1);");
