@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Níor éirigh leis an nuashonrú.  Tuairiscigh an tsaincheist seo do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">phobal Nextcloud </a> le do thoil.",
     "Continue to {productName}" : "Lean ar aghaidh chuig {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","The update was successful. Redirecting you to {productName} in %n seconds.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind."],
+    "Done" : "Déanta",
     "Applications menu" : "Roghchlár feidhmchlár",
     "Apps" : "Feidhmchláir",
     "More apps" : "Tuilleadh apps",
     "_{count} notification_::_{count} notifications_" : ["{count} fógra","{count} fógra","{count} fógra","{count} fógra","{count} fógra"],
     "No" : "Níl",
     "Yes" : "Tá",
+    "App password" : "Pasfhocal aip",
+    "Grant access" : "Deonaigh rochtain",
     "The remote URL must include the user." : "Ní mór an t-úsáideoir a chur san áireamh sa URL iargúlta.",
     "Invalid remote URL." : "URL cianda neamhbhailí.",
     "Failed to add the public link to your Nextcloud" : "Theip ar an nasc poiblí a chur le do Nextcloud",
@@ -248,12 +251,13 @@ OC.L10N.register(
     "Results" : "Torthaí",
     "Load more results" : "Íoslódáil níos mó torthaí",
     "Search in" : "Cuardaigh isteach",
+    "Partial matches" : "Cluichí páirteacha",
     "Log in" : "Logáil isteach",
     "Logging in …" : "Ag logáil isteach …",
     "Log in to {productName}" : "Logáil isteach ar {productName}",
     "Wrong login or password." : "Logáil isteach mícheart nó pasfhocal.",
     "This account is disabled" : "Tá an cuntas seo díchumasaithe",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bhraitheamar go leor iarrachtaí logáil isteach neamhbhailí ó do IP. Dá bhrí sin tá do logáil isteach eile throttled suas go dtí 30 soicind.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "An iomarca iarrachtaí logála isteach míchearta. Déan iarracht arís i gceann 30 soicind.",
     "Account name or email" : "Ainm cuntais nó ríomhphost",
     "Account name" : "Ainm chuntais",
     "Server side authentication failed!" : "Theip ar fhíordheimhniú taobh an fhreastalaí!",
@@ -326,12 +330,28 @@ OC.L10N.register(
     "Back" : "Ar ais",
     "Login form is disabled." : "Tá an fhoirm logáil isteach díchumasaithe.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Tá foirm logáil isteach Nextcloud díchumasaithe. Úsáid rogha logáil isteach eile má tá sé ar fáil nó déan teagmháil le do lucht riaracháin.",
+    "Connect to your account" : "Ceangail le do chuntas",
+    "Security warning" : "Rabhadh slándála",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Mura bhfuil tú ag iarraidh gléas nó aip nua a chur ar bun, tá duine éigin ag iarraidh bob a bhualadh ort rochtain a thabhairt dóibh ar do shonraí. Sa chás seo, ná téigh ar aghaidh agus ina ionad sin déan teagmháil le riarthóir do chórais.",
+    "Alternative log in using app password" : "Logáil isteach malartach ag baint úsáide as pasfhocal app",
+    "Account connected" : "Cuntas ceangailte",
+    "Your client should now be connected!" : "Ba chóir go mbeadh do chliant ceangailte anois!",
+    "You can close this window." : "Is féidir leat an fhuinneog seo a dhúnadh.",
+    "Account access" : "Rochtain chuntais",
     "More actions" : "Tuilleadh gníomhartha",
     "User menu" : "Roghchlár úsáideora",
     "Your guest name: {user}" : "Ainm d'aoi: {user}",
     "You are currently not identified." : "Níl aitheantas tugtha duit faoi láthair.",
     "Set public name" : "Socraigh ainm poiblí",
     "Change public name" : "Athraigh ainm poiblí",
+    "This share is password-protected" : "Tá an sciar seo cosanta ag pasfhocal",
+    "The password is wrong or expired. Please try again or request a new one." : "Tá an pasfhocal mícheart nó imithe in éag. Bain triail eile as nó iarr ceann nua le do thoil. ",
+    "Submit" : "Cuir isteach",
+    "Please type in your email address to request a temporary password" : "Clóscríobh isteach do sheoladh ríomhphoist chun pasfhocal sealadach a iarraidh le do thoil",
+    "Password sent!" : "Pasfhocal seolta!",
+    "You are not authorized to request a password for this share" : "Níl tú údaraithe pasfhocal a iarraidh don sciar seo",
+    "Email address" : "Seoladh ríomhphoist",
+    "Request password" : "Iarr pasfhocal",
     "Password is too weak" : "Tá pasfhocal ró-lag",
     "Password is weak" : "Tá pasfhocal lag",
     "Password is average" : "Is pasfhocal meánach",
@@ -343,7 +363,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Chun eolas a fháil ar conas do fhreastalaí a chumrú i gceart, {linkStart}féach ar an doiciméadú{linkEnd}",
     "Autoconfig file detected" : "Braitheadh ​​comhad Autoconfig",
     "The setup form below is pre-filled with the values from the config file." : "Tá an fhoirm socraithe thíos réamhlíonta leis na luachanna ón gcomhad cumraíochta.",
-    "Security warning" : "Rabhadh slándála",
     "Create administration account" : "Cruthaigh cuntas riaracháin",
     "Administration account name" : "Ainm an chuntais riaracháin",
     "Administration account password" : "Pasfhocal cuntas riaracháin",
@@ -396,6 +415,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} roghnaithe)",
     "Error loading file exists template" : "Earráid agus an comhad á lódáil tá an teimpléad ann",
     "Saving …" : "Shábháil …",
+    "Groups" : "Grúpaí",
+    "Group list is empty" : "Tá liosta an ghrúpa folamh",
+    "Unable to retrieve the group list" : "Ní féidir liosta na ngrúpaí a fháil",
     "seconds ago" : "soicind ó shin",
     "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
@@ -446,25 +468,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Téigh ar aghaidh chuig nascleanúint an aip",
     "Go to %s" : "Téigh go %s",
     "Get your own free account" : "Faigh do chuntas saor in aisce féin",
-    "Connect to your account" : "Ceangail le do chuntas",
-    "Please log in before granting %1$s access to your %2$s account." : "Logáil isteach sula dtabharfaidh tú rochtain do %1$s ar do chuntas %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Mura bhfuil tú ag iarraidh gléas nó aip nua a chur ar bun, tá duine éigin ag iarraidh bob a bhualadh ort rochtain a thabhairt dóibh ar do shonraí. Sa chás seo, ná téigh ar aghaidh agus ina ionad sin déan teagmháil le riarthóir do chórais.",
-    "App password" : "Pasfhocal aip",
-    "Grant access" : "Deonaigh rochtain",
-    "Alternative log in using app password" : "Logáil isteach malartach ag baint úsáide as pasfhocal app",
-    "Account access" : "Rochtain chuntais",
-    "Currently logged in as %1$s (%2$s)." : "Logáilte isteach mar %1$s (%2$s) faoi láthair.",
-    "You are about to grant %1$s access to your %2$s account." : "Tá tú ar tí rochtain a thabhairt do %1$s ar do chuntas %2$s.",
-    "Account connected" : "Cuntas ceangailte",
-    "Your client should now be connected!" : "Ba chóir go mbeadh do chliant ceangailte anois!",
-    "You can close this window." : "Is féidir leat an fhuinneog seo a dhúnadh.",
     "Previous" : "Roimhe Seo",
-    "This share is password-protected" : "Tá an sciar seo cosanta ag pasfhocal",
-    "The password is wrong or expired. Please try again or request a new one." : "Tá an pasfhocal mícheart nó imithe in éag. Bain triail eile as nó iarr ceann nua le do thoil. ",
-    "Please type in your email address to request a temporary password" : "Clóscríobh isteach do sheoladh ríomhphoist chun pasfhocal sealadach a iarraidh le do thoil",
-    "Email address" : "Seoladh ríomhphoist",
-    "Password sent!" : "Pasfhocal seolta!",
-    "You are not authorized to request a password for this share" : "Níl tú údaraithe pasfhocal a iarraidh don sciar seo",
     "Two-factor authentication" : "Fíordheimhniú dhá-fhachtóir",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tá slándáil fheabhsaithe cumasaithe do do chuntas. Roghnaigh an dara fachtóir le haghaidh fíordheimhnithe:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Níorbh fhéidir ceann amháin ar a laghad de do mhodhanna údaraithe dhá-fhachtóir a lódáil. Déan teagmháil le do riarthóir le do thoil.",
@@ -510,6 +514,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
     "Searching …" : "Ag cuardach…",
     "Logging in …" : "Ag logáil isteach…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bhraitheamar go leor iarrachtaí logáil isteach neamhbhailí ó do IP. Dá bhrí sin tá do logáil isteach eile throttled suas go dtí 30 soicind.",
     "Loading apps …" : "Aipeanna á lódáil…",
     "Installing apps …" : "Aipeanna á suiteáil…",
     "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
@@ -541,6 +546,9 @@ OC.L10N.register(
     "Configure the database" : "Cumraigh an bunachar sonraí",
     "Only %s is available." : "Níl ach %s ar fáil.",
     "Database account" : "Cuntas bunachar sonraí",
-    "Installing …" : "Suiteáil…"
+    "Installing …" : "Suiteáil…",
+    "Please log in before granting %1$s access to your %2$s account." : "Logáil isteach sula dtabharfaidh tú rochtain do %1$s ar do chuntas %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Logáilte isteach mar %1$s (%2$s) faoi láthair.",
+    "You are about to grant %1$s access to your %2$s account." : "Tá tú ar tí rochtain a thabhairt do %1$s ar do chuntas %2$s."
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
