@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de ficheiro descoñecido",
     "An error occurred. Please contact your admin." : "Produciuse un erro. Póñase en contacto coa administración da instancia.",
     "Invalid image" : "Imaxe incorrecta",
-    "No temporary profile picture available, try again" : "Non hai unha imaxe temporal de perfil dispoñíbel, volva tentalo",
-    "No crop data provided" : "Non indicou como recortar",
-    "No valid crop data provided" : "Os datos recortados fornecidos non son válidos",
-    "Crop is not square" : "O recorte non é cadrado",
     "State token does not match" : "O testemuño de estado non coincide",
     "Invalid app password" : "Contrasinal da aplicación incorrecto ",
     "Could not complete login" : "Non foi posíbel completar o acceso",
@@ -46,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Non atopado",
     "Node is locked" : "O nodo está bloqueado",
     "Bad request" : "Solicitude incorrecta",
+    "Input text is too long" : "O texto de entrada é demasiado longo",
     "Requested task type does not exist" : "O tipo de tarefa solicitado non existe",
     "Necessary language model provider is not available" : "O provedor de modelos de linguaxe necesario non está dispoñíbel",
     "No text to image provider is available" : "Non hai ningún provedor de texto a imaxe dispoñíbel",
@@ -53,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "Non hai ningún provedor de tradución dispoñíbel",
     "Could not detect language" : "Non foi posíbel detectar o idioma",
     "Unable to translate" : "Non é posíbel traducir",
+    "No valid filters provided" : "Non se forneceu ningún filtro válido",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Paso do arranxo:",
     "Repair info:" : "Información do arranxo:",
@@ -200,15 +198,7 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "unknown text" : "texto descoñecido",
-    "Hello world!" : "Ola xente!",
-    "sunny" : "soleado",
-    "Hello {name}, the weather is {weather}" : "Ola {name}, a situación meteorolóxica é {weather}",
-    "Hello {name}" : "Ola {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes son os resultados da súa busca<script>alert(1)</script></strong>",
-    "new" : "novo",
-    "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualización está en curso, saír desta páxina podería interromper o proceso nalgúns contornos.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualización está en proceso, saír desta páxina podería interromper o proceso nalgúns contornos.",
     "Update to {version}" : "Actualizar a {version}",
     "An error occurred." : "Produciuse un erro",
     "Please reload the page." : "Volva cargar a páxina.",
@@ -216,12 +206,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Fallou a actualización. Informe desta incidencia na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
     "Continue to {productName}" : "Continuar a {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundo.","A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundos."],
+    "Done" : "Feito",
+    "Scan QR code to log in" : "Escanee o código QR para acceder",
+    "Use {productName} mobile client you want to connect to scan the code" : "Empregue o cliente móbil {productName} ao que quere conectarse para escanear o código",
+    "Code will expire {timeCountdown} or after use" : "O código caducará en {timeCountdown} ou após o seu uso",
     "Applications menu" : "Menú de aplicacións",
     "Apps" : "Aplicacións",
     "More apps" : "Máis aplicacións",
     "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificacións"],
     "No" : "Non",
     "Yes" : "Si",
+    "App password" : "Contrasinal da aplicación",
+    "Grant access" : "Permitir o acceso",
     "The remote URL must include the user." : "O URL remoto debe incluír o usuario.",
     "Invalid remote URL." : "URL remoto incorrecto",
     "Failed to add the public link to your Nextcloud" : "Non foi posíbel engadir a ligazón pública ao seu Nextcloud",
@@ -237,14 +233,16 @@ OC.L10N.register(
     "Search in current app" : "Buscar na aplicación actual",
     "Clear search" : "Limpar a busca",
     "Search everywhere" : "Buscar en todos os sitios",
-    "Searching …" : "Buscando…",
+    "Searching …" : "Buscando…",
     "Start typing to search" : "Comece a escribir para buscar",
+    "Minimum search length is {minSearchLength} characters" : "A lonxitude mínima da busca é de {minSearchLength} caracteres",
     "No matching results" : "Non hai resultados coincidentes",
     "Today" : "Hoxe",
     "Last 7 days" : "Últimos 7 días",
     "Last 30 days" : "Últimos 30 días",
     "This year" : "Este ano",
     "Last year" : "Último ano",
+    "Between {startDate} and {endDate}" : "Entre {startDate} e {endDate}",
     "Unified search" : "Busca unificada",
     "Search apps, files, tags, messages" : "Buscar aplicacións, ficheiros, etiquetas, mensaxes",
     "Places" : "Lugares",
@@ -256,12 +254,13 @@ OC.L10N.register(
     "Results" : "Resultados",
     "Load more results" : "Cargando máis resultados",
     "Search in" : "Buscar en",
+    "Partial matches" : "Coincidencias parciais",
     "Log in" : "Acceder",
-    "Logging in …" : "Acceder…",
+    "Logging in …" : "Accedendo a…",
     "Log in to {productName}" : "Acceda a {productName}",
     "Wrong login or password." : "Acceso ou contrasinal incorrectos.",
     "This account is disabled" : "Esta conta está desactivada",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos varias tentativas de acceso non válidas desde o seu IP. Por mor diso, o seu próximo acceso estará limitado a 30 segundos",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Demasiados intentos de acceso incorrectos. Ténteo de novo en 30 segundos.",
     "Account name or email" : "Nome da conta ou correo-e",
     "Account name" : "Nome da conta",
     "Server side authentication failed!" : "A autenticación fracasou do lado do servidor!",
@@ -271,6 +270,7 @@ OC.L10N.register(
     "An internal error occurred." : "Produciuse un erro interno",
     "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto coa administración desta instancia.",
     "Password" : "Contrasinal",
+    "Remember me" : "Lembrarmo",
     "Log in with a device" : "Acceder cun dispositivo",
     "Login or email" : "Acceso ou correo-e",
     "Your account is not setup for passwordless login." : "A súa conta non está configurada para o acceso sen contrasinal.",
@@ -294,21 +294,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, follas de cálculo e presentacións, feitos en Collabora Online.",
     "Distraction free note taking app." : "Aplicación para tomar notas sen distraccións.",
     "Recommended apps" : "Aplicacións recomendadas",
-    "Loading apps …" : "Cargando aplicacións…",
+    "Loading apps …" : "Cargando aplicacións…",
     "Could not fetch list of apps from the App Store." : "Non foi posíbel recuperar a lista de aplicacións da tenda de aplicacións.",
     "App download or installation failed" : "Produciuse un fallo ao descargar ou instalar a aplicación",
     "Cannot install this app because it is not compatible" : "Non é posíbel instalar esta aplicación porque non ser compatíbel",
     "Cannot install this app" : "Non é posíbel instalar esta aplicación",
     "Skip" : "Omitir",
-    "Installing apps …" : "Instalando aplicacións…",
+    "Installing apps …" : "Instalando aplicacións…",
     "Install recommended apps" : "Instalar aplicacións recomendadas",
+    "Online" : "En liña",
+    "Away" : "Ausente",
+    "Busy" : "Ocupado",
+    "Do not disturb" : "Non molestar",
+    "Mute all notifications" : "Silenciar todas as notificacións",
+    "Invisible" : "Invisíbel",
+    "Appear offline" : "Aparecer como sen conexión",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menú de axustes",
-    "Loading your contacts …" : "Cargando os seus contactos…",
-    "Looking for {term} …" : "Buscando {term}…",
+    "Loading your contacts …" : "Cargando os seus contactos…",
+    "Looking for {term} …" : "Buscando {term}…",
     "Search contacts" : "Buscar contactos",
     "Reset search" : "Restabelecer a busca",
-    "Search contacts …" : "Buscar contactos…",
+    "Search contacts …" : "Buscar contactos…",
     "Could not load your contacts" : "Non foi posíbel cargar os seus contactos",
     "No contacts found" : "Non se atopou ningún contacto.",
     "Show all contacts" : "Amosar todos os contactos",
@@ -320,18 +327,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Produciuse un erro ao buscar por {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "A busca comeza unha vez que comeza a escribir e pódese acceder aos resultados coas teclas de frecha",
     "Search for {name} only" : "Buscar só por {name}",
-    "Loading more results …" : "Cargando máis resultados…",
+    "Loading more results …" : "Cargando máis resultados…",
     "Forgot password?" : "Esqueceu o contrasinal?",
     "Back to login form" : "Volver ao formulario de acceso",
     "Back" : "Atrás",
     "Login form is disabled." : "O formulario de acceso está bloqueado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulario de acceso a Nextcloud está desactivado. Use outra opción de acceso se está dispoñíbel ou póñase en contacto coa súa administración.",
+    "Connect to your account" : "Conectar coa súa conta",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Acceda antes de concederlle a «{client}» acceso á súa conta en {instanceName}.",
+    "Security warning" : "Advertencia de seguranza",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non está a configurar un dispositivo ou aplicación nova, alguén está tentando enganalo para que lle permita o acceso aos seus datos. Neste caso non continúe e póñase en contacto coa administración do sistema.",
+    "Log in using password" : "Acceder empregando contrasinal",
+    "Alternative log in using app password" : "Acceso alternativo usando o contrasinal da aplicación",
+    "Account connected" : "Conta conectada",
+    "Your client should now be connected!" : "O seu cliente xa debe estar conectado!",
+    "You can close this window." : "Pode pechar esta xanela.",
+    "Account access" : "Acceso á conta",
+    "Currently logged in as {userDisplayName} ({userId})." : "Agora está conectado como {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Está a piques de concederlle a «{client}» acceso á a súa conta en {instanceName}.",
     "More actions" : "Máis accións",
     "User menu" : "Menú de usuario",
     "Your guest name: {user}" : "Nome do seu convidado: {user}",
     "You are currently not identified." : "Actualmente non está identificado.",
     "Set public name" : "Definir o nome público",
     "Change public name" : "Cambiar o nome público",
+    "This share is password-protected" : "Esta compartición está protexida con contrasinal ",
+    "The password is wrong or expired. Please try again or request a new one." : "O contrasinal é erróneo ou caducou. Volva tentalo ou solicite un novo.",
+    "Submit" : "Enviar",
+    "Please type in your email address to request a temporary password" : "Escriba o seu enderezo de correo para solicitar un contrasinal temporal",
+    "Password sent!" : "Contrasinal enviado!",
+    "You are not authorized to request a password for this share" : "Vde. non ten autorización para solicitar un contrasinal para esta compartición",
+    "Email address" : "Enderezo de correo",
+    "Request password" : "Solicitar contrasinal",
+    "Forgot password" : "Esqueceuselle o contrasinal",
     "Password is too weak" : "O contrasinal é demasiado feble",
     "Password is weak" : "O contrasinal é feble",
     "Password is average" : "O contrasinal é normaliño",
@@ -343,13 +371,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Para obter información de como configurar axeitadamente o servidor, {linkStart}vexa a documentación{linkEnd}.",
     "Autoconfig file detected" : "Detectouse o ficheiro de configuración automática",
     "The setup form below is pre-filled with the values from the config file." : "O seguinte formulario de configuración está precuberto cos valores do ficheiro de configuración.",
-    "Security warning" : "Advertencia de seguranza",
     "Create administration account" : "Crear unha conta de administración",
     "Administration account name" : "Nome da conta de administración",
     "Administration account password" : "Contrasinal da conta de administración",
     "Storage & database" : "Almacenamento e base de datos",
     "Data folder" : "Cartafol de datos",
     "Database configuration" : "Configuración da base de datos",
+    "Database type" : "Tipo de base de datos",
     "Only {firstAndOnlyDatabase} is available." : "Só está dispoñíbel {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para escoller outros tipos de bases de datos.",
     "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
@@ -357,6 +385,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Escolleu SQLite como base de datos.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite só debería empregarse para instancias mínimas e de desenvolvemento. Para produción recomendámoslle que empregue unha infraestrutura de base de datos diferente.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se emprega clientes para a sincronización dos ficheiros, desaconséllase encarecidamente o uso de SQLite.",
+    "Database connection" : "Conexión coa base de datos",
     "Database user" : "Usuario da base de datos",
     "Database password" : "Contrasinal da base de datos",
     "Database name" : "Nome da base de datos",
@@ -364,7 +393,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifique o número do porto xunto co nome do anfitrión (p. ex. localhost:5432)",
     "Database host" : "Servidor da base de datos",
     "localhost" : "localhost",
-    "Installing …" : "Instalando…",
+    "Installing …" : "Instalando…",
     "Install" : "Instalar",
     "Need help?" : "Precisa axuda?",
     "See the documentation" : "Vexa a documentación",
@@ -373,7 +402,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador non é compatíbel. Actualice a unha versión máis recente ou a unha compatíbel.",
     "Continue with this unsupported browser" : "Continuar con este navegador non compatíbel",
     "Supported versions" : "Versións compatíbeis",
-    "Search {types} …" : "Buscando {types}…",
+    "Search {types} …" : "Buscando {types}…",
     "Choose {file}" : "Escoller {file}",
     "Choose" : "Escoller",
     "Copy to {target}" : "Copiar en {target}",
@@ -387,13 +416,16 @@ OC.L10N.register(
     "New Files" : "Novos ficheiros",
     "Already existing files" : "Ficheiros existentes",
     "Which files do you want to keep?" : "Que ficheiros quere conservar?",
-    "If you select both versions, the copied file will have a number added to its name." : "Se selecciona ambas versións, o ficheiro copiado terá un número engadido ao nome.",
+    "If you select both versions, the copied file will have a number added to its name." : "Se selecciona ámbalas dúas versións, o ficheiro copiado terá un número engadido ao nome.",
     "Cancel" : "Cancelar",
     "Continue" : "Continuar",
     "(all selected)" : "(todo o seleccionado)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Produciuse un erro ao cargar o modelo de ficheiro existente",
-    "Saving …" : "Gardando…",
+    "Saving …" : "Gardando…",
+    "Groups" : "Grupos",
+    "Group list is empty" : "A lista de grupos está baleira",
+    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Falta a conexión co servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Produciuse un problema a cargar a páxina, volverá cargar en %n segundo","Produciuse un problema ao cargar a páxina, volverá cargar en %n segundos"],
@@ -402,23 +434,14 @@ OC.L10N.register(
     "Hide details" : "Agochar os detalles",
     "Rename project" : "Cambiar o nome do proxecto",
     "Failed to rename the project" : "Produciuse un fallo ao cambiarlle o nome ao proxecto",
-    "Failed to create a project" : "Produciuse un fallo ao crear o proxecto",
+    "Failed to create a project" : "Produciuse un fallo ao crear un proxecto",
     "Failed to add the item to the project" : "Produciuse un fallo ao engadir un elemento o proxecto",
     "Connect items to a project to make them easier to find" : "Conecte os elementos a un proxecto para que sexan máis doados de atopar",
     "Type to search for existing projects" : "Escriba para buscar proxectos existentes",
     "New in" : "Novo en",
     "View changelog" : "Ver as notas da versión",
-    "No action available" : "Non hai accións dispoñíbeis",
-    "Error fetching contact actions" : "Produciuse un erro ao recuperar as accións do contacto",
     "Close \"{dialogTitle}\" dialog" : "Pechar o diálogo «{dialogTitle}».",
     "Email length is at max (255)" : "Acadouse a lonxitude máxima do correo-e (255)",
-    "Non-existing tag #{tag}" : "A etiqueta #{tag} non existe",
-    "Restricted" : "Restrinxida",
-    "Invisible" : "Invisíbel",
-    "Delete" : "Eliminar",
-    "Rename" : "Cambiar o nome",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "Non se atopou ningunha etiqueta",
     "Clipboard not available, please copy manually" : "O portapapeis non está dispoñíbel, cópieo manualmente",
     "Personal" : "Persoal",
     "Accounts" : "Contas",
@@ -453,25 +476,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ir á navegación da aplicación",
     "Go to %s" : "Ira a %s",
     "Get your own free account" : "Obteña a súa propia conta de balde",
-    "Connect to your account" : "Conectar coa súa conta",
-    "Please log in before granting %1$s access to your %2$s account." : "Acceda antes de concederlle a %1$s acceso á súa conta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non está a configurar un dispositivo ou aplicación nova, alguén está tentando enganalo para que lle permita o acceso aos seus datos. Neste caso non continúe e póñase en contacto coa administración do sistema.",
-    "App password" : "Contrasinal da aplicación",
-    "Grant access" : "Permitir o acceso",
-    "Alternative log in using app password" : "Acceso alternativo usando o contrasinal da aplicación",
-    "Account access" : "Acceso á conta",
-    "Currently logged in as %1$s (%2$s)." : "Agora está conectado como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Está a piques de concederlle a %1$s permiso para acceder á súa conta %2$s.",
-    "Account connected" : "Conta conectada",
-    "Your client should now be connected!" : "O seu cliente xa debe estar conectado!",
-    "You can close this window." : "Pode pechar esta xanela.",
     "Previous" : "Anterior",
-    "This share is password-protected" : "Esta compartición está protexida con contrasinal ",
-    "The password is wrong or expired. Please try again or request a new one." : "O contrasinal é erróneo ou caducou. Volva tentalo ou solicite un novo.",
-    "Please type in your email address to request a temporary password" : "Escriba o seu enderezo de correo para solicitar un contrasinal temporal",
-    "Email address" : "Enderezo de correo",
-    "Password sent!" : "Contrasinal enviado!",
-    "You are not authorized to request a password for this share" : "Vde. non ten autorización para solicitar un contrasinal para esta compartición",
     "Two-factor authentication" : "Autenticación de dous factores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Foi activada a seguranza obrigatoria para a súa conta. Escolla un segundo factor para a autenticación. ",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Non foi posíbel cargar alomenos un dos seus métodos de autenticación de dous factores. Póñase en contacto cun administrador.",
@@ -506,19 +511,39 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto coa administración do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
     "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter máis detalles revise a {linkstart}documentación ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Parolas, videochamadas, compartición de pantalla, xuntanzas en liña e conferencias web;  no seu navegador e con aplicacións móbiles.",
-    "You have not added any info yet" : "Aínda non engadiu ningunha información",
-    "{user} has not added any info yet" : "{user} aínda non engadiu ningunha información",
-    "Error opening the user status modal, try hard refreshing the page" : "Produciuse un erro ao abrir a xanela modal de estado do usuario, tente forzar a actualización da páxina",
-    "Edit Profile" : "Editar o perfil",
-    "The headline and about sections will show up here" : "As seccións título e sobre aparecerán aquí",
+    "unknown text" : "texto descoñecido",
+    "Hello world!" : "Ola mundo!",
+    "sunny" : "soleado",
+    "Hello {name}, the weather is {weather}" : "Ola {name}, a situación meteorolóxica é {weather}",
+    "Hello {name}" : "Ola {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes son os resultados da súa busca<script>alert(1)</script></strong>",
+    "new" : "novo",
+    "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
+    "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis",
+    "Searching …" : "Buscando…",
+    "Logging in …" : "Acceder…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos varias tentativas de acceso non válidas desde o seu IP. Por mor diso, o seu próximo acceso estará limitado a 30 segundos",
+    "Loading apps …" : "Cargando aplicacións…",
+    "Installing apps …" : "Instalando aplicacións…",
+    "Loading your contacts …" : "Cargando os seus contactos…",
+    "Looking for {term} …" : "Buscando {term}…",
+    "Search contacts …" : "Buscar contactos…",
+    "Loading more results …" : "Cargando máis resultados…",
+    "Search {types} …" : "Buscando {types}…",
+    "Saving …" : "Gardando…",
     "Very weak password" : "Contrasinal moi feble",
     "Weak password" : "Contrasinal feble",
     "So-so password" : "Contrasinal non moi aló",
     "Good password" : "Contrasinal bo",
     "Strong password" : "Contrasinal forte",
-    "Profile not found" : "Non se atopou o perfil",
-    "The profile does not exist." : "O perfil non existe.",
+    "No action available" : "Non hai accións dispoñíbeis",
+    "Error fetching contact actions" : "Produciuse un erro ao recuperar as accións do contacto",
+    "Non-existing tag #{tag}" : "A etiqueta #{tag} non existe",
+    "Restricted" : "Restrinxida",
+    "Delete" : "Eliminar",
+    "Rename" : "Cambiar o nome",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "Non se atopou ningunha etiqueta",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro .htaccess non está a traballar.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter información sobre como configurar o seu servidor de xeito correcto, vexa a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Crear unha conta de administración</strong>",
@@ -529,6 +554,9 @@ OC.L10N.register(
     "Configure the database" : "Configurar a base de datos",
     "Only %s is available." : "Só está dispoñíbel %s.",
     "Database account" : "Conta da base de datos",
-    "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis"
+    "Installing …" : "Instalando…",
+    "Please log in before granting %1$s access to your %2$s account." : "Acceda antes de concederlle a %1$s acceso á súa conta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Agora está conectado como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Está a piques de concederlle a %1$s permiso para acceder á súa conta %2$s."
 },
 "nplurals=2; plural=(n != 1);");
