@@ -57,14 +57,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Sljedeće aplikacije su onemogućene: %s",
     "Already up to date" : "Nema potrebe za ažuriranjem",
     "Unknown" : "Nepoznata pogreška",
-    "unknown text" : "nepoznati tekst",
-    "Hello world!" : "Pozdrav svijete!",
-    "sunny" : "sunčano",
-    "Hello {name}, the weather is {weather}" : "Pozdrav {name}, vrijeme je {weather}",
-    "Hello {name}" : "Pozdrav {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Rezultati vašeg pretraživanja<script>alert(1)</script></strong>",
-    "new" : "novo",
-    "_download %n file_::_download %n files_" : ["preuzimanje %n datoteke","preuzimanje %n datoteka","preuzimanje %n datoteka"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ažuriranje je u tijeku, napuštanjem ove stranice možete prekinuti postupak u nekim okruženjima.",
     "Update to {version}" : "Ažuriraj na {version}",
     "An error occurred." : "Došlo je do pogreške.",
@@ -77,9 +69,9 @@ OC.L10N.register(
     "More apps" : "Više aplikacija",
     "No" : "Ne",
     "Yes" : "Da",
+    "Grant access" : "Dodijeli pristup",
     "Failed to add the public link to your Nextcloud" : "Dodavanje javne poveznice u Nextcloud nije uspjelo",
     "Create share" : "Stvori dijeljenje",
-    "Searching …" : "Traženje…",
     "Start typing to search" : "Počnite unositi tekst za pretraživanje",
     "Last year" : "Prošle godine",
     "Date" : "Datum",
@@ -87,8 +79,6 @@ OC.L10N.register(
     "Results" : "Rezultati",
     "Load more results" : "Učitaj više rezultata",
     "Log in" : "Prijava",
-    "Logging in …" : "Prijavljivanje...",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Otkrili smo nekoliko nevažećih pokušaja prijave s vaše IP adrese. Iduća prijava odgađa se za najviše 30 sekundi.",
     "Server side authentication failed!" : "Autentifikacija na poslužitelju nije uspjela!",
     "Please contact your administrator." : "Obratite se svom administratoru.",
     "An internal error occurred." : "Došlo je do unutarnje pogreške.",
@@ -112,19 +102,16 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Čuvajte podatke o kolegama i prijateljima na jednom mjestu bez ugrožavanja njihovih osobnih informacija.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednostavna aplikacija za upravljanje e-poštom, integrirana s aplikacijama Files, Contacts i Calendar.",
     "Recommended apps" : "Preporučene aplikacije",
-    "Loading apps …" : "Učitavanje aplikacija…",
     "Could not fetch list of apps from the App Store." : "Dohvaćanje popisa aplikacija iz trgovine aplikacijama nije uspjelo.",
     "App download or installation failed" : "Neuspješno preuzimanje ili instalacija aplikacije",
     "Cannot install this app because it is not compatible" : "Aplikaciju nije moguće instalirati jer nije kompatibilna",
     "Cannot install this app" : "Ovu aplikaciju nije moguće instalirati",
     "Skip" : "Preskoči",
-    "Installing apps …" : "Instaliranje aplikacija…",
     "Install recommended apps" : "Instaliraj preporučene aplikacije",
+    "Busy" : "Zauzeto",
+    "Invisible" : "Nevidljiva",
     "Settings menu" : "Izbornik postavki",
-    "Loading your contacts …" : "Učitavanje vaših kontakata...",
-    "Looking for {term} …" : "Tražim {term}…",
     "Reset search" : "Resetiraj pretraživanje",
-    "Search contacts …" : "Pretraži kontakte...",
     "Could not load your contacts" : "Učitavanje vaših kontakata trenutno nije moguće",
     "No contacts found" : "Nikakvi kontakti nisu nađeni",
     "Show all contacts" : "Prikaži sve kontakte",
@@ -134,12 +121,22 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje","Unesite {minSearchLength} ili više znakova za pretraživanje"],
     "An error occurred while searching for {type}" : "Došlo je do pogreške pri traženju {type}",
     "Search for {name} only" : "Traži samo {name}",
-    "Loading more results …" : "Učitavanje više rezultata…",
     "Forgot password?" : "Zaboravili ste zaporku?",
     "Back" : "Natrag",
     "Login form is disabled." : "Obrazac za prijavu je onemogućen.",
-    "More actions" : "Dodatne radnje",
+    "Connect to your account" : "Povežite se sa svojim računom",
     "Security warning" : "Sigurnosno upozorenje",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ako ne pokušavate postaviti novi uređaj ili aplikaciju, netko vas pokušava navesti da mu odobrite pristup svojim podacima. U tom slučaju nemojte nastaviti, već se obratite administratoru sustava.",
+    "Account connected" : "Račun povezan",
+    "Your client should now be connected!" : "Vaš klijent sada bi trebao biti povezan!",
+    "You can close this window." : "Možete zatvoriti ovaj prozor.",
+    "Account access" : "Pristup računu",
+    "More actions" : "Dodatne radnje",
+    "This share is password-protected" : "Ovaj zajednički resurs je zaštićen zaporkom",
+    "Submit" : "Šalji",
+    "Email address" : "Adresa e-pošte",
+    "Request password" : "Zatraži zaporku",
+    "Forgot password" : "Zaboravljena zaporka",
     "Storage & database" : "Pohrana i baza podataka",
     "Data folder" : "Mapa za podatke",
     "Install and activate additional PHP modules to choose other database types." : "Instalirajte i aktivirajte dodatne module PHP-a kako biste odabrali druge vrste baza podataka.",
@@ -157,7 +154,6 @@ OC.L10N.register(
     "Install" : "Instaliraj",
     "Need help?" : "Treba li vam pomoć?",
     "See the documentation" : "Pogledajte dokumentaciju",
-    "Search {types} …" : "Traži {types}…",
     "Choose" : "Odaberite",
     "Copy" : "Kopiraj",
     "Move" : "Premjesti",
@@ -174,7 +170,10 @@ OC.L10N.register(
     "(all selected)" : "(sve odabrano)",
     "({count} selected)" : "({count} odabran)",
     "Error loading file exists template" : "Pogrešno učitavanje predloška za postojeću datoteku",
-    "Saving …" : "Spremanje...",
+    "Saving …" : "Spremanje…",
+    "Groups" : "Grupe",
+    "Group list is empty" : "Popis grupa je prazan",
+    "Unable to retrieve the group list" : "Nije moguće preuzeti popis grupa",
     "seconds ago" : "prije nekoliko sekundi",
     "Connection to server lost" : "Izgubljena veza s poslužiteljem",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi","Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi","Pogreška pri učitavanju stranice, ponovno učitavanje za %n sekundi"],
@@ -189,8 +188,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Upišite za pretraživanje postojećih projekata",
     "New in" : "Novo u",
     "View changelog" : "Prikaži zapis promjena",
-    "No action available" : "Nikakve radnje trenutno nisu dostupne",
-    "Error fetching contact actions" : "Pogreška pri dohvaćanju radnji kontakata",
     "Personal" : "Osobno",
     "Accounts" : "Korisnićki računi",
     "Admin" : "Administrator",
@@ -221,18 +218,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Preskoči na navigaciju aplikacije",
     "Go to %s" : "Idi na %s",
     "Get your own free account" : "Otvorite besplatni račun",
-    "Connect to your account" : "Povežite se sa svojim računom",
-    "Please log in before granting %1$s access to your %2$s account." : "Prijavite se prije odobravanja pristupa %1$s svom računu %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ako ne pokušavate postaviti novi uređaj ili aplikaciju, netko vas pokušava navesti da mu odobrite pristup svojim podacima. U tom slučaju nemojte nastaviti, već se obratite administratoru sustava.",
-    "Grant access" : "Dodijeli pristup",
-    "Account access" : "Pristup računu",
-    "You are about to grant %1$s access to your %2$s account." : "Dopustit ćete osobi %1$s pristup vašem računu %2$s.",
-    "Account connected" : "Račun povezan",
-    "Your client should now be connected!" : "Vaš klijent sada bi trebao biti povezan!",
-    "You can close this window." : "Možete zatvoriti ovaj prozor.",
     "Previous" : "Prethodna",
-    "This share is password-protected" : "Ovaj zajednički resurs je zaštićen zaporkom",
-    "Email address" : "Adresa e-pošte",
     "Two-factor authentication" : "Dvofaktorska autentifikacija",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vaš račun sada je dodatno osiguran. Odaberite drugi faktor za provođenje autentifikacije:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nije moguće učitati jedan od omogućenih načina dvofaktorske autentifikacije. Obratite se svom administratoru.",
@@ -264,21 +250,36 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ova %s instanca trenutno je u načinu za održavanje; ovo može potrajati.",
     "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
-    "No temporary profile picture available, try again" : "Slike privremenih profila nisu dostupne, pokušajte ponovno",
-    "No crop data provided" : "Nema podataka o rezanju",
-    "No valid crop data provided" : "Nema valjanih podataka za rezanje",
-    "Crop is not square" : "Rez nije kvadrat",
     "Error occurred while checking server setup" : "Pogreška prilikom provjere postavki poslužitelja",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Više informacija potražite u {linkstart}dokumentaciji ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
+    "unknown text" : "nepoznati tekst",
+    "Hello world!" : "Pozdrav svijete!",
+    "sunny" : "sunčano",
+    "Hello {name}, the weather is {weather}" : "Pozdrav {name}, vrijeme je {weather}",
+    "Hello {name}" : "Pozdrav {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Rezultati vašeg pretraživanja<script>alert(1)</script></strong>",
+    "new" : "novo",
+    "_download %n file_::_download %n files_" : ["preuzimanje %n datoteke","preuzimanje %n datoteka","preuzimanje %n datoteka"],
+    "Searching …" : "Traženje…",
+    "Logging in …" : "Prijavljivanje...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Otkrili smo nekoliko nevažećih pokušaja prijave s vaše IP adrese. Iduća prijava odgađa se za najviše 30 sekundi.",
+    "Loading apps …" : "Učitavanje aplikacija…",
+    "Installing apps …" : "Instaliranje aplikacija…",
+    "Loading your contacts …" : "Učitavanje vaših kontakata...",
+    "Looking for {term} …" : "Tražim {term}…",
+    "Search contacts …" : "Pretraži kontakte...",
+    "Loading more results …" : "Učitavanje više rezultata…",
+    "Search {types} …" : "Traži {types}…",
+    "Saving …" : "Spremanje...",
     "Very weak password" : "Zaporka vrlo slaba",
     "Weak password" : "Zaporka Slaba",
     "So-so password" : "Zaporka prosječne jačine",
     "Good password" : "Zaporka dobra",
     "Strong password" : "Zaporka jaka",
+    "No action available" : "Nikakve radnje trenutno nisu dostupne",
+    "Error fetching contact actions" : "Pogreška pri dohvaćanju radnji kontakata",
     "Non-existing tag #{tag}" : "Nepostojeća oznaka #{tag}",
     "Restricted" : "Ograničeno",
-    "Invisible" : "Nevidljiva",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Oznake za suradnju",
@@ -288,6 +289,8 @@ OC.L10N.register(
     "Show password" : "Pokaži zaporku",
     "Toggle password visibility" : "Uključivanje/isključivanje vidljivosti zaporke",
     "Configure the database" : "Konfiguriraj bazu podataka",
-    "Only %s is available." : "Jedino je %s dostupan."
+    "Only %s is available." : "Jedino je %s dostupan.",
+    "Please log in before granting %1$s access to your %2$s account." : "Prijavite se prije odobravanja pristupa %1$s svom računu %2$s.",
+    "You are about to grant %1$s access to your %2$s account." : "Dopustit ćete osobi %1$s pristup vašem računu %2$s."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
