@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunità di Nextcloud </a>.",
     "Continue to {productName}" : "Continua in {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} in %n secondo.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi."],
+    "Done" : "Completato",
     "Applications menu" : "Menu applicazioni",
     "Apps" : "Applicazioni",
     "More apps" : "Altre applicazioni",
     "_{count} notification_::_{count} notifications_" : ["{count} notifica","{count} notifiche","{count} notifiche"],
     "No" : "No",
     "Yes" : "Sì",
+    "App password" : "Password dell'applicazione",
+    "Grant access" : "Accorda accesso",
     "The remote URL must include the user." : "L'URL remoto deve includere l'utente.",
     "Invalid remote URL." : "URL remoto non valido.",
     "Failed to add the public link to your Nextcloud" : "Aggiunta del collegamento pubblico al tuo Nextcloud non riuscita",
@@ -248,12 +251,13 @@ OC.L10N.register(
     "Results" : "Risultati",
     "Load more results" : "Carica più risultati",
     "Search in" : "Cerca all'interno",
+    "Partial matches" : "Corrispondenze parziali",
     "Log in" : "Accedi",
     "Logging in …" : "Accesso in corso ...",
     "Log in to {productName}" : "Accedi a {productName}",
     "Wrong login or password." : "Nome utente o password errati.",
     "This account is disabled" : "Questo account è disabilitato",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Abbiamo rilevato molti tentativi di autenticazione non riusciti dal tuo indirizzo IP. Di conseguenza, il prossimo tentativo è ritardato di 30 secondi.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Troppi tentativi di accesso errati. Riprova tra 30 secondi.",
     "Account name or email" : "Nome utente o email",
     "Account name" : "Nome account",
     "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
@@ -326,12 +330,29 @@ OC.L10N.register(
     "Back" : "Indietro",
     "Login form is disabled." : "Il modulo di accesso è disabilitato.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
+    "Connect to your account" : "Connetti il tuo account",
+    "Security warning" : "Avviso di sicurezza",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non stai tentando di configurare un nuovo dispositivo o applicazione, qualcuno sta provando a ingannarti per ottenere l'accesso ai tuoi dati. In questo caso non procedere e contatta l'amministratore di sistema.",
+    "Alternative log in using app password" : "Accesso alternativo utilizzando la password dell'applicazione",
+    "Account connected" : "Account connesso",
+    "Your client should now be connected!" : "Il client ora dovrebbe essere connesso!",
+    "You can close this window." : "Puoi chiudere questa finestra.",
+    "Account access" : "Accesso account",
     "More actions" : "Altre azioni",
     "User menu" : "Menu utente",
     "Your guest name: {user}" : "Il tuo nome ospite: {user}",
     "You are currently not identified." : "Al momento non sei stato identificato.",
     "Set public name" : "Imposta nome pubblico",
     "Change public name" : "Cambia nome pubblico",
+    "This share is password-protected" : "Questa condivisione è protetta da password",
+    "The password is wrong or expired. Please try again or request a new one." : "La password è errata o scaduta. Riprova o richiedine una nuova.",
+    "Submit" : "Invia",
+    "Please type in your email address to request a temporary password" : "Inserisci il tuo indirizzo email per richiedere una password temporanea",
+    "Password sent!" : "Password inviata!",
+    "You are not authorized to request a password for this share" : "Non sei autorizzato a richiedere una password per questa condivisione",
+    "Email address" : "Indirizzo email",
+    "Request password" : "Richiedi password",
+    "Forgot password" : "Password dimenticata",
     "Password is too weak" : "La password è troppo debole",
     "Password is weak" : "La password è debole",
     "Password is average" : "La password è mediocre",
@@ -343,7 +364,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Per informazioni su come configurare correttamente il tuo server, {linkStart}consultare la documentazione{linkEnd}",
     "Autoconfig file detected" : "File di configurazione automatica rilevato",
     "The setup form below is pre-filled with the values from the config file." : "Il modulo di configurazione riportato di seguito è precompilato con i valori del file di configurazione.",
-    "Security warning" : "Avviso di sicurezza",
     "Create administration account" : "Crea un account amministrazione",
     "Administration account name" : "Nome dell'account di amministrazione",
     "Administration account password" : "Password dell'account di amministrazione",
@@ -396,6 +416,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} selezionati)",
     "Error loading file exists template" : "Errore durante il caricamento del modello del file esistente",
     "Saving …" : "Salvataggio…",
+    "Groups" : "Gruppi",
+    "Group list is empty" : "L'elenco dei gruppi è vuoto",
+    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
     "seconds ago" : "secondi fa",
     "Connection to server lost" : "Connessione al server interrotta",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
@@ -446,25 +469,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Passa alla navigazione dell'applicazione",
     "Go to %s" : "Vai a %s",
     "Get your own free account" : "Ottieni il tuo account gratuito",
-    "Connect to your account" : "Connetti il tuo account",
-    "Please log in before granting %1$s access to your %2$s account." : "Accedi prima di accordare a %1$s l'accesso al tuo account %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non stai tentando di configurare un nuovo dispositivo o applicazione, qualcuno sta provando a ingannarti per ottenere l'accesso ai tuoi dati. In questo caso non procedere e contatta l'amministratore di sistema.",
-    "App password" : "Password dell'applicazione",
-    "Grant access" : "Accorda accesso",
-    "Alternative log in using app password" : "Accesso alternativo utilizzando la password dell'applicazione",
-    "Account access" : "Accesso account",
-    "Currently logged in as %1$s (%2$s)." : "Attualmente connesso come %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s.",
-    "Account connected" : "Account connesso",
-    "Your client should now be connected!" : "Il client ora dovrebbe essere connesso!",
-    "You can close this window." : "Puoi chiudere questa finestra.",
     "Previous" : "Precedente",
-    "This share is password-protected" : "Questa condivisione è protetta da password",
-    "The password is wrong or expired. Please try again or request a new one." : "La password è errata o scaduta. Riprova o richiedine una nuova.",
-    "Please type in your email address to request a temporary password" : "Inserisci il tuo indirizzo email per richiedere una password temporanea",
-    "Email address" : "Indirizzo email",
-    "Password sent!" : "Password inviata!",
-    "You are not authorized to request a password for this share" : "Non sei autorizzato a richiedere una password per questa condivisione",
     "Two-factor authentication" : "Autenticazione a due fattori",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sicurezza migliorata è abilitata per il tuo account. Scegli un secondo fattore per l'autenticazione:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossibile caricare almeno uno dei metodi di autenticazione a due fattori. Contatta il tuo amministratore.",
@@ -510,6 +515,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti",
     "Searching …" : "Ricerca in corso…",
     "Logging in …" : "Accesso in corso...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Abbiamo rilevato molti tentativi di autenticazione non riusciti dal tuo indirizzo IP. Di conseguenza, il prossimo tentativo è ritardato di 30 secondi.",
     "Loading apps …" : "Caricamento applicazioni…",
     "Installing apps …" : "Installazione applicazioni…",
     "Loading your contacts …" : "Caricamento dei tuoi contatti...",
@@ -541,6 +547,9 @@ OC.L10N.register(
     "Configure the database" : "Configura il database",
     "Only %s is available." : "È disponibile solo %s.",
     "Database account" : "Database account",
-    "Installing …" : "Installazione …"
+    "Installing …" : "Installazione …",
+    "Please log in before granting %1$s access to your %2$s account." : "Accedi prima di accordare a %1$s l'accesso al tuo account %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Attualmente connesso come %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
