@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
     "Continue to {productName}" : "{productName} に進む",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
+    "Done" : "完了",
     "Applications menu" : "アプリケーションメニュー",
     "Apps" : "アプリ",
     "More apps" : "さらにアプリ",
     "_{count} notification_::_{count} notifications_" : ["通知 {count} 件"],
     "No" : "いいえ",
     "Yes" : "はい",
+    "App password" : "アプリパスワード",
+    "Grant access" : "アクセスを許可",
     "The remote URL must include the user." : "リモートURLにはユーザーを含める必要があります。",
     "Invalid remote URL." : "無効なリモートURLです。",
     "Failed to add the public link to your Nextcloud" : "このNextcloudに公開リンクを追加できませんでした",
@@ -253,7 +256,6 @@ OC.L10N.register(
     "Log in to {productName}" : "{productName} へログイン",
     "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
     "This account is disabled" : "アカウントが無効化されています",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
     "Account name or email" : "アカウント名またはメールアドレス",
     "Account name" : "アカウント名",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
@@ -326,12 +328,29 @@ OC.L10N.register(
     "Back" : "戻る",
     "Login form is disabled." : "ログインフォームは無効です。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud ログインフォームは無効になっています。 利用可能な場合は別のログインオプションを使用するか、管理者に問い合わせてください。",
+    "Connect to your account" : "あなたのアカウントに接続する",
+    "Security warning" : "セキュリティ警告",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "新しいデバイスやアプリを設定しようとしていないのに、今この画面が表示された場合、誰かがあなたを騙してデータへのアクセス権を奪取しようとしています。その場合は、ここで止めてシステム管理者に連絡してください。",
+    "Alternative log in using app password" : "アプリパスワードを使用した代替ログイン",
+    "Account connected" : "アカウントに接続しました",
+    "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
+    "You can close this window." : "このウィンドウは閉じてしまって構いません。",
+    "Account access" : "アカウントによるアクセス許可",
     "More actions" : "その他のアクション",
     "User menu" : "ユーザーメニュー",
     "Your guest name: {user}" : "ゲスト名: {user}",
     "You are currently not identified." : "現在識別されていません。",
     "Set public name" : "公開名の設定",
     "Change public name" : "公開名を変更",
+    "This share is password-protected" : "この共有はパスワードで保護されています",
+    "The password is wrong or expired. Please try again or request a new one." : "パスワードが間違っているか有効期限切れです。後で再度お試しいただくか、新しいパスワードをリクエストしてください。",
+    "Submit" : "提出する",
+    "Please type in your email address to request a temporary password" : "仮パスワードを申請するためにメールアドレスを入力してください。",
+    "Password sent!" : "パスワードを送信しました",
+    "You are not authorized to request a password for this share" : "この共有のためのパスワードを要求する権限はありません。",
+    "Email address" : "メールアドレス",
+    "Request password" : "パスワードを入力",
+    "Forgot password" : "パスワードをお忘れですか?",
     "Password is too weak" : "パスワードが脆弱すぎます",
     "Password is weak" : "パスワードが脆弱です",
     "Password is average" : "パスワードは普通です",
@@ -343,7 +362,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "サーバーを適切に設定する方法については、{linkStart}ドキュメントを参照してください{linkEnd}",
     "Autoconfig file detected" : "自動設定ファイルが検出されました",
     "The setup form below is pre-filled with the values from the config file." : "以下のセットアップフォームには、設定ファイルの値があらかじめ入力されています。",
-    "Security warning" : "セキュリティ警告",
     "Create administration account" : "管理アカウントを作成",
     "Administration account name" : "管理者アカウント名",
     "Administration account password" : "管理者アカウントパスワード",
@@ -396,6 +414,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} 選択)",
     "Error loading file exists template" : "既存ファイルのテンプレートの読み込みエラー",
     "Saving …" : "保存中 …",
+    "Groups" : "グループ",
+    "Group list is empty" : "グループリストが空です",
+    "Unable to retrieve the group list" : "グループリストを取得できません",
     "seconds ago" : "数秒前",
     "Connection to server lost" : "サーバーとの接続が切断されました",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
@@ -446,25 +467,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "アプリのナビゲーションにスキップする",
     "Go to %s" : "%sに移動",
     "Get your own free account" : "無料でアカウントを作成する",
-    "Connect to your account" : "あなたのアカウントに接続する",
-    "Please log in before granting %1$s access to your %2$s account." : "あなたの %2$s アカウントに %1$s アクセスを許可する前にログインしてください。",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "新しいデバイスやアプリを設定しようとしていないのに、今この画面が表示された場合、誰かがあなたを騙してデータへのアクセス権を奪取しようとしています。その場合は、ここで止めてシステム管理者に連絡してください。",
-    "App password" : "アプリパスワード",
-    "Grant access" : "アクセスを許可",
-    "Alternative log in using app password" : "アプリパスワードを使用した代替ログイン",
-    "Account access" : "アカウントによるアクセス許可",
-    "Currently logged in as %1$s (%2$s)." : "現在、%1$s (%2$s)としてログインしています。",
-    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
-    "Account connected" : "アカウントに接続しました",
-    "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
-    "You can close this window." : "このウィンドウは閉じてしまって構いません。",
     "Previous" : "前へ",
-    "This share is password-protected" : "この共有はパスワードで保護されています",
-    "The password is wrong or expired. Please try again or request a new one." : "パスワードが間違っているか有効期限切れです。後で再度お試しいただくか、新しいパスワードをリクエストしてください。",
-    "Please type in your email address to request a temporary password" : "仮パスワードを申請するためにメールアドレスを入力してください。",
-    "Email address" : "メールアドレス",
-    "Password sent!" : "パスワードを送信しました",
-    "You are not authorized to request a password for this share" : "この共有のためのパスワードを要求する権限はありません。",
     "Two-factor authentication" : "二要素認証",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "このアカウントは強化セキュリティが適用されています。二要素認証を行ってください。",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "有効な二要素認証方式のうち少なくとも1つをロードできませんでした。 管理者に連絡してください。",
@@ -510,6 +513,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
     "Searching …" : "検索しています…",
     "Logging in …" : "ログイン中...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
     "Loading apps …" : "アプリを読み込み中…",
     "Installing apps …" : "アプリをインストールしています…",
     "Loading your contacts …" : "連絡先を読み込み中...",
@@ -541,6 +545,9 @@ OC.L10N.register(
     "Configure the database" : "データベースを設定してください",
     "Only %s is available." : "%s のみ有効です。",
     "Database account" : "データベースアカウント",
-    "Installing …" : "インストールしています…"
+    "Installing …" : "インストールしています…",
+    "Please log in before granting %1$s access to your %2$s account." : "あなたの %2$s アカウントに %1$s アクセスを許可する前にログインしてください。",
+    "Currently logged in as %1$s (%2$s)." : "現在、%1$s (%2$s)としてログインしています。",
+    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可"
 },
 "nplurals=1; plural=0;");
