@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "უცნობი ფაილის ტიპი",
     "An error occurred. Please contact your admin." : "მოხდა შეცდომა. გთხოვთ, დაუკავშირდეთ თქვენს ადმინისტრატორს.",
     "Invalid image" : "არასწორი სურათი",
-    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
-    "No crop data provided" : "No crop data provided",
-    "No valid crop data provided" : "No valid crop data provided",
-    "Crop is not square" : "Crop is not square",
     "State token does not match" : "State token does not match",
     "Invalid app password" : "Invalid app password",
     "Could not complete login" : "Could not complete login",
@@ -29,6 +25,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
     "Login" : "Login",
+    "Unsupported email length (>255)" : "იმეილი ძალიან გრძელია (>255)",
     "Password reset is disabled" : "Password reset is disabled",
     "Could not reset password because the token is expired" : "Could not reset password because the token is expired",
     "Could not reset password because the token is invalid" : "Could not reset password because the token is invalid",
@@ -38,6 +35,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
     "Reset your password" : "Reset your password",
+    "The given provider is not available" : "მოცემული პროვაიდერი მიუწვდომელია",
     "Task not found" : "Task not found",
     "Internal error" : "Internal error",
     "Not found" : "Not found",
@@ -48,16 +46,16 @@ OC.L10N.register(
     "No translation provider available" : "No translation provider available",
     "Could not detect language" : "Could not detect language",
     "Unable to translate" : "Unable to translate",
-    "Nextcloud Server" : "Nextcloud Server",
-    "Some of your link shares have been removed" : "Some of your link shares have been removed",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
-    "Learn more ↗" : "Learn more ↗",
-    "Preparing update" : "Preparing update",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Repair step:",
     "Repair info:" : "Repair info:",
     "Repair warning:" : "Repair warning:",
     "Repair error:" : "Repair error:",
+    "Nextcloud Server" : "Nextcloud Server",
+    "Some of your link shares have been removed" : "Some of your link shares have been removed",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
+    "Learn more ↗" : "Learn more ↗",
+    "Preparing update" : "Preparing update",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
     "Turned on maintenance mode" : "Turned on maintenance mode",
     "Turned off maintenance mode" : "Turned off maintenance mode",
@@ -74,16 +72,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
     "Already up to date" : "Already up to date",
-    "Error occurred while checking server setup" : "Error occurred while checking server setup",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
-    "unknown text" : "unknown text",
-    "Hello world!" : "Hello world!",
-    "sunny" : "sunny",
-    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
-    "Hello {name}" : "Hello {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
-    "new" : "new",
-    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "Unknown" : "Unknown",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
     "Update to {version}" : "Update to {version}",
     "An error occurred." : "An error occurred.",
@@ -92,19 +81,24 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
     "Continue to {productName}" : "Continue to {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
+    "Done" : "დასრულდა",
     "Applications menu" : "Applications menu",
     "Apps" : "Apps",
     "More apps" : "More apps",
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "No",
     "Yes" : "Yes",
+    "App password" : "App password",
+    "Grant access" : "Grant access",
     "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
     "Create share" : "Create share",
+    "Please copy the link manually:" : "გთხოვთ, ლინკი ხელით ჩასვათ:",
     "Custom date range" : "Custom date range",
     "Pick start date" : "Pick start date",
     "Pick end date" : "Pick end date",
     "Search in date range" : "Search in date range",
-    "Searching …" : "Searching …",
+    "Clear search" : "წაშალე ძიების ისტორია",
+    "Search everywhere" : "მოძებნე ყველგან",
     "Start typing to search" : "Start typing to search",
     "No matching results" : "No matching results",
     "Today" : "Today",
@@ -114,23 +108,28 @@ OC.L10N.register(
     "Last year" : "Last year",
     "Unified search" : "Unified search",
     "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
+    "Places" : "ადგილები",
     "Date" : "Date",
     "Search people" : "Search people",
     "People" : "People",
     "Filter in current view" : "Filter in current view",
+    "Results" : "შედეგი",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
     "Log in" : "Log in",
-    "Logging in …" : "Logging in …",
     "Log in to {productName}" : "Log in to {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
+    "Wrong login or password." : "არასწორი მომხმარებელი ან პაროლი.",
+    "This account is disabled" : "ექაუნთი გათიშულია",
     "Account name or email" : "Account name or email",
+    "Account name" : "ექაუნთის სახელი",
     "Server side authentication failed!" : "Server side authentication failed!",
     "Please contact your administrator." : "Please contact your administrator.",
+    "Session error" : "სესიის შეცდომა",
     "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Password" : "პაროლი",
     "Log in with a device" : "Log in with a device",
+    "Login or email" : "მომხმარებელის სახელი ან იმეილი",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
@@ -150,21 +149,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
     "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
-    "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
     "App download or installation failed" : "App download or installation failed",
     "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
     "Cannot install this app" : "Cannot install this app",
     "Skip" : "Skip",
-    "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
+    "Online" : "Online",
+    "Away" : "Away",
+    "Busy" : "Busy",
+    "Do not disturb" : "Do not disturb",
+    "Invisible" : "Invisible",
     "Avatar of {displayName}" : "Avatar of {displayName}",
     "Settings menu" : "Settings menu",
-    "Loading your contacts …" : "Loading your contacts …",
-    "Looking for {term} …" : "Looking for {term} …",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
-    "Search contacts …" : "Search contacts …",
     "Could not load your contacts" : "Could not load your contacts",
     "No contacts found" : "No contacts found",
     "Show all contacts" : "Show all contacts",
@@ -172,17 +171,41 @@ OC.L10N.register(
     "Search" : "Search",
     "No results for {query}" : "No results for {query}",
     "Press Enter to start searching" : "Press Enter to start searching",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
-    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","გთხოვთ, შეიყვანოთ {minSearchLength} ან მეტი ასო ძიებისთვის"],
+    "An error occurred while searching for {type}" : "შეცდომა დაფიქსირდა {type}-ის ძიებისას",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
-    "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
-    "Forgot password?" : "Forgot password?",
+    "Search for {name} only" : "მოძებნე მარტო {name} ",
+    "Forgot password?" : "დაგავიწყდათ პაროლი?",
     "Back to login form" : "Back to login form",
-    "Back" : "Back",
+    "Back" : "უკან",
     "Login form is disabled." : "Login form is disabled.",
-    "More actions" : "More actions",
+    "Connect to your account" : "Connect to your account",
     "Security warning" : "Security warning",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
+    "Alternative log in using app password" : "Alternative log in using app password",
+    "Account connected" : "Account connected",
+    "Your client should now be connected!" : "Your client should now be connected!",
+    "You can close this window." : "You can close this window.",
+    "Account access" : "Account access",
+    "More actions" : "More actions",
+    "This share is password-protected" : "This share is password-protected",
+    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
+    "Submit" : "Submit",
+    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
+    "Password sent!" : "Password sent!",
+    "You are not authorized to request a password for this share" : "You are not authorized to request a password for this share",
+    "Email address" : "Email address",
+    "Request password" : "Request password",
+    "Password is too weak" : "პაროლი ძალიან სუსტია",
+    "Password is weak" : "პაროლი სუსტია",
+    "Password is average" : "პაროლი დამაკმაყოფილებელია",
+    "Password is strong" : "პაროლი ძლიერია",
+    "Password is very strong" : "პაროლი ძალიან ძლიერია",
+    "Password is extremely strong" : "პაროლი ძალზე ძლიერია",
+    "Unknown password strength" : "პაროლის სიძლიერე უცნობია",
+    "Create administration account" : "შექმენი ადმინისტრატორის ექაუნთი",
+    "Administration account name" : "ადმინისტრატორის ექაუნთის სახელი",
+    "Administration account password" : "ადმინისტრატორის ექაუნთის პაროლი",
     "Storage & database" : "Storage & database",
     "Data folder" : "Data folder",
     "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
@@ -197,7 +220,6 @@ OC.L10N.register(
     "Database tablespace" : "Database tablespace",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
     "Database host" : "Database host",
-    "Installing …" : "Installing …",
     "Install" : "Install",
     "Need help?" : "Need help?",
     "See the documentation" : "See the documentation",
@@ -206,7 +228,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
     "Copy to {target}" : "Copy to {target}",
@@ -226,7 +247,10 @@ OC.L10N.register(
     "(all selected)" : "(all selected)",
     "({count} selected)" : "({count} selected)",
     "Error loading file exists template" : "Error loading file exists template",
-    "Saving …" : "Saving …",
+    "Saving …" : "Saving …",
+    "Groups" : "Groups",
+    "Group list is empty" : "Group list is empty",
+    "Unable to retrieve the group list" : "Unable to retrieve the group list",
     "seconds ago" : "seconds ago",
     "Connection to server lost" : "Connection to server lost",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
@@ -241,24 +265,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "New in",
     "View changelog" : "View changelog",
-    "No action available" : "No action available",
-    "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
-    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
-    "Restricted" : "Restricted",
-    "Invisible" : "Invisible",
-    "Delete" : "Delete",
-    "Rename" : "Rename",
-    "Collaborative tags" : "Collaborative tags",
-    "No tags found" : "No tags found",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
     "Help" : "Help",
     "Access forbidden" : "Access forbidden",
+    "Back to %s" : "Back to %s",
     "Page not found" : "Page not found",
     "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
-    "Back to %s" : "Back to %s",
     "Too many requests" : "Too many requests",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "Error",
@@ -282,25 +297,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Skip to navigation of app",
     "Go to %s" : "Go to %s",
     "Get your own free account" : "Get your own free account",
-    "Connect to your account" : "Connect to your account",
-    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
-    "App password" : "App password",
-    "Grant access" : "Grant access",
-    "Alternative log in using app password" : "Alternative log in using app password",
-    "Account access" : "Account access",
-    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
-    "Account connected" : "Account connected",
-    "Your client should now be connected!" : "Your client should now be connected!",
-    "You can close this window." : "You can close this window.",
     "Previous" : "Previous",
-    "This share is password-protected" : "This share is password-protected",
-    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
-    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
-    "Email address" : "Email address",
-    "Password sent!" : "Password sent!",
-    "You are not authorized to request a password for this share" : "You are not authorized to request a password for this share",
     "Two-factor authentication" : "Two-factor authentication",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
@@ -332,26 +329,49 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
-    "Currently open" : "Currently open",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "You have not added any info yet" : "You have not added any info yet",
-    "{user} has not added any info yet" : "{user} has not added any info yet",
-    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
-    "Edit Profile" : "Edit Profile",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
-    "Error loading message template: {error}" : "Error loading message template: {error}",
+    "Error occurred while checking server setup" : "Error occurred while checking server setup",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
+    "unknown text" : "unknown text",
+    "Hello world!" : "Hello world!",
+    "sunny" : "sunny",
+    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
+    "Hello {name}" : "Hello {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
+    "new" : "new",
+    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "Searching …" : "Searching …",
+    "Logging in …" : "Logging in …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
+    "Loading apps …" : "Loading apps …",
+    "Installing apps …" : "Installing apps …",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
+    "Search contacts …" : "Search contacts …",
+    "Loading more results …" : "შედეგი იტვირთება …",
+    "Search {types} …" : "Search {types} …",
+    "Saving …" : "Saving …",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
-    "Profile not found" : "Profile not found",
-    "The profile does not exist." : "The profile does not exist.",
+    "No action available" : "No action available",
+    "Error fetching contact actions" : "Error fetching contact actions",
+    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
+    "Restricted" : "Restricted",
+    "Delete" : "Delete",
+    "Rename" : "Rename",
+    "Collaborative tags" : "Collaborative tags",
+    "No tags found" : "No tags found",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
     "Show password" : "Show password",
     "Toggle password visibility" : "Toggle password visibility",
     "Configure the database" : "Configure the database",
-    "Only %s is available." : "Only %s is available."
+    "Only %s is available." : "Only %s is available.",
+    "Installing …" : "Installing …",
+    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
+    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account."
 },
 "nplurals=2; plural=(n!=1);");
