@@ -73,12 +73,14 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
     "Continue to {productName}" : "Tęsti {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
+    "Done" : "Atlikta",
     "Applications menu" : "Programų meniu",
     "Apps" : "Programėlės",
     "More apps" : "Daugiau programėlių",
     "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
     "No" : "Ne",
     "Yes" : "Taip",
+    "Grant access" : "Suteikti prieigą",
     "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "Create share" : "Sukurti viešinį",
     "Please copy the link manually:" : "Nukopijuokite nuorodą rankiniu būdu:",
@@ -95,7 +97,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Prisijunkite prie {productName}",
     "Wrong login or password." : "Neteisingas prisijungimas ar slaptažodis.",
     "This account is disabled" : "Ši paskyra yra išjungta",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
     "Account name or email" : "Paskyros vardas ar el. paštas",
     "Account name" : "Paskyros pavadinimas",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
@@ -103,6 +104,7 @@ OC.L10N.register(
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Password" : "Slaptažodis",
+    "Remember me" : "Prisiminti mane",
     "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Login or email" : "Prisijungimas ar el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
@@ -144,8 +146,20 @@ OC.L10N.register(
     "Search for {name} only" : "Ieškoti tik {name}",
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
-    "More actions" : "Daugiau veiksmų",
+    "Connect to your account" : "Prisijunkite prie paskyros",
     "Security warning" : "Saugumo įspėjimas",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
+    "Account connected" : "Paskyra prijungta",
+    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
+    "You can close this window." : "Galite užverti šį langą.",
+    "Account access" : "Paskyros prieiga",
+    "More actions" : "Daugiau veiksmų",
+    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
+    "Submit" : "Pateikti",
+    "Password sent!" : "Slaptažodis išsiųstas!",
+    "Email address" : "El. pašto adresas",
+    "Request password" : "Prašyti slaptažodžio",
+    "Forgot password" : "Pamiršau slaptažodį",
     "Storage & database" : "Saugykla ir duomenų bazė",
     "Data folder" : "Duomenų aplankas",
     "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
@@ -186,6 +200,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} pažymėtų)",
     "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
     "Saving …" : "Įrašoma…",
+    "Groups" : "Grupės",
+    "Group list is empty" : "Grupės sąrašas yra tuščias",
+    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
     "seconds ago" : "prieš keletą sekundžių",
     "Connection to server lost" : "Ryšys su serveriu nutrūko",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
@@ -230,20 +247,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Pereiti į programėlės naršymą",
     "Go to %s" : "Pereiti į %s",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
-    "Connect to your account" : "Prisijunkite prie paskyros",
-    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
-    "Grant access" : "Suteikti prieigą",
-    "Account access" : "Paskyros prieiga",
-    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
-    "Account connected" : "Paskyra prijungta",
-    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
-    "You can close this window." : "Galite užverti šį langą.",
     "Previous" : "Ankstesnis",
-    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
-    "Email address" : "El. pašto adresas",
-    "Password sent!" : "Slaptažodis išsiųstas!",
     "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
@@ -285,6 +289,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
     "Searching …" : "Ieškoma…",
     "Logging in …" : "Prisijungiama …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
     "Loading apps …" : "Įkeliamos programėlės…",
     "Installing apps …" : "Įdiegiamos programėlės…",
     "Loading your contacts …" : "Įkeliami jūsų adresatai…",
@@ -313,6 +318,9 @@ OC.L10N.register(
     "Configure the database" : "Konfigūruokite duomenų bazę",
     "Only %s is available." : "Yra prieinama tik %s.",
     "Database account" : "Duomenų bazės paskyra",
-    "Installing …" : "Įdiegiama…"
+    "Installing …" : "Įdiegiama…",
+    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
+    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
