@@ -344,6 +344,14 @@ OC.L10N.register(
     "You are currently not identified." : "Моментално не сте идентификувани.",
     "Set public name" : "Постави јавно име",
     "Change public name" : "Промени јавно име",
+    "This share is password-protected" : "Ова споделување е заштитено со лозинка",
+    "The password is wrong or expired. Please try again or request a new one." : "Лозинката е погрешна или е истечена. Ве молиме обидете се повторно или побарајте нова лозинка.",
+    "Submit" : "Испрати",
+    "Please type in your email address to request a temporary password" : "Внесете ја вашата е-пошта адреса за да добиете привремена лозинка",
+    "Password sent!" : "Лозинка е испратена!",
+    "You are not authorized to request a password for this share" : "Не сте авторизиран за да побарате лозинка за ова споделување",
+    "Email address" : "Е-пошта адреси",
+    "Request password" : "Барање на лозинка",
     "Password is too weak" : "Лозинката е премногу слаба",
     "Password is weak" : "Лозинката е слава",
     "Password is average" : "Лозинката е просечна",
@@ -461,12 +469,6 @@ OC.L10N.register(
     "Go to %s" : "Оди до %s",
     "Get your own free account" : "Креирајте ваша сметка",
     "Previous" : "Претходно",
-    "This share is password-protected" : "Ова споделување е заштитено со лозинка",
-    "The password is wrong or expired. Please try again or request a new one." : "Лозинката е погрешна или е истечена. Ве молиме обидете се повторно или побарајте нова лозинка.",
-    "Please type in your email address to request a temporary password" : "Внесете ја вашата е-пошта адреса за да добиете привремена лозинка",
-    "Email address" : "Е-пошта адреси",
-    "Password sent!" : "Лозинка е испратена!",
-    "You are not authorized to request a password for this share" : "Не сте авторизиран за да побарате лозинка за ова споделување",
     "Two-factor authentication" : "Двофакторна автентикација",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Подобрете ја сигурноста на вашата сметка. Изберете двофакторна автентификација:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможе да се вчита овозможениот начини за дво-факторна автентификација. Ве молиме контактирајте го администраторот.",
