@@ -136,12 +136,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
     "Continue to {productName}" : "Fortsett til {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
+    "Done" : "Ferdig",
     "Applications menu" : "Applikasjonsmeny",
     "Apps" : "Apper",
     "More apps" : "Flere apper",
     "_{count} notification_::_{count} notifications_" : ["{count} varsel","{count} varsler"],
     "No" : "Nei",
     "Yes" : "Ja",
+    "App password" : "App passord",
+    "Grant access" : "Gi tilgang",
     "The remote URL must include the user." : "Den eksterne URL-adressen må inkludere brukeren.",
     "Invalid remote URL." : "Ugyldig ekstern URL.",
     "Failed to add the public link to your Nextcloud" : "Feil oppsto under oppretting av offentlig lenke til din Nextcloud",
@@ -181,7 +184,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Logg på {productName}",
     "Wrong login or password." : "Feil pålogging eller passord.",
     "This account is disabled" : "Denne kontoen er deaktivert",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har detektert flere ugyldige påloggingsforsøk fra din IP-adresse. Derfor er din neste innlogging forsinket med opptil 30 sekunder.",
     "Account name or email" : "Kontonavn eller e-postadresse",
     "Account name" : "Kontonavn",
     "Server side authentication failed!" : "Autentisering mislyktes på serveren!",
@@ -246,12 +248,29 @@ OC.L10N.register(
     "Back" : "Tilbake",
     "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-påloggingsskjemaet er deaktivert. Bruk et annet påloggingsalternativ hvis tilgjengelig, eller kontakt administrasjonen din.",
+    "Connect to your account" : "Koble til kontoen din",
+    "Security warning" : "Sikkerhetsadvarsel",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke prøver å sette opp en ny enhet eller app, så er det noen som nå prøver å lure deg til å gi de tilgang til dine data. Stopp i så fall øyeblikkelig og kontakt din systemadministrator.",
+    "Alternative log in using app password" : "Alternativ innlogging ved bruk av app passord",
+    "Account connected" : "Konto er koblet",
+    "Your client should now be connected!" : "Din klient skal nå være koblet til!",
+    "You can close this window." : "Du kan lukke dette vinduet.",
+    "Account access" : "Kontotilgang",
     "More actions" : "Flere handlinger",
     "User menu" : "Brukermeny",
     "Your guest name: {user}" : "Ditt gjestenavn: {user}",
     "You are currently not identified." : "Du er for øyeblikket ikke identifisert.",
     "Set public name" : "Sett offentlig navn",
     "Change public name" : "Endre offentlig navn",
+    "This share is password-protected" : "Denne deling er beskyttet med passord",
+    "The password is wrong or expired. Please try again or request a new one." : "Passordet er feil eller har utgått. Prøv igjen eller be om et nytt.",
+    "Submit" : "Send inn",
+    "Please type in your email address to request a temporary password" : "Oppgi e-post adresse for å få midlertidig passord",
+    "Password sent!" : "Passord er sendt.",
+    "You are not authorized to request a password for this share" : "Du mangler tillatelse for å etterspørre passord til deling. ",
+    "Email address" : "E-post adresse",
+    "Request password" : "Forespør om passord",
+    "Forgot password" : "Glemt passord",
     "Password is too weak" : "Passordet er for svakt",
     "Password is weak" : "Passordet er svakt",
     "Password is average" : "Passordet er middels sterkt",
@@ -261,7 +280,6 @@ OC.L10N.register(
     "Unknown password strength" : "Ukjent passordstyrke",
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi <code>.htaccess</code>-filen ikke fungerer.",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For informasjon om hvordan å konfigurere din server, vennligst {linkStart}se dokumentasjonen{linkEnd}",
-    "Security warning" : "Sikkerhetsadvarsel",
     "Create administration account" : "Opprett administratorkonto",
     "Storage & database" : "Lagring og database",
     "Data folder" : "Datamappe",
@@ -307,6 +325,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} valgt)",
     "Error loading file exists template" : "Feil ved lasting av \"filen eksisterer\"-mal",
     "Saving …" : "Lagrer ...",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Gruppeliste er tom",
+    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
     "seconds ago" : "for få sekunder siden",
     "Connection to server lost" : "Mistet tilkobling til server",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
@@ -357,25 +378,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Gå til navigasjon av app",
     "Go to %s" : "Gå til %s",
     "Get your own free account" : "Få din egen gratis konto",
-    "Connect to your account" : "Koble til kontoen din",
-    "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke prøver å sette opp en ny enhet eller app, så er det noen som nå prøver å lure deg til å gi de tilgang til dine data. Stopp i så fall øyeblikkelig og kontakt din systemadministrator.",
-    "App password" : "App passord",
-    "Grant access" : "Gi tilgang",
-    "Alternative log in using app password" : "Alternativ innlogging ved bruk av app passord",
-    "Account access" : "Kontotilgang",
-    "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto.",
-    "Account connected" : "Konto er koblet",
-    "Your client should now be connected!" : "Din klient skal nå være koblet til!",
-    "You can close this window." : "Du kan lukke dette vinduet.",
     "Previous" : "Forrige",
-    "This share is password-protected" : "Denne deling er beskyttet med passord",
-    "The password is wrong or expired. Please try again or request a new one." : "Passordet er feil eller har utgått. Prøv igjen eller be om et nytt.",
-    "Please type in your email address to request a temporary password" : "Oppgi e-post adresse for å få midlertidig passord",
-    "Email address" : "E-post adresse",
-    "Password sent!" : "Passord er sendt.",
-    "You are not authorized to request a password for this share" : "Du mangler tillatelse for å etterspørre passord til deling. ",
     "Two-factor authentication" : "Tofaktor-autentisering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Utvidet sikkerhet er tilgjengelig fo rdin konto. Velg en to-faktor for autentisering.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunne ikke laste minst en av de aktiverte tofaktor metodene. Ta kontakt med administrasjonen din.",
@@ -421,6 +424,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Direkte lenke kopiert til utklippstavlen",
     "Searching …" : "Søker ...",
     "Logging in …" : "Logger inn…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har detektert flere ugyldige påloggingsforsøk fra din IP-adresse. Derfor er din neste innlogging forsinket med opptil 30 sekunder.",
     "Loading apps …" : "Laster apper ... ",
     "Installing apps …" : "Installerer apper ... ",
     "Loading your contacts …" : "Laster inn kontaktene dine…",
@@ -452,6 +456,9 @@ OC.L10N.register(
     "Configure the database" : "Sett opp databasen",
     "Only %s is available." : "Kun %s er tilgjengelig.",
     "Database account" : "Databasekonto",
-    "Installing …" : "Installerer ..."
+    "Installing …" : "Installerer ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
+    "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto."
 },
 "nplurals=2; plural=(n != 1);");
