@@ -68,6 +68,7 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
     "No" : "No",
     "Yes" : "Yes",
+    "Grant access" : "Donar accès",
     "Start typing to search" : "Començatz de picar per recercar",
     "Today" : "Uèi",
     "Date" : "Data",
@@ -75,7 +76,6 @@ OC.L10N.register(
     "Load more results" : "Cargar mai de resultats",
     "Log in" : "Connexion",
     "Log in to {productName}" : "Se connectar a {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
     "Account name or email" : "Nom d’utilizaire o email",
     "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
     "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
@@ -124,8 +124,21 @@ OC.L10N.register(
     "Forgot password?" : "Senhal oblidat ?",
     "Back" : "Retorn",
     "Login form is disabled." : "Lo formulari de connexion es desactivat.",
-    "More actions" : "Mai d’accions",
+    "Connect to your account" : "Connectatz-vos a vòstre compte",
     "Security warning" : "Avertiment de seguretat",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
+    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
+    "Account connected" : "Compte connectat",
+    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
+    "You can close this window." : "Podètz tampar aquesta fenèstra.",
+    "Account access" : "Accès compte",
+    "More actions" : "Mai d’accions",
+    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
+    "Submit" : "Transmetre",
+    "Password sent!" : "Senhal enviat !",
+    "You are not authorized to request a password for this share" : "Sètz pas autorizat a demandar un senhal per aqueste partiment",
+    "Email address" : "Adreça mail",
+    "Request password" : "Demandar senhal",
     "Storage & database" : "Emmagazinatge & basa de donada",
     "Data folder" : "Dossièr de donadas",
     "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
@@ -161,6 +174,8 @@ OC.L10N.register(
     "Continue" : "Contunhar",
     "(all selected)" : "(totes seleccionats)",
     "({count} selected)" : "({count} seleccionats)",
+    "Group list is empty" : "La lista de grop es voida",
+    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
     "seconds ago" : "fa qualques segondas",
     "Connection to server lost" : "Connexion al servidor perduda",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
@@ -204,22 +219,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Passar a la navegacion d’aplications",
     "Go to %s" : "Anar a %s",
     "Get your own free account" : "Obtenètz vòstre pròpri compte gratuit",
-    "Connect to your account" : "Connectatz-vos a vòstre compte",
-    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
-    "Grant access" : "Donar accès",
-    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
-    "Account access" : "Accès compte",
-    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
-    "Account connected" : "Compte connectat",
-    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
-    "You can close this window." : "Podètz tampar aquesta fenèstra.",
     "Previous" : "Precedent",
-    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
-    "Email address" : "Adreça mail",
-    "Password sent!" : "Senhal enviat !",
-    "You are not authorized to request a password for this share" : "Sètz pas autorizat a demandar un senhal per aqueste partiment",
     "Two-factor authentication" : "Autentificacion dos factors",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguretat renfortida es activada per vòstre compte. Causissètz un segond factor per l’autentificacion :",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Cargament impossible d’almens un metòde d’autentificacion dos factors. Contactatz vòstre admin.",
@@ -259,6 +259,7 @@ OC.L10N.register(
     "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
     "Searching …" : "Recèrca…",
     "Logging in …" : "Identificacion…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
     "Loading apps …" : "Cargament aplicacions…",
     "Installing apps …" : "Installacion aplicacions…",
     "Loading your contacts …" : "Cargaments dels contactes…",
@@ -286,6 +287,9 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar la visibilitat del senhal",
     "Configure the database" : "Configurar la basa de donadas",
     "Only %s is available." : "Sonque %s es disponible.",
-    "Installing …" : "Installacion..."
+    "Installing …" : "Installacion...",
+    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s."
 },
 "nplurals=2; plural=(n > 1);");
