@@ -205,12 +205,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizacja nie powiodła się. Zgłoś ten problem do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">społeczności Nextcloud</a>.",
     "Continue to {productName}" : "Przejdź do {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundę.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundy.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund."],
+    "Done" : "Gotowe",
     "Applications menu" : "Menu aplikacji",
     "Apps" : "Aplikacje",
     "More apps" : "Więcej aplikacji",
     "_{count} notification_::_{count} notifications_" : ["{count} powiadomienie","{count} powiadomienia","{count} powiadomień","{count} powiadomień"],
     "No" : "Nie",
     "Yes" : "Tak",
+    "App password" : "Hasło aplikacji",
+    "Grant access" : "Udziel dostępu",
     "The remote URL must include the user." : "Zdalny adres URL musi zawierać nazwę użytkownika.",
     "Invalid remote URL." : "Nieprawidłowy zdalny adres URL.",
     "Failed to add the public link to your Nextcloud" : "Nie udało się dodać linku publicznego do Nextcloud",
@@ -252,7 +255,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Zaloguj się do {productName}",
     "Wrong login or password." : "Błędny login lub hasło.",
     "This account is disabled" : "To konto jest wyłączone",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
     "Account name or email" : "Nazwa konta lub e-mail",
     "Account name" : "Nazwa konta",
     "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
@@ -325,12 +327,29 @@ OC.L10N.register(
     "Back" : "Wstecz",
     "Login form is disabled." : "Formularz logowania jest wyłączony.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formularz logowania Nextcloud jest wyłączony. Użyj innej opcji logowania, jeśli jest dostępna, lub skontaktuj się z administracją.",
+    "Connect to your account" : "Połącz z kontem",
+    "Security warning" : "Ostrzeżenie bezpieczeństwa",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
+    "Alternative log in using app password" : "Alternatywne logowanie przy użyciu hasła do aplikacji",
+    "Account connected" : "Połączono z kontem",
+    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
+    "You can close this window." : "Możesz zamknąć to okno.",
+    "Account access" : "Dostęp do konta",
     "More actions" : "Więcej akcji",
     "User menu" : "Menu użytkownika",
     "Your guest name: {user}" : "Twoja nazwa gościa: {user}",
     "You are currently not identified." : "Obecnie nie jesteś zidentyfikowany.",
     "Set public name" : "Ustaw nazwę publiczną",
     "Change public name" : "Zmień nazwę publiczną",
+    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
+    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
+    "Submit" : "Wyślij",
+    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
+    "Password sent!" : "Hasło wysłane!",
+    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
+    "Email address" : "Adres e-mail",
+    "Request password" : "Żądanie hasła",
+    "Forgot password" : "Zapomniałeś hasła?",
     "Password is too weak" : "Hasło jest za słabe",
     "Password is weak" : "Hasło jest słabe",
     "Password is average" : "Hasło jest przeciętne",
@@ -342,7 +361,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Aby uzyskać informacje na temat prawidłowej konfiguracji serwera, {linkStart}zapoznaj się z dokumentacją{linkEnd}",
     "Autoconfig file detected" : "Wykryto plik autokonfiguracjny",
     "The setup form below is pre-filled with the values from the config file." : "Poniższy formularz konfiguracji jest wstępnie wypełniony wartościami z pliku konfiguracyjnego.",
-    "Security warning" : "Ostrzeżenie bezpieczeństwa",
     "Create administration account" : "Utwórz konto administracyjne",
     "Administration account name" : "Nazwa konta administracyjnego",
     "Administration account password" : "Hasło do konta administracyjnego",
@@ -395,6 +413,9 @@ OC.L10N.register(
     "({count} selected)" : "(wybrano {count})",
     "Error loading file exists template" : "Błąd podczas ładowania pliku istniejącego szablonu",
     "Saving …" : "Zapisywanie…",
+    "Groups" : "Grupy",
+    "Group list is empty" : "Lista grup jest pusta",
+    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
     "seconds ago" : "przed chwilą",
     "Connection to server lost" : "Utracono połączenie z serwerem",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
@@ -445,25 +466,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Przejdź do nawigacji aplikacji",
     "Go to %s" : "Przejdź do %s",
     "Get your own free account" : "Załóż własne bezpłatne konto",
-    "Connect to your account" : "Połącz z kontem",
-    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
-    "App password" : "Hasło aplikacji",
-    "Grant access" : "Udziel dostępu",
-    "Alternative log in using app password" : "Alternatywne logowanie przy użyciu hasła do aplikacji",
-    "Account access" : "Dostęp do konta",
-    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s.",
-    "Account connected" : "Połączono z kontem",
-    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
-    "You can close this window." : "Możesz zamknąć to okno.",
     "Previous" : "Poprzedni",
-    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
-    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
-    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
-    "Email address" : "Adres e-mail",
-    "Password sent!" : "Hasło wysłane!",
-    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
     "Two-factor authentication" : "Uwierzytelnianie dwuskładnikowe",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Dodatkowe zabezpieczenia są włączone dla Twojego konta. Wybierz drugą metodę uwierzytelniania:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nie można załadować co najmniej jednej z włączonych dwuskładnikowych metod uwierzytelnienia. Skontaktuj się z administratorem.",
@@ -509,6 +512,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka",
     "Searching …" : "Wyszukiwanie…",
     "Logging in …" : "Logowanie…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
     "Loading apps …" : "Wczytywanie aplikacji…",
     "Installing apps …" : "Instalowanie aplikacji…",
     "Loading your contacts …" : "Wczytywanie kontaktów…",
@@ -540,6 +544,9 @@ OC.L10N.register(
     "Configure the database" : "Skonfiguruj bazę danych",
     "Only %s is available." : "Dostępne jest tylko %s.",
     "Database account" : "Konto bazy danych",
-    "Installing …" : "Instalowanie…"
+    "Installing …" : "Instalowanie…",
+    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
