@@ -347,6 +347,15 @@ OC.L10N.register(
     "You are currently not identified." : "No momento, você não está identificado.",
     "Set public name" : "Definir nome público",
     "Change public name" : "Mudar nome público",
+    "This share is password-protected" : "Compartilhamento protegido por senha",
+    "The password is wrong or expired. Please try again or request a new one." : "A senha está errada ou expirou. Tente novamente ou solicite uma nova.",
+    "Submit" : "Enviar",
+    "Please type in your email address to request a temporary password" : "Digite seu endereço de e-mail para solicitar uma senha temporária",
+    "Password sent!" : "Senha enviada!",
+    "You are not authorized to request a password for this share" : "Você não está autorizado a solicitar uma senha para este compartilhamento",
+    "Email address" : "Endereço de e-mail",
+    "Request password" : "Solicitar a senha",
+    "Forgot password" : "Esqueci a senha",
     "Password is too weak" : "A senha é muito fraca",
     "Password is weak" : "A senha é fraca",
     "Password is average" : "A senha é média",
@@ -464,12 +473,6 @@ OC.L10N.register(
     "Go to %s" : "Vá para %s",
     "Get your own free account" : "Obtenha uma conta grátis",
     "Previous" : "Anterior",
-    "This share is password-protected" : "Compartilhamento protegido por senha",
-    "The password is wrong or expired. Please try again or request a new one." : "A senha está errada ou expirou. Tente novamente ou solicite uma nova.",
-    "Please type in your email address to request a temporary password" : "Digite seu endereço de e-mail para solicitar uma senha temporária",
-    "Email address" : "Endereço de e-mail",
-    "Password sent!" : "Senha enviada!",
-    "You are not authorized to request a password for this share" : "Você não está autorizado a solicitar uma senha para este compartilhamento",
     "Two-factor authentication" : "Autenticação de dois fatores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança aprimorada está ativada para sua conta. Escolha um segundo fator para autenticação:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar ao menos um dos métodos de autenticação de dois fatores ativados. Por favor, entre em contato com o administrador.",
