@@ -179,6 +179,15 @@ OC.L10N.register(
     "You can close this window." : "Puteți închide această fereastră.",
     "Account access" : "Acces cont",
     "More actions" : "Mai multe acțiuni",
+    "This share is password-protected" : "Această partajare este protejată cu parolă",
+    "The password is wrong or expired. Please try again or request a new one." : "Parola este greșită sau a expirat. Încercați din nou sau solicitați actualizarea acesteia.",
+    "Submit" : "Trimite",
+    "Please type in your email address to request a temporary password" : "Introduceți emailul dumneavoastră pentru a solicita o parolă provizorie",
+    "Password sent!" : "Parola a fost transmisă!",
+    "You are not authorized to request a password for this share" : "Nu sunteți autorizat să solicitați o parolă pentru această partajare",
+    "Email address" : "Email",
+    "Request password" : "Solicitați o parolă",
+    "Forgot password" : "Am uitat parola",
     "Storage & database" : "Stocare și baza de date",
     "Data folder" : "Director date",
     "Install and activate additional PHP modules to choose other database types." : "Instalează și activează module PHP adiționale pentru a putea alege alte tipuri de baze de date.",
@@ -270,12 +279,6 @@ OC.L10N.register(
     "Go to %s" : "Salt la %s",
     "Get your own free account" : "Obțineți contul personal gratuit",
     "Previous" : "Precedentul",
-    "This share is password-protected" : "Această partajare este protejată cu parolă",
-    "The password is wrong or expired. Please try again or request a new one." : "Parola este greșită sau a expirat. Încercați din nou sau solicitați actualizarea acesteia.",
-    "Please type in your email address to request a temporary password" : "Introduceți emailul dumneavoastră pentru a solicita o parolă provizorie",
-    "Email address" : "Email",
-    "Password sent!" : "Parola a fost transmisă!",
-    "You are not authorized to request a password for this share" : "Nu sunteți autorizat să solicitați o parolă pentru această partajare",
     "Two-factor authentication" : "Autentificare în doi-factori",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Acest cont are activată securitatea îmbunătățită. Selectați al doilea factor pentru autentificare:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nu s-a putut încărca cel puțin o metodă de autentificare în doi pași. Contactați administratorul.",
