@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Неизвестный тип файла",
     "An error occurred. Please contact your admin." : "Произошла ошибка. Свяжитесь со своим администратором.",
     "Invalid image" : "Недопустимое изображение",
-    "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
-    "No crop data provided" : "Не указана информация о кадрировании",
-    "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
-    "Crop is not square" : "Кадр не является квадратом",
     "State token does not match" : "Токен состояния не совпадает",
     "Invalid app password" : "Неверный пароль приложения",
     "Could not complete login" : "Не удалось завершить вход в систему",
     "State token missing" : "Отсутствует токен состояния",
     "Your login token is invalid or has expired" : "Ваш токен неверен или истёк",
+    "Please use original client" : "Используйте оригинальное приложение-клиент",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Используется сборка Nextcloud для сообщества. Данная сборка не поддерживается и имеет ограниченный функционал push-уведомлений.",
     "Login" : "Войти",
     "Unsupported email length (>255)" : "Неподдерживаемая длина адреса эл. почты (более 255 символов)",
@@ -43,7 +40,9 @@ OC.L10N.register(
     "Task not found" : "Задача не найдена",
     "Internal error" : "Внутренняя ошибка",
     "Not found" : "Не найдено",
+    "Node is locked" : "Узел заблокирован",
     "Bad request" : "Неверный запрос",
+    "Input text is too long" : "Введённый текст слишком длинный",
     "Requested task type does not exist" : "Запрошенный тип задачи не существует",
     "Necessary language model provider is not available" : "Необходимый поставщик языковой модели недоступен",
     "No text to image provider is available" : "Поставщик преобразования текста в изображение недоступен",
@@ -51,6 +50,12 @@ OC.L10N.register(
     "No translation provider available" : "Поставщик услуг перевода недоступен",
     "Could not detect language" : "Не удалось определить язык",
     "Unable to translate" : "Не удается перевести",
+    "No valid filters provided" : "Нет подходящих фильтров",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Шаг восстановления:",
+    "Repair info:" : "Информация восстановления:",
+    "Repair warning:" : "Предупреждение восстановления:",
+    "Repair error:" : "Ошибка восстановления:",
     "Nextcloud Server" : "Сервер Nextcloud",
     "Some of your link shares have been removed" : "Некоторые из ваших ссылок на общие ресурсы были удалены",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Из-за ошибки в безопасности нам пришлось удалить некоторые из ваших ссылок на опубликованные файлы или папки. Перейдите по ссылке для получения дополнительной информации.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Для увеличения лимита пользователей введите код подписки в приложении «Поддержка». Оформление подписки рекомендуется при использовании Nexcloud в бизнесе, а также позволяет получить дополнительные преимущества, предлагаемые Nextcloud для корпоративных пользователей.",
     "Learn more ↗" : "Дополнительная информация ↗",
     "Preparing update" : "Подготовка к обновлению",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Шаг восстановления:",
-    "Repair info:" : "Информация восстановления:",
-    "Repair warning:" : "Предупреждение восстановления:",
-    "Repair error:" : "Ошибка восстановления:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Пожалуйста, используйте обновление из терминала, поскольку обновление через браузер отключено в вашем файле конфигурации config.php.",
     "Turned on maintenance mode" : "Включён режим обслуживания ",
     "Turned off maintenance mode" : "Отключён режим обслуживания",
@@ -79,16 +79,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (несовместимое)",
     "The following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
     "Already up to date" : "Не нуждается в обновлении",
-    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
-    "unknown text" : "неизвестный текст",
-    "Hello world!" : "Привет мир!",
-    "sunny" : "солнечно",
-    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
-    "Hello {name}" : "Здравствуйте, {name}!",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
-    "new" : "новый",
-    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
+    "Windows Command Script" : "Командный сценарий Windows",
+    "Electronic book document" : "Электронная книга",
+    "TrueType Font Collection" : "Набор шрифтов TrueType",
+    "Web Open Font Format" : "Файл шрифта в формате Open Font",
+    "GPX geographic data" : "Пространственные данные GPX",
+    "Gzip archive" : "Архив Gzip",
+    "Adobe Illustrator document" : "Файл Adode Illustrator",
+    "Java source code" : "Исходный код на языке Java",
+    "JavaScript source code" : "Исходный код на языке JavaScript",
+    "JSON document" : "Файл в формате JSON",
+    "Microsoft Access database" : "База данных Microsoft Access",
+    "Microsoft OneNote document" : "Документ Microsoft OneNote",
+    "Microsoft Word document" : "Документ Microsoft Word",
+    "Unknown" : "Неизвестно",
+    "PDF document" : "Документ в формате PDF",
+    "PostScript document" : "Документ в формате PostScript",
+    "RSS summary" : "RSS-сводка",
+    "Android package" : "Пакет Android",
+    "KML geographic data" : "Пространственные данные в формате MKL",
+    "KML geographic compressed data" : "Сжатые пространственные данные в формате KML",
+    "Lotus Word Pro document" : "Документ Lotus Word Pro",
+    "Excel spreadsheet" : "Таблица Excel",
+    "Excel add-in" : "Дополнение Excel",
+    "Excel 2007 binary spreadsheet" : "Таблица в двоичном формате Excel 2007",
+    "Excel spreadsheet template" : "Шаблон таблицы Excel",
+    "Outlook Message" : "Сообщение Outlook",
+    "PowerPoint presentation" : "Презентация Powerpoint",
+    "PowerPoint add-in" : "Дополнение Powerpoint",
+    "PowerPoint presentation template" : "Шаблон презентации Powerpoint",
+    "Word document" : "Документ Word",
+    "ODF formula" : "Формула в формате ODF",
+    "ODG drawing" : "Рисунок в формате ODG",
+    "ODG drawing (Flat XML)" : "Рисунок в формате ODG (простой XML)",
+    "ODG template" : "Шаблон ODG",
+    "ODP presentation" : "Презентация в формате ODP",
+    "ODP presentation (Flat XML)" : "Презентация в формате ODP (простой XML)",
+    "ODP template" : "Шаблон ODP",
+    "ODS spreadsheet" : "Таблица ODS",
+    "ODS spreadsheet (Flat XML)" : "Таблица ODS (плоский XML)",
+    "ODS template" : "Шаблон ODS",
+    "ODT document" : "Документ ODT",
+    "ODT document (Flat XML)" : "Документ ODT (плоский XML)",
+    "ODT template" : "Шаблон ODT",
+    "PowerPoint 2007 presentation" : "Презентация PowerPoint 2007",
+    "PowerPoint 2007 show" : "Демонстрация PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Шаблон презентации PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Таблица Excel 2007",
+    "Excel 2007 spreadsheet template" : "Шаблон таблицы Excel 2007",
+    "Word 2007 document" : "Документ Word 2007",
+    "Word 2007 document template" : "Шаблон документа Word 2007",
+    "Microsoft Visio document" : "Документ Microsoft Visio",
+    "WordPerfect document" : "Документ WordPerfect",
+    "7-zip archive" : "Архив 7-zip",
+    "Blender scene" : "Сцена Blender",
+    "Bzip2 archive" : "Архив Bzip2",
+    "Debian package" : "Пакет Debian",
+    "FictionBook document" : "Документ FictionBook",
+    "Unknown font" : "Неизвестный шрифт",
+    "Krita document" : "Документ Krita",
+    "Mobipocket e-book" : "Электронная книга Mobipocket",
+    "Windows Installer package" : "Пакет Windows Installer",
+    "Perl script" : "Сценарий Perl",
+    "PHP script" : "Сценарий PHP",
+    "Tar archive" : "Архив tar",
+    "XML document" : "Документ в формате XML",
+    "YAML document" : "Документ в формате YAML",
+    "Zip archive" : "Архив zip",
+    "Zstandard archive" : "Архив zstandart",
+    "AAC audio" : "Звуковой файл в формате AAC",
+    "FLAC audio" : "Звуковой файл в формате FLAC",
+    "MPEG-4 audio" : "Звуковой файл в формате MPEG-4",
+    "MP3 audio" : "Звуковой файл в формате MP3",
+    "Ogg audio" : "Звуковой файл в формате ogg",
+    "RIFF/WAVe standard Audio" : "Стандартное аудио RIFF/WAVe",
+    "WebM audio" : "Аудио WebM",
+    "MP3 ShoutCast playlist" : "Плейлист MP3 ShoutCast",
+    "Windows BMP image" : "Точечный рисунок Windows",
+    "Better Portable Graphics image" : "Изображение Better Portable Graphics",
+    "EMF image" : "Изображение в формате EMF",
+    "GIF image" : "Изображение в формате GIF",
+    "HEIC image" : "Изображение в формате HEIC",
+    "HEIF image" : "Изображение в формате HEIF",
+    "JPEG-2000 JP2 image" : "Изображение в формате JPEG-2000 JP2",
+    "JPEG image" : "Изображение в формате JPEG",
+    "PNG image" : "Изображение PNG",
+    "SVG image" : "Изображение в формате PNG",
+    "Truevision Targa image" : "Изображение в формате Truevision Targa",
+    "TIFF image" : "Изображение в формате TIFF",
+    "WebP image" : "Изображение в формате WebP",
+    "Digital raw image" : "Файл цифрового негатива",
+    "Windows Icon" : "Значок Windows",
+    "Email message" : "Сообщение эл. почты",
+    "VCS/ICS calendar" : "Календарь VCS/ICS",
+    "CSS stylesheet" : "Таблица стилей CSS",
+    "CSV document" : "Документ в формате CSV",
+    "HTML document" : "Документ в формате HTML",
+    "Markdown document" : "Документ в формате Markdown",
+    "Org-mode file" : "Файл Org-mode",
+    "Plain text document" : "Текстовый документ",
+    "Rich Text document" : "Документ в формате Rich Text",
+    "Electronic business card" : "Цифровая визитная карточка",
+    "C++ source code" : "Исходный код на языке C++",
+    "LDIF address book" : "Адресная книга в формате LDIF",
+    "NFO document" : "Файл описания в формате NFO",
+    "PHP source" : "Исходный код на языке PHP",
+    "Python script" : "Файл сценария на языке Python",
+    "ReStructuredText document" : "Документ ReStructuredText",
+    "3GPP multimedia file" : "Мультимедийный файл в формате 3GPP",
+    "MPEG video" : "Видеофайл в формате MPEG",
+    "DV video" : "Видеофайл в формате DV",
+    "MPEG-2 transport stream" : "Транспортный поток в формате MPEG-2",
+    "MPEG-4 video" : "Видеофайл в формате MPEG-4",
+    "Ogg video" : "Видеофайл в формате Ogg",
+    "QuickTime video" : "Видеофайл в формате QuickTime",
+    "WebM video" : "Видеофайл в формате WebM",
+    "Flash video" : "Видеофайл в формате Flash",
+    "Matroska video" : "Видеофайл в формате Matroska",
+    "Windows Media video" : "Видеофайл в формате Windows Media",
+    "AVI video" : "Видеофайл в формате AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
     "Update to {version}" : "Обновление до версии {version}",
     "An error occurred." : "Произошла ошибка.",
@@ -97,19 +206,22 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
     "Continue to {productName}" : "Перейти к {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
+    "Done" : "Выполненные",
     "Applications menu" : "Меню приложений",
     "Apps" : "Приложения",
     "More apps" : "Ещё приложения",
     "_{count} notification_::_{count} notifications_" : ["{count} уведомление","{count} уведомлений","{count} уведомлений","{count} уведомлений"],
     "No" : "Нет",
     "Yes" : "Да",
+    "App password" : "Пароль приложения",
+    "Grant access" : "Разрешить доступ",
     "The remote URL must include the user." : "Удаленный URL-адрес должен содержать имя пользователя.",
     "Invalid remote URL." : "Неверный удаленный URL-адрес.",
     "Failed to add the public link to your Nextcloud" : "Не удалось создать общедоступную ссылку",
     "Federated user" : "Федеративный пользователь",
     "user@your-nextcloud.org" : "пользователь@ваш-nextcloud.org",
     "Create share" : "Создать общий ресурс",
-    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
+    "Direct link copied" : "Прямая ссылка скопирована",
     "Please copy the link manually:" : "Выполните копирование ссылки вручную:",
     "Custom date range" : "Настраиваемый диапазон дат",
     "Pick start date" : "Выберите дату начала",
@@ -118,14 +230,16 @@ OC.L10N.register(
     "Search in current app" : "Поиск в текущем приложении",
     "Clear search" : "Очистить поиск",
     "Search everywhere" : "Искать везде",
-    "Searching …" : "Поиск…",
+    "Searching …" : "Поиск …",
     "Start typing to search" : "Начните вводить символы для поиска",
+    "Minimum search length is {minSearchLength} characters" : "Минимальная длина поиска - {minSearchLength} символов",
     "No matching results" : "Нет совпадающих результатов",
     "Today" : "Сегодня",
     "Last 7 days" : "Последние 7 дней",
     "Last 30 days" : "Последние 30 дней",
     "This year" : "Этот год",
     "Last year" : "Прошлый год",
+    "Between {startDate} and {endDate}" : "Между {startDate} и {endDate}",
     "Unified search" : "Объединённый поиск",
     "Search apps, files, tags, messages" : "Поиск приложений, файлов, тегов, сообщений",
     "Places" : "Места",
@@ -133,22 +247,25 @@ OC.L10N.register(
     "Search people" : "Поиск людей",
     "People" : "Люди",
     "Filter in current view" : "Фильтр в текущем виде",
+    "Search connected services" : "Поиск подключенных сервисов",
     "Results" : "Результаты",
     "Load more results" : "Загрузить дополнительные результаты",
     "Search in" : "Искать в",
     "Log in" : "Войти",
-    "Logging in …" : "Вход в систему…",
+    "Logging in …" : "Вход в систему …",
     "Log in to {productName}" : "Вход в {productName}",
     "Wrong login or password." : "Неверное имя пользователя или пароль.",
     "This account is disabled" : "Эта учётная запись отключена",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
     "Account name or email" : "Учётная запись или адрес эл. почты",
     "Account name" : "Имя учётной записи",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
     "Please contact your administrator." : "Обратитесь к своему администратору.",
+    "Session error" : "Ошибка сеанса",
+    "It appears your session token has expired, please refresh the page and try again." : "Похоже, токен вашей сессии истёк. Пожалуйста, обновите страницу и попробуйте снова.",
     "An internal error occurred." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Попробуйте ещё раз или свяжитесь со своим администратором",
     "Password" : "Пароль",
+    "Remember me" : "Запомнить меня",
     "Log in with a device" : "Войти с устройства",
     "Login or email" : "Имя пользователя или адрес эл. почты",
     "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
@@ -172,21 +289,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Совместная работа с документами, таблицами и презентациями, основанная на Collabora Online.",
     "Distraction free note taking app." : "Простые приложение для ведения заметок.",
     "Recommended apps" : "Рекомендованные приложения",
-    "Loading apps …" : "Получение списка приложений…",
+    "Loading apps …" : "Загрузка приложений …",
     "Could not fetch list of apps from the App Store." : "Не удалось получить список приложений.",
     "App download or installation failed" : "Не удалось скачать или установить приложение",
     "Cannot install this app because it is not compatible" : "Приложение не может быть установлено, так как оно несовместимо",
     "Cannot install this app" : "Это приложение не может быть установлено",
     "Skip" : "Пропустить",
-    "Installing apps …" : "Установка приложений…",
+    "Installing apps …" : "Установка приложений …",
     "Install recommended apps" : "Установить рекомендуемые приложения",
+    "Online" : "В сети",
+    "Away" : "Неактивен",
+    "Busy" : "Занят",
+    "Do not disturb" : "Не беспокоить",
+    "Mute all notifications" : "Без уведомлений",
+    "Invisible" : "Невидимый",
+    "Appear offline" : "\"Не в сети\" для остальных",
     "Avatar of {displayName}" : "Изображение профиля {displayName}",
     "Settings menu" : "Меню настроек",
-    "Loading your contacts …" : "Загрузка контактов…",
-    "Looking for {term} …" : "Поиск {term}…",
+    "Loading your contacts …" : "Загрузка контактов …",
+    "Looking for {term} …" : "Поиск {term} …",
     "Search contacts" : "Поиск контактов",
     "Reset search" : "Очистить поиск",
-    "Search contacts …" : "Поиск контакта…",
+    "Search contacts …" : "Поиск контактов …",
     "Could not load your contacts" : "Ошибка получения контактов",
     "No contacts found" : "Контактов не найдено",
     "Show all contacts" : "Показать все контакты",
@@ -198,13 +322,35 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Поиск начнётся при наборе текста. Для перехода к результатам поиска используйте клавиши со стрелками.",
     "Search for {name} only" : "Искать только для «{name}»",
-    "Loading more results …" : "Загрузка дополнительных результатов…",
+    "Loading more results …" : "Загрузка дополнительных результатов …",
     "Forgot password?" : "Забыли пароль?",
     "Back to login form" : "Вернуться к форме входа",
     "Back" : "Назад",
     "Login form is disabled." : "Форма входа отключена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
+    "Connect to your account" : "Вход в систему",
+    "Security warning" : "Предупреждение безопасности",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
+    "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
+    "Account connected" : "Аккаунт подключен",
+    "Your client should now be connected!" : "Приложение-клиент подключено.",
+    "You can close this window." : "Можете закрыть это окно.",
+    "Account access" : "Доступ к аккаунту",
     "More actions" : "Больше действий",
+    "User menu" : "Меню пользователя",
+    "Your guest name: {user}" : "Ваше гостевое имя: {user}",
+    "You are currently not identified." : "В данный момент вы не идентифицированы.",
+    "Set public name" : "Задать публичное имя",
+    "Change public name" : "Изменить публичное имя",
+    "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
+    "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
+    "Submit" : "Отправить ответ",
+    "Please type in your email address to request a temporary password" : "Введите свой адрес эл. почты для запроса временного пароля",
+    "Password sent!" : "Пароль отправлен",
+    "You are not authorized to request a password for this share" : "У вас недостаточно прав для запроса пароля для доступа к этому общему ресурсу",
+    "Email address" : "Адрес эл. почты",
+    "Request password" : "Запрос пароля",
+    "Forgot password" : "Забыли пароль",
     "Password is too weak" : "Пароль слишком слабый",
     "Password is weak" : "Пароль слабый",
     "Password is average" : "Пароль средний",
@@ -216,13 +362,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Информацию о том, как правильно настроить сервер,{linkStart} смотрите в документации.{linkEnd}",
     "Autoconfig file detected" : "Обнаружен файл автоконфигурации",
     "The setup form below is pre-filled with the values from the config file." : "Форма настройки ниже, предварительно заполнена значениями из файла конфигурации.",
-    "Security warning" : "Предупреждение безопасности",
     "Create administration account" : "Создать учетную запись администратора",
     "Administration account name" : "Имя учетной записи администратора",
     "Administration account password" : "Пароль учетной записи администратора",
     "Storage & database" : "Хранилище и база данных",
     "Data folder" : "Каталог с данными",
     "Database configuration" : "Конфигурация базы данных",
+    "Database type" : "Тип базы данных",
     "Only {firstAndOnlyDatabase} is available." : "Только {firstAndOnlyDatabase} доступно.",
     "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
     "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
@@ -230,6 +376,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
+    "Database connection" : "Соединение с базой данных",
     "Database user" : "Пользователь базы данных",
     "Database password" : "Пароль базы данных",
     "Database name" : "Имя базы данных",
@@ -237,7 +384,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
     "Database host" : "Хост базы данных",
     "localhost" : "локальный хост",
-    "Installing …" : "Установка ...",
+    "Installing …" : "Установка …",
     "Install" : "Установить",
     "Need help?" : "Требуется помощь?",
     "See the documentation" : "Посмотреть документацию",
@@ -246,7 +393,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
     "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
     "Supported versions" : "Поддерживаемые версии",
-    "Search {types} …" : "Поиск {types}…",
+    "Search {types} …" : "Поиск {types} …",
     "Choose {file}" : "Выбран «{file}»",
     "Choose" : "Выбрать",
     "Copy to {target}" : "Скопировать в {target}",
@@ -266,7 +413,10 @@ OC.L10N.register(
     "(all selected)" : "(все выбранные)",
     "({count} selected)" : "(выбрано: {count})",
     "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
-    "Saving …" : "Сохранение…",
+    "Saving …" : "Сохранение…",
+    "Groups" : "Группы",
+    "Group list is empty" : "Список групп пуст",
+    "Unable to retrieve the group list" : "Не удалось получить список групп",
     "seconds ago" : "только что",
     "Connection to server lost" : "Потеряно подключение к серверу",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
@@ -281,26 +431,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
     "New in" : "Новые возможности",
     "View changelog" : "Просмотреть изменения",
-    "No action available" : "Нет доступных действий",
-    "Error fetching contact actions" : "Ошибка получения действий контакта",
     "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
     "Email length is at max (255)" : "Максимальная длина адреса эл. почты (255 символов)",
-    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
-    "Restricted" : "Ограниченный",
-    "Invisible" : "Невидимый",
-    "Delete" : "Удалить",
-    "Rename" : "Переименовать",
-    "Collaborative tags" : "Совместные теги",
-    "No tags found" : "Метки не найдены",
     "Clipboard not available, please copy manually" : "Буфер обмена недоступен, пожалуйста, скопируйте вручную",
     "Personal" : "Личное",
     "Accounts" : "Учётные записи",
     "Admin" : "Администрирование",
     "Help" : "Помощь",
     "Access forbidden" : "Доступ запрещён",
+    "You are not allowed to access this page." : "Вам не разрешен доступ к этой странице.",
+    "Back to %s" : "Вернуться к %s",
     "Page not found" : "Страница не найдена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страница не найдена на сервере, или у вас нет прав на ее просмотр.",
-    "Back to %s" : "Вернуться к %s",
     "Too many requests" : "Превышено количество запросов",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Превышено количество запросов из вашей сети. Попробуйте позднее или сообщите администратору об этой ошибке.",
     "Error" : "Ошибка",
@@ -325,25 +467,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Перейти к навигации по приложению",
     "Go to %s" : "Перейти к %s",
     "Get your own free account" : "Создайте свою бесплатную учётную запись",
-    "Connect to your account" : "Вход в систему",
-    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
-    "App password" : "Пароль приложения",
-    "Grant access" : "Разрешить доступ",
-    "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
-    "Account access" : "Доступ к аккаунту",
-    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s.",
-    "Account connected" : "Аккаунт подключен",
-    "Your client should now be connected!" : "Приложение-клиент подключено.",
-    "You can close this window." : "Можете закрыть это окно.",
     "Previous" : "Предыдущий",
-    "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
-    "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
-    "Please type in your email address to request a temporary password" : "Введите свой адрес эл. почты для запроса временного пароля",
-    "Email address" : "Адрес эл. почты",
-    "Password sent!" : "Пароль отправлен",
-    "You are not authorized to request a password for this share" : "У вас недостаточно прав для запроса пароля для доступа к этому общему ресурсу",
     "Two-factor authentication" : "Двухфакторная аутентификация",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повышенная безопасность включена для вашей учетной записи. Выберете второй фактор для подтверждения подлинности пользователя.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Не удалось использовать хотя бы один из двух настроенных способов двуфакторной аутентификации. Обратитесь к администратору.",
@@ -376,23 +500,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
     "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
-    "Currently open" : "Сейчас открыто",
-    "Login with username or email" : "Войти по имени пользователя или адресу эл. почты",
-    "Login with username" : "Войти по имени пользователя",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Текстовые сообщения, видеозвонки, демонстрация содержимого экрана, онлайн общение и веб-конференции на ПК и мобильных устройствах. ",
-    "You have not added any info yet" : "Вы ещё не добавили никакой информации",
-    "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
-    "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
-    "Edit Profile" : "Редактирование профиля",
-    "The headline and about sections will show up here" : "Разделы \"Заголовок\" и \"О вас\" будут отображаться здесь",
-    "Error loading message template: {error}" : "Ошибка загрузки шаблона сообщений: {error}",
+    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
+    "unknown text" : "неизвестный текст",
+    "Hello world!" : "Привет мир!",
+    "sunny" : "солнечно",
+    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
+    "Hello {name}" : "Здравствуйте, {name}!",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
+    "new" : "новый",
+    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
+    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
+    "Searching …" : "Поиск…",
+    "Logging in …" : "Вход в систему…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
+    "Loading apps …" : "Получение списка приложений…",
+    "Installing apps …" : "Установка приложений…",
+    "Loading your contacts …" : "Загрузка контактов…",
+    "Looking for {term} …" : "Поиск {term}…",
+    "Search contacts …" : "Поиск контакта…",
+    "Loading more results …" : "Загрузка дополнительных результатов…",
+    "Search {types} …" : "Поиск {types}…",
+    "Saving …" : "Сохранение…",
     "Very weak password" : "Очень слабый пароль",
     "Weak password" : "Слабый пароль",
     "So-so password" : "Так себе пароль",
     "Good password" : "Хороший пароль",
     "Strong password" : "Надёжный пароль",
-    "Profile not found" : "Профиль не найден",
-    "The profile does not exist." : "Профиль не существует",
+    "No action available" : "Нет доступных действий",
+    "Error fetching contact actions" : "Ошибка получения действий контакта",
+    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
+    "Restricted" : "Ограниченный",
+    "Delete" : "Удалить",
+    "Rename" : "Переименовать",
+    "Collaborative tags" : "Совместные теги",
+    "No tags found" : "Метки не найдены",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Создайте учетную запись администратора</strong>",
@@ -402,6 +544,10 @@ OC.L10N.register(
     "Toggle password visibility" : "Переключить видимость пароля",
     "Configure the database" : "Настройка базы данных",
     "Only %s is available." : "Доступен только %s.",
-    "Database account" : "Учётная запись базы данных"
+    "Database account" : "Учётная запись базы данных",
+    "Installing …" : "Установка ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
+    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
