@@ -78,6 +78,8 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notìfica","{count} notìficas"],
     "No" : "No",
     "Yes" : "Eja",
+    "App password" : "Crae de s'aplicatzione",
+    "Grant access" : "Dona atzessu",
     "Failed to add the public link to your Nextcloud" : "No at fatu a agiùnghere su ligòngiu pùblicu in Nextcloud",
     "Create share" : "Crea cumpartzidura",
     "Custom date range" : "Perìodu personalizadu",
@@ -101,7 +103,6 @@ OC.L10N.register(
     "Search in" : "Chirca in",
     "Log in" : "Intra",
     "Log in to {productName}" : "Identìfica·ti in {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
     "Account name or email" : "Nùmene de su contu o indiritzu de posta",
     "Server side authentication failed!" : "Autenticatzione de s'ala de su serbidore faddida!",
     "Please contact your administrator." : "Cuntata s'amministratzione.",
@@ -155,8 +156,20 @@ OC.L10N.register(
     "Back to login form" : "Torra a su formulàriu de identificatzione",
     "Back" : "A coa",
     "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
-    "More actions" : "Àteras atziones",
+    "Connect to your account" : "Connete·ti a su contu tuo",
     "Security warning" : "Avisu de seguresa",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si non ses chirchende de cunfigurare unu dispositivu o un'aplicatzione noa, un'àtera persone est proende a si fàghere dare atzessu a is datos tuos. In custu casu, non sigas e cuntata s'amministratzione de su sistema tuo.",
+    "Alternative log in using app password" : "Identificatzione alternativa cun crae de s'aplicatzione",
+    "Account connected" : "Contu collegadu",
+    "Your client should now be connected!" : "Su cliente tuo immoe diat dèpere èssere collegadu!",
+    "You can close this window." : "Podes serrare custa ventana",
+    "Account access" : "Atzessu a su contu",
+    "More actions" : "Àteras atziones",
+    "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
+    "Submit" : "Imbia",
+    "Password sent!" : "Crae imbiada.",
+    "Email address" : "Indiritzu de posta eletrònica",
+    "Request password" : "Pedi sa crae",
     "Storage & database" : "Depòsitu e base de datos",
     "Data folder" : "Cartella de datos",
     "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
@@ -199,6 +212,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} seletzionadu)",
     "Error loading file exists template" : "Errore in su carrigamentu de su modellu de archìviu",
     "Saving …" : "Sarvende ...",
+    "Groups" : "Grupos",
+    "Group list is empty" : "S'elencu de is grupos est bòida",
+    "Unable to retrieve the group list" : "Non faghet a recuperare s'elencu de is grupos",
     "seconds ago" : "segundos a immoe",
     "Connection to server lost" : "Connessione a su serbidore pèrdida",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
@@ -244,21 +260,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Brinca a sa navigatzione de s'aplicatzione",
     "Go to %s" : "Bae a %s",
     "Get your own free account" : "Otene su contu tuo a gratis",
-    "Connect to your account" : "Connete·ti a su contu tuo",
-    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su contu tuo de %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si non ses chirchende de cunfigurare unu dispositivu o un'aplicatzione noa, un'àtera persone est proende a si fàghere dare atzessu a is datos tuos. In custu casu, non sigas e cuntata s'amministratzione de su sistema tuo.",
-    "App password" : "Crae de s'aplicatzione",
-    "Grant access" : "Dona atzessu",
-    "Alternative log in using app password" : "Identificatzione alternativa cun crae de s'aplicatzione",
-    "Account access" : "Atzessu a su contu",
-    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo.",
-    "Account connected" : "Contu collegadu",
-    "Your client should now be connected!" : "Su cliente tuo immoe diat dèpere èssere collegadu!",
-    "You can close this window." : "Podes serrare custa ventana",
     "Previous" : "Pretzedente",
-    "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
-    "Email address" : "Indiritzu de posta eletrònica",
-    "Password sent!" : "Crae imbiada.",
     "Two-factor authentication" : "Autenticatzione a duos fatores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Su megioru de seguresa est ativadu in su contu tuo. Sèbera unu segundu fatore pro s'autenticatzione:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No at fatu a carriggare a su mancu unu de is mètodos de autenticatzione a duos fatores ativados. Cuntata s'amministratzione.",
@@ -302,6 +304,7 @@ OC.L10N.register(
     "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
     "Searching …" : "Chirchende …",
     "Logging in …" : "Intrende ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
     "Loading apps …" : "Carrighende aplicatziones ...",
     "Installing apps …" : "Installende aplicatziones ...",
     "Loading your contacts …" : "Carrighende is cuntatos...",
@@ -329,6 +332,8 @@ OC.L10N.register(
     "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
     "Configure the database" : "Cunfigura sa base de datos",
     "Only %s is available." : "%s isceti est a disponimentu.",
-    "Installing …" : "Installende ..."
+    "Installing …" : "Installende ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su contu tuo de %2$s.",
+    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo."
 },
 "nplurals=2; plural=(n != 1);");
