@@ -40,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Naloge ni mogoče najti",
     "Internal error" : "Notranja napaka",
     "Not found" : "Predmeta ni mogoče najti",
+    "Node is locked" : "Vozlišče je zaklenjeno",
     "Bad request" : "Neustrezna zahteva",
     "Requested task type does not exist" : "Zahtevana vrsta naloge ne obstaja",
     "Necessary language model provider is not available" : "Zahtevan ponudnik jezikovnega modela ni na voljo",
@@ -48,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Ponudnik prevoda ni na voljo.",
     "Could not detect language" : "Ni mogoče zaznati jezika.",
     "Unable to translate" : "Ni mogoče prevajati",
+    "No valid filters provided" : "Ni veljavnih filtrov",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korak nadgradnje:",
     "Repair info:" : "Podrobnosti nadgradnje:",
@@ -99,6 +101,7 @@ OC.L10N.register(
     "Lotus Word Pro document" : "Dokument Lotus Word Pro",
     "Excel spreadsheet" : "Preglednica Excel",
     "Excel add-in" : "Razširitev Excel",
+    "Excel 2007 binary spreadsheet" : "Preglednica Excel 2007",
     "Excel spreadsheet template" : "Predloga preglednice Excel",
     "Outlook Message" : "Sporočilo Outlook",
     "PowerPoint presentation" : "Predstavitev PowerPoint",
@@ -107,14 +110,19 @@ OC.L10N.register(
     "Word document" : "Dokument Word",
     "ODF formula" : "Formula ODF",
     "ODG drawing" : "Risba ODG",
+    "ODG drawing (Flat XML)" : "Risba ODG (Flat XML)",
     "ODG template" : "Predloga ODG",
     "ODP presentation" : "Predstavitev ODP",
+    "ODP presentation (Flat XML)" : "Predstavitev ODP (Flat XML)",
     "ODP template" : "Predloga ODP",
     "ODS spreadsheet" : "Preglednica ODS",
+    "ODS spreadsheet (Flat XML)" : "Predstavitev ODS (Flat XML)",
     "ODS template" : "Predloga ODS",
     "ODT document" : "Dokument ODT",
+    "ODT document (Flat XML)" : "Dokument ODT (Flat XML)",
     "ODT template" : "Predloga ODT",
     "PowerPoint 2007 presentation" : "Predstavitev PowerPoint 2007",
+    "PowerPoint 2007 show" : "Predstavitev PowerPoint 2007",
     "PowerPoint 2007 presentation template" : "Predloga predstavitve PowerPoint 2007",
     "Excel 2007 spreadsheet" : "Preglednica Excel 2007",
     "Excel 2007 spreadsheet template" : "Predloga preglednice Excel 2007",
@@ -123,6 +131,7 @@ OC.L10N.register(
     "Microsoft Visio document" : "Dokument Microsoft Visio",
     "WordPerfect document" : "Dokument WordPerfect",
     "7-zip archive" : "Arhiv 7-zip",
+    "Blender scene" : "Scena programa Blender",
     "Bzip2 archive" : "Arhiv Bzip2",
     "Debian package" : "Programski paket Debian",
     "FictionBook document" : "Dokument FictionBook",
@@ -142,19 +151,23 @@ OC.L10N.register(
     "MPEG-4 audio" : "Zvok MPEG-4",
     "MP3 audio" : "Zvok MP3",
     "Ogg audio" : "Zvok OGG",
+    "RIFF/WAVe standard Audio" : "Zvočni zapis RIFF/WAVe",
     "WebM audio" : "Zvok WebM",
     "Windows BMP image" : "Slika Windows BMP",
     "EMF image" : "Slika EMF",
     "GIF image" : "Slika GIF",
     "HEIC image" : "Slika HEIC",
     "HEIF image" : "Slika HEIF",
+    "JPEG-2000 JP2 image" : "Slika JPEG-2000 JP2",
     "JPEG image" : "Slika JPEG",
     "PNG image" : "Slika PNG",
     "SVG image" : "Risba SVG",
+    "Truevision Targa image" : "Slika Truevision Targa",
     "TIFF image" : "Slika TIFF",
     "WebP image" : "Slika WebP",
     "Digital raw image" : "Surova digitalna slika",
     "Windows Icon" : "Ikona Windows",
+    "Email message" : "Elektronsko sporočilo",
     "VCS/ICS calendar" : "Koledar VCS/ICS",
     "CSS stylesheet" : "Slogovna predloga CSS",
     "CSV document" : "Dokument CSV",
@@ -168,17 +181,16 @@ OC.L10N.register(
     "NFO document" : "Dokument NFO",
     "PHP source" : "Izvorna koda PHP",
     "Python script" : "Skript Python",
+    "3GPP multimedia file" : "Predstavna datoteka 3GPP",
     "MPEG video" : "Video MPEG",
     "DV video" : "Video DV",
     "MPEG-4 video" : "Video MPEG-4",
-    "unknown text" : "neznano besedilo",
-    "Hello world!" : "Pozdravljen svet!",
-    "sunny" : "sončno",
-    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
-    "Hello {name}" : "Pozdravljeni, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To so zadetki iskanja<script>alert(1)</script></strong>.",
-    "new" : "novo",
-    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
+    "Ogg video" : "Video OGG",
+    "QuickTime video" : "Video QuickTime",
+    "WebM video" : "Video WebM",
+    "Matroska video" : "Video Matroska",
+    "Windows Media video" : "Video Windows Media",
+    "AVI video" : "Video AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
     "Update to {version}" : "Posodobitev na različico {version}",
     "An error occurred." : "Prišlo je do napake.",
@@ -187,12 +199,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
     "Continue to {productName}" : "Nadaljuj v {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
+    "Done" : "Končano",
     "Applications menu" : "Meni programov",
     "Apps" : "Programi",
     "More apps" : "Več programov",
     "_{count} notification_::_{count} notifications_" : ["{count} obvestilo","{count} obvestili","{count} obvestila","{count} obvestil"],
     "No" : "Ne",
     "Yes" : "Da",
+    "App password" : "Geslo programa",
+    "Grant access" : "Odobri dostop",
     "The remote URL must include the user." : "Oddaljeni naslov URL mora vključevati uporabniško ime.",
     "Invalid remote URL." : "Neveljaven oddaljeni naslov URL.",
     "Failed to add the public link to your Nextcloud" : "Dodajanje javne povezave v oblak je spodletelo.",
@@ -207,7 +222,7 @@ OC.L10N.register(
     "Search in current app" : "Poišči v predlaganem programu",
     "Clear search" : "Počisti iskanje",
     "Search everywhere" : "Išči povsod",
-    "Searching …" : "Poteka iskanje ...",
+    "Searching …" : "Poteka iskanje ...",
     "Start typing to search" : "Začnite tipkati za iskanje",
     "No matching results" : "Ni zadetkov iskanja",
     "Today" : "Danes",
@@ -226,11 +241,9 @@ OC.L10N.register(
     "Load more results" : "Naloži več zadetkov",
     "Search in" : "Poišči v",
     "Log in" : "Prijava",
-    "Logging in …" : "Poteka prijavljanje ...",
     "Log in to {productName}" : "Prijava v {productName}",
     "Wrong login or password." : "Napačna prijava ali geslo.",
     "This account is disabled" : "Ta račun je onemogočen",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
     "Account name or email" : "Ime računa ali elektronski naslov",
     "Account name" : "Ime računa",
     "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
@@ -263,21 +276,25 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Sodelovanje pri ustvarjanju dokumentov, preglednic in predstavitev, ki zahtevajo storitev Collabora Online.",
     "Distraction free note taking app." : "Enostavno beleženje in zapisovanje",
     "Recommended apps" : "Priporočeni programi",
-    "Loading apps …" : "Poteka nalaganje programov ...",
+    "Loading apps …" : "Poteka nalaganje programov ...",
     "Could not fetch list of apps from the App Store." : "Ni mogoče pridobiti seznama programov iz trgovine.",
     "App download or installation failed" : "Prejem oziroma namestitev programa je spodletela.",
     "Cannot install this app because it is not compatible" : "Programa ni mogoče namestiti, ker ni skladen z različico okolja.",
     "Cannot install this app" : "Programa ni mogoče namestiti.",
     "Skip" : "Preskoči",
-    "Installing apps …" : "Poteka nameščanje programov ...",
+    "Installing apps …" : "Poteka nameščanje programov ...",
     "Install recommended apps" : "Namesti priporočene programe",
+    "Online" : "Trenutno na spletu",
+    "Away" : "Ne spremljam",
+    "Busy" : "Zasedeno",
+    "Do not disturb" : "Ne moti",
+    "Mute all notifications" : "Utiša vsa obvestila",
+    "Invisible" : "Drugim nevidno",
+    "Appear offline" : "Pokaže kot brez povezave",
     "Avatar of {displayName}" : "Podoba osebe {displayName}",
     "Settings menu" : "Meni nastavitev",
-    "Loading your contacts …" : "Poteka nalaganje stikov ...",
-    "Looking for {term} …" : "Poteka iskanje {term} …",
     "Search contacts" : "Poišči med stiki",
     "Reset search" : "Ponastavi iskanje",
-    "Search contacts …" : "Poišči med stiki ...",
     "Could not load your contacts" : "Stikov ni mogoče naložiti",
     "No contacts found" : "Ni najdenih stikov",
     "Show all contacts" : "Prikaži vse stike",
@@ -289,13 +306,32 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Prišlo je do napake med iskanjem vrste {type}.",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Iskanje se začne, ko začnete vpisovati besedilo, do rezultatov pa je mogoče dostop tudi s smernimi tipkami.",
     "Search for {name} only" : "Išči le za {name}",
-    "Loading more results …" : "Poteka nalaganje več zadetkov ...",
     "Forgot password?" : "Ali ste pozabili geslo?",
     "Back to login form" : "Nazaj na prijavni obrazec",
     "Back" : "Nazaj",
     "Login form is disabled." : "Prijavni obrazec je onemogočen.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prijavni obrazec Nextcloud je onemogočen. Če je mogoče, izberite drug način prijave, ali pa stopite v stik s skrbnikom sistema.",
+    "Connect to your account" : "Povežite z računom",
+    "Security warning" : "Varnostno opozorilo",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Če ne poskušate dodati naprave ali programa, vas poskuša nekdo pretentati v odobritev dostopa do vaših podatkov. Če se vam zdi, da je tako, ne nadaljujte s potrjevanjem, ampak stopite v stik s skrbnikom sistema.",
+    "Alternative log in using app password" : "Alternativni način prijave z uporabo gesla programa",
+    "Account connected" : "Račun je povezan",
+    "Your client should now be connected!" : "Odjemalec naj bi bil sedaj povezan!",
+    "You can close this window." : "To okno lahko zaprete.",
+    "Account access" : "Dostop do računa",
     "More actions" : "Več dejanj",
+    "User menu" : "Uporabniški meni",
+    "Set public name" : "Nastavi javno ime",
+    "Change public name" : "Spremeni javno ime",
+    "This share is password-protected" : "To mesto je zaščiteno z geslom",
+    "The password is wrong or expired. Please try again or request a new one." : "Geslo je napačno ali je preteklo. Poskusite znova ali zahtevajte novo geslo.",
+    "Submit" : "Pošlji",
+    "Please type in your email address to request a temporary password" : "Vpišite elektronski naslov, na katerega bo začasno dodeljeno gesla.",
+    "Password sent!" : "Geslo je poslano!",
+    "You are not authorized to request a password for this share" : "Za zahteve pridobitve gesla ni ustreznih dovoljenj",
+    "Email address" : "Elektronski naslov",
+    "Request password" : "Zahtevaj geslo",
+    "Forgot password" : "Ali ste pozabili geslo?",
     "Password is too weak" : "Geslo je prešibko",
     "Password is weak" : "Geslo je šibko",
     "Password is average" : "Geslo je povprečno",
@@ -307,13 +343,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Za podrobnosti o pravilnih nastavitvah strežnika {linkStart}preglejte dokumentacijo{linkEnd}",
     "Autoconfig file detected" : "Zaznana je datoteka za samodejno nastavitev",
     "The setup form below is pre-filled with the values from the config file." : "Namestitveni obrazec je izpolnjen iz vrednostmi, prevzetimi iz nastavitvene datoteke.",
-    "Security warning" : "Varnostno opozorilo",
     "Create administration account" : "Ustvari skrbniški račun",
     "Administration account name" : "Ime skrbniškega računa",
     "Administration account password" : "Geslo skrbniškega računa",
     "Storage & database" : "Shramba in podatkovna zbirka",
     "Data folder" : "Podatkovna mapa",
     "Database configuration" : "Nastavitve podatkovne zbirke",
+    "Database type" : "Vrsta podatkovne zbirke",
     "Only {firstAndOnlyDatabase} is available." : "Na voljo je le {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
     "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
@@ -328,7 +364,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
     "Database host" : "Gostitelj podatkovne zbirke",
     "localhost" : "localhost",
-    "Installing …" : "Poteka nameščanje ...",
+    "Installing …" : "Poteka nameščanje ...",
     "Install" : "Namesti",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
@@ -337,7 +373,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Uporabljen brskalnik ni podprt. Posodobite program na novejšo različico, ali pa uporabite drug program.",
     "Continue with this unsupported browser" : "Nadaljuj delo z nepodprtim brskalnikom",
     "Supported versions" : "Podprte različice",
-    "Search {types} …" : "Poišči {types} …",
     "Choose {file}" : "Izberite datoteko {file}",
     "Choose" : "Izbor",
     "Copy to {target}" : "Kopiraj na {target}",
@@ -357,7 +392,10 @@ OC.L10N.register(
     "(all selected)" : "(vse izbrano)",
     "({count} selected)" : "({count} izbranih)",
     "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
-    "Saving …" : "Poteka shranjevanje ...",
+    "Saving …" : "Poteka shranjevanje …",
+    "Groups" : "Skupine",
+    "Group list is empty" : "Seznam skupin je prazen",
+    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
     "seconds ago" : "pred nekaj sekundami",
     "Connection to server lost" : "Povezava s strežnikom je izgubljena",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
@@ -372,8 +410,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
     "New in" : "Novo v",
     "View changelog" : "Poglej dnevnik sprememb",
-    "No action available" : "Ni razpoložljivih dejanj",
-    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Close \"{dialogTitle}\" dialog" : "Zapri pogovorno okno »{dialogTitle}«",
     "Email length is at max (255)" : "Dolžina sporočila je dosegla omejitev (255)",
     "Clipboard not available, please copy manually" : "Odložišče ni na voljo, kopirajte ročno",
@@ -409,25 +445,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Preskoči na program za krmarjenje",
     "Go to %s" : "Odpri oblak %s",
     "Get your own free account" : "Pridobite brezplačni račun",
-    "Connect to your account" : "Povežite z računom",
-    "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Če ne poskušate dodati naprave ali programa, vas poskuša nekdo pretentati v odobritev dostopa do vaših podatkov. Če se vam zdi, da je tako, ne nadaljujte s potrjevanjem, ampak stopite v stik s skrbnikom sistema.",
-    "App password" : "Geslo programa",
-    "Grant access" : "Odobri dostop",
-    "Alternative log in using app password" : "Alternativni način prijave z uporabo gesla programa",
-    "Account access" : "Dostop do računa",
-    "Currently logged in as %1$s (%2$s)." : "Dejavna je prijava %1$s (%2$s)",
-    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s.",
-    "Account connected" : "Račun je povezan",
-    "Your client should now be connected!" : "Odjemalec naj bi bil sedaj povezan!",
-    "You can close this window." : "To okno lahko zaprete.",
     "Previous" : "Predhodna",
-    "This share is password-protected" : "To mesto je zaščiteno z geslom",
-    "The password is wrong or expired. Please try again or request a new one." : "Geslo je napačno ali je preteklo. Poskusite znova ali zahtevajte novo geslo.",
-    "Please type in your email address to request a temporary password" : "Vpišite elektronski naslov, na katerega bo začasno dodeljeno gesla.",
-    "Email address" : "Elektronski naslov",
-    "Password sent!" : "Geslo je poslano!",
-    "You are not authorized to request a password for this share" : "Za zahteve pridobitve gesla ni ustreznih dovoljenj",
     "Two-factor authentication" : "Dvo-stopenjska overitev",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Za vaš račun je omogočena zahteva za višjo raven varnosti. Izberite drugo stopnjo overitve:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ni mogoče naložiti niti enega od omogočenih načinov dvostopenjske overitve prijave. Stopite v stik s skrbnikom sistema.",
@@ -460,32 +478,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
     "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
-    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
-    "No crop data provided" : "Ni podanih podatkov obreza",
-    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
-    "Crop is not square" : "Obrez ni pravokoten",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, video klici, souporaba zaslonske slike, spletni sestanki in konference – znotraj brskalnika in z mobilnimi napravami.",
-    "You have not added any info yet" : "Ni še vpisanih podrobnosti",
-    "{user} has not added any info yet" : "Oseba {user} še ni dodala nobenih podrobnosti.",
-    "Error opening the user status modal, try hard refreshing the page" : "Prišlo je do napake pri odpiranju modalnega okna stanja uporabnika. Napako je mogoče razrešiti z osvežitvijo strani.",
-    "Edit Profile" : "Uredi profil",
-    "The headline and about sections will show up here" : "Naslovnica in odsek s podatki bo prikazan na tem mestu.",
+    "unknown text" : "neznano besedilo",
+    "Hello world!" : "Pozdravljen svet!",
+    "sunny" : "sončno",
+    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
+    "Hello {name}" : "Pozdravljeni, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To so zadetki iskanja<script>alert(1)</script></strong>.",
+    "new" : "novo",
+    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
+    "Direct link copied to clipboard" : "Povezava je kopirana v odložišče.",
+    "Searching …" : "Poteka iskanje ...",
+    "Logging in …" : "Poteka prijavljanje ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
+    "Loading apps …" : "Poteka nalaganje programov ...",
+    "Installing apps …" : "Poteka nameščanje programov ...",
+    "Loading your contacts …" : "Poteka nalaganje stikov ...",
+    "Looking for {term} …" : "Poteka iskanje {term} …",
+    "Search contacts …" : "Poišči med stiki ...",
+    "Loading more results …" : "Poteka nalaganje več zadetkov ...",
+    "Search {types} …" : "Poišči {types} …",
+    "Saving …" : "Poteka shranjevanje ...",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Šibko geslo",
     "So-so password" : "Slabo geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
+    "No action available" : "Ni razpoložljivih dejanj",
+    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
     "Restricted" : "Omejeno",
-    "Invisible" : "Drugim nevidno",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Sodelovalne oznake",
     "No tags found" : "Ni najdenih oznak",
-    "Profile not found" : "Profila ni mogoče najti",
-    "The profile does not exist." : "Profil ne obstaja.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Ustvari skrbniški račun</strong>",
@@ -496,6 +523,9 @@ OC.L10N.register(
     "Configure the database" : "Nastavi podatkovno zbirko",
     "Only %s is available." : "Na voljo je le %s.",
     "Database account" : "Račun podatkovne zbirke",
-    "Direct link copied to clipboard" : "Povezava je kopirana v odložišče."
+    "Installing …" : "Poteka nameščanje ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
+    "Currently logged in as %1$s (%2$s)." : "Dejavna je prijava %1$s (%2$s)",
+    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
