@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Okänd filtyp",
     "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
     "Invalid image" : "Ogiltig bild",
-    "No temporary profile picture available, try again" : "Ingen temporär profilbild finns tillgänglig, försök igen",
-    "No crop data provided" : "Inga beskärningsdata har angivits",
-    "No valid crop data provided" : "Ingen giltig beskärningsdata tillhandahölls",
-    "Crop is not square" : "Beskärning är inte kvadratisk",
     "State token does not match" : "Tillstånds-token matchar inte",
     "Invalid app password" : "Felaktigt app-lösenord",
     "Could not complete login" : "Kunde inte slutföra inloggningen",
     "State token missing" : "Statustoken saknas",
     "Your login token is invalid or has expired" : "Din inloggnings-token är ogiltigt eller har gått ut",
+    "Please use original client" : "Använd ursprunglig klient",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Denna community-release av Nextcloud stöds inte och pushnotifikationer är begränsade.",
     "Login" : "Logga in",
     "Unsupported email length (>255)" : "E-postlängd som inte stöds (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Uppgiften hittades inte",
     "Internal error" : "Internt fel",
     "Not found" : "Hittades inte",
+    "Node is locked" : "Noden är låst",
     "Bad request" : "Felaktigt anrop",
     "Requested task type does not exist" : "Den begärda uppgiftstypen finns inte",
     "Necessary language model provider is not available" : "Nödvändig språkmodellsleverantör är inte tillgänglig",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Ingen översättning tillgänglig",
     "Could not detect language" : "Kunde inte identifiera språk",
     "Unable to translate" : "Kan inte översätta",
+    "No valid filters provided" : "Inga giltiga filter angivna",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Reparationssteg: ",
+    "Repair info:" : "Reparationsinfo:",
+    "Repair warning:" : "Reparationsvarning:",
+    "Repair error:" : "Reparationsfel:",
     "Nextcloud Server" : "Nextcloud-server",
     "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ange din prenumerationsnyckel i supportappen för att öka användargränsen. Detta ger dig också alla ytterligare fördelar som Nextcloud Enterprise erbjuder och rekommenderas starkt för användning i företag.",
     "Learn more ↗" : "Läs mer ↗",
     "Preparing update" : "Förbereder uppdatering",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Reparationssteg: ",
-    "Repair info:" : "Reparationsinfo:",
-    "Repair warning:" : "Reparationsvarning:",
-    "Repair error:" : "Reparationsfel:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Var vänlig och uppdatera via kommandotolken då uppdatering via webbläsaren är inaktiverat i config.php",
     "Turned on maintenance mode" : "Aktiverade underhållsläge",
     "Turned off maintenance mode" : "Inaktivera underhållsläge",
@@ -79,16 +78,16 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (inkompatibel)",
     "The following apps have been disabled: %s" : "Följande appar har inaktiverats: %s",
     "Already up to date" : "Redan uppdaterad",
-    "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "För mer detaljer se {linkstart}dokumentationen ↗{linkend}.",
-    "unknown text" : "okänd text",
-    "Hello world!" : "Hej världen!",
-    "sunny" : "soligt",
-    "Hello {name}, the weather is {weather}" : "Hej {name}, vädret är {weather}",
-    "Hello {name}" : "Hej {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Detta är ditt sökresultat<script>alert(1)</script></strong>",
-    "new" : "ny",
-    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Hämta %n filer"],
+    "JSON document" : "JSON-dokument",
+    "Unknown" : "Okänd",
+    "Excel spreadsheet" : "Excel-kalkylark",
+    "PowerPoint presentation" : "PowerPoint-presentation",
+    "PNG image" : "PNG-bild",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppdateringen pågår, om sidan lämnas kan uppdateringen misslyckas. ",
     "Update to {version}" : "Uppdatera till {version}",
     "An error occurred." : "Ett fel inträffade.",
@@ -97,19 +96,22 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppdateringen misslyckades. Rapportera felet till <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
     "Continue to {productName}" : "Fortsätt till {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekund.","Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekunder."],
+    "Done" : "Klar",
     "Applications menu" : "Appmeny",
     "Apps" : "Appar",
     "More apps" : "Fler appar",
     "_{count} notification_::_{count} notifications_" : ["{count} meddelande","{count} meddelanden"],
     "No" : "Nej",
     "Yes" : "Ja",
+    "App password" : " Applösenord",
+    "Grant access" : "Tillåt åtkomst",
     "The remote URL must include the user." : "Den externa adressen måste inkludera användaren.",
     "Invalid remote URL." : "Ogiltig extern adress.",
     "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
     "Federated user" : "Federerad användare",
     "user@your-nextcloud.org" : "användare@din-nextcloud.se",
     "Create share" : "Skapa delning",
-    "Direct link copied to clipboard" : "Direktlänk kopierad till urklipp",
+    "Direct link copied" : "Direktlänk kopierad",
     "Please copy the link manually:" : "Kopiera länken manuellt:",
     "Custom date range" : "Anpassat datumintervall",
     "Pick start date" : "Välj startdatum",
@@ -118,14 +120,16 @@ OC.L10N.register(
     "Search in current app" : "Sök i nuvarande app",
     "Clear search" : "Rensa sökning",
     "Search everywhere" : "Sök överallt",
-    "Searching …" : "Söker ...",
+    "Searching …" : "Söker …",
     "Start typing to search" : "Börja skriva för att söka",
+    "Minimum search length is {minSearchLength} characters" : "Minsta söklängd är {minSearchLength} tecken",
     "No matching results" : "Inga matchande resultat",
     "Today" : "Idag",
     "Last 7 days" : "Senaste 7 dagarna",
     "Last 30 days" : "Senaste 30 dagarna",
     "This year" : "Det här året",
     "Last year" : "Förra året",
+    "Between {startDate} and {endDate}" : "Mellan {startDate} och {endDate}",
     "Unified search" : "Enhetlig sökning",
     "Search apps, files, tags, messages" : "Sök efter appar, filer, taggar, meddelanden",
     "Places" : "Platser",
@@ -133,15 +137,15 @@ OC.L10N.register(
     "Search people" : "Sök efter användare",
     "People" : "Personer",
     "Filter in current view" : "Filtrera i aktuell vy",
+    "Search connected services" : "Sök anslutna tjänster",
     "Results" : "Resultat",
     "Load more results" : "Hämta fler resultat",
     "Search in" : "Sök i",
     "Log in" : "Logga in",
-    "Logging in …" : "Loggar in ...",
+    "Logging in …" : "Loggar in …",
     "Log in to {productName}" : "Logga in på {productName}",
     "Wrong login or password." : "Felaktigt inloggning eller lösenord.",
     "This account is disabled" : "Detta konto är inaktiverat",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
     "Account name or email" : "Användarnamn eller e-post",
     "Account name" : "Kontonamn",
     "Server side authentication failed!" : "Servern misslyckades med autentisering!",
@@ -174,21 +178,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kollaborativa dokument, kalkylark och presentationer, byggt på Collabora Online",
     "Distraction free note taking app." : "Distraktionsfri anteckningsapp.",
     "Recommended apps" : "Rekommenderade appar",
-    "Loading apps …" : "Läser in appar …",
+    "Loading apps …" : "Laddar appar …",
     "Could not fetch list of apps from the App Store." : "Det gick inte att hämta listan över appar från App Store.",
     "App download or installation failed" : "Hämtning eller installation av appen misslyckades",
     "Cannot install this app because it is not compatible" : "Appen kan inte installeras eftersom den inte är kompatibel",
     "Cannot install this app" : "Kan inte installera denna app",
     "Skip" : "Hoppa över",
-    "Installing apps …" : "Installerar appar ...",
+    "Installing apps …" : "Installerar appar …",
     "Install recommended apps" : "Installera rekommenderade appar",
+    "Online" : "Online",
+    "Away" : "Borta",
+    "Busy" : "Upptagen",
+    "Do not disturb" : "Stör ej",
+    "Mute all notifications" : "Stäng av alla aviseringar",
+    "Invisible" : "Osynlig",
+    "Appear offline" : "Visa som frånkopplad",
     "Avatar of {displayName}" : "Avatar för {displayName}",
     "Settings menu" : "Inställningsmeny",
-    "Loading your contacts …" : "Läser in dina kontakter ...",
-    "Looking for {term} …" : "Letar efter {term} …",
+    "Loading your contacts …" : "Läser in dina kontakter …",
+    "Looking for {term} …" : "Letar efter {term} …",
     "Search contacts" : "Sök kontakter",
     "Reset search" : "Återställ sökning",
-    "Search contacts …" : "Sök kontakter ...",
+    "Search contacts …" : "Sök kontakter …",
     "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
     "No contacts found" : "Inga kontakter hittades",
     "Show all contacts" : "Visa alla kontakter",
@@ -200,13 +211,31 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Sökningen startar när du börjar skriva och resultat kan nås med piltangenterna",
     "Search for {name} only" : "Sök efter endast {name}",
-    "Loading more results …" : "Hämtar fler resultat ...",
+    "Loading more results …" : "Hämtar fler resultat …",
     "Forgot password?" : "Glömt lösenordet?",
     "Back to login form" : "Tillbaka till inloggningsformulär",
     "Back" : "Tillbaka",
     "Login form is disabled." : "Inloggningsfomuläret är inaktiverat.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Inloggningsformuläret är inaktiverat. Använd om tillgänglig en annan inloggnings-metod eller kontakta administrationen.",
+    "Connect to your account" : "Anslut ditt konto",
+    "Security warning" : "Säkerhetsvarning",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Om du inte försöker konfigurera en ny enhet eller app, försöker någon lura dig att ge dem åtkomst till din data. Fortsätt i så fall inte, utan kontakta istället din systemadministratör.",
+    "Alternative log in using app password" : "Alternativ inloggning med applösenord",
+    "Account connected" : "Konto anslutet",
+    "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
+    "You can close this window." : "Du kan stänga det här fönstret.",
+    "Account access" : "Kontoåtkomst",
     "More actions" : "Fler händelser",
+    "Your guest name: {user}" : "Ditt gästnamn: {user}",
+    "This share is password-protected" : "Denna delning är lösenordsskyddad",
+    "The password is wrong or expired. Please try again or request a new one." : "Lösenordet är fel eller har gått ut. Försök igen eller begär ett nytt.",
+    "Submit" : "Skicka",
+    "Please type in your email address to request a temporary password" : "Skriv in din e-postadress för att begära ett tillfälligt lösenord",
+    "Password sent!" : "Lösenord skickat!",
+    "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
+    "Email address" : "E-postadress",
+    "Request password" : "Begär lösenord",
+    "Forgot password" : "Glömt lösenord",
     "Password is too weak" : "Lösenordet är för svagt",
     "Password is weak" : "Lösenordet är svagt",
     "Password is average" : "Lösenordet är medelstarkt",
@@ -214,12 +243,17 @@ OC.L10N.register(
     "Password is very strong" : "Lösenordet är mycket starkt",
     "Password is extremely strong" : "Lösenordet är extremt starkt",
     "Unknown password strength" : "Okänd lösenordsstyrka",
-    "Security warning" : "Säkerhetsvarning",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Din datakatalog och dina filer är troligen åtkomliga från internet eftersom <code>.htaccess</code> filen inte fungerar.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "För information om hur du konfigurerar din server korrekt,  {linkStart}se dokumentationen{linkEnd}",
+    "Autoconfig file detected" : "Auto-konfigurationsfil upptäckt",
+    "The setup form below is pre-filled with the values from the config file." : "Inställningsformuläret nedan är förifyllt med värden från konfigurationsfilen.",
     "Create administration account" : "Skapa administratörskonto",
     "Administration account name" : "Namn på administratörskonto",
     "Administration account password" : "Lösenord för administratörskonto",
     "Storage & database" : "Lagring & databas",
     "Data folder" : "Datamapp",
+    "Database configuration" : "Databaskonfiguration",
+    "Only {firstAndOnlyDatabase} is available." : "Endast {firstAndOnlyDatabase} är tillgänglig.",
     "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
     "For more details check out the documentation." : "För mer detaljer se dokumentationen",
     "Performance warning" : "Prestandavarning",
@@ -232,7 +266,7 @@ OC.L10N.register(
     "Database tablespace" : "Databas tabellutrymme",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
     "Database host" : "Databasserver",
-    "Installing …" : "Installerar …",
+    "localhost" : "localhost",
     "Install" : "Installera",
     "Need help?" : "Behövs hjälp?",
     "See the documentation" : "Se dokumentationen",
@@ -241,7 +275,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din webbläsare stöds inte. Uppgradera till en nyare version eller en som stöds.",
     "Continue with this unsupported browser" : "Fortsätt med webbläsare som inte stöds",
     "Supported versions" : "Stödda versioner",
-    "Search {types} …" : "Sök {types} …",
+    "Search {types} …" : "Sök {types} …",
     "Choose {file}" : "Välj {file}",
     "Choose" : "Välj",
     "Copy to {target}" : "Kopiera till {target}",
@@ -261,7 +295,10 @@ OC.L10N.register(
     "(all selected)" : "(Alla valda)",
     "({count} selected)" : "({count} valda)",
     "Error loading file exists template" : "Fel vid inläsning av fil finns i mall",
-    "Saving …" : "Sparar ...",
+    "Saving …" : "Sparar …",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Grupplistan är tom",
+    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "seconds ago" : "sekunder sedan",
     "Connection to server lost" : "Anslutning till server förlorad",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem med att läsa in sidan, uppdaterar om %n sekund","Problem med att läsa in sidan, uppdaterar om %n sekunder"],
@@ -276,26 +313,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv för att söka efter befintliga projekt",
     "New in" : "Ny i",
     "View changelog" : "Visa ändringslogg",
-    "No action available" : "Ingen åtgärd tillgänglig",
-    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
     "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
     "Email length is at max (255)" : "E-postlängden är max (255)",
-    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
-    "Restricted" : "Begränsad",
-    "Invisible" : "Osynlig",
-    "Delete" : "Ta bort",
-    "Rename" : "Byt namn",
-    "Collaborative tags" : "Samverkanstaggar",
-    "No tags found" : "Hittade inga taggar",
     "Clipboard not available, please copy manually" : "Urklipp är inte tillgängligt, kopiera manuellt",
     "Personal" : "Personliga Inställningar",
     "Accounts" : "Konton",
     "Admin" : "Admin",
     "Help" : "Hjälp",
     "Access forbidden" : "Åtkomst förbjuden",
+    "You are not allowed to access this page." : "Du har inte behörighet till denna sida.",
+    "Back to %s" : "Tillbaka till %s",
     "Page not found" : "Sidan hittades inte",
     "The page could not be found on the server or you may not be allowed to view it." : "Sidan kunde inte hittas på servern eller så kanske du inte har behörighet att se den.",
-    "Back to %s" : "Tillbaka till %s",
     "Too many requests" : "För många förfrågningar",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
     "Error" : "Fel",
@@ -320,25 +349,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Skippa till navigering av app",
     "Go to %s" : "Gå till %s",
     "Get your own free account" : "Skaffa ett eget gratiskonto",
-    "Connect to your account" : "Anslut ditt konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Om du inte försöker konfigurera en ny enhet eller app, försöker någon lura dig att ge dem åtkomst till din data. Fortsätt i så fall inte, utan kontakta istället din systemadministratör.",
-    "App password" : " Applösenord",
-    "Grant access" : "Tillåt åtkomst",
-    "Alternative log in using app password" : "Alternativ inloggning med applösenord",
-    "Account access" : "Kontoåtkomst",
-    "Currently logged in as %1$s (%2$s)." : "För närvarande inloggad som %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto.",
-    "Account connected" : "Konto anslutet",
-    "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
-    "You can close this window." : "Du kan stänga det här fönstret.",
     "Previous" : "Föregående",
-    "This share is password-protected" : "Denna delning är lösenordsskyddad",
-    "The password is wrong or expired. Please try again or request a new one." : "Lösenordet är fel eller har gått ut. Försök igen eller begär ett nytt.",
-    "Please type in your email address to request a temporary password" : "Skriv in din e-postadress för att begära ett tillfälligt lösenord",
-    "Email address" : "E-postadress",
-    "Password sent!" : "Lösenord skickat!",
-    "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
     "Two-factor authentication" : "Tvåfaktorsautentisering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Det gick inte att läsa in minst en av dina aktiverade tvåfaktorsautentiseringsmetoder. Vänligen kontakta din systemadministratören.",
@@ -371,23 +382,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
     "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
-    "Currently open" : "För närvarande öppen",
-    "Login with username or email" : "Logga in med användarnamn eller e-post",
-    "Login with username" : "Logga in med användarnamn",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatt, videosamtal, skärmdelning, onlinemöten och webbkonferenser – i din webbläsare och med mobilappar.",
-    "You have not added any info yet" : "Du har inte angivit någon information ännu",
-    "{user} has not added any info yet" : "{user} har inte angivit någon information ännu",
-    "Error opening the user status modal, try hard refreshing the page" : "Kunde inte öppna användarstatus-rutan, försök att ladda om sidan",
-    "Edit Profile" : "Redigera profil",
-    "The headline and about sections will show up here" : "Rubriken och avsnitten \"om\" kommer att dyka upp här",
-    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
+    "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "För mer detaljer se {linkstart}dokumentationen ↗{linkend}.",
+    "unknown text" : "okänd text",
+    "Hello world!" : "Hej världen!",
+    "sunny" : "soligt",
+    "Hello {name}, the weather is {weather}" : "Hej {name}, vädret är {weather}",
+    "Hello {name}" : "Hej {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Detta är ditt sökresultat<script>alert(1)</script></strong>",
+    "new" : "ny",
+    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Hämta %n filer"],
+    "Direct link copied to clipboard" : "Direktlänk kopierad till urklipp",
+    "Searching …" : "Söker ...",
+    "Logging in …" : "Loggar in ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
+    "Loading apps …" : "Läser in appar …",
+    "Installing apps …" : "Installerar appar ...",
+    "Loading your contacts …" : "Läser in dina kontakter ...",
+    "Looking for {term} …" : "Letar efter {term} …",
+    "Search contacts …" : "Sök kontakter ...",
+    "Loading more results …" : "Hämtar fler resultat ...",
+    "Search {types} …" : "Sök {types} …",
+    "Saving …" : "Sparar ...",
     "Very weak password" : "Väldigt svagt lösenord",
     "Weak password" : "Svagt lösenord",
     "So-so password" : "Okej lösenord",
     "Good password" : "Bra lösenord",
     "Strong password" : "Starkt lösenord",
-    "Profile not found" : "Profil kunde inte hittas",
-    "The profile does not exist." : "Profilen existerar inte.",
+    "No action available" : "Ingen åtgärd tillgänglig",
+    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
+    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
+    "Restricted" : "Begränsad",
+    "Delete" : "Ta bort",
+    "Rename" : "Byt namn",
+    "Collaborative tags" : "Samverkanstaggar",
+    "No tags found" : "Hittade inga taggar",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din datakatalog och filer är förmodligen tillgängliga från Internet eftersom filen .htaccess inte fungerar.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Information hur din server bäst konfigureras kan hittas i <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Skapa ett administratörskonto</strong>",
@@ -397,6 +426,10 @@ OC.L10N.register(
     "Toggle password visibility" : "Växla lösenordsynlighet",
     "Configure the database" : "Konfigurera databasen",
     "Only %s is available." : "Endast %s är tillgänglig.",
-    "Database account" : "Databaskonto"
+    "Database account" : "Databaskonto",
+    "Installing …" : "Installerar …",
+    "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
+    "Currently logged in as %1$s (%2$s)." : "För närvarande inloggad som %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto."
 },
 "nplurals=2; plural=(n != 1);");
