@@ -104,6 +104,8 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} การแจ้งเตือน"],
     "No" : "ไม่",
     "Yes" : "ใช่",
+    "App password" : "รหัสผ่านแอป",
+    "Grant access" : "อนุญาตให้เข้าถึง",
     "Pick start date" : "เลือกวันที่เริ่มต้น",
     "Pick end date" : "เลือกวันที่สิ้นสุด",
     "Search in current app" : "ค้นหาในแอปปัจจุบัน",
@@ -125,7 +127,6 @@ OC.L10N.register(
     "Log in to {productName}" : "เข้าสู่ระบบไปยัง {productName}",
     "Wrong login or password." : "ล็อกอินหรือรหัสผ่านไม่ถูกต้อง",
     "This account is disabled" : "บัญชีนี้ถูกปิดใช้งาน",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "เราตรวจพบการเข้าสู่ระบบที่ไม่ถูกต้องจากที่อยู่ IP ของคุณหลายครั้ง การเข้าสู่ระบบถัดไปของคุณถูกควบคุมเป็นเวลาอย่างมาก 30 วินาที",
     "Account name or email" : "ชื่อหรืออีเมลบัญชี",
     "Account name" : "ชื่อบัญชี",
     "Server side authentication failed!" : "การรับรองความถูกต้องฝั่งเซิร์ฟเวอร์ล้มเหลว!",
@@ -180,7 +181,21 @@ OC.L10N.register(
     "Back to login form" : "กลับสู่แบบฟอร์มเข้าสู่ระบบ",
     "Back" : "ย้อนกลับ",
     "Login form is disabled." : "ฟอร์มล็อกอินถูกปิดใช้งาน",
+    "Connect to your account" : "เชื่อมต่อบัญชีของคุณ",
     "Security warning" : "คำเตือนความปลอดภัย",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "หากคุณไม่ได้เป็นคนตั้งค่าอุปกรณ์หรือแอปใหม่ อาจมีบุคคลอื่นกำลังหลอกให้คุณอนุญาตให้พวกเขาเข้าถึงข้อมูลของคุณ ในกรณีนี้ห้ามดำเนินการต่อ ให้ติดต่อผู้ดูแลระบบของคุณ",
+    "Alternative log in using app password" : "การเข้าสู่ระบบทางเลือกโดยใช้รหัสผ่านแอป",
+    "Account connected" : "เชื่อมต่อบัญชีแล้ว",
+    "Your client should now be connected!" : "ไคลเอ็นต์ของคุณควรได้รับการเชื่อมต่อแล้ว",
+    "You can close this window." : "คุณสามารถปิดหน้าต่างนี้ได้",
+    "Account access" : "การเข้าถึงบัญชี",
+    "This share is password-protected" : "การแชร์นี้มีการป้องกันด้วยรหัสผ่าน",
+    "The password is wrong or expired. Please try again or request a new one." : "รหัสผ่านไม่ถูกต้องหรือหมดอายุ กรุณาลองอีกครั้งหรือขอรหัสผ่านใหม่",
+    "Submit" : "ส่ง",
+    "Please type in your email address to request a temporary password" : "กรุณาพิมพ์ที่อยู่อีเมลของคุณเพื่อขอรหัสผ่านชั่วคราว",
+    "Password sent!" : "ส่งรหัสผ่านแล้ว!",
+    "You are not authorized to request a password for this share" : "คุณไม่ได้รับอนุญาตให้ขอรหัสผ่านสำหรับแชร์นี้",
+    "Email address" : "ที่อยู่อีเมล",
     "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
     "Data folder" : "โฟลเดอร์เก็บข้อมูล",
     "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่น ๆ",
@@ -222,6 +237,9 @@ OC.L10N.register(
     "(all selected)" : "(เลือกทั้งหมด)",
     "({count} selected)" : "(เลือก {count} รายการ)",
     "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์เทมเพลตที่มีอยู่",
+    "Groups" : "กลุ่ม",
+    "Group list is empty" : "รายชื่อกลุ่มว่างอยู่",
+    "Unable to retrieve the group list" : "ไม่สามารถดึงรายชื่อกลุ่ม",
     "seconds ago" : "วินาทีที่แล้ว",
     "Connection to server lost" : "การเชื่อมต่อไปยังเซิร์ฟเวอร์สูญหาย",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["เกิดปัญหาขณะโหลดหน้าเว็บ จะโหลดหน้าเว็บใหม่ใน %n วินาที"],
@@ -268,25 +286,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "ข้ามไปที่การนำทางของแอป",
     "Go to %s" : "ไปที่ %s",
     "Get your own free account" : "รับบัญชีฟรีของคุณ",
-    "Connect to your account" : "เชื่อมต่อบัญชีของคุณ",
-    "Please log in before granting %1$s access to your %2$s account." : "กรุณาเข้าสู่ระบบก่อนอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "หากคุณไม่ได้เป็นคนตั้งค่าอุปกรณ์หรือแอปใหม่ อาจมีบุคคลอื่นกำลังหลอกให้คุณอนุญาตให้พวกเขาเข้าถึงข้อมูลของคุณ ในกรณีนี้ห้ามดำเนินการต่อ ให้ติดต่อผู้ดูแลระบบของคุณ",
-    "App password" : "รหัสผ่านแอป",
-    "Grant access" : "อนุญาตให้เข้าถึง",
-    "Alternative log in using app password" : "การเข้าสู่ระบบทางเลือกโดยใช้รหัสผ่านแอป",
-    "Account access" : "การเข้าถึงบัญชี",
-    "Currently logged in as %1$s (%2$s)." : "ขณะนี้เข้าสู่ระบบเป็น %1$s (%2$s)",
-    "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
-    "Account connected" : "เชื่อมต่อบัญชีแล้ว",
-    "Your client should now be connected!" : "ไคลเอ็นต์ของคุณควรได้รับการเชื่อมต่อแล้ว",
-    "You can close this window." : "คุณสามารถปิดหน้าต่างนี้ได้",
     "Previous" : "ก่อนหน้า",
-    "This share is password-protected" : "การแชร์นี้มีการป้องกันด้วยรหัสผ่าน",
-    "The password is wrong or expired. Please try again or request a new one." : "รหัสผ่านไม่ถูกต้องหรือหมดอายุ กรุณาลองอีกครั้งหรือขอรหัสผ่านใหม่",
-    "Please type in your email address to request a temporary password" : "กรุณาพิมพ์ที่อยู่อีเมลของคุณเพื่อขอรหัสผ่านชั่วคราว",
-    "Email address" : "ที่อยู่อีเมล",
-    "Password sent!" : "ส่งรหัสผ่านแล้ว!",
-    "You are not authorized to request a password for this share" : "คุณไม่ได้รับอนุญาตให้ขอรหัสผ่านสำหรับแชร์นี้",
     "Two-factor authentication" : "การยืนยันสองปัจจัย",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ความปลอดภัยขั้นสูงถูกเปิดสำหรับบัญชีของคุณ เลือกปัจจัยที่สองเพื่อรับรองความถูกต้อง:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "ไม่สามารถโหลดหนึ่งในวิธียืนยันสองปัจจัยของคุณ กรุณาติดต่อผู้ดูแลระบบ",
@@ -330,6 +330,7 @@ OC.L10N.register(
     "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
     "Searching …" : "กำลังค้นหา …",
     "Logging in …" : "กำลังเข้าสู่ระบบ ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "เราตรวจพบการเข้าสู่ระบบที่ไม่ถูกต้องจากที่อยู่ IP ของคุณหลายครั้ง การเข้าสู่ระบบถัดไปของคุณถูกควบคุมเป็นเวลาอย่างมาก 30 วินาที",
     "Loading apps …" : "กำลังโหลดแอป …",
     "Installing apps …" : "กำลังติดตั้งแอป …",
     "Loading your contacts …" : "กำลังโหลดรายชื่อผู้ติดต่อของคุณ …",
@@ -358,6 +359,9 @@ OC.L10N.register(
     "Configure the database" : "ตั้งค่าฐานข้อมูล",
     "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
     "Database account" : "บัญชีฐานข้อมูล",
-    "Installing …" : "กำลังติดตั้ง …"
+    "Installing …" : "กำลังติดตั้ง …",
+    "Please log in before granting %1$s access to your %2$s account." : "กรุณาเข้าสู่ระบบก่อนอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
+    "Currently logged in as %1$s (%2$s)." : "ขณะนี้เข้าสู่ระบบเป็น %1$s (%2$s)",
+    "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ"
 },
 "nplurals=1; plural=0;");
