@@ -207,6 +207,7 @@ OC.L10N.register(
     "Continue to {productName}" : "{productName} ile ilerle",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
     "Done" : "Tamam",
+    "Scan QR code to log in" : "Oturum açmak için kare kodu tarayın",
     "Applications menu" : "Uygulamalar menüsü",
     "Apps" : "Uygulamalar",
     "More apps" : "Diğer uygulamalar",
@@ -288,7 +289,7 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "İş arkadaşlarınızın ve tanıdıklarınızın kayıtlarını kişisel bilgilerini sızdırmadan tek bir yerde tutun.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Dosyalar, Kişiler ve Takvim uygulamaları ile bir arada çalışan basit bir e-posta uygulaması.",
     "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri. Bilgisayar ve mobil aygıtlar için uygulamalar.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online üzerinde hazırlanmış iş birlikli çalışma belgeleri, hesap tabloları ve sunumlar.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online üzerinde hazırlanmış iş birlikli belgeler, çalışma sayfaları ve sunumlar.",
     "Distraction free note taking app." : "Dikkatinizi dağıtmayan not alma uygulaması.",
     "Recommended apps" : "Önerilen uygulamalar",
     "Loading apps …" : "Uygulamalar yükleniyor…",
@@ -344,6 +345,15 @@ OC.L10N.register(
     "You are currently not identified." : "Şu anda tanımlanmamışsınız.",
     "Set public name" : "Herkese açık adı ayarla",
     "Change public name" : "Herkese açık adı değiştir",
+    "This share is password-protected" : "Bu paylaşım parola korumalı",
+    "The password is wrong or expired. Please try again or request a new one." : "Parola hatalı ya da geçerlilik süresi dolmuş. Lütfen yeniden deneyin ya da parolanızı değiştirin. ",
+    "Submit" : "Gönder",
+    "Please type in your email address to request a temporary password" : "Lütfen geçici parola isteğinde bulunmak için e-posta adresinizi yazın",
+    "Password sent!" : "Parola gönderildi!",
+    "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
+    "Email address" : "E-posta adresi",
+    "Request password" : "Parola iste",
+    "Forgot password" : "Parolamı Unuttum",
     "Password is too weak" : "Parola çok kolay",
     "Password is weak" : "Parola kolay",
     "Password is average" : "Parola orta zorlukta",
@@ -461,12 +471,6 @@ OC.L10N.register(
     "Go to %s" : "%s bölümüne git",
     "Get your own free account" : "Ücretsiz hesabınızı açın",
     "Previous" : "Önceki",
-    "This share is password-protected" : "Bu paylaşım parola korumalı",
-    "The password is wrong or expired. Please try again or request a new one." : "Parola hatalı ya da geçerlilik süresi dolmuş. Lütfen yeniden deneyin ya da parolanızı değiştirin. ",
-    "Please type in your email address to request a temporary password" : "Lütfen geçici parola isteğinde bulunmak için e-posta adresinizi yazın",
-    "Email address" : "E-posta adresi",
-    "Password sent!" : "Parola gönderildi!",
-    "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
     "Two-factor authentication" : "İki adımlı doğrulama",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hesabınız için gelişmiş güvenlik etkinleştirildi. Kimlik doğrulaması için bir ikinci adım seçin:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kullanıma alınmış iki adımlı doğrulama yöntemlerinden en az biri yüklenemedi. Lütfen yöneticiniz ile görüşün.",
