@@ -344,6 +344,14 @@ OC.L10N.register(
     "You are currently not identified." : "سىزنىڭ كىملىكىڭىز ھازىرچە ئېنىقلانمىدى.",
     "Set public name" : "ئاممىۋى ئىسىم قۇرۇڭ",
     "Change public name" : "ئاممىۋى ئىسىمنى ئۆزگەرتىڭ",
+    "This share is password-protected" : "بۇ ئورتاقلىشىش مەخپىي نومۇر بىلەن قوغدىلىدۇ",
+    "The password is wrong or expired. Please try again or request a new one." : "پارول خاتا ياكى ۋاقتى ئۆتكەن. قايتا سىناڭ ياكى يېڭىنى تەلەپ قىلىڭ.",
+    "Submit" : "يوللاڭ",
+    "Please type in your email address to request a temporary password" : "ۋاقىتلىق پارول تەلەپ قىلىش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى كىرگۈزۈڭ",
+    "Password sent!" : "پارول ئەۋەتىلدى!",
+    "You are not authorized to request a password for this share" : "بۇ ئورتاقلىشىش ئۈچۈن پارول تەلەپ قىلىش ھوقۇقىڭىز يوق",
+    "Email address" : "ئېلخەت ئادرېسى",
+    "Request password" : "پارول تەلەپ قىلىڭ",
     "Password is too weak" : "پارول بەك ئاجىز",
     "Password is weak" : "پارول ئاجىز",
     "Password is average" : "پارول ئادەتتىكىچە",
@@ -461,12 +469,6 @@ OC.L10N.register(
     "Go to %s" : "%s گە بېرىڭ",
     "Get your own free account" : "ئۆزىڭىزنىڭ ھەقسىز ھېساباتىغا ئېرىشىڭ",
     "Previous" : "ئالدىنقى",
-    "This share is password-protected" : "بۇ ئورتاقلىشىش مەخپىي نومۇر بىلەن قوغدىلىدۇ",
-    "The password is wrong or expired. Please try again or request a new one." : "پارول خاتا ياكى ۋاقتى ئۆتكەن. قايتا سىناڭ ياكى يېڭىنى تەلەپ قىلىڭ.",
-    "Please type in your email address to request a temporary password" : "ۋاقىتلىق پارول تەلەپ قىلىش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى كىرگۈزۈڭ",
-    "Email address" : "ئېلخەت ئادرېسى",
-    "Password sent!" : "پارول ئەۋەتىلدى!",
-    "You are not authorized to request a password for this share" : "بۇ ئورتاقلىشىش ئۈچۈن پارول تەلەپ قىلىش ھوقۇقىڭىز يوق",
     "Two-factor authentication" : "ئىككى ئامىللىق دەلىللەش",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ھېساباتىڭىزغا بىخەتەرلىك كۈچەيتىلگەن. دەلىللەشنىڭ ئىككىنچى ئامىلىنى تاللاڭ:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "قوزغىتىلغان ئىككى ئامىللىق ئاپتوماتىك ئۇسۇلدىن كەم دېگەندە بىرنى يۈكلىيەلمىدىڭىز. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
