@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Невідомий тип файлу",
     "An error occurred. Please contact your admin." : "Виникла помилка. Будь ласка, зв'яжіться з вашим адміністратором.",
     "Invalid image" : "Невірне зображення",
-    "No temporary profile picture available, try again" : "Тимчасове зображення профілю недоступне, спробуйте ще раз",
-    "No crop data provided" : "Відсутня інформація щодо кадрування",
-    "No valid crop data provided" : "Не вказані коректні дані про кадрування",
-    "Crop is not square" : "Кадр не є квадратним",
     "State token does not match" : "Токен стану не збігається",
     "Invalid app password" : "Неправильний пароль застосунку",
     "Could not complete login" : "Не вдалося увійти",
     "State token missing" : "Відсутній токен стану.",
     "Your login token is invalid or has expired" : "Ваш токен для входу неправильний або термін його дії вичерпано",
+    "Please use original client" : "Використовуйте оригінальний клієнт",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Цей випуск спільноти Nextcloud не підтримується, а push-сповіщення обмежені.",
     "Login" : "Вхід",
     "Unsupported email length (>255)" : "Довжина адреси ел.пошти не підтримується (більше 255 символів)",
@@ -43,7 +40,9 @@ OC.L10N.register(
     "Task not found" : "Завдання не знайдено",
     "Internal error" : "Внутрішня помилка",
     "Not found" : "Не знайдено",
+    "Node is locked" : "Вузол заблоковано",
     "Bad request" : "Хибний запит",
+    "Input text is too long" : "Введений текст задовгий",
     "Requested task type does not exist" : "Запитаний вид завдання відсутній",
     "Necessary language model provider is not available" : "Постачальний потрібної мовної моделі недоступний",
     "No text to image provider is available" : "Відсутній постачальник конвертування тексту у зображення",
@@ -51,6 +50,12 @@ OC.L10N.register(
     "No translation provider available" : "Постачальник послуг перекладу недоступний",
     "Could not detect language" : "Не вдалося визначити мову",
     "Unable to translate" : "Не вдалося перекласти",
+    "No valid filters provided" : "Не надано дійсні фільтри",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Крок у відновленні:",
+    "Repair info:" : "Інформація про відновлення:",
+    "Repair warning:" : "Застереження щодо відновлення:",
+    "Repair error:" : "Помилка під час відновлення:",
     "Nextcloud Server" : "Сервер Nextcloud",
     "Some of your link shares have been removed" : "Окремі посилання на спільні елементи було вилучено",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Через ваду з безпекою ми вимушені були вилучити деякі ваші спільні посилання. Будь ласка, перегляньте цю докладну інформацію.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Зазначте ваш ключ підписки у застосунку підтримки, щоб збільшити кількість дозволених облікових записів. Після цього ви отримаєте всі додаткові переваги, які надає Nextcloud для бізнесу. Ми рекомендуємо це зробити для комерційних користувачів.",
     "Learn more ↗" : "Дізнайтеся більше ↗",
     "Preparing update" : "Підготовка оновлення",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Крок у відновленні:",
-    "Repair info:" : "Інформація про відновлення:",
-    "Repair warning:" : "Застереження щодо відновлення:",
-    "Repair error:" : "Помилка під час відновлення:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Будь ласка, скористайтеся оновленням через командний рядок, оскільки оновлення через бравзер вимкнено у файлі налаштувань config.php.",
     "Turned on maintenance mode" : "Активовано режим технічного обслуговування",
     "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
@@ -79,16 +79,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (несумісне)",
     "The following apps have been disabled: %s" : "Ці застосунки було вимкнено: %s",
     "Already up to date" : "Вже актуально",
-    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Додаткову інформацію див. у {linkstart}документації ↗{linkend}.",
-    "unknown text" : "невідомий текст",
-    "Hello world!" : "Привіт, світе!",
-    "sunny" : "сонячно",
-    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
-    "Hello {name}" : "Привіт {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Це ваші результати пошуку<script>alert(1)</script></strong>",
-    "new" : "новий",
-    "_download %n file_::_download %n files_" : ["звантаження %n файлу","звантаження %n файлів","звантаження %n файлів","звантаження %n файлів"],
+    "Windows Command Script" : "Скрипт Windows",
+    "Electronic book document" : "Документ електронної книги",
+    "TrueType Font Collection" : "Колекція шрифтів TrueType",
+    "Web Open Font Format" : "Відкритий формат шрифтів Web",
+    "GPX geographic data" : "Дані географічних координат GPX",
+    "Gzip archive" : "Архів Gzip",
+    "Adobe Illustrator document" : "Документ Adobe Illustrator",
+    "Java source code" : "Вихідний код Java",
+    "JavaScript source code" : "Вихідний код JavaScript",
+    "JSON document" : "Документ JSON",
+    "Microsoft Access database" : "База даних Microsoft Access",
+    "Microsoft OneNote document" : "Документ Microsoft OneNote",
+    "Microsoft Word document" : "Документ Microsoft Word",
+    "Unknown" : "Невідомо",
+    "PDF document" : "Документ PDF",
+    "PostScript document" : "Документ PostScript",
+    "RSS summary" : "RSS-підсумок",
+    "Android package" : "Пакунок Android",
+    "KML geographic data" : "Географічні дані KML",
+    "KML geographic compressed data" : "Стислі географічні дані KML",
+    "Lotus Word Pro document" : "Документ Lotus Word Pro",
+    "Excel spreadsheet" : "Електронна таблиця Excel",
+    "Excel add-in" : "Доповнення Excel",
+    "Excel 2007 binary spreadsheet" : "Бінарна електронна таблиця Excel 2007",
+    "Excel spreadsheet template" : "Шаблон таблиці Excel",
+    "Outlook Message" : "Ел. лист Outlook",
+    "PowerPoint presentation" : "Презентація PowerPoint",
+    "PowerPoint add-in" : "Додаток PowerPoint",
+    "PowerPoint presentation template" : "Шаблон презентації PowerPoint",
+    "Word document" : "Документ Word",
+    "ODF formula" : "Формула ODF",
+    "ODG drawing" : "Креслення ODG",
+    "ODG drawing (Flat XML)" : "Креслення ODG (Flat XML)",
+    "ODG template" : "Шаблон ODG",
+    "ODP presentation" : "Презентація ODP",
+    "ODP presentation (Flat XML)" : "Презентація ODP (Flat XML)",
+    "ODP template" : "Шаблон ODP",
+    "ODS spreadsheet" : "Електронна таблиця ODS",
+    "ODS spreadsheet (Flat XML)" : "Електронна таблиця ODS (Flat XML)",
+    "ODS template" : "Шаблон ODS",
+    "ODT document" : "Документ ODT",
+    "ODT document (Flat XML)" : "Документ ODT (Flat XML)",
+    "ODT template" : "Шаблон ODT",
+    "PowerPoint 2007 presentation" : "Презентація PowerPoint 2007",
+    "PowerPoint 2007 show" : "Презентація PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Шаблон презентації PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Електронна таблиця Excel 2007",
+    "Excel 2007 spreadsheet template" : "Шаблон електронної таблиці Excel 2007",
+    "Word 2007 document" : "Документ Word 2007",
+    "Word 2007 document template" : "Шаблон документа Word 2007",
+    "Microsoft Visio document" : "Документ Microsoft Visio",
+    "WordPerfect document" : "Документ WordPerfect",
+    "7-zip archive" : "Архів 7-zip",
+    "Blender scene" : "Сцена Blender",
+    "Bzip2 archive" : "Архів Bzip2",
+    "Debian package" : "Пакунок Debian",
+    "FictionBook document" : "Документ FictionBook",
+    "Unknown font" : "Невідомий шрифт",
+    "Krita document" : "Документ Krita",
+    "Mobipocket e-book" : "Електронна книга Mobipocket",
+    "Windows Installer package" : "Пакунок Windows Installer",
+    "Perl script" : "Скрипт Perl",
+    "PHP script" : "Скрипт PHP",
+    "Tar archive" : "Архів Tar",
+    "XML document" : "XML-документ",
+    "YAML document" : "Документ YAML",
+    "Zip archive" : "Архів Zip",
+    "Zstandard archive" : "Архів Zstandard",
+    "AAC audio" : "Аудіо AAC",
+    "FLAC audio" : "Аудіо FLAC",
+    "MPEG-4 audio" : "Аудіо MPEG-4",
+    "MP3 audio" : "Аудіо MP3",
+    "Ogg audio" : "Аудіо Ogg",
+    "RIFF/WAVe standard Audio" : "Стандарт RIFF/WAVe Аудіо",
+    "WebM audio" : "Аудіо WebM",
+    "MP3 ShoutCast playlist" : "Плейлист MP3 ShoutCast",
+    "Windows BMP image" : "Зображення Windows BMP",
+    "Better Portable Graphics image" : "Зображення Better Portable Graphics",
+    "EMF image" : "Зображення EMF",
+    "GIF image" : "Зображення GIF",
+    "HEIC image" : "Зображення HEIC",
+    "HEIF image" : "Зображення HEIF",
+    "JPEG-2000 JP2 image" : "Зображення JPEG-2000 JP2",
+    "JPEG image" : "Зображення JPEG",
+    "PNG image" : "Зображення PNG",
+    "SVG image" : "Зображення SVG",
+    "Truevision Targa image" : "Зображення Truevision Targa",
+    "TIFF image" : "Зображення TIFF",
+    "WebP image" : "Зображення WebP",
+    "Digital raw image" : "Зображення Digital raw",
+    "Windows Icon" : "Піктограма Windows",
+    "Email message" : "Електронне повідомлення",
+    "VCS/ICS calendar" : "Календар VCS/ICS",
+    "CSS stylesheet" : "Таблиця стилів CSS",
+    "CSV document" : "Документ CSV",
+    "HTML document" : "Документ HTML",
+    "Markdown document" : "Документ Markdown",
+    "Org-mode file" : "Файл Org-mode",
+    "Plain text document" : "Тестовий документ",
+    "Rich Text document" : "Документ Rich Text",
+    "Electronic business card" : "Електронна візитна картка",
+    "C++ source code" : "Вихідний код C++",
+    "LDIF address book" : "Адресна книга LDIF",
+    "NFO document" : "Документ NFO",
+    "PHP source" : "Вихідний файл PHP",
+    "Python script" : "Скрипт Python",
+    "ReStructuredText document" : "Документ ReStructuredText",
+    "3GPP multimedia file" : "Мультимедійний файл 3GPP",
+    "MPEG video" : "Відео MPEG",
+    "DV video" : "Відео DV",
+    "MPEG-2 transport stream" : "Транспортний потік MPEG-2",
+    "MPEG-4 video" : "Відео MPEG-4",
+    "Ogg video" : "Відео Ogg",
+    "QuickTime video" : "Відео QuickTime",
+    "WebM video" : "Відео WebM",
+    "Flash video" : "Відео Flash",
+    "Matroska video" : "Відео Matroska",
+    "Windows Media video" : "Відео Windows Media",
+    "AVI video" : "Відео AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Відбувається оновлення. Не залишайте цю сторінку, це може перервати процес у деяких середовищах.",
     "Update to {version}" : "Оновлення до {version}",
     "An error occurred." : "Виникла помилка.",
@@ -97,19 +206,22 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Оновлення не вдалося. Будь ласка, повідомте про це питання в <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">спільноту Nextcloud</a>.",
     "Continue to {productName}" : "Перейти до {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Оновлення пройшло успішно. Переспрямування на {productName} за %n секунду.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди."],
+    "Done" : "Готово",
     "Applications menu" : "Меню застосунків",
     "Apps" : "Застосунки",
     "More apps" : "Більше застосунків",
     "_{count} notification_::_{count} notifications_" : ["{count} сповіщень","{count} сповіщень","{count} сповіщень","{count} сповіщень"],
     "No" : "Ні",
     "Yes" : "Так",
+    "App password" : "Пароль застосунку",
+    "Grant access" : "Дозволити доступ",
     "The remote URL must include the user." : "Віддалена адреса повинна містити в собі імʼя користувача.",
     "Invalid remote URL." : "Недійсна віддалена адреса.",
-    "Failed to add the public link to your Nextcloud" : "Не вдалося додати загальнодоступне посилання до вашого Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Не вдалося додати публічне посилання до вашого Nextcloud",
     "Federated user" : "Обʼєднаний користувач",
     "user@your-nextcloud.org" : "користувач@ваш-nextcloud.org",
     "Create share" : "Передати у публічний доступ",
-    "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
+    "Direct link copied" : "Пряме посилання скопійовано",
     "Please copy the link manually:" : "Будь ласка, скопіюйте посилання вручну:",
     "Custom date range" : "Власний вибір проміжку",
     "Pick start date" : "Виберіть початкову дату",
@@ -118,14 +230,16 @@ OC.L10N.register(
     "Search in current app" : "Шукати в поточному застосунку",
     "Clear search" : "Очистити пошук",
     "Search everywhere" : "Шукати всюди",
-    "Searching …" : "Пошук ...",
+    "Searching …" : "Шукаю...",
     "Start typing to search" : "Що шукаємо?",
+    "Minimum search length is {minSearchLength} characters" : "Мінімальна довжина фрази пошуку складає {minSearchLength} символів",
     "No matching results" : "Відсутні збіги",
     "Today" : "Сьогодні",
     "Last 7 days" : "За останні 7 днів",
     "Last 30 days" : "За останні 30 днів",
     "This year" : "Цього року",
     "Last year" : "Минулого року",
+    "Between {startDate} and {endDate}" : "Між {startDate} та {endDate}",
     "Unified search" : "Універсальний пошук",
     "Search apps, files, tags, messages" : "Шукати застосунки, файли, мітки, повідомлення",
     "Places" : "Місця",
@@ -133,15 +247,17 @@ OC.L10N.register(
     "Search people" : "Пошук контактів",
     "People" : "Користувачі",
     "Filter in current view" : "Фільтр поточного подання",
+    "Search connected services" : "Пошук під'єднаних сервісів",
     "Results" : "Результат",
     "Load more results" : "Завантажити більше результатів",
     "Search in" : "Шукати у",
+    "Partial matches" : "Частковий збіг",
     "Log in" : "Увійти",
-    "Logging in …" : "Вхід ...",
+    "Logging in …" : "Вхід в систему ...",
     "Log in to {productName}" : "Увійдіть до {productName}",
     "Wrong login or password." : "Неправильне ім'я облікового запису або пароль.",
     "This account is disabled" : "Цей обліковий запис вимкнено.",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ми виявили кілька недійсних спроб входу з вашого IP-адресу. Тому  наступну спробу входу можна буде здійснити через 30 секунд.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Забагато спроб неправильного входу. Спробуйте ще раз за 30 секунд.",
     "Account name or email" : "Ім'я користувача або електронна пошта",
     "Account name" : "Назва облікового запису",
     "Server side authentication failed!" : "Невдала авторизація на стороні сервера!",
@@ -151,6 +267,7 @@ OC.L10N.register(
     "An internal error occurred." : "Виникла внутрішня помилка.",
     "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
     "Password" : "Пароль",
+    "Remember me" : "Запам'ятати мене",
     "Log in with a device" : "Увійти за допомогою пристрою",
     "Login or email" : "Ім'я облікового запису або адреса ел.пошти",
     "Your account is not setup for passwordless login." : "Ваш обліковий запис не налаштовано на безпарольний вхід.",
@@ -174,21 +291,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Спільні документи, електронні таблиці та презентації, створені на Collabora Online.",
     "Distraction free note taking app." : "Застосунок для ведення нотаток без зайвих відволікань.",
     "Recommended apps" : "Рекомендовані застосунки",
-    "Loading apps …" : "Завантаження застосунків ...",
+    "Loading apps …" : "Завантаження програм ...",
     "Could not fetch list of apps from the App Store." : "Не вдалося отримати список застосунків із App Store.",
     "App download or installation failed" : "Помилка із звантаженням або встановленням застосунку",
     "Cannot install this app because it is not compatible" : "Неможливо встановити цей застосунок, оскільки він не є сумісним",
     "Cannot install this app" : "Не вдається встановити цей застосунок",
     "Skip" : "Пропустити",
-    "Installing apps …" : "Встановлення застосунків ...",
+    "Installing apps …" : "Встановлення додатків ...",
     "Install recommended apps" : "Встановити рекомендовані застосунки",
+    "Online" : "Доступний(-а)",
+    "Away" : "Відсутній(-я)",
+    "Busy" : "Зайнято",
+    "Do not disturb" : "Не турбувати",
+    "Mute all notifications" : "Вимкнути всі сповіщення",
+    "Invisible" : "Невидимка",
+    "Appear offline" : "Перебуваю поза мережею",
     "Avatar of {displayName}" : "Зображення користувача для {displayName}",
     "Settings menu" : "Меню налаштувань",
-    "Loading your contacts …" : "Завантаження контактів...",
-    "Looking for {term} …" : "Шукаєте {term}",
+    "Loading your contacts …" : "Завантаження контактів ...",
+    "Looking for {term} …" : "Шукайте {term}...",
     "Search contacts" : "Шукати контакти",
     "Reset search" : "Повторити пошук",
-    "Search contacts …" : "Пошук контакту...",
+    "Search contacts …" : "Пошук контактів ...",
     "Could not load your contacts" : "Неможливо завантажити ваші контакти",
     "No contacts found" : "Контактів не знайдено",
     "Show all contacts" : "Показувати всі контакти",
@@ -200,13 +324,34 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Завантажити більше результатів",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Пошук здійснюватиметься одразу, як ви почнете набирати. Щоби вибрати результат, будь ласка, скористайтеся кнопками зі стрілками.",
     "Search for {name} only" : "Пошук лише у {name}",
-    "Loading more results …" : "Завантаження інших результатів…",
+    "Loading more results …" : "Завантажено більше результатів ...",
     "Forgot password?" : "Забули пароль?",
     "Back to login form" : "Повернутися на сторінку входу",
     "Back" : "Назад",
     "Login form is disabled." : "Форма входу вимкнена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму авторизації у хмарі Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
+    "Connect to your account" : "Увійти до вашого облікового запису",
+    "Security warning" : "Попередження безпеки",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Якщо ви не намагаєтеся налаштувати новий пристрій або застосунок, то це може означати, що хтось намагається обманом змусити вас надати доступ до ваших даних. У цьому випадку не продовжуйте, а зверніться до системного адміністратора.",
+    "Alternative log in using app password" : "Альтернативний логін, використовуючи пароль застосунку",
+    "Account connected" : "Обліковий запис під’єднано",
+    "Your client should now be connected!" : "Зараз ваш клієнт має бути приєднано!",
+    "You can close this window." : "Ви можете закрити це вікно.",
+    "Account access" : "Доступ до облікового запису",
     "More actions" : "Більше дій",
+    "User menu" : "Меню користувача",
+    "Your guest name: {user}" : "Ваше ім'я гостя: {user}",
+    "You are currently not identified." : "Вас не визначено.",
+    "Set public name" : "Встановити загальне ім'я",
+    "Change public name" : "Змінити загальне ім'я",
+    "This share is password-protected" : "Доступ до цього ресурсу захищений паролем",
+    "The password is wrong or expired. Please try again or request a new one." : "Пароль неправильний або термін дії минув. Спробуйте ще раз або надішліть запит на новий.",
+    "Submit" : "Відправити",
+    "Please type in your email address to request a temporary password" : "Будь ласка, введіть адресу електронної пошти, щоб отримати тимчасовий пароль",
+    "Password sent!" : "Пароль надіслано!",
+    "You are not authorized to request a password for this share" : "Ви не маєте права запитувати пароль для цього ресурсу",
+    "Email address" : "Адреса ел.пошти",
+    "Request password" : "Запит пароля",
     "Password is too weak" : "Занадто простий пароль ",
     "Password is weak" : "Простий пароль",
     "Password is average" : "Пароль середньої складності",
@@ -218,13 +363,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Ознайомтеся з{linkStart}документацію{linkEnd} з налаштування сервера.",
     "Autoconfig file detected" : "Виявлено файл автоконфігурації",
     "The setup form below is pre-filled with the values from the config file." : "Форму для налаштування попередньо заповнено значеннями з файлу конфігурації.",
-    "Security warning" : "Попередження безпеки",
     "Create administration account" : "Створіть обліковий запис адміністратора",
     "Administration account name" : "Ім'я облікового запису адміністратора",
     "Administration account password" : "Пароль облікового запису адміністратора",
     "Storage & database" : "Сховище і база даних",
     "Data folder" : "Каталог з даними",
     "Database configuration" : "Конфігурація бази даних",
+    "Database type" : "Тип бази даних",
     "Only {firstAndOnlyDatabase} is available." : "Лише {firstAndOnlyDatabase} доступна для вибору.",
     "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
     "For more details check out the documentation." : "За подробицями зверніться до документації.",
@@ -232,6 +377,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Ви вибрали SQLite як базу даних",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite слід використовувати лише для мінімалістичних серверних конфігурацій або для розробки. Для продуктових версій рекомендуємо використовувати базу даних іншого типу.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Якщо ви використовуєте клієнти для синхронізації файлів, використання SQLite вкрай не рекомендується.",
+    "Database connection" : "З'єднання бази даних",
     "Database user" : "Користувач бази даних",
     "Database password" : "Пароль для бази даних",
     "Database name" : "Назва бази даних",
@@ -239,7 +385,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям вузла (напр., localhost:5432).",
     "Database host" : "Вузол бази даних",
     "localhost" : "localhost",
-    "Installing …" : "Встановлення…",
+    "Installing …" : "Встановлення ...",
     "Install" : "Встановити",
     "Need help?" : "Потрібна допомога?",
     "See the documentation" : "Подивитись документацію",
@@ -248,7 +394,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш бравзер не підтримується. Будь ласка, оновіть бравзер до новішої версії або скористайтеся таким, що підтримується.",
     "Continue with this unsupported browser" : "Продовжити з бравзером, що не підтримується.",
     "Supported versions" : "Підтримувані версії",
-    "Search {types} …" : "Пошук {types} …",
+    "Search {types} …" : "Пошук {types}...",
     "Choose {file}" : "Виберіть {file}",
     "Choose" : "Вибрати",
     "Copy to {target}" : "Копіювати до {target}",
@@ -268,7 +414,10 @@ OC.L10N.register(
     "(all selected)" : "(все вибрано)",
     "({count} selected)" : "({count} вибрано)",
     "Error loading file exists template" : "Помилка при завантаженні шаблону існуючого файлу",
-    "Saving …" : "Збереження …",
+    "Saving …" : "Збереження ...",
+    "Groups" : "Групи",
+    "Group list is empty" : "Список груп порожній",
+    "Unable to retrieve the group list" : "Неможливо отримати список груп",
     "seconds ago" : "кілька секунд тому",
     "Connection to server lost" : "З'єднання з сервером втрачено",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблема під час завантаження сторінки, повторне завантаження за %n секунду.","Проблема під час завантаження сторінки, повторне завантаження за %n секунди.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд."],
@@ -283,26 +432,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Зазначте для пошуку серед наявних проєктів",
     "New in" : "Нові можливості",
     "View changelog" : "Подивитись зміни",
-    "No action available" : "Немає доступних дій",
-    "Error fetching contact actions" : "Неможливо отримати дії з контактами",
     "Close \"{dialogTitle}\" dialog" : "Закрити меню \"{dialogTitle}\"",
     "Email length is at max (255)" : "Досягнуто максимальну довжина адреси ел.пошти (255 символів)",
-    "Non-existing tag #{tag}" : "Ця мітка не існує #{tag}",
-    "Restricted" : "Обмежена",
-    "Invisible" : "Невидимка",
-    "Delete" : "Вилучити",
-    "Rename" : "Перейменувати",
-    "Collaborative tags" : "Мітки для організації співпраці",
-    "No tags found" : "Міток не знайдено",
     "Clipboard not available, please copy manually" : "Буфер обміну не доступний, скопіюйте вручну",
     "Personal" : "Особисте",
     "Accounts" : "Користувачі",
     "Admin" : "Адміністратор",
     "Help" : "Допомога",
     "Access forbidden" : "Доступ заборонено",
+    "You are not allowed to access this page." : "Відсутні права доступу до цієї сторінки.",
+    "Back to %s" : "Назад до %s",
     "Page not found" : "Сторінку не знайдено",
     "The page could not be found on the server or you may not be allowed to view it." : "Не вдалося знайти сторінку на сервері або вам не дозволено її перегляд.",
-    "Back to %s" : "Назад до %s",
     "Too many requests" : "Забагато запитів",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Забагато запитів із вашої мережі. Повторіть спробу пізніше або зверніться до адміністратора, якщо це помилка.",
     "Error" : "Помилка",
@@ -327,25 +468,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Перейти до навігації застосунку",
     "Go to %s" : "Перейти до %s",
     "Get your own free account" : "Отримати безкоштовний обліковий запис",
-    "Connect to your account" : "Увійти до вашого облікового запису",
-    "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Якщо ви не намагаєтеся налаштувати новий пристрій або застосунок, то це може означати, що хтось намагається обманом змусити вас надати доступ до ваших даних. У цьому випадку не продовжуйте, а зверніться до системного адміністратора.",
-    "App password" : "Пароль застосунку",
-    "Grant access" : "Дозволити доступ",
-    "Alternative log in using app password" : "Альтернативний логін, використовуючи пароль застосунку",
-    "Account access" : "Доступ до облікового запису",
-    "Currently logged in as %1$s (%2$s)." : "Зараз увійшли як %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s.",
-    "Account connected" : "Обліковий запис під’єднано",
-    "Your client should now be connected!" : "Зараз ваш клієнт має бути приєднано!",
-    "You can close this window." : "Ви можете закрити це вікно.",
     "Previous" : "Назад",
-    "This share is password-protected" : "Доступ до цього ресурсу захищений паролем",
-    "The password is wrong or expired. Please try again or request a new one." : "Пароль неправильний або термін дії минув. Спробуйте ще раз або надішліть запит на новий.",
-    "Please type in your email address to request a temporary password" : "Будь ласка, введіть адресу електронної пошти, щоб отримати тимчасовий пароль",
-    "Email address" : "Адреса ел.пошти",
-    "Password sent!" : "Пароль надіслано!",
-    "You are not authorized to request a password for this share" : "Ви не маєте права запитувати пароль для цього ресурсу",
     "Two-factor authentication" : "Двофакторна авторизація",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Для вашого облікового запису налаштовано посилену безпеку. Виберіть другий фактор авторизації.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможливо завантажити щонайменше один з активованих вами способів двофакторної авторизації. Будь ласка, сконтактуйте з адміністратором.",
@@ -378,23 +501,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Для сервера хмари %s увімкнено режим технічного обслуговування.",
     "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора, якщо це повідомлення не зникає або з'явилося несподівано.",
-    "Currently open" : "Наразі відкрито",
-    "Login with username or email" : "Увійти з ім'ям користувача або ел. поштою",
-    "Login with username" : "Увійти з ім'ям користувача",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чати, відеовиклики, демонстрація екану, онлайнові зустрічі та вебконференції у вашому браузері та на мобільних застосунках.",
-    "You have not added any info yet" : "Ви ще не додали жодної інформації",
-    "{user} has not added any info yet" : "{user} ще не додав жодної інформації",
-    "Error opening the user status modal, try hard refreshing the page" : "Помилка відкриття режиму статусу користувача. Спробуйте оновити сторінку",
-    "Edit Profile" : "Редагувати профіль",
-    "The headline and about sections will show up here" : "Тут відображатимуться заголовок і розділи про",
-    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
+    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Додаткову інформацію див. у {linkstart}документації ↗{linkend}.",
+    "unknown text" : "невідомий текст",
+    "Hello world!" : "Привіт, світе!",
+    "sunny" : "сонячно",
+    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
+    "Hello {name}" : "Привіт {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Це ваші результати пошуку<script>alert(1)</script></strong>",
+    "new" : "новий",
+    "_download %n file_::_download %n files_" : ["звантаження %n файлу","звантаження %n файлів","звантаження %n файлів","звантаження %n файлів"],
+    "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
+    "Searching …" : "Пошук ...",
+    "Logging in …" : "Вхід ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ми виявили кілька недійсних спроб входу з вашого IP-адресу. Тому  наступну спробу входу можна буде здійснити через 30 секунд.",
+    "Loading apps …" : "Завантаження застосунків ...",
+    "Installing apps …" : "Встановлення застосунків ...",
+    "Loading your contacts …" : "Завантаження контактів...",
+    "Looking for {term} …" : "Шукаєте {term}",
+    "Search contacts …" : "Пошук контакту...",
+    "Loading more results …" : "Завантаження інших результатів…",
+    "Search {types} …" : "Пошук {types} …",
+    "Saving …" : "Збереження …",
     "Very weak password" : "Дуже слабкий пароль",
     "Weak password" : "Слабкий пароль",
     "So-so password" : "Такий собі пароль",
     "Good password" : "Надійний пароль",
     "Strong password" : "Надійний пароль",
-    "Profile not found" : "Профіль не знайдено",
-    "The profile does not exist." : "Профіль не існує.",
+    "No action available" : "Немає доступних дій",
+    "Error fetching contact actions" : "Неможливо отримати дії з контактами",
+    "Non-existing tag #{tag}" : "Ця мітка не існує #{tag}",
+    "Restricted" : "Обмежена",
+    "Delete" : "Вилучити",
+    "Rename" : "Перейменувати",
+    "Collaborative tags" : "Мітки для організації співпраці",
+    "No tags found" : "Міток не знайдено",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог з даними та ваші файли можуть мати доступ з інтернету, оскільки файл .htaccess не дійсний.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Для отримання інформації про те, як правильно налаштувати свій сервер, перегляньте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацію</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Створити адміністративний обліковий запис</strong>",
@@ -404,6 +545,10 @@ OC.L10N.register(
     "Toggle password visibility" : "Перемкнути видимість пароля",
     "Configure the database" : "Налаштування бази даних",
     "Only %s is available." : "Доступно тільки %s.",
-    "Database account" : "Обліковий запис БД"
+    "Database account" : "Обліковий запис БД",
+    "Installing …" : "Встановлення…",
+    "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
+    "Currently logged in as %1$s (%2$s)." : "Зараз увійшли як %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
