@@ -84,12 +84,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Yangilash muvaffaqiyatsiz tugadi. Iltimos, bu muammo haqida  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud hamjamiyatiga </a> xabar qiling..",
     "Continue to {productName}" : " {productName}ni davom eting",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : [" {productName}ni yangilanish muvaffaqiyatli bo'ldi. Sizni yo'naltirish %n sekund."],
+    "Done" : "Bajarildi",
     "Applications menu" : "Ilovalar menyusi",
     "Apps" : "Ilovalar",
     "More apps" : "Ko'proq ilovalar",
     "_{count} notification_::_{count} notifications_" : ["{count} bildirishnomalarnotifications"],
     "No" : "Yo`q",
     "Yes" : "Ha",
+    "App password" : "Ilova paroli",
+    "Grant access" : "Ruxsat berish",
     "The remote URL must include the user." : "Masofaviy URL foydalanuvchini o'z ichiga olishi kerak.",
     "Invalid remote URL." : "Xato masofadagi URL.",
     "Failed to add the public link to your Nextcloud" : "Keyingi bulutga umumiy havolani qo'shib bo'lmadi",
@@ -125,7 +128,6 @@ OC.L10N.register(
     "Log in to {productName}" : " {productName}ga kirish",
     "Wrong login or password." : "Noto'g'ri login yoki parol.",
     "This account is disabled" : "Bu akkaunt o'chirilgan",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Biz sizning IP-dan bir nechta noto'g'ri kirish urinishlarini aniqladik. Shuning uchun sizning keyingi kirishingiz 30 soniyagacha qisqartiriladi.",
     "Account name or email" : "Akkaunt nomi yoki elektron pochta",
     "Account name" : "Akkaunt nomi",
     "Server side authentication failed!" : "Server tomoni autentifikatsiyasi muvaffaqiyatsiz tugadi!",
@@ -191,7 +193,22 @@ OC.L10N.register(
     "Back" : "Orqaga",
     "Login form is disabled." : "Kirish shakli o'chirilgan.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Next bulutli kirish shakli o'chirilgan. Agar mavjud bo'lsa, boshqa kirish opsiyasidan foydalaning yoki administratoringizga murojaat qiling.",
+    "Connect to your account" : "Akkauntingizni ulang",
+    "Security warning" : "Xavfsizlik haqida ogohlantirish",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Agar siz yangi qurilma yoki ilovani oʻrnatmoqchi boʻlmasangiz, kimdir sizni aldab, maʼlumotlaringizga kirish huquqini berishga harakat qilmoqda. Bunday holda davom etmang va o'rniga tizim administratoriga murojaat qiling.",
+    "Alternative log in using app password" : "Ilova paroli yordamida muqobil tizimga kiring",
+    "Account connected" : "Akkaunt ulangan",
+    "Your client should now be connected!" : "Sizning mijozingiz endi ulangan bo'lishi kerak!",
+    "You can close this window." : "Ushbu oynani yopishingiz mumkin.",
+    "Account access" : "Hisobga kirish",
     "More actions" : "Ko'proq harakatlar",
+    "This share is password-protected" : "Bu almashish parol bilan himoyalangan",
+    "The password is wrong or expired. Please try again or request a new one." : "Parol noto'g'ri yoki muddati o'tgan. Iltimos, qayta urinib ko'ring yoki yangisini so'rang.",
+    "Submit" : "Yuborish",
+    "Please type in your email address to request a temporary password" : "Vaqtinchalik parol so'rash uchun elektron pochta manzilingizni kiriting",
+    "Password sent!" : "Parol yuborildi!",
+    "You are not authorized to request a password for this share" : "Siz ushbu ulashish uchun parol soʻrash huquqiga ega emassiz",
+    "Email address" : "E-pochta manzili",
     "Password is too weak" : "Parol juda zaif",
     "Password is weak" : "Parol zaif",
     "Password is average" : "Parol o'rtacha",
@@ -203,7 +220,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : " Serveringizni qanday qilib to'g'ri sozlash haqida ma'lumot olish uchun iltimos{linkStart}dagi {linkEnd}hujjatlarga qarang",
     "Autoconfig file detected" : "Avtokonfig fayli aniqlandi",
     "The setup form below is pre-filled with the values from the config file." : "Quyidagi o'rnatish shakli konfiguratsiya faylidagi qiymatlar bilan oldindan to'ldirilgan.",
-    "Security warning" : "Xavfsizlik haqida ogohlantirish",
     "Create administration account" : "Boshqaruv hisobini yarating",
     "Administration account name" : "Administrator akkauntining nomi",
     "Administration account password" : "Administrator akkauntining paroli",
@@ -251,6 +267,7 @@ OC.L10N.register(
     "(all selected)" : "(barchasi tanlangan)",
     "({count} selected)" : "({count} tanlangan)",
     "Error loading file exists template" : "Fayl shablonini yuklashda xatolik yuz berdi",
+    "Groups" : "Groups",
     "seconds ago" : "soniya avval",
     "Connection to server lost" : "Serverga ulanish uzildi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sahifani yuklashda muammo yuz berdi, %n sekundda qayta yuklanmoqda"],
@@ -300,25 +317,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ilova navigatsiyasiga oʻtish",
     "Go to %s" : " %sga o`tish",
     "Get your own free account" : "O'zingizning bepul akkauntingizni oling",
-    "Connect to your account" : "Akkauntingizni ulang",
-    "Please log in before granting %1$s access to your %2$s account." : "Iltimos,  %1$s akkauntingizga kirishdan oldin   %2$s akkauntiga kirishga ruxsat bering.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Agar siz yangi qurilma yoki ilovani oʻrnatmoqchi boʻlmasangiz, kimdir sizni aldab, maʼlumotlaringizga kirish huquqini berishga harakat qilmoqda. Bunday holda davom etmang va o'rniga tizim administratoriga murojaat qiling.",
-    "App password" : "Ilova paroli",
-    "Grant access" : "Ruxsat berish",
-    "Alternative log in using app password" : "Ilova paroli yordamida muqobil tizimga kiring",
-    "Account access" : "Hisobga kirish",
-    "Currently logged in as %1$s (%2$s)." : "Hozirda  %1$s (%2$s) sifatida tizimga kirgan.",
-    "You are about to grant %1$s access to your %2$s account." : " Siz %1$s akkauntiga ruxsat berish arafasidasiz %2$s.",
-    "Account connected" : "Akkaunt ulangan",
-    "Your client should now be connected!" : "Sizning mijozingiz endi ulangan bo'lishi kerak!",
-    "You can close this window." : "Ushbu oynani yopishingiz mumkin.",
     "Previous" : "Oldingi",
-    "This share is password-protected" : "Bu almashish parol bilan himoyalangan",
-    "The password is wrong or expired. Please try again or request a new one." : "Parol noto'g'ri yoki muddati o'tgan. Iltimos, qayta urinib ko'ring yoki yangisini so'rang.",
-    "Please type in your email address to request a temporary password" : "Vaqtinchalik parol so'rash uchun elektron pochta manzilingizni kiriting",
-    "Email address" : "E-pochta manzili",
-    "Password sent!" : "Parol yuborildi!",
-    "You are not authorized to request a password for this share" : "Siz ushbu ulashish uchun parol soʻrash huquqiga ega emassiz",
     "Two-factor authentication" : "Ikki faktorli autentifikatsiya",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hisobingiz uchun kengaytirilgan xavfsizlik yoqilgan. Autentifikatsiya uchun ikkinchi omilni tanlang:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Yoqilgan ikki faktorli autentifikatsiya usullaridan kamida bittasini yuklab bo‘lmadi. Iltimos, adminingizga murojaat qiling.",
@@ -364,6 +363,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Klipbordga nusxa olish",
     "Searching …" : "Qidirilmoqda …",
     "Logging in …" : "Kirilmoqda …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Biz sizning IP-dan bir nechta noto'g'ri kirish urinishlarini aniqladik. Shuning uchun sizning keyingi kirishingiz 30 soniyagacha qisqartiriladi.",
     "Loading apps …" : "Ilovalarni yuklash …",
     "Installing apps …" : "Ilovalarni o'rnatish …",
     "Loading your contacts …" : "Kontaktlaringiz yuklanmoqda …",
@@ -395,6 +395,9 @@ OC.L10N.register(
     "Configure the database" : "Ma'lumotlar bazasini moslashtiring",
     "Only %s is available." : "Faqat %s uchun mavjud.",
     "Database account" : "Akkauntlar ma`lumotlar bazasi",
-    "Installing …" : "Oʻrnatilmoqda…"
+    "Installing …" : "Oʻrnatilmoqda…",
+    "Please log in before granting %1$s access to your %2$s account." : "Iltimos,  %1$s akkauntingizga kirishdan oldin   %2$s akkauntiga kirishga ruxsat bering.",
+    "Currently logged in as %1$s (%2$s)." : "Hozirda  %1$s (%2$s) sifatida tizimga kirgan.",
+    "You are about to grant %1$s access to your %2$s account." : " Siz %1$s akkauntiga ruxsat berish arafasidasiz %2$s."
 },
 "nplurals=1; plural=0;");
