@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Không biết kiểu tập tin",
     "An error occurred. Please contact your admin." : "Có lỗi xảy ra. Vui lòng báo cho quản trị viên.",
     "Invalid image" : "Hình ảnh không hợp lệ",
-    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
-    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
-    "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
-    "Crop is not square" : "Trích xuất không chuẩn",
     "State token does not match" : "Mã trạng thái không khớp",
     "Invalid app password" : "Mật khẩu ứng dụng không hợp lệ",
     "Could not complete login" : "Không thể hoàn thành đăng nhập",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "Không có nhà cung cấp bản dịch",
     "Could not detect language" : "Không thể phát hiện ngôn ngữ",
     "Unable to translate" : "Không thể dịch",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Bước sửa chữa:",
+    "Repair info:" : "Thông tin sửa chữa:",
+    "Repair warning:" : "Cảnh báo sửa chữa:",
+    "Repair error:" : "Lỗi sửa chữa:",
     "Nextcloud Server" : "Máy chủ vWorkspace",
     "Some of your link shares have been removed" : "Một số liên kết chia sẻ của bạn đã bị xóa",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Do lỗi bảo mật, chúng tôi đã phải xóa một số liên kết chia sẻ của bạn. Vui lòng xem liên kết để biết thêm thông tin.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Hãy nhập khóa đăng ký của bạn vào ứng dụng \"Support\" để tăng giới hạn tài khoản. Việc này cũng sẽ cung cấp cho bạn những đặc quyền do Nextcloud Enterprise cung cấp.",
     "Learn more ↗" : "Để biết thêm↗",
     "Preparing update" : "Đang chuẩn bị cập nhật",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Bước sửa chữa:",
-    "Repair info:" : "Thông tin sửa chữa:",
-    "Repair warning:" : "Cảnh báo sửa chữa:",
-    "Repair error:" : "Lỗi sửa chữa:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Vui lòng sử dụng trình cập nhật dòng lệnh vì cập nhật qua trình duyệt bị tắt trong config.php của bạn.",
     "Turned on maintenance mode" : "Bật chế độ bảo trì",
     "Turned off maintenance mode" : "Tắt chế độ bảo trì",
@@ -79,16 +75,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (không tương thích)",
     "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
     "Already up to date" : "Đã được cập nhật bản mới nhất",
-    "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Để biết thêm chi tiết, hãy xem tài liệu ↗ {linkstart} {linkend}.",
-    "unknown text" : "văn bản không rõ",
-    "Hello world!" : "Hello world!",
-    "sunny" : "nắng",
-    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
-    "Hello {name}" : "Xin chào {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
-    "new" : "mới",
-    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
+    "Unknown" : "Không xác định",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
     "Update to {version}" : "Cập nhật lên {version}",
     "An error occurred." : "Đã xảy ra lỗi.",
@@ -97,24 +84,25 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
     "Continue to {productName}" : "Tiếp tục đến {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Cập nhật đã thành công. Chuyển hướng bạn đến {productName} trong %n seconds."],
+    "Done" : "Hoàn tất",
     "Applications menu" : "Menu ứng dụng",
     "Apps" : "Ứng dụng",
     "More apps" : "Thêm ứng dụng",
     "_{count} notification_::_{count} notifications_" : ["{count} thông báo"],
     "No" : "Không",
     "Yes" : "Có",
+    "App password" : "Mật khẩu ứng dụng",
+    "Grant access" : "Cấp quyền truy cập",
     "Failed to add the public link to your Nextcloud" : "Không thể thêm liên kết công khai",
     "Federated user" : "Người dùng được liên kết",
     "user@your-nextcloud.org" : "người_dùng@nextcloud_của_bạn.org",
     "Create share" : "Tạo chia sẻ",
-    "Direct link copied to clipboard" : "URL đã được sao chép vào bộ nhớ tạm",
     "Please copy the link manually:" : "Vui lòng sao chép thủ công liên kết:",
     "Pick start date" : "Chọn ngày bắt đầu",
     "Pick end date" : "Chọn ngày kết thúc",
     "Search in date range" : "Tìm trong khoảng ngày",
     "Search in current app" : "Tìm trong ứng dụng hiện tại",
     "Search everywhere" : "Tìm ở bất kì đâu",
-    "Searching …" : "Đang tìm kiếm ...",
     "Start typing to search" : "Nhập để tìm kiếm",
     "No matching results" : "Không có kết quả trùng khớp",
     "Today" : "Hôm nay",
@@ -131,17 +119,13 @@ OC.L10N.register(
     "Load more results" : "Tải thêm kết quả",
     "Search in" : "Tìm kiếm trong",
     "Log in" : "Đăng nhập",
-    "Logging in …" : "Đang đăng nhập",
     "Log in to {productName}" : "Đăng nhập vào {productName}",
     "Wrong login or password." : "Tên người dùng hoặc mật khẩu sai.",
     "This account is disabled" : "Tài khoản này không còn khả dụng",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Chúng tôi đã phát hiện nhiều lần đăng nhập không hợp lệ từ IP của bạn. Do đó, lần đăng nhập tiếp theo của bạn được điều chỉnh lên đến 30 giây.",
     "Account name or email" : "Tên tài khoản hoặc email",
     "Account name" : "Tên tài khoản",
     "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
     "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
-    "Temporary error" : "Lỗi tạm thời",
-    "Please try again." : "Vui lòng thử lại sau",
     "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
     "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
     "Password" : "Mật khẩu",
@@ -167,21 +151,23 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Tài liệu, bảng tính và bản trình bày cộng tác, được xây dựng trên Collabora Online.",
     "Distraction free note taking app." : "Ứng dụng ghi chú không gây xao lãng.",
     "Recommended apps" : "Ứng dụng được đề xuất",
-    "Loading apps …" : "Đang tải ứng dụng ...",
     "Could not fetch list of apps from the App Store." : "Không thể tìm nạp danh sách ứng dụng từ App Store.",
     "App download or installation failed" : "Tải xuống hoặc cài đặt ứng dụng không thành công",
     "Cannot install this app because it is not compatible" : "Không thể cài đặt ứng dụng này vì nó không tương thích",
     "Cannot install this app" : "Không thể cài đặt ứng dụng này",
     "Skip" : "Bỏ qua",
-    "Installing apps …" : "Đang cài đặt ứng dụng ...",
     "Install recommended apps" : "Cài đặt các ứng dụng được đề xuất",
+    "Online" : "Trực tuyến",
+    "Away" : "Tạm vắng",
+    "Busy" : "Bận",
+    "Do not disturb" : "Đừng làm phiền",
+    "Mute all notifications" : "Tắt tiếng tất cả thông báo",
+    "Invisible" : "Vô hình",
+    "Appear offline" : "Đang offline",
     "Avatar of {displayName}" : "Ảnh đại diện của {displayName}",
     "Settings menu" : "Trình đơn thiết lập",
-    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
-    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
     "Search contacts" : "Tìm kiếm liên hệ",
     "Reset search" : "Đặt lại tìm kiếm",
-    "Search contacts …" : "Tìm liên hệ ...",
     "Could not load your contacts" : "Không thể tải liên hệ của bạn",
     "No contacts found" : "Không tìm thấy liên hệ nào",
     "Show all contacts" : "Hiện tất cả liên hệ",
@@ -193,14 +179,29 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Đã xảy ra lỗi khi tìm kiếm {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Tìm kiếm bắt đầu khi bạn bắt đầu nhập và có thể đạt được kết quả bằng các phím mũi tên",
     "Search for {name} only" : "Chỉ tìm kiếm {name}",
-    "Loading more results …" : "Tải thêm kết quả ...",
     "Forgot password?" : "Quên mật khẩu sao?",
     "Back to login form" : "Quay lại trang đăng nhập",
     "Back" : "Quay lại",
     "Login form is disabled." : "Trang đăng nhập bị vô hiệu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Phương thức đăng nhập này đã bị tắt. Sử dụng hình thức đăng nhập khả dụng khác hoặc liên hệ quản trị viên.",
-    "More actions" : "Nhiều hành động hơn",
+    "Connect to your account" : "Kết nối tài khoản của bạn",
     "Security warning" : "Cảnh báo bảo mật",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Nếu bạn không cố gắng thiết lập một thiết bị hoặc ứng dụng mới, ai đó đang cố lừa bạn cấp cho họ quyền truy cập vào dữ liệu của bạn. Trong trường hợp này, không tiếp tục và thay vào đó hãy liên hệ với quản trị viên hệ thống của bạn.",
+    "Alternative log in using app password" : "Đăng nhập thay thế bằng mật khẩu dành cho ứng dụng",
+    "Account connected" : "Tài khoản đã được kết nối",
+    "Your client should now be connected!" : "Máy khách của bạn bây giờ sẽ được kết nối!",
+    "You can close this window." : "Bạn có thể đóng lại cửa sổ này",
+    "Account access" : "Truy cập tài khoản",
+    "More actions" : "Nhiều hành động hơn",
+    "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
+    "The password is wrong or expired. Please try again or request a new one." : "Mật khẩu không đúng hoặc đã hết hạn.\nVui lòng thử lại hoặc yêu cầu mật khẩu mới.",
+    "Submit" : "Gửi",
+    "Please type in your email address to request a temporary password" : "Vui lòng nhập địa chỉ email để yêu cầu mật khẩu tạm",
+    "Password sent!" : "Đã gửi Mật khẩu",
+    "You are not authorized to request a password for this share" : "Bạn không được phép yêu cầu mật khẩu cho chia sẻ này",
+    "Email address" : "Địa chỉ thư điện tử",
+    "Request password" : "Yêu cầu mật khẩu",
+    "Forgot password" : "Quên mật khẩu",
     "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
     "Data folder" : "Thư mục dữ liệu",
     "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
@@ -215,7 +216,6 @@ OC.L10N.register(
     "Database tablespace" : "Cơ sở dữ liệu tablespace",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
     "Database host" : "Database host",
-    "Installing …" : "Đang cài đặt",
     "Install" : "Cài đặt",
     "Need help?" : "Cần hỗ trợ ?",
     "See the documentation" : "Xem tài liệu",
@@ -224,7 +224,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
     "Continue with this unsupported browser" : "Tiếp tục với trình duyệt không được hỗ trợ này",
     "Supported versions" : "Các phiên bản được hỗ trợ",
-    "Search {types} …" : "Tìm kiếm {types} ...",
     "Choose {file}" : "Chọn {file}",
     "Choose" : "Chọn",
     "Copy to {target}" : "Sao chép vào {target}",
@@ -244,7 +243,9 @@ OC.L10N.register(
     "(all selected)" : "(Tất cả các lựa chọn)",
     "({count} selected)" : "({count} được chọn)",
     "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
-    "Saving …" : "Đang lưu ...",
+    "Groups" : "Nhóm",
+    "Group list is empty" : "Danh sách nhóm trống",
+    "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
     "seconds ago" : "vài giây trước",
     "Connection to server lost" : "Kết nối tới máy chủ bị mất",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
@@ -259,25 +260,16 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nhập để tìm kiếm các dự án hiện có",
     "New in" : "Mới trong",
     "View changelog" : "Xem nhật ký thay đổi",
-    "No action available" : "Không có hành động nào",
-    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
     "Close \"{dialogTitle}\" dialog" : "Đóng hộp thoại \"{dialogTitle}\"",
     "Email length is at max (255)" : "Độ dài Email đã đạt giới hạn (255 ký tự)",
-    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
-    "Restricted" : "Bị giới hạn",
-    "Invisible" : "Vô hình",
-    "Delete" : "Xóa",
-    "Rename" : "Sửa tên",
-    "Collaborative tags" : "Thẻ cộng tác",
-    "No tags found" : "Không tìm thấy thẻ",
     "Personal" : "Cá nhân",
     "Accounts" : "Tài khoản",
     "Admin" : "Quản trị",
     "Help" : "Giúp đỡ",
     "Access forbidden" : "Truy cập bị cấm",
+    "Back to %s" : "Quay lại %s",
     "Page not found" : "Trang không tìm thấy",
     "The page could not be found on the server or you may not be allowed to view it." : "Không thể tìm thấy trang trên máy chủ hoặc bạn có thể không được phép xem nó.",
-    "Back to %s" : "Quay lại %s",
     "Too many requests" : "Có quá nhiều yêu cầu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Có quá nhiều yêu cầu từ mạng của bạn. Thử lại sau hoặc liên hệ với quản trị viên của bạn nếu đây là lỗi.",
     "Error" : "Lỗi",
@@ -302,25 +294,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Chuyển tới điều hướng của ứng dụng",
     "Go to %s" : "Đi tới %s",
     "Get your own free account" : "Nhận tài khoản miễn phí",
-    "Connect to your account" : "Kết nối tài khoản của bạn",
-    "Please log in before granting %1$s access to your %2$s account." : "Vui lòng đăng nhập trước khi cấp quyền cho %1$s truy cập vào tài khoản %2$s của bạn.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Nếu bạn không cố gắng thiết lập một thiết bị hoặc ứng dụng mới, ai đó đang cố lừa bạn cấp cho họ quyền truy cập vào dữ liệu của bạn. Trong trường hợp này, không tiếp tục và thay vào đó hãy liên hệ với quản trị viên hệ thống của bạn.",
-    "App password" : "Mật khẩu ứng dụng",
-    "Grant access" : "Cấp quyền truy cập",
-    "Alternative log in using app password" : "Đăng nhập thay thế bằng mật khẩu dành cho ứng dụng",
-    "Account access" : "Truy cập tài khoản",
-    "Currently logged in as %1$s (%2$s)." : "Hiện đang đăng nhập với tư cách %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Bạn sắp cấp quyền truy cập cho %1$s vào tài khoản %2$s của mình.",
-    "Account connected" : "Tài khoản đã được kết nối",
-    "Your client should now be connected!" : "Máy khách của bạn bây giờ sẽ được kết nối!",
-    "You can close this window." : "Bạn có thể đóng lại cửa sổ này",
     "Previous" : "Trước",
-    "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
-    "The password is wrong or expired. Please try again or request a new one." : "Mật khẩu không đúng hoặc đã hết hạn.\nVui lòng thử lại hoặc yêu cầu mật khẩu mới.",
-    "Please type in your email address to request a temporary password" : "Vui lòng nhập địa chỉ email để yêu cầu mật khẩu tạm",
-    "Email address" : "Địa chỉ thư điện tử",
-    "Password sent!" : "Đã gửi Mật khẩu",
-    "You are not authorized to request a password for this share" : "Bạn không được phép yêu cầu mật khẩu cho chia sẻ này",
     "Two-factor authentication" : "Xác thực 2 bước",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bảo mật nâng cao được bật cho tài khoản của bạn. Chọn yếu tố thứ hai để xác thực:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Không thể tải ít nhất một trong các phương pháp xác thực hai yếu tố được kích hoạt của bạn. Vui lòng liên hệ với quản trị viên của bạn.",
@@ -353,29 +327,51 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
     "This page will refresh itself when the instance is available again." : "Trang này sẽ tự làm mới khi phiên bản khả dụng trở lại.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
-    "Currently open" : "Hiện đang mở",
-    "Login with username or email" : "Đăng nhập bằng tên người dùng hoặc Email",
-    "Login with username" : "Đăng nhập bằng tên đăng nhập",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Trò chuyện, cuộc gọi video, chia sẻ màn hình, cuộc họp trực tuyến và hội nghị trên web - trong trình duyệt của bạn và với các ứng dụng dành cho thiết bị di động.",
-    "You have not added any info yet" : "Bạn chưa thêm bất kỳ thông tin nào",
-    "{user} has not added any info yet" : "{user} chưa thêm bất kỳ thông tin nào",
-    "Error opening the user status modal, try hard refreshing the page" : "Lỗi khi mở phương thức trạng thái người dùng, hãy thử làm mới trang",
-    "Edit Profile" : "Chỉnh sửa hồ sơ",
-    "The headline and about sections will show up here" : "Dòng tiêu đề và phần giới thiệu sẽ hiển thị ở đây",
-    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
+    "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Để biết thêm chi tiết, hãy xem tài liệu ↗ {linkstart} {linkend}.",
+    "unknown text" : "văn bản không rõ",
+    "Hello world!" : "Hello world!",
+    "sunny" : "nắng",
+    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
+    "Hello {name}" : "Xin chào {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
+    "new" : "mới",
+    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
+    "Direct link copied to clipboard" : "URL đã được sao chép vào bộ nhớ tạm",
+    "Searching …" : "Đang tìm kiếm ...",
+    "Logging in …" : "Đang đăng nhập",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Chúng tôi đã phát hiện nhiều lần đăng nhập không hợp lệ từ IP của bạn. Do đó, lần đăng nhập tiếp theo của bạn được điều chỉnh lên đến 30 giây.",
+    "Loading apps …" : "Đang tải ứng dụng ...",
+    "Installing apps …" : "Đang cài đặt ứng dụng ...",
+    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
+    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
+    "Search contacts …" : "Tìm liên hệ ...",
+    "Loading more results …" : "Tải thêm kết quả ...",
+    "Search {types} …" : "Tìm kiếm {types} ...",
+    "Saving …" : "Đang lưu ...",
     "Very weak password" : "Mật khẩu rất yếu",
     "Weak password" : "Mật khẩu yếu",
     "So-so password" : "Mật khẩu tạm được",
     "Good password" : "Mật khẩu tốt",
     "Strong password" : "Mật khẩu mạnh",
-    "Profile not found" : "Không tìm thấy hồ sơ",
-    "The profile does not exist." : "Hồ sơ không tồn tại.",
+    "No action available" : "Không có hành động nào",
+    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
+    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
+    "Restricted" : "Bị giới hạn",
+    "Delete" : "Xóa",
+    "Rename" : "Sửa tên",
+    "Collaborative tags" : "Thẻ cộng tác",
+    "No tags found" : "Không tìm thấy thẻ",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Để biết thông tin về cách cấu hình đúng máy chủ của bạn, vui lòng xem <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">tài liệu</a>.",
     "Show password" : "Hiện mật khẩu",
     "Toggle password visibility" : "Chuyển chế độ hiển thị mật khẩu",
     "Configure the database" : "Cấu hình cơ sở dữ liệu",
     "Only %s is available." : "Chỉ %s khả dụng.",
-    "Database account" : "Tài khoản CSDL"
+    "Database account" : "Tài khoản CSDL",
+    "Installing …" : "Đang cài đặt",
+    "Please log in before granting %1$s access to your %2$s account." : "Vui lòng đăng nhập trước khi cấp quyền cho %1$s truy cập vào tài khoản %2$s của bạn.",
+    "Currently logged in as %1$s (%2$s)." : "Hiện đang đăng nhập với tư cách %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Bạn sắp cấp quyền truy cập cho %1$s vào tài khoản %2$s của mình."
 },
 "nplurals=1; plural=0;");
