@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "未找到",
     "Node is locked" : "节点已锁定",
     "Bad request" : "请求错误",
+    "Input text is too long" : "输入文本太长",
     "Requested task type does not exist" : "请求的任务类型不存在",
     "Necessary language model provider is not available" : "无必要的语言模型提供程序",
     "No text to image provider is available" : "没有可用的文字转图片提供者",
@@ -205,12 +206,16 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud社区</a>。",
     "Continue to {productName}" : "继续到 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后你将重定向到 {productName}。"],
+    "Done" : "完成",
+    "Scan QR code to log in" : "扫描二维码登录",
     "Applications menu" : "应用程序菜单",
     "Apps" : "应用",
     "More apps" : "更多的应用程序",
     "_{count} notification_::_{count} notifications_" : ["{count} 条通知"],
     "No" : "否",
     "Yes" : "是",
+    "App password" : "应用密码",
+    "Grant access" : "授权访问",
     "The remote URL must include the user." : "远程 URL 必须包含用户。",
     "Invalid remote URL." : "无效远程 URL。",
     "Failed to add the public link to your Nextcloud" : "无法将公开链接添加到您的 Nextcloud",
@@ -247,12 +252,13 @@ OC.L10N.register(
     "Results" : "结果",
     "Load more results" : "加载更多结果",
     "Search in" : "搜索",
+    "Partial matches" : "部分匹配",
     "Log in" : "登录",
     "Logging in …" : "正在登录 …",
     "Log in to {productName}" : "登录到 {productName}",
     "Wrong login or password." : "账号或密码错误",
     "This account is disabled" : "此账号已停用",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到你的 IP 进行了多次无效登录尝试。因此，你的下一次登录将被延迟 30 秒。",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "错误登录尝试次数过多，请在 30 秒后重试。",
     "Account name or email" : "账号名称或电子邮箱",
     "Account name" : "账号名称",
     "Server side authentication failed!" : "服务端身份验证失败！",
@@ -262,6 +268,7 @@ OC.L10N.register(
     "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系您的管理员。",
     "Password" : "密码",
+    "Remember me" : "记住我",
     "Log in with a device" : "使用设备登录",
     "Login or email" : "账号或电子邮箱",
     "Your account is not setup for passwordless login." : "你的账号未设置无密码登录。",
@@ -293,6 +300,13 @@ OC.L10N.register(
     "Skip" : "跳过",
     "Installing apps …" : "正在安装应用 …",
     "Install recommended apps" : "安装推荐的应用",
+    "Online" : "在线",
+    "Away" : "离开",
+    "Busy" : "忙碌",
+    "Do not disturb" : "勿扰",
+    "Mute all notifications" : "静音所有通知",
+    "Invisible" : "隐藏",
+    "Appear offline" : "显示为离线",
     "Avatar of {displayName}" : "{displayName} 的头像",
     "Settings menu" : "设置菜单",
     "Loading your contacts …" : "正在加载您的联系人 …",
@@ -317,12 +331,29 @@ OC.L10N.register(
     "Back" : "返回",
     "Login form is disabled." : "登录表单已禁用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
+    "Connect to your account" : "连接到您的账号",
+    "Security warning" : "安全警告",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
+    "Alternative log in using app password" : "使用应用密码进行登录",
+    "Account connected" : "账号已连接",
+    "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
+    "You can close this window." : "您可以关闭此窗口。",
+    "Account access" : "账号访问",
     "More actions" : "更多操作 ",
     "User menu" : "用户菜单",
     "Your guest name: {user}" : "您的访客名称：{user}",
     "You are currently not identified." : "您当前未被标识。",
     "Set public name" : "设置公开名称",
     "Change public name" : "更改公开名称",
+    "This share is password-protected" : "这个共享是被密码保护的",
+    "The password is wrong or expired. Please try again or request a new one." : "密码错误的或已经过期。请重试或申请一个新的。",
+    "Submit" : "提交",
+    "Please type in your email address to request a temporary password" : "请输入您的电子邮箱地址以申请一个临时密码",
+    "Password sent!" : "密码已发送！",
+    "You are not authorized to request a password for this share" : "您无权要求获得此共享的密码",
+    "Email address" : "电子邮箱地址",
+    "Request password" : "需要密码",
+    "Forgot password" : "忘记密码",
     "Password is too weak" : "密码太弱",
     "Password is weak" : "弱密码",
     "Password is average" : "一般密码",
@@ -334,7 +365,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有关如何正确配置服务器的信息，{linkStart}请参阅文档{linkEnd}",
     "Autoconfig file detected" : "检测到自动配置文件",
     "The setup form below is pre-filled with the values from the config file." : "下方设置表单预先填写了配置文件中的值。",
-    "Security warning" : "安全警告",
     "Create administration account" : "创建管理员账号",
     "Administration account name" : "管理员账号名称",
     "Administration account password" : "管理员账号密码",
@@ -387,6 +417,9 @@ OC.L10N.register(
     "({count} selected)" : "（选择了 {count} 个）",
     "Error loading file exists template" : "加载文件存在性模板失败",
     "Saving …" : "正在保存 …",
+    "Groups" : "用户组",
+    "Group list is empty" : "群组列表为空",
+    "Unable to retrieve the group list" : "无法获取分组列表",
     "seconds ago" : "几秒前",
     "Connection to server lost" : "与服务器的连接断开",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
@@ -437,25 +470,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "跳过应用向导",
     "Go to %s" : "转至 %s",
     "Get your own free account" : "获取自己的免费账号",
-    "Connect to your account" : "连接到您的账号",
-    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
-    "App password" : "应用密码",
-    "Grant access" : "授权访问",
-    "Alternative log in using app password" : "使用应用密码进行登录",
-    "Account access" : "账号访问",
-    "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
-    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。",
-    "Account connected" : "账号已连接",
-    "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
-    "You can close this window." : "您可以关闭此窗口。",
     "Previous" : "上一个",
-    "This share is password-protected" : "这个共享是被密码保护的",
-    "The password is wrong or expired. Please try again or request a new one." : "密码错误的或已经过期。请重试或申请一个新的。",
-    "Please type in your email address to request a temporary password" : "请输入您的电子邮箱地址以申请一个临时密码",
-    "Email address" : "电子邮箱地址",
-    "Password sent!" : "密码已发送！",
-    "You are not authorized to request a password for this share" : "您无权要求获得此共享的密码",
     "Two-factor authentication" : "两步验证",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账号已启用安全增强。请选择第二种验证方式。",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "无法载入您启用的任何两步验证方法。请联系管理员。",
@@ -501,6 +516,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "直链已复制至粘贴板",
     "Searching …" : "正在搜索 ...",
     "Logging in …" : "正在登录……",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到你的 IP 进行了多次无效登录尝试。因此，你的下一次登录将被延迟 30 秒。",
     "Loading apps …" : "正在加载应用…",
     "Installing apps …" : "正在安装应用...",
     "Loading your contacts …" : "正在加载您的联系人……",
@@ -518,7 +534,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "查找联系人时出错",
     "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
     "Restricted" : "受限",
-    "Invisible" : "隐藏",
     "Delete" : "删除",
     "Rename" : "重命名",
     "Collaborative tags" : "协作标签",
@@ -533,6 +548,9 @@ OC.L10N.register(
     "Configure the database" : "配置数据库",
     "Only %s is available." : "仅 %s 可用。",
     "Database account" : "数据库账号",
-    "Installing …" : "正在安装..."
+    "Installing …" : "正在安装...",
+    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
+    "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
+    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。"
 },
 "nplurals=1; plural=0;");
