@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "找不到",
     "Node is locked" : "節點已鎖定",
     "Bad request" : "錯誤的請求",
+    "Input text is too long" : "輸入文字太長",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型程式",
     "No text to image provider is available" : "沒有可用的文字轉影像提供者",
@@ -205,12 +206,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新失敗。請前往 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>回報此問題。",
     "Continue to {productName}" : "繼續使用 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。將在 %n 秒後重新導向至 {productName}。"],
+    "Done" : "完成",
+    "Scan QR code to log in" : "掃描 QR code 以登入",
+    "Use {productName} mobile client you want to connect to scan the code" : "使用您要連線的 {productName} 行動裝置客戶端掃描此條碼",
+    "Code will expire {timeCountdown} or after use" : "條碼會在 {timeCountdown} 後或使用後失效",
     "Applications menu" : "應用程式選單",
     "Apps" : "應用程式",
     "More apps" : "更多應用程式",
     "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
     "No" : "否",
     "Yes" : "是",
+    "App password" : "應用程式密碼",
+    "Grant access" : "授權存取",
     "The remote URL must include the user." : "遠端 URL 必須包含使用者。",
     "Invalid remote URL." : "無效的遠端 URL。",
     "Failed to add the public link to your Nextcloud" : "無法將公開連結新增到您的 Nextcloud",
@@ -247,12 +254,13 @@ OC.L10N.register(
     "Results" : "結果",
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋條件",
+    "Partial matches" : "部份符合",
     "Log in" : "登入",
     "Logging in …" : "正在登入……",
     "Log in to {productName}" : "登入 {productName}",
     "Wrong login or password." : "錯誤的帳號或密碼。",
     "This account is disabled" : "此帳號已停用",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時 30 秒。",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "不正確的登入嘗試次數太多。請於 30 秒後再試一次。",
     "Account name or email" : "帳號名稱或電子郵件",
     "Account name" : "帳號名稱",
     "Server side authentication failed!" : "伺服器端認證失敗！",
@@ -262,6 +270,7 @@ OC.L10N.register(
     "An internal error occurred." : "發生內部錯誤。",
     "Please try again or contact your administrator." : "請重試，或聯絡您的系統管理員。",
     "Password" : "密碼",
+    "Remember me" : "記住我",
     "Log in with a device" : "使用裝置登入",
     "Login or email" : "帳號或電子郵件",
     "Your account is not setup for passwordless login." : "您的帳號尚未設定無密碼登入。",
@@ -293,6 +302,13 @@ OC.L10N.register(
     "Skip" : "跳過",
     "Installing apps …" : "正在安裝應用程式 ……",
     "Install recommended apps" : "安裝推薦的應用程式",
+    "Online" : "上線",
+    "Away" : "離開",
+    "Busy" : "忙碌",
+    "Do not disturb" : "請勿打擾",
+    "Mute all notifications" : "靜音所有通知",
+    "Invisible" : "隱藏",
+    "Appear offline" : "顯示為離線",
     "Avatar of {displayName}" : "{displayName} 的頭像",
     "Settings menu" : "設定選單",
     "Loading your contacts …" : "正在載入您的聯絡人 ……",
@@ -317,12 +333,33 @@ OC.L10N.register(
     "Back" : "返回",
     "Login form is disabled." : "登入表單已停用。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
+    "Connect to your account" : "連結您的帳號",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "請先登入，再授權「{client}」存取您 {instanceName} 帳號。",
+    "Security warning" : "安全性警告",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若您並未嘗試設定新裝置或應用程式，那麼某人可能正在欺騙您讓他們存取您的資料。在這種情況下，請不要繼續，請聯絡您的系統管理員。",
+    "Log in using password" : "使用密碼登入",
+    "Alternative log in using app password" : "使用應用程式密碼替代登入",
+    "Account connected" : "已連結帳號",
+    "Your client should now be connected!" : "客戶端現在應該已連線！",
+    "You can close this window." : "您可以關閉此視窗。",
+    "Account access" : "帳號存取",
+    "Currently logged in as {userDisplayName} ({userId})." : "目前登入為 {userDisplayName} ({userId})。",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "您將要授權「{client}」存取您的 {instanceName} 帳號。",
     "More actions" : "更多動作",
     "User menu" : "使用者選單",
     "Your guest name: {user}" : "您的訪客名稱：{user}",
     "You are currently not identified." : "目前無法辨識您的身份。",
     "Set public name" : "設定公開名稱",
     "Change public name" : "變更公開名稱",
+    "This share is password-protected" : "此分享受密碼保護",
+    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。請重試，或重新申請。",
+    "Submit" : "提交",
+    "Please type in your email address to request a temporary password" : "請輸入您的電子郵件地址以申請臨時密碼",
+    "Password sent!" : "密碼已傳送！",
+    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
+    "Email address" : "電子郵件地址",
+    "Request password" : "請求密碼",
+    "Forgot password" : "忘記密碼",
     "Password is too weak" : "非常弱密碼",
     "Password is weak" : "弱密碼",
     "Password is average" : "一般密碼",
@@ -334,7 +371,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "{linkStart}閱讀說明文件{linkEnd}來瞭解如何正確設定您的伺服器",
     "Autoconfig file detected" : "偵測到自動組態檔案",
     "The setup form below is pre-filled with the values from the config file." : "下面的設定表單已預先填入設定檔中的值。",
-    "Security warning" : "安全性警告",
     "Create administration account" : "建立管理員帳號",
     "Administration account name" : "管理員帳號名稱",
     "Administration account password" : "管理員帳號密碼",
@@ -387,6 +423,9 @@ OC.L10N.register(
     "({count} selected)" : "（已選取 {count} 項）",
     "Error loading file exists template" : "載入已存在的範本時發生錯誤",
     "Saving …" : "正在儲存 …",
+    "Groups" : "群組",
+    "Group list is empty" : "群組列表空白",
+    "Unable to retrieve the group list" : "無法擷取群組列表",
     "seconds ago" : "幾秒前",
     "Connection to server lost" : "伺服器連線中斷",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
@@ -437,25 +476,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "跳到應用程式導覽",
     "Go to %s" : "前往 %s",
     "Get your own free account" : "取得免費帳號",
-    "Connect to your account" : "連結您的帳號",
-    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號。",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若您並未嘗試設定新裝置或應用程式，那麼某人可能正在欺騙您讓他們存取您的資料。在這種情況下，請不要繼續，請聯絡您的系統管理員。",
-    "App password" : "應用程式密碼",
-    "Grant access" : "授權存取",
-    "Alternative log in using app password" : "使用應用程式密碼替代登入",
-    "Account access" : "帳號存取",
-    "Currently logged in as %1$s (%2$s)." : "目前登入為 %1$s（%2$s）。",
-    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。",
-    "Account connected" : "已連結帳號",
-    "Your client should now be connected!" : "客戶端現在應該已連線！",
-    "You can close this window." : "您可以關閉此視窗。",
     "Previous" : "上一個",
-    "This share is password-protected" : "此分享受密碼保護",
-    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。請重試，或重新申請。",
-    "Please type in your email address to request a temporary password" : "請輸入您的電子郵件地址以申請臨時密碼",
-    "Email address" : "電子郵件地址",
-    "Password sent!" : "密碼已傳送！",
-    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
     "Two-factor authentication" : "雙因子認證",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的帳號已啟用進階安全機制，請選擇一個雙因子認證方法：",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何一個雙因子認證方法。請聯絡管理員。",
@@ -501,6 +522,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
     "Searching …" : "正在搜尋…",
     "Logging in …" : "正在登入…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時 30 秒。",
     "Loading apps …" : "正在載入應用程式…",
     "Installing apps …" : "正在安裝應用程式…",
     "Loading your contacts …" : "正在載入聯絡人…",
@@ -518,7 +540,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
-    "Invisible" : "隱藏",
     "Delete" : "刪除",
     "Rename" : "重新命名",
     "Collaborative tags" : "協作標籤",
@@ -533,6 +554,9 @@ OC.L10N.register(
     "Configure the database" : "設定資料庫組態",
     "Only %s is available." : "剩下 %s 可使用。",
     "Database account" : "資料庫帳號",
-    "Installing …" : "正在安裝…"
+    "Installing …" : "正在安裝…",
+    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號。",
+    "Currently logged in as %1$s (%2$s)." : "目前登入為 %1$s（%2$s）。",
+    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。"
 },
 "nplurals=1; plural=0;");
