@@ -12,7 +12,7 @@ OC.L10N.register(
     "%s email verification" : "%s E-Mail-Überprüfung",
     "Email verification" : "E-Mail-Überprüfung",
     "Click the following button to confirm your email." : "Klicken Sie auf die folgende Schaltfläche, um Ihre E-Mail zu bestätigen.",
-    "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken um Ihre E-Mail-Adresse zu bestätigen",
+    "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken, um Ihre E-Mail-Adresse zu bestätigen",
     "Confirm your email" : "Ihre E-Mail-Adresse bestätigen",
     "Other activities" : "Andere Aktivitäten",
     "%1$s and %2$s" : "%1$s und %2$s",
@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Ziel existiert nicht",
     "Destination is not creatable" : "Ziel kann nicht erstellt werden",
     "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
+    "%1$s (renamed)" : "%1$s (umbenannt)",
+    "renamed file" : "Umbenannte Datei",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" ist ein verbotener Datei- oder Ordnername.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" ist ein verbotenes Präfix für Datei- oder Ordnernamen.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ist in einem Datei- oder Ordnernamen unzulässig.",
@@ -101,7 +103,7 @@ OC.L10N.register(
     "Invalid parent path" : "Ungültiger übergeordneter Pfad",
     "File already exists" : "Datei bereits vorhanden",
     "Invalid path" : "Ungültiger Pfad",
-    "Failed to create file from template" : "Fehler beim Erstellen der Datei aus Vorlage",
+    "Failed to create file from template" : "Datei konnte nicht aus Vorlage erstellt werden",
     "Templates" : "Vorlagen",
     "Storage %s cannot be moved" : "Speicherplatz %s kann nicht verschoben werden",
     "Moving a share (%s) into a shared folder is not allowed" : "Verschieben einer Freigabe (%s) in einen freigegebenen Ordner ist unzulässig",
@@ -127,13 +129,15 @@ OC.L10N.register(
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Accounts" : "Konten",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "%s auf Bluesky anzeigen",
     "Email" : "E-Mail",
     "Mail %s" : "E-Mail %s",
     "Fediverse" : "Fediverse",
     "View %s on the fediverse" : "Zeige %s auf dem Fediverse",
     "Phone" : "Telefon",
     "Call %s" : "%s anrufen",
-    "Twitter" : "Twitter",
+    "Twitter" : "X",
     "View %s on Twitter" : "%s auf Twitter anzeigen",
     "Website" : "Webseite",
     "Visit %s" : "%s besuchen",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "Über",
     "Display name" : "Anzeigename",
     "Headline" : "Überschrift",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisation",
     "Role" : "Funktion",
     "Pronouns" : "Pronomen",
     "Unknown account" : "Unbekanntes Konto",
@@ -156,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
     "Oracle Login and/or password not valid" : "Oracle-Anmeldename und/oder -Passwort ungültig",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-Anmeldename und/oder Passwort ungültig",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "macOS is not supported and %s will not work properly on this platform." : "MacOS wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren.",
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entfernen Sie die open_basedir-Einstellung in Ihrer php.ini oder wechseln Sie zu 64-Bit-PHP.",
@@ -201,6 +205,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Der Pfad ist bereits mit dieser Gruppe geteilt",
     "Link sharing is not allowed" : "Freigabe via Link ist nicht erlaubt",
     "Public upload is not allowed" : "Öffentliches Hochladen ist nicht erlaubt",
+    "You cannot share a folder that contains other shares" : "Ein Ordner, der andere Freigaben enthält, kann nicht geteilt werden",
     "Sharing is disabled" : "Teilen ist deaktiviert",
     "Sharing is disabled for you" : "Teilen ist für Sie deaktiviert",
     "Cannot share with the share owner" : "Teilen mit dem Freigabeeigentümer nicht möglich",
@@ -272,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ein gültiger Anmeldename muss angegeben werden.",
     "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
     "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
+    "Username is too long" : "Benutzername ist zu lang",
     "Login is invalid because files already exist for this user" : "Der Anmeldename ist ungültig, da bereits Dateien von diesem Benutzer existieren",
     "Account disabled" : "Konto deaktiviert",
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
@@ -284,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Es kann nicht in das Verzeichnis \"config\" geschrieben werden.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Oder wenn Sie möchten, dass die Datei config.php schreibgeschützt bleiben soll, dann setzen Sie die Option \"config_is_read_only\" in der Datei auf True. Siehe %s",
-    "Cannot write into \"apps\" directory." : "Es kann nicht in das Verzeichnis \"apps\" geschrieben werden.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
     "Cannot create \"data\" directory." : "Kann das \"Daten\"-Verzeichnis nicht erstellen.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können normalerweise korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
@@ -296,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Bitte kontaktieren Sie Ihre Serveradministration und bitten Sie um die Installation des Moduls.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung \"%s\" ist nicht auf \"%s\" gesetzt.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann Ihre Nextcloud wieder lauffähig machen.",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
@@ -311,7 +313,7 @@ OC.L10N.register(
     "Your data directory is invalid." : "Ihr Datenverzeichnis ist ungültig.",
     "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Stellen Sie sicher, dass eine Datei \"%1$s\" im Wurzelverzeichnis des Datenverzeichnisses existiert. Sie sollte folgenden Inhalt haben: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Aktion \"%s\" wird nicht unterstützt oder ist nicht implementiert.",
-    "Authentication failed, wrong token or provider ID given" : "Authentifizierung ist fehlgeschlagen. Falsches Token oder Provider-ID wurde übertragen.",
+    "Authentication failed, wrong token or provider ID given" : "Authentifizierung fehlgeschlagen, falsches Token oder falsche Provider-ID angegeben",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Es fehlen Parameter um die Anfrage zu bearbeiten. Fehlende Parameter: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" wird bereits von Cloud-Federation-Provider \"%2$s\" verwendet.",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud-Federation-Provider mit ID: \"%s\" ist nicht vorhanden.",
@@ -322,26 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Damit diese Prüfung ausgeführt werden kann, müssen Sie sicherstellen, dass Ihr Webserver eine Verbindung zu sich selbst herstellen kann. Daher muss er in der Lage sein, mindestens eine seiner `trusted_domains` oder `overwrite.cli.url` aufzulösen und eine Verbindung zu ihnen herzustellen. Dieser Fehler kann das Ergebnis einer serverseitigen DNS-Nichtübereinstimmung oder einer ausgehenden Firewall-Regel sein.",
+    "Analyze images" : "Bilder analysieren",
+    "Ask a question about the given images." : "Eine Frage zu den angegebenen Bildern stellen.",
+    "Images" : "Bilder",
+    "Images to ask a question about" : "Bilder, zu denen eine Frage gestellt werden soll",
+    "Question" : "Frage",
+    "What to ask about the images." : "Was alles zu den Bildern gefragt werden kann.",
+    "Generated response" : "Erzeugte Antwort",
+    "The answer to the question" : "Die Antwort auf die Frage",
+    "Audio chat" : "Audio-Chat",
+    "Voice chat with the assistant" : "Sprachchat mit dem Assistenten",
+    "System prompt" : "Systemaufforderung",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
+    "Chat voice message" : "Chat-Sprachnachricht",
+    "Describe a task that you want the assistant to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
+    "Chat history" : "Chatverlauf",
+    "The history of chat messages before the current message, starting with a message by the user." : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers.",
+    "Input transcript" : "Eingabetranskript",
+    "Transcription of the audio input" : "Transkription der Audio-Eingabe",
+    "Response voice message" : "Antwort-Sprachnachricht",
+    "The generated voice response as part of the conversation" : "Die erstellte Sprachantwort als Teil des Gesprächs",
+    "Output transcript" : "Ausgabetranskript",
+    "Transcription of the audio output" : "Transkription der Audio-Ausgabe",
     "Transcribe audio" : "Audio transkribieren",
     "Transcribe the things said in an audio" : "Inhalt der Audiodatei transkribieren",
     "Audio input" : "Audioeingang",
     "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
     "Transcription" : "Transkription",
     "The transcribed text" : "Der transkribierte Text",
-    "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "Chatten Sie mit einem Agenten",
-    "Chat message" : "Chatnachricht",
-    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "Chat by voice with an agent" : "Per Stimme mit einem Agenten chatten",
+    "Describe a task that you want the agent to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
     "Confirmation" : "Bestätigung",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Ob zuvor angeforderte Aktionen bestätigt werden sollen: 0 für Verweigerung und 1 für Bestätigung.",
     "Conversation token" : "Unterhaltungstoken",
     "A token representing the conversation." : "Ein Token, das die Unterhaltung repräsentiert.",
-    "Generated response" : "Erzeugte Antwort",
-    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "The new conversation token" : "Das neue Unterhaltungstoken",
     "Send this along with the next interaction." : "Dies zusammen mit der nächsten Interaktion senden.",
     "Requested actions by the agent" : "Vom Agenten angeforderte Aktionen",
     "Actions that the agent would like to carry out in JSON format." : "Aktionen, die der Agent durchführen möchte, im JSON-Format.",
+    "Chat with an agent" : "Chatten Sie mit einem Agenten",
+    "Chat message" : "Chatnachricht",
+    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "Context write" : "Im Kontext schreiben",
     "Writes text in a given style based on the provided source material." : "Schreibt Text in einem vorgegebenen Stil auf Basis des bereitgestellten Quellmaterials.",
     "Writing style" : "Schreibstil",
@@ -355,6 +379,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Der Text aus dem ein Emoji erstellt werden soll",
     "Generated emoji" : "Erstelltes Emoji",
     "The generated emoji based on the input text" : "Das aus dem eingegebenen Text erstelltes Emoji",
+    "Optical character recognition" : "Texterkennung",
+    "Extract text from files like images or PDFs" : "Text aus Dateien wie Bildern oder PDFs extrahieren",
+    "Input files" : "Eingabedateien",
+    "The files to extract text from" : "Die Dateien, aus denen Text extrahiert werden soll",
+    "Output texts" : "Ausgabetexte",
+    "The texts that were extracted from the files" : "Die Texte, die aus den Dateien extrahiert wurden",
     "Generate image" : "Bild erstellen",
     "Generate an image from a text prompt" : "Bild aus einer Texteingabe erstellen",
     "Prompt" : "Prompt",
@@ -363,6 +393,11 @@ OC.L10N.register(
     "How many images to generate" : "Wie viele Bilder erstellt werden sollen",
     "Output images" : "Ausgegebene Bilder",
     "The generated images" : "Die erstellten Bilder",
+    "Generate speech" : "Sprache erstellen",
+    "Generate speech from a transcript" : "Sprache aus einem Transkript erstellen",
+    "Write transcript that you want the assistant to generate speech from" : "Schreiben Sie ein Transkript, aus dem der Assistent Sprache erstellen soll",
+    "Output speech" : "Sprachausgabe",
+    "The generated speech" : "Die erstellte Sprache",
     "Free text to text prompt" : "Freie Text-zu-Text-Eingabeaufforderung",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Führt eine beliebige Eingabeaufforderung mit einem Sprachmodell aus, das eine Antwort zurückgibt",
     "Describe a task that you want the assistant to do or ask a question" : "Beschreiben Sie eine Aufgabe, die der Assistent erledigen soll, oder stellen Sie eine Frage",
@@ -376,9 +411,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Der umgeschriebene Text im gewünschten Ton, geschrieben von Assistant:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Mit dem Assistenten chatten",
-    "System prompt" : "Systemaufforderung",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
-    "Chat history" : "Chatverlauf",
     "The history of chat messages before the current message, starting with a message by the user" : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers",
     "Response message" : "Antwortnachricht",
     "The generated response as part of the conversation" : "Die erstellte Antwort als Teil der Unterhaltung",
@@ -442,21 +474,12 @@ OC.L10N.register(
     "Generate headline" : "Kopfzeile erzeugen",
     "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
-    "Education Edition" : "Bildungsausgabe",
-    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
-    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
-    "File name is too long" : "Dateiname ist zu lang",
-    "Users" : "Benutzer",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s hat »%2$s« mit Ihnen geteilt und möchte folgendes hinzufügen:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s hat »%2$s« mit Ihnen geteilt und möchte folgendes hinzufügen",
-    "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit Ihnen geteilten Datei hinzugefügt",
-    "Open »%s«" : "»%s« öffnen",
-    "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit Ihnen geteilt",
-    "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit Ihnen geteilt.",
-    "Click the button below to open it." : "Klicken Sie zum Öffnen auf die untere Schaltfläche.",
-    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte später erneut versuchen.",
-    "Cannot download file" : "Datei kann nicht heruntergeladen werden",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stellen Sie sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des Datenverzeichnisses existiert.",
-    "Path contains files shared with you" : "Der Pfad enthält für Sie freigegebene Dateien"
+    "Organisation" : "Organisation",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "Login is too long" : "Der Kontenname ist zu lang",
+    "Cannot write into \"apps\" directory." : "Es kann nicht in das Verzeichnis \"apps\" geschrieben werden.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>."
 },
 "nplurals=2; plural=(n != 1);");
