@@ -4,7 +4,7 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
     "This can usually be fixed by giving the web server write access to the config directory." : "Isto normalmente pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mais, se prefire manter o ficheiro config.php como de só lectura, estabeleza a opción «config_is_read_only» como verdadeira nel.",
-    "See %s" : "Vexa %s",
+    "See %s" : "Consulte %s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "A aplicación %1$s non está presente ou ten unha versión non compatíbel con este servidor. Comprobe o directorio de aplicacións.",
     "Sample configuration detected" : "Detectouse a configuración de exemplo",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
     "Oracle Login and/or password not valid" : "O acceso de Oracle e/ou o contrasinal non son válidos",
     "PostgreSQL Login and/or password not valid" : "O acceso de PostgreSQL e/ou o contrasinal non son válidos",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS non é compatíbel e %s non funcionará correctamente nesta plataforma.",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux en troques.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
