@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
     "Oracle Login and/or password not valid" : "Nome utente e/o password Oracle non validi",
     "PostgreSQL Login and/or password not valid" : "Nome utente e/o password non corretta per PostgreSQL",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS non è supportato e %s non funzionerà correttamente su questa piattaforma.",
     "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
@@ -379,6 +380,11 @@ OC.L10N.register(
     "Generated emoji" : "Emoji generata",
     "The generated emoji based on the input text" : "L'emoji generata in base al testo inserito",
     "Optical character recognition" : "Riconoscimento ottico dei caratteri",
+    "Extract text from files like images or PDFs" : "Estrai testo da file come immagini o PDF",
+    "Input files" : "File in ingresso",
+    "The files to extract text from" : "Scegli in file da cui estrarre il testo",
+    "Output texts" : "Testo in uscita",
+    "The texts that were extracted from the files" : "Il testo che è stato estratto dai file",
     "Generate image" : "Genera immagine",
     "Generate an image from a text prompt" : "Genera un'immagine da un prompt di testo",
     "Prompt" : "Prompt",
