@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "宛先が存在しません",
     "Destination is not creatable" : "宛先は作成できません",
     "Dot files are not allowed" : "隠しファイルは許可されていません",
+    "%1$s (renamed)" : "%1$s (リネーム済み)",
+    "renamed file" : "リネーム済みファイル",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\"は禁止されているファイル名またはフォルダー名です。",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\"は、ファイル名やフォルダー名には使用できない接頭辞です。",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\"はファイル名やフォルダー名の中に入れることはできません。",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "設定",
     "Log out" : "ログアウト",
     "Accounts" : "アカウント",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Blueskyで%sを表示",
     "Email" : "メール",
     "Mail %s" : "メール %s",
     "Fediverse" : "フェディバース",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "詳細",
     "Display name" : "表示名",
     "Headline" : "見出し",
-    "Organisation" : "組織",
+    "Organization" : "共同作業",
     "Role" : "ロール",
     "Pronouns" : "代名詞",
     "Unknown account" : "不明なアカウント",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
     "Oracle Login and/or password not valid" : "Oracleのログイン名またはパスワードが有効ではありません",
     "PostgreSQL Login and/or password not valid" : "PostgreSQLのログイン名またはパスワードが有効ではありません",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "ログイン名を提供する必要があります",
     "Login contains whitespace at the beginning or at the end" : "ログイン名の最初か最後に空白が含まれています",
     "Login must not consist of dots only" : "ログイン名はドットのみで構成されてはいけません",
+    "Username is too long" : "ユーザー名が長すぎます",
     "Login is invalid because files already exist for this user" : "このユーザのファイルが既に存在するため、このログイン名は使用できません",
     "Account disabled" : "アカウントは無効",
     "Login canceled by app" : "アプリによりログインが中止されました",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "\"config\" ディレクトリに書き込みできません",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "これは通常、Webサーバーの configディレクトリ に書き込み権限を与えることで解決できます。%s を見てください",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "またはconfig.phpファイルを読み取り専用にしたい場合は、オプション \"config_is_read_only\"をtrueに設定してください。 詳しくは%sを確認してください。",
-    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
     "Cannot create \"data\" directory." : "dataディレクトリを作成できません。",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "これは通常、ウェブサーバーにルートディレクトリへの書き込み権限を与えることで解決できます。詳しくは%sを確認してください。",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。詳しくは%sを確認してください。",
@@ -297,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "サーバー管理者にモジュールのインストールを依頼してください。",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP設定の\"%s\"が \"%s\"に設定されていません",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini のこの設定を調整して、再度 Nextcloudを起動してください。",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>の値は <code>0</code>であるべきですが、<code>%s</code> に設定されています。",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
@@ -323,25 +323,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "このチェックを実行させるには、Webサーバーが自分自身に接続できることを確認しなければならない。そのため、少なくとも一つの `trusted_domains` または `overwrite.cli.url` を解決して接続できなければなりません。この失敗は、サーバ側のDNSの不一致やアウトバウンドファイアウォールルールの結果かもしれません。",
+    "Analyze images" : "画像を分析する",
+    "Ask a question about the given images." : "与えられた画像について質問してください。",
+    "Images" : "画像",
+    "Images to ask a question about" : "質問したい画像",
+    "Question" : "質問",
+    "What to ask about the images." : "画像について質問する。",
+    "Generated response" : "生成された応答",
+    "The answer to the question" : "質問への回答",
+    "Audio chat" : "音声チャット",
+    "Voice chat with the assistant" : "アシスタントとの音声チャット",
+    "System prompt" : "システムプロンプト",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
+    "Chat voice message" : "チャット音声メッセージ",
+    "Describe a task that you want the assistant to do or ask a question." : "アシスタントに実行してほしいタスクを説明するか質問を投げかけてください。",
+    "Chat history" : "チャット履歴",
+    "The history of chat messages before the current message, starting with a message by the user." : "現在のメッセージ以前に送信されたチャットメッセージの履歴で、ユーザーが送信したメッセージから始まるもの。",
+    "Input transcript" : "文字起こしを入力",
+    "Transcription of the audio input" : "音声入力の文字起こし",
+    "Response voice message" : "応答音声メッセージ",
+    "The generated voice response as part of the conversation" : "会話の一部として生成された音声応答",
+    "Output transcript" : "文字起こしを出力",
+    "Transcription of the audio output" : "音声出力の文字起こし",
     "Transcribe audio" : "音声の書き起こし",
     "Transcribe the things said in an audio" : "音声で言ったことを書き起こす",
     "Audio input" : "音声入力",
     "The audio to transcribe" : "文字起こしする音声",
     "Transcription" : "書き起こし",
     "The transcribed text" : "書き起こされたテキスト",
-    "Chat with an agent" : "エージェントとチャット",
-    "Chat message" : "チャットメッセージ",
-    "A chat message to send to the agent." : "エージェントに送信するチャットメッセージ。",
+    "Chat by voice with an agent" : "エージェントと音声でチャットする",
+    "Describe a task that you want the agent to do or ask a question." : "エージェントに実行してほしいタスクを説明するか質問を投げかけてください。エージェントと音声でチャットできます。",
     "Confirmation" : "確認",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "以前に要求されたアクションを承認するかどうか： 0なら拒否、1なら承認。",
     "Conversation token" : "会話トークン",
     "A token representing the conversation." : "会話を表すトークン。",
-    "Generated response" : "生成された応答",
-    "The response from the chat model." : "チャットモデルからの応答。",
     "The new conversation token" : "新しい会話トークン",
     "Send this along with the next interaction." : "次の交流と一緒にこれを送る。",
     "Requested actions by the agent" : "エージェントが要求するアクション",
     "Actions that the agent would like to carry out in JSON format." : "エージェントが JSON 形式で実行したいアクション。",
+    "Chat with an agent" : "エージェントとチャット",
+    "Chat message" : "チャットメッセージ",
+    "A chat message to send to the agent." : "エージェントに送信するチャットメッセージ。",
+    "The response from the chat model." : "チャットモデルからの応答。",
     "Context write" : "コンテキストを書く",
     "Writes text in a given style based on the provided source material." : "提供されたソース資料に基づいて、指定されたスタイルでテキストを作成します。",
     "Writing style" : "文体",
@@ -355,6 +378,7 @@ OC.L10N.register(
     "The text to generate an emoji for" : "絵文字を生成するテキスト",
     "Generated emoji" : "生成された絵文字",
     "The generated emoji based on the input text" : "入力テキストに基づいて生成された絵文字",
+    "Optical character recognition" : "OCR",
     "Generate image" : "画像生成",
     "Generate an image from a text prompt" : "テキストプロンプトから画像を生成する",
     "Prompt" : "プロンプト",
@@ -363,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "生成する画像の数",
     "Output images" : "出力画像",
     "The generated images" : "生成された画像",
+    "Generate speech" : "スピーチの生成",
+    "Generate speech from a transcript" : "原稿からスピーチを生成する",
+    "Write transcript that you want the assistant to generate speech from" : "アシスタントに音声を生成させたい原稿を書きます",
+    "Output speech" : "スピーチの出力",
+    "The generated speech" : "生成されたスピーチ",
     "Free text to text prompt" : "フリーテキストからテキストへのプロンプト",
     "Runs an arbitrary prompt through a language model that returns a reply" : "応答を返す言語モデルを通じて任意のプロンプトを実行します",
     "Describe a task that you want the assistant to do or ask a question" : "アシスタントに実行してほしいタスクまたは質問を記述します",
@@ -376,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "アシスタントが書き直した、希望するトーンの文章：",
     "Chat" : "チャット",
     "Chat with the assistant" : "アシスタントとチャット",
-    "System prompt" : "システムプロンプト",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
-    "Chat history" : "チャット履歴",
     "The history of chat messages before the current message, starting with a message by the user" : "ユーザーのメッセージから始まる、現在のメッセージより前のチャットメッセージの履歴",
     "Response message" : "応答メッセージ",
     "The generated response as part of the conversation" : "会話の一部として生成された応答",
@@ -442,20 +468,12 @@ OC.L10N.register(
     "Generate headline" : "見出しの生成",
     "Summarizes text by reducing its length without losing key information." : "重要な情報を失わずにテキストの長さを要約して短縮する。",
     "Extracts topics from a text and outputs them separated by commas." : "テキストからトピックを抽出し、カンマ区切りで出力します。",
-    "Education Edition" : "教育向けエディション",
-    "File name is a reserved word" : "ファイル名が予約された単語です",
-    "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
-    "File name is too long" : "ファイル名が長すぎます",
-    "Users" : "ユーザー",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
-    "Open »%s«" : "»%s«を開く",
-    "%1$s shared »%2$s« with you" : "%1$s は »%2$s« をあなたと共有しました",
-    "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
-    "Click the button below to open it." : "開くには下のボタンをクリック",
-    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
-    "Cannot download file" : "ファイルをダウンロードできません",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。"
+    "Organisation" : "組織",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
+    "Login is too long" : "ログインが長すぎます",
+    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>の値は <code>0</code>であるべきですが、<code>%s</code> に設定されています。",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。"
 },
 "nplurals=1; plural=0;");
