@@ -18,6 +18,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
+    "Education bundle" : "Едукативно издание",
     "Enterprise bundle" : "Професионален пакет",
     "Groupware bundle" : "Пакет со групни производи",
     "Hub bundle" : "Централизиран пакет",
@@ -52,34 +53,40 @@ OC.L10N.register(
     "Avatar image is not square" : "Сликата за Аватар не е квадратна",
     "Files" : "Датотеки",
     "View profile" : "Прегледај профил",
+    "_%nh_::_%nh_" : ["%nч","%nч"],
+    "_%nm_::_%nm_" : ["%nм","%nм"],
     "Local time: %s" : "Локално време: %s",
     "today" : "денес",
     "tomorrow" : "утре",
     "yesterday" : "вчера",
-    "_in %n day_::_in %n days_" : ["за 1 ден","за %n дена"],
-    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
+    "_in %n day_::_in %n days_" : ["за %n ден","за %n дена"],
+    "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
     "next month" : "следниот месец",
     "last month" : "предходниот месец",
     "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца"],
     "_%n month ago_::_%n months ago_" : ["пред %n месец","пред %n месеци"],
     "next year" : "следниот месец",
     "last year" : "предходната година",
-    "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
-    "_%n year ago_::_%n years ago_" : ["пред 1 година","пред %n години"],
-    "_in %n hour_::_in %n hours_" : ["за 1 час","за %n часа"],
-    "_%n hour ago_::_%n hours ago_" : ["пред 1 час","пред %n часа"],
-    "_in %n minute_::_in %n minutes_" : ["за 1 минута","за %n минути"],
-    "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
+    "_in %n year_::_in %n years_" : ["за %n година","за %n години"],
+    "_%n year ago_::_%n years ago_" : ["пред %n година","пред %n години"],
+    "_in %n hour_::_in %n hours_" : ["за %n час","за %n часа"],
+    "_%n hour ago_::_%n hours ago_" : ["пред %n час","пред %n часа"],
+    "_in %n minute_::_in %n minutes_" : ["за %n минута","за %n минути"],
+    "_%n minute ago_::_%n minutes ago_" : ["пред %n минута","пред %n минути"],
     "in a few seconds" : "за неколку секунди",
     "seconds ago" : "пред неколку секунди",
     "Empty file" : "Празна датотека",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул со ИД: %s не постои. Овозможете го во параметрите на апликациите или контактирајте администратор.",
     "Dot files are not allowed" : "Датотеки само со точки не се дозволени",
+    "%1$s (renamed)" : "%1$s (преименувано)",
+    "renamed file" : "преименувана датотека",
+    "Filenames must not end with \"%1$s\"." : "Името неможе да завршува со \"%1$s\".",
     "File already exists" : "Датотека веќе постои",
     "Invalid path" : "Невалидна патека",
     "Failed to create file from template" : "Неуспешно креирање на датотека од шаблон",
     "Templates" : "Шаблони",
     "Filename contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
+    "Filename is too long" : "Името на датотеката е премногу долго",
     "Empty filename is not allowed" : "Датотеки без име не се дозволени",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Апликацијата \"%s\" неможе да се инсталира бидејќи датотеката appinfo неможе да се прочита.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликацијата \"%s\" неможе да се инсталира бидејќи не е компатибилна со верзијата на серверот.",
@@ -107,30 +114,46 @@ OC.L10N.register(
     "About" : "За",
     "Display name" : "Име и презиме",
     "Headline" : "Наслов",
-    "Organisation" : "Организација",
+    "Organization" : "Организација",
     "Role" : "Улога",
+    "Unknown account" : "Непознат корисник",
     "Additional settings" : "Дополнителни параметри",
+    "Enter the database Login and name for %s" : "Внесете го корисничкото име и името на базата за %s",
+    "Enter the database Login for %s" : "Внесете го името на базата за %s",
     "Enter the database name for %s" : "Внесете го името на базата за %s",
     "You cannot use dots in the database name %s" : "Не можеш да користиш точки во името на базата %s",
+    "MySQL Login and/or password not valid" : "Погрешно MySQL корисничко име и/или лозинка",
     "You need to enter details of an existing account." : "Потребно е да внесете детали од постоечката сметка.",
     "Oracle connection could not be established" : "Oracle врската неможе да се воспостави",
+    "Oracle Login and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
     "For the best results, please consider using a GNU/Linux server instead." : "За најдобри резултати, размислете за користење на сервер со GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Највероватно оваа истанца %s е стартувана на 32-битна PHP средина и open_basedir е конфигурано во php.ini. Ова ќе прави проблеми со датотеки поголеми од 4 GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Отстранете го параметарот open_basedir од php.ini или преминете на 64-битна PHP средина.",
+    "Set an admin Login." : "Постави администраторско корисничко име",
     "Set an admin password." : "Постави администраторска лозинка.",
     "Cannot create or write into the data directory %s" : "Неможете да креирате или да запишувате во папката за податоци %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "За позадинското споделување %s мора се имплементира интерфејсот OCP\\Share_Backend",
     "Sharing backend %s not found" : "Не е пронајдено позадинско споделување %s",
     "Sharing backend for %s not found" : "Не е пронајдено позадинско споделување за %s.",
+    "%1$s shared %2$s with you" : "%1$s сподели %2$s со вас",
+    "Open %s" : "Отвори %s",
     "%1$s via %2$s" : "%1$s преку %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s сподели %2$s со вас и сака да додаде:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s сподели %2$s со вас и сака да додаде",
+    "%s added a note to a file shared with you" : "%s додаде белешка до датотеката што ја сподели со вас",
     "Unknown share type" : "Непознат вид на споделување",
+    "You cannot share your root folder" : "Не можете да ја споделите коренската папка",
     "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
     "Cannot increase permissions of %s" : "Неможат да се зголемат дозволите на %s",
     "Files cannot be shared with delete permissions" : "Датотеки неможат да бидат споделени со дозвола за бришење",
     "Files cannot be shared with create permissions" : "Датотеки неможат да бидат споделени со дозвола за создавање",
     "Expiration date is in the past" : "Рокот на траење е во минато време",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од 1 ден","Неможе да се постави рок на траење повеќе од %s дена"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од %n ден","Неможе да се постави рок на траење повеќе од %n дена"],
     "Sharing is only allowed with group members" : "Споделувањето е овозможено само со членови на групата",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Споделувањето %s е неуспешно, бидејќи ова е веќе споделено со сметката  на %s",
+    "Path is already shared with this group" : "Патеката веќе е споделена со оваа група",
+    "Sharing is disabled" : "Споделувањето не е дозволено",
     "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисникот не е креиран затоа што максималниот број на корисници е достигнат. Проверете ги вашите известувања за да дознаете повеќе.",
     "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
@@ -179,7 +202,16 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Ное.",
     "Dec." : "Дек.",
-    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
+    "A valid password must be provided" : "Мора да се внесе валидна лозинка",
+    "The Login is already being used" : "Корисничкото име е веќе во употреба",
+    "Could not create account" : "Неможе да се креира сметка",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име: \"a-z\", \"A-Z\", \"0-9\", празно место и \"_.@-'\"",
+    "A valid Login must be provided" : "Мора да се внесе валидно корисничко име ",
+    "Login contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
+    "Login must not consist of dots only" : "Корисничкото име не смее да се состои само од точки",
+    "Username is too long" : "Корисничкото име е премногу долго",
+    "Login is invalid because files already exist for this user" : "Невалидно корисничкото име бидејќи веќе постојат датотеки за овој корисник",
+    "Account disabled" : "Сметката е оневозможена",
     "Login canceled by app" : "Најавата е одкажана од апликација",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликацијата \"%1$s\" не може да се инсталира затоа што следниве зависности не се исполнети: %2$s",
     "a safe home for all your data" : "безбеден дом за сите ваши податоци",
@@ -190,8 +222,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не може да зе запишува во \"config\" директориумот",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во config папката. Видете %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него. Видете %s",
-    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
     "Cannot create \"data\" directory." : "Неможе да се креира директориум \"data\"",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволите најчесто се поправаат со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
@@ -202,17 +232,18 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Замолете го сервер администраторот да го инсталира додатокот.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Прилагодувањето на оваа поставка во php.ini ќе направи повторно да работи ",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP поставено да ги поставува во линија внатрешните блокови на документите. Ова ќе ги направи неколку основни апликации недостапни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ова е веројатно предизвикано од кеш-меморија/забрзување како што се Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулот е инсталиран, но сеуште се прикажува како да недостасува?",
     "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
     "The required %s config variable is not configured in the config.php file." : "Потребната променлива %s не е конфигурирана config.php датотеката.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Замолете го сервер администраторот да ја провери конфигурацијата.",
+    "Your data directory is readable by other people." : "Вашата папка со податоци може да се чита и од други корисници.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Поставете дозвола на папката 0770, за да неможе да се чита од други корисници.",
     "Your data directory must be an absolute path." : "Вашата папка со податоци мора да биде апсолутна патека.",
     "Check the value of \"datadirectory\" in your configuration." : "Проверете ја вредноста на \"datadirectory\" во вашата конфигурација.",
     "Your data directory is invalid." : "Вашата папка со податоци не е валидна.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Осигурете се дека има датотека наречена \"%1$s\" во главната папка со податоци. Треба да содржи: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Акцијата \"%s\" не е поддржана или не е имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспешна автентификација, погрешен токен или зададен погрешен ИД",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Некој параметри недостасуваат за да се комплетира барањето.Параметри шо недостасуваат: \"%s\"",
@@ -224,24 +255,21 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Storage connection timeout. %s" : "Поврзувањето со складиштето не успеа. %s",
+    "Images" : "Слики",
+    "Question" : "Прашање",
+    "Confirmation" : "Потврда",
+    "Optical character recognition" : "Оптичко препознавање на карактери",
     "Text" : "Текст",
     "Summary" : "Резиме",
     "Translate" : "Преведи",
+    "Result" : "Резултат",
     "Generate headline" : "Генерирај заглавие",
-    "Education Edition" : "Едукативно издание",
-    "File name is a reserved word" : "Името на датотеката е резервиран збор",
-    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
-    "File name is too long" : "Името на датотеката е премногу долго",
-    "Users" : "Корисници",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ја сподели папката »%2$s« и додаде:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ја сподели папката »%2$s« и додаде",
-    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
-    "Open »%s«" : "Отвори »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
-    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
-    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
-    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
-    "Cannot download file" : "Не може да се преземе датотеката",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Осигурете се дека има датотека наречена \".ocdata\" во главната папка со податоци."
+    "Organisation" : "Организација",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не е поддржана и %s нема да работи соодветно на оваа платформа. Користењето е на ваш ризик! ",
+    "Login is too long" : "Корисничкото име е премногу долго",
+    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
