@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Cieľ neexistuje",
     "Destination is not creatable" : "Cieľ nie je možné vytvoriť",
     "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
+    "%1$s (renamed)" : "%1$s (premenovaný)",
+    "renamed file" : "premenovaný súbor",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" je zakázané pre súbor alebo adresár",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" je zakázaná predpona pre názov súboru alebo adresára.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" nie je povolené v názve súboru alebo adresára",
