@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
     "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS stöds inte och %s kommer inte att fungera korrekt på denna plattform.",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
@@ -379,6 +380,11 @@ OC.L10N.register(
     "Generated emoji" : "Genererad emoji",
     "The generated emoji based on the input text" : "Den genererade emojin baserad på inmatningstexten",
     "Optical character recognition" : "Optisk teckenigenkänning",
+    "Extract text from files like images or PDFs" : "Extrahera text från filer som bilder eller PDF:er",
+    "Input files" : "Indatafiler",
+    "The files to extract text from" : "Filer att extrahera text från",
+    "Output texts" : "Utdata-texter",
+    "The texts that were extracted from the files" : "Texterna som extraherades från filerna",
     "Generate image" : "Skapa bild",
     "Generate an image from a text prompt" : "Skapa en bild från en textuppmaning",
     "Prompt" : "Uppmaning",
