@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle ئۇلىنىشى قۇرۇلمىدى",
     "Oracle Login and/or password not valid" : "Oracle كىرىش ۋە / ياكى پارول ئىناۋەتلىك ئەمەس",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL كىرىش ۋە / ياكى پارول ئىناۋەتلىك ئەمەس",
+    "macOS is not supported and %s will not work properly on this platform." : "MacOS نى قوللىمايدۇ، %s بۇ سۇپادا نورمال ئىشلىمەيدۇ.",
     "For the best results, please consider using a GNU/Linux server instead." : "ئەڭ ياخشى ئۈنۈمگە ئېرىشىش ئۈچۈن ، ئۇنىڭ ئورنىغا GNU / Linux مۇلازىمېتىرىنى ئىشلىتىشنى ئويلىشىڭ.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "قارىغاندا بۇ %s مىسالى 32 بىتلىق PHP مۇھىتىدا ئىجرا بولۇۋاتقاندەك ، open_basedir php.ini دا تەڭشەلگەن. بۇ 4 GB دىن يۇقىرى ھۆججەتلەردە مەسىلە كۆرۈلىدۇ ۋە ئۈمىدسىزلىنىدۇ.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Php.ini دىكى open_basedir تەڭشىكىنى ئېلىۋېتىڭ ياكى 64 بىتلىق PHP غا ئالماشتۇرۇڭ.",
@@ -379,6 +380,11 @@ OC.L10N.register(
     "Generated emoji" : "ھاسىل قىلىنغان emoji",
     "The generated emoji based on the input text" : "كىرگۈزۈلگەن تېكىستنى ئاساس قىلغان ھاسىل قىلىنغان emoji",
     "Optical character recognition" : "ئوپتىكىلىق خاراكتېر تونۇش",
+    "Extract text from files like images or PDFs" : "PDF ياكى سۈرەتتەك ھۆججەتلەردىن تېكىستنى چىقار",
+    "Input files" : "كىرگۈزگۈچى ھۆججەتلەر",
+    "The files to extract text from" : "تېكىست چىقىرۋالدىغان ھۆججەتلەر",
+    "Output texts" : "نەتىنجە تېكىستلەر",
+    "The texts that were extracted from the files" : "ھۆججەتلەردىن چىقىرۋېلىندىغان تېكىستلەر",
     "Generate image" : "رەسىم ھاسىل قىلىش",
     "Generate an image from a text prompt" : "تېكىست ئەسكەرتمىسىدىن رەسىم ھاسىل قىلىڭ",
     "Prompt" : "تېز",
